@@ -17,9 +17,8 @@
 
 package org.apache.poi.hpsf.examples;
 
-import java.io.FileInputStream;
+import java.io.File;
 import java.io.IOException;
-import java.util.Iterator;
 import java.util.List;
 
 import org.apache.poi.hpsf.NoPropertySetStreamException;
@@ -37,12 +36,10 @@ import org.apache.poi.util.HexDump;
  * Call it with the document's file name as command-line parameter.</p>
  *
  * <p>Explanations can be found in the HPSF HOW-TO.</p>
- *
- * @author Rainer Klute <a
- * href="mailto:klute@rainer-klute.de">&lt;klute@rainer-klute.de&gt;</a>
  */
-public class ReadCustomPropertySets
-{
+public final class ReadCustomPropertySets {
+
+    private ReadCustomPropertySets() {}
 
     /**
      * <p>Runs the example program.</p>
@@ -58,15 +55,16 @@ public class ReadCustomPropertySets
 
         /* Register a listener for *all* documents. */
         r.registerListener(new MyPOIFSReaderListener());
-        r.read(new FileInputStream(filename));
+        r.read(new File(filename));
     }
 
 
     static class MyPOIFSReaderListener implements POIFSReaderListener
     {
+        @Override
         public void processPOIFSReaderEvent(final POIFSReaderEvent event)
         {
-            PropertySet ps = null;
+            PropertySet ps;
             try
             {
                 ps = PropertySetFactory.create(event.getStream());
@@ -95,10 +93,8 @@ public class ReadCustomPropertySets
             /* Print the list of sections: */
             List<Section> sections = ps.getSections();
             int nr = 0;
-            for (Iterator<Section> i = sections.iterator(); i.hasNext();)
-            {
+            for (Section sec : sections) {
                 /* Print a single section: */
-                Section sec = i.next();
                 out("   Section " + nr++ + ":");
                 String s = hex(sec.getFormatID().getBytes());
                 s = s.substring(0, s.length() - 1);
@@ -110,26 +106,24 @@ public class ReadCustomPropertySets
 
                 /* Print the properties: */
                 Property[] properties = sec.getProperties();
-                for (int i2 = 0; i2 < properties.length; i2++)
-                {
+                for (Property p : properties) {
                     /* Print a single property: */
-                    Property p = properties[i2];
                     long id = p.getID();
                     long type = p.getType();
                     Object value = p.getValue();
                     out("      Property ID: " + id + ", type: " + type +
-                        ", value: " + value);
+                            ", value: " + value);
                 }
             }
         }
     }
 
-    static void out(final String msg)
+    private static void out(final String msg)
     {
         System.out.println(msg);
     }
 
-    static String hex(final byte[] bytes)
+    private static String hex(final byte[] bytes)
     {
         return HexDump.dump(bytes, 0L, 0);
     }
