@@ -19,7 +19,7 @@ package org.apache.poi.poifs.poibrowser;
 
 import java.awt.event.WindowAdapter;
 import java.awt.event.WindowEvent;
-import java.io.FileInputStream;
+import java.io.File;
 import java.io.IOException;
 
 import javax.swing.JFrame;
@@ -37,20 +37,11 @@ import org.apache.poi.poifs.eventfilesystem.POIFSReader;
  * JTree}. Specify their filenames on the command line!</p>
  *
  * @see POIFSReader
- *
- * @author Rainer Klute <a
- * href="mailto:klute@rainer-klute.de">&lt;klute@rainer-klute.de&gt;</a>
  */
 @SuppressWarnings("serial")
 public class POIBrowser extends JFrame
 {
 
-    /**
-     * <p>The tree's root node must be visible to all methods.</p>
-     */
-    protected MutableTreeNode rootNode;
-
-
 
     /**
      * <p>Takes a bunch of file names as command line parameters,
@@ -62,12 +53,11 @@ public class POIBrowser extends JFrame
         new POIBrowser().run(args);
     }
 
-
-
     protected void run(String[] args)
     {
         addWindowListener(new WindowAdapter()
             {
+                @Override
                 public void windowClosing(WindowEvent e)
                 {
                         System.exit(0);
@@ -76,8 +66,11 @@ public class POIBrowser extends JFrame
 
         /* Create the tree model with a root node. The latter is
          * invisible but it must be present because a tree model
-         * always needs a root. */
-        rootNode = new DefaultMutableTreeNode("POI Filesystems");
+         * always needs a root.
+         *
+         * The tree's root node must be visible to all methods.
+         */
+        MutableTreeNode rootNode = new DefaultMutableTreeNode("POI Filesystems");
         DefaultTreeModel treeModel = new DefaultTreeModel(rootNode);
 
         /* Create the tree UI element. */
@@ -86,24 +79,17 @@ public class POIBrowser extends JFrame
 
         /* Add the POI filesystems to the tree. */
         int displayedFiles = 0;
-        for (int i = 0; i < args.length; i++)
-        {
-            final String filename = args[i];
-            try
-            {
+        for (final String filename : args) {
+            try {
                 POIFSReader r = new POIFSReader();
                 r.registerListener(new TreeReaderListener(filename, rootNode));
-                r.read(new FileInputStream(filename));
+                r.read(new File(filename));
                 displayedFiles++;
-            }
-            catch (IOException ex)
-            {
+            } catch (IOException ex) {
                 System.err.println(filename + ": " + ex);
-            }
-            catch (Exception t)
-            {
+            } catch (Exception t) {
                 System.err.println("Unexpected exception while reading \"" +
-                                   filename + "\":");
+                        filename + "\":");
                 t.printStackTrace(System.err);
             }
         }
