@@ -19,14 +19,15 @@
 package org.apache.poi.ss.examples;
 
 import java.io.File;
-import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
 import java.io.IOException;
 import java.net.URL;
+import java.util.Locale;
 
-import org.apache.poi.hssf.usermodel.HSSFWorkbook;
 import org.apache.poi.hssf.usermodel.HSSFSheet;
+import org.apache.poi.hssf.usermodel.HSSFWorkbook;
 import org.apache.poi.ss.usermodel.ClientAnchor;
+import org.apache.poi.ss.usermodel.ClientAnchor.AnchorType;
 import org.apache.poi.ss.usermodel.Drawing;
 import org.apache.poi.ss.usermodel.Row;
 import org.apache.poi.ss.usermodel.Sheet;
@@ -201,13 +202,13 @@ import org.apache.poi.util.IOUtils;
 public class AddDimensionedImage {
 
     // Four constants that determine how - and indeed whether - the rows
-    // and columns an image may overlie should be expanded to accomodate that
+    // and columns an image may overlie should be expanded to accommodate that
     // image.
     // Passing EXPAND_ROW will result in the height of a row being increased
-    // to accomodate the image if it is not already larger. The image will
+    // to accommodate the image if it is not already larger. The image will
     // be layed across one or more columns.
     // Passing EXPAND_COLUMN will result in the width of the column being
-    // increased to accomodate the image if it is not already larger. The image
+    // increased to accommodate the image if it is not already larger. The image
     // will be layed across one or many rows.
     // Passing EXPAND_ROW_AND_COLUMN will result in the height of the row
     // bing increased along with the width of the column to accomdate the
@@ -268,7 +269,7 @@ public class AddDimensionedImage {
      *                                            to the resizeBehaviour
      *                                            parameter.
      */
-    public void addImageToSheet(String cellNumber, Sheet sheet, Drawing drawing,
+    public void addImageToSheet(String cellNumber, Sheet sheet, Drawing<?> drawing,
             URL imageFile, double reqImageWidthMM, double reqImageHeightMM,
             int resizeBehaviour) throws IOException, IllegalArgumentException {
         // Convert the String into column and row indices then chain the
@@ -328,14 +329,14 @@ public class AddDimensionedImage {
      *                                            it is of a type that cannot
      *                                            currently be added to the worksheet.
      */
-    public void addImageToSheet(int colNumber, int rowNumber, Sheet sheet, Drawing drawing,
+    public void addImageToSheet(int colNumber, int rowNumber, Sheet sheet, Drawing<?> drawing,
             URL imageFile, double reqImageWidthMM, double reqImageHeightMM,
             int resizeBehaviour) throws IOException,
                                                      IllegalArgumentException {
-        ClientAnchor anchor = null;
-        ClientAnchorDetail rowClientAnchorDetail = null;
-        ClientAnchorDetail colClientAnchorDetail = null;
-        int imageType = 0;
+        ClientAnchor anchor;
+        ClientAnchorDetail rowClientAnchorDetail;
+        ClientAnchorDetail colClientAnchorDetail;
+        int imageType;
 
         // Validate the resizeBehaviour parameter.
         if((resizeBehaviour != AddDimensionedImage.EXPAND_COLUMN) &&
@@ -347,7 +348,7 @@ public class AddDimensionedImage {
         }
 
         // Call methods to calculate how the image and sheet should be
-        // manipulated to accomodate the image; columns and then rows.
+        // manipulated to accommodate the image; columns and then rows.
         colClientAnchorDetail = this.fitImageToColumns(sheet, colNumber,
                 reqImageWidthMM, resizeBehaviour);
         rowClientAnchorDetail = this.fitImageToRows(sheet, rowNumber,
@@ -364,29 +365,33 @@ public class AddDimensionedImage {
 
         anchor.setDx1(0);
         anchor.setDy1(0);
-        anchor.setDx2(colClientAnchorDetail.getInset());
-        anchor.setDy2(rowClientAnchorDetail.getInset());
-        anchor.setCol1(colClientAnchorDetail.getFromIndex());
-        anchor.setRow1(rowClientAnchorDetail.getFromIndex());
-        anchor.setCol2(colClientAnchorDetail.getToIndex());
-        anchor.setRow2(rowClientAnchorDetail.getToIndex());
+        if (colClientAnchorDetail != null) {
+            anchor.setDx2(colClientAnchorDetail.getInset());
+            anchor.setCol1(colClientAnchorDetail.getFromIndex());
+            anchor.setCol2(colClientAnchorDetail.getToIndex());
+        }
+        if (rowClientAnchorDetail != null) {
+            anchor.setDy2(rowClientAnchorDetail.getInset());
+            anchor.setRow1(rowClientAnchorDetail.getFromIndex());
+            anchor.setRow2(rowClientAnchorDetail.getToIndex());
+        }
 
         // For now, set the anchor type to do not move or resize the
-        // image as the size of the row/column is adjusted. This could easilly
+        // image as the size of the row/column is adjusted. This could easily
         // become another parameter passed to the method. Please read the note
         // above regarding the behaviour of image resizing.
-        anchor.setAnchorType(ClientAnchor.MOVE_AND_RESIZE);
+        anchor.setAnchorType(AnchorType.MOVE_AND_RESIZE);
 
         // Now, add the picture to the workbook. Note that unlike the similar
         // method in the HSSF Examples section, the image type is checked. First,
         // the image files location is identified by interrogating the URL passed
         // to the method, the images type is identified before it is added to the
         // sheet.
-        String sURL = imageFile.toString().toLowerCase();
+        String sURL = imageFile.toString().toLowerCase(Locale.ROOT);
 	if( sURL.endsWith(".png") ) {
             imageType = Workbook.PICTURE_TYPE_PNG;
 	}
-	else if( sURL.endsWith("jpg") || sURL.endsWith(".jpeg") ) {
+	else if( sURL.endsWith(".jpg") || sURL.endsWith(".jpeg") ) {
             imageType = Workbook.PICTURE_TYPE_JPEG;
 	}
 	else  {
@@ -399,14 +404,14 @@ public class AddDimensionedImage {
     }
 
     /**
-     * Determines whether the sheets columns should be re-sized to accomodate
+     * Determines whether the sheets columns should be re-sized to accommodate
      * the image, adjusts the columns width if necessary and creates then
      * returns a ClientAnchorDetail object that facilitates construction of
      * an ClientAnchor that will fix the image on the sheet and establish
      * it's size.
      *
      * @param sheet A reference to the sheet that will 'contain' the image.
-     * @param colNumber A primtive int that contains the index number of a
+     * @param colNumber A primitive int that contains the index number of a
      *                  column on the sheet.
      * @param reqImageWidthMM A primitive double that contains the required
      *                        width of the image in millimetres
@@ -426,16 +431,16 @@ public class AddDimensionedImage {
     private ClientAnchorDetail fitImageToColumns(Sheet sheet, int colNumber,
             double reqImageWidthMM, int resizeBehaviour) {
 
-        double colWidthMM = 0.0D;
-        double colCoordinatesPerMM = 0.0D;
-        int pictureWidthCoordinates = 0;
+        double colWidthMM;
+        double colCoordinatesPerMM;
+        int pictureWidthCoordinates;
         ClientAnchorDetail colClientAnchorDetail = null;
 
         // Get the colum's width in millimetres
         colWidthMM = ConvertImageUnits.widthUnits2Millimetres(
                 (short)sheet.getColumnWidth(colNumber));
 
-        // Check that the column's width will accomodate the image at the
+        // Check that the column's width will accommodate the image at the
         // required dimension. If the width of the column is LESS than the
         // required width of the image, decide how the application should
         // respond - resize the column or overlay the image across one or more
@@ -495,7 +500,7 @@ public class AddDimensionedImage {
     }
 
     /**
-     * Determines whether the sheets row should be re-sized to accomodate
+     * Determines whether the sheets row should be re-sized to accommodate
      * the image, adjusts the rows height if necessary and creates then
      * returns a ClientAnchorDetail object that facilitates construction of
      * a ClientAnchor that will fix the image on the sheet and establish
@@ -521,10 +526,10 @@ public class AddDimensionedImage {
      */
     private ClientAnchorDetail fitImageToRows(Sheet sheet, int rowNumber,
             double reqImageHeightMM, int resizeBehaviour) {
-        Row row = null;
-        double rowHeightMM = 0.0D;
-        double rowCoordinatesPerMM = 0.0D;
-        int pictureHeightCoordinates = 0;
+        Row row;
+        double rowHeightMM;
+        double rowCoordinatesPerMM;
+        int pictureHeightCoordinates;
         ClientAnchorDetail rowClientAnchorDetail = null;
 
         // Get the row and it's height
@@ -537,7 +542,7 @@ public class AddDimensionedImage {
         // Get the row's height in millimetres
         rowHeightMM = row.getHeightInPoints() / ConvertImageUnits.POINTS_PER_MILLIMETRE;
 
-        // Check that the row's height will accomodate the image at the required
+        // Check that the row's height will accommodate the image at the required
         // dimensions. If the height of the row is LESS than the required height
         // of the image, decide how the application should respond - resize the
         // row or overlay the image across a series of rows.
@@ -611,13 +616,13 @@ public class AddDimensionedImage {
     private ClientAnchorDetail calculateColumnLocation(Sheet sheet,
                                                        int startingColumn,
                                                        double reqImageWidthMM) {
-        ClientAnchorDetail anchorDetail = null;
+        ClientAnchorDetail anchorDetail;
         double totalWidthMM = 0.0D;
         double colWidthMM = 0.0D;
-        double overlapMM = 0.0D;
-        double coordinatePositionsPerMM = 0.0D;
+        double overlapMM;
+        double coordinatePositionsPerMM;
         int toColumn = startingColumn;
-        int inset = 0;
+        int inset;
 
         // Calculate how many columns the image will have to
         // span in order to be presented at the required size.
@@ -721,14 +726,14 @@ public class AddDimensionedImage {
      */
     private ClientAnchorDetail calculateRowLocation(Sheet sheet,
             int startingRow, double reqImageHeightMM) {
-        ClientAnchorDetail clientAnchorDetail = null;
-        Row row = null;
+        ClientAnchorDetail clientAnchorDetail;
+        Row row;
         double rowHeightMM = 0.0D;
         double totalRowHeightMM = 0.0D;
-        double overlapMM = 0.0D;
-        double rowCoordinatesPerMM = 0.0D;
+        double overlapMM;
+        double rowCoordinatesPerMM;
         int toRow = startingRow;
-        int inset = 0;
+        int inset;
 
         // Step through the rows in the sheet and accumulate a total of their
         // heights.
@@ -811,50 +816,23 @@ public class AddDimensionedImage {
      *
      * @param args the command line arguments
      */
-    public static void main(String[] args) {
-    	String imageFile = null;
-    	String outputFile = null;
-        FileOutputStream fos = null;
-        Workbook workbook = null;
-        Sheet sheet = null;
-        try {
-        	if(args.length < 2){
-        		System.err.println("Usage: AddDimensionedImage imageFile outputFile");
-        		return;
-        	}
-        	workbook = new HSSFWorkbook();   // OR XSSFWorkbook
-        	sheet = workbook.createSheet("Picture Test");
-               	imageFile = args[0];
-        	outputFile = args[1];
-        	new AddDimensionedImage().addImageToSheet("B5", sheet, sheet.createDrawingPatriarch(),
-        		new File(imageFile).toURI().toURL(), 100, 40,
-        		AddDimensionedImage.EXPAND_ROW_AND_COLUMN);
-      		fos = new FileOutputStream(outputFile);
+    public static void main(String[] args) throws IOException {
+        if(args.length < 2){
+    		System.err.println("Usage: AddDimensionedImage imageFile outputFile");
+    		return;
+    	}
+
+        final String imageFile = args[0];
+        final String outputFile = args[1];
+
+        try (final Workbook workbook = new HSSFWorkbook();
+             final FileOutputStream fos = new FileOutputStream(outputFile)) {   // OR XSSFWorkbook
+            Sheet sheet = workbook.createSheet("Picture Test");
+            new AddDimensionedImage().addImageToSheet("B5", sheet, sheet.createDrawingPatriarch(),
+                    new File(imageFile).toURI().toURL(), 100, 40,
+                    AddDimensionedImage.EXPAND_ROW_AND_COLUMN);
             workbook.write(fos);
         }
-        catch(FileNotFoundException fnfEx) {
-            System.out.println("Caught an: " + fnfEx.getClass().getName());
-            System.out.println("Message: " + fnfEx.getMessage());
-            System.out.println("Stacktrace follows...........");
-            fnfEx.printStackTrace(System.out);
-        }
-        catch(IOException ioEx) {
-            System.out.println("Caught an: " + ioEx.getClass().getName());
-            System.out.println("Message: " + ioEx.getMessage());
-            System.out.println("Stacktrace follows...........");
-            ioEx.printStackTrace(System.out);
-        }
-        finally {
-            if(fos != null) {
-                try {
-                    fos.close();
-                    fos = null;
-                }
-                catch(IOException ioEx) {
-                    // I G N O R E
-                }
-            }
-        }
     }
 
     /**
@@ -885,9 +863,9 @@ public class AddDimensionedImage {
      */
     public class ClientAnchorDetail {
 
-        public int fromIndex = 0;
-        public int toIndex = 0;
-        public int inset = 0;
+        public int fromIndex;
+        public int toIndex;
+        public int inset;
 
         /**
          * Create a new instance of the ClientAnchorDetail class using the
@@ -983,8 +961,6 @@ public class AddDimensionedImage {
 
         /**
         * pixel units to excel width units(units of 1/256th of a character width)
-        * @param pxs
-        * @return
         */
         public static short pixel2WidthUnits(int pxs) {
             short widthUnits = (short) (EXCEL_COLUMN_WIDTH_FACTOR *
@@ -996,9 +972,6 @@ public class AddDimensionedImage {
         /**
          * excel width units(units of 1/256th of a character width) to pixel
          * units.
-         *
-         * @param widthUnits
-         * @return
          */
         public static int widthUnits2Pixel(short widthUnits) {
             int pixels = (widthUnits / EXCEL_COLUMN_WIDTH_FACTOR)
@@ -1043,4 +1016,4 @@ public class AddDimensionedImage {
         	return points / 72D * 25.4;
         }
     }
-}
\ No newline at end of file
+}
