@@ -27,8 +27,8 @@ import java.io.FilenameFilter;
 import java.io.IOException;
 import java.util.ArrayList;
 
-import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
 import org.apache.poi.ss.usermodel.Cell;
+import org.apache.poi.ss.usermodel.CellType;
 import org.apache.poi.ss.usermodel.DataFormatter;
 import org.apache.poi.ss.usermodel.FormulaEvaluator;
 import org.apache.poi.ss.usermodel.Row;
@@ -131,13 +131,13 @@ import org.apache.poi.ss.usermodel.WorkbookFactory;
  */
 public class ToCSV {
 
-    private Workbook workbook = null;
-    private ArrayList<ArrayList<String>> csvData = null;
-    private int maxRowWidth = 0;
-    private int formattingConvention = 0;
-    private DataFormatter formatter = null;
-    private FormulaEvaluator evaluator = null;
-    private String separator = null;
+    private Workbook workbook;
+    private ArrayList<ArrayList<String>> csvData;
+    private int maxRowWidth;
+    private int formattingConvention;
+    private DataFormatter formatter;
+    private FormulaEvaluator evaluator;
+    private String separator;
 
     private static final String CSV_FILE_EXTENSION = ".csv";
     private static final String DEFAULT_SEPARATOR = ",";
@@ -181,13 +181,10 @@ public class ToCSV {
      *         exist or if the value passed to the strDestination paramater refers
      *         to a folder that does not exist or simply does not refer to a
      *         folder.
-     * @throws org.apache.poi.openxml4j.exceptions.InvalidFormatException Thrown
-     *         if the xml markup encountered whilst parsing a SpreadsheetML
-     *         file (.xlsx) is invalid.
      */
     public void convertExcelToCSV(String strSource, String strDestination)
                        throws FileNotFoundException, IOException,
-                              IllegalArgumentException, InvalidFormatException {
+                              IllegalArgumentException {
 
         // Simply chain the call to the overloaded convertExcelToCSV(String,
         // String, String, int) method, pass the default separator and ensure
@@ -225,14 +222,11 @@ public class ToCSV {
      *         exist or if the value passed to the strDestination paramater refers
      *         to a folder that does not exist or simply does not refer to a
      *         folder.
-     * @throws org.apache.poi.openxml4j.exceptions.InvalidFormatException Thrown
-     *         if the xml markup encounetered whilst parsing a SpreadsheetML
-     *         file (.xlsx) is invalid.
      */
     public void convertExcelToCSV(String strSource, String strDestination,
                                   String separator)
                        throws FileNotFoundException, IOException,
-                              IllegalArgumentException, InvalidFormatException {
+                              IllegalArgumentException {
 
         // Simply chain the call to the overloaded convertExcelToCSV(String,
         // String, String, int) method and ensure that certain embedded
@@ -274,18 +268,15 @@ public class ToCSV {
      *         value passed to the formattingConvention parameter is other than
      *         one of the values defined by the constants ToCSV.EXCEL_STYLE_ESCAPING
      *         and ToCSV.UNIX_STYLE_ESCAPING.
-     * @throws org.apache.poi.openxml4j.exceptions.InvalidFormatException Thrown
-     *         if the xml markup encounetered whilst parsing a SpreadsheetML
-     *         file (.xlsx) is invalid.
      */
     public void convertExcelToCSV(String strSource, String strDestination,
                                   String separator, int formattingConvention)
                        throws FileNotFoundException, IOException,
-                              IllegalArgumentException, InvalidFormatException {
+                              IllegalArgumentException {
         File source = new File(strSource);
         File destination = new File(strDestination);
-        File[] filesList = null;
-        String destinationFilename = null;
+        File[] filesList;
+        String destinationFilename;
 
         // Check that the source file/folder exists.
         if(!source.exists()) {
@@ -343,23 +334,25 @@ public class ToCSV {
         // (.xls) and the other a SpreadsheetML file (.xlsx), then the names
         // for both CSV files will be identical and one CSV file will,
         // therefore, over-write the other.
-        for(File excelFile : filesList) {
-            // Open the workbook
-            this.openWorkbook(excelFile);
-
-            // Convert it's contents into a CSV file
-            this.convertToCSV();
-
-            // Build the name of the csv folder from that of the Excel workbook.
-            // Simply replace the .xls or .xlsx file extension with .csv
-            destinationFilename = excelFile.getName();
-            destinationFilename = destinationFilename.substring(
-                    0, destinationFilename.lastIndexOf(".")) +
-                    ToCSV.CSV_FILE_EXTENSION;
-
-            // Save the CSV file away using the newly constricted file name
-            // and to the specified directory.
-            this.saveCSVFile(new File(destination, destinationFilename));
+        if (filesList != null) {
+            for(File excelFile : filesList) {
+                // Open the workbook
+                this.openWorkbook(excelFile);
+    
+                // Convert it's contents into a CSV file
+                this.convertToCSV();
+    
+                // Build the name of the csv folder from that of the Excel workbook.
+                // Simply replace the .xls or .xlsx file extension with .csv
+                destinationFilename = excelFile.getName();
+                destinationFilename = destinationFilename.substring(
+                        0, destinationFilename.lastIndexOf(".")) +
+                        ToCSV.CSV_FILE_EXTENSION;
+    
+                // Save the CSV file away using the newly constricted file name
+                // and to the specified directory.
+                this.saveCSVFile(new File(destination, destinationFilename));
+            }
         }
     }
 
@@ -371,17 +364,11 @@ public class ToCSV {
      *        either binary (.xls) or SpreadsheetML (.xlsx) format.
      * @throws java.io.FileNotFoundException Thrown if the file cannot be located.
      * @throws java.io.IOException Thrown if a problem occurs in the file system.
-     * @throws org.apache.poi.openxml4j.exceptions.InvalidFormatException Thrown
-     *         if invalid xml is found whilst parsing an input SpreadsheetML
-     *         file.
      */
     private void openWorkbook(File file) throws FileNotFoundException,
-                                           IOException, InvalidFormatException {
-        FileInputStream fis = null;
-        try {
-            System.out.println("Opening workbook [" + file.getName() + "]");
-
-            fis = new FileInputStream(file);
+                                           IOException {
+        System.out.println("Opening workbook [" + file.getName() + "]");
+        try (FileInputStream fis = new FileInputStream(file)) {
 
             // Open the workbook and then create the FormulaEvaluator and
             // DataFormatter instances that will be needed to, respectively,
@@ -391,11 +378,6 @@ public class ToCSV {
             this.evaluator = this.workbook.getCreationHelper().createFormulaEvaluator();
             this.formatter = new DataFormatter(true);
         }
-        finally {
-            if(fis != null) {
-                fis.close();
-            }
-        }
     }
 
     /**
@@ -403,10 +385,10 @@ public class ToCSV {
      * a CSV file.
      */
     private void convertToCSV() {
-        Sheet sheet = null;
-        Row row = null;
-        int lastRowNum = 0;
-        this.csvData = new ArrayList<ArrayList<String>>();
+        Sheet sheet;
+        Row row;
+        int lastRowNum;
+        this.csvData = new ArrayList<>();
 
         System.out.println("Converting files contents to CSV format.");
 
@@ -448,19 +430,15 @@ public class ToCSV {
      */
     private void saveCSVFile(File file)
                                      throws FileNotFoundException, IOException {
-        FileWriter fw = null;
-        BufferedWriter bw = null;
-        ArrayList<String> line = null;
-        StringBuffer buffer = null;
-        String csvLineElement = null;
-        try {
+        ArrayList<String> line;
+        StringBuffer buffer;
+        String csvLineElement;
+
+        // Open a writer onto the CSV file.
+        try (BufferedWriter bw = new BufferedWriter(new FileWriter(file))) {
 
             System.out.println("Saving the CSV file [" + file.getName() + "]");
 
-            // Open a writer onto the CSV file.
-            fw = new FileWriter(file);
-            bw = new BufferedWriter(fw);
-
             // Step through the elements of the ArrayList that was used to hold
             // all of the data recovered from the Excel workbooks' sheets, rows
             // and cells.
@@ -504,12 +482,6 @@ public class ToCSV {
                 }
             }
         }
-        finally {
-            if(bw != null) {
-                bw.flush();
-                bw.close();
-            }
-        }
     }
 
     /**
@@ -521,9 +493,9 @@ public class ToCSV {
      *            an Excel workbook.
      */
     private void rowToCSV(Row row) {
-        Cell cell = null;
-        int lastCellNum = 0;
-        ArrayList<String> csvLine = new ArrayList<String>();
+        Cell cell;
+        int lastCellNum;
+        ArrayList<String> csvLine = new ArrayList<>();
 
         // Check to ensure that a row was recovered from the sheet as it is
         // possible that one or more rows between other populated rows could be
@@ -541,7 +513,7 @@ public class ToCSV {
                     csvLine.add("");
                 }
                 else {
-                    if(cell.getCellType() != Cell.CELL_TYPE_FORMULA) {
+                    if(cell.getCellType() != CellType.FORMULA) {
                         csvLine.add(this.formatter.formatCellValue(cell));
                     }
                     else {
@@ -600,7 +572,7 @@ public class ToCSV {
      *         speech mark characters correctly escaped.
      */
     private String escapeEmbeddedCharacters(String field) {
-        StringBuffer buffer = null;
+        StringBuffer buffer;
 
         // If the fields contents should be formatted to confrom with Excel's
         // convention....
@@ -668,7 +640,7 @@ public class ToCSV {
         // with matching names but different extensions - Test.xls and Test.xlsx
         // for example - then the CSV file generated from one will overwrite
         // that generated from the other.
-        ToCSV converter = null;
+        ToCSV converter;
         boolean converted = true;
         long startTime = System.currentTimeMillis();
         try {
@@ -763,6 +735,7 @@ public class ToCSV {
          *         file ends with either '.xls' or '.xlsx' and false will be
          *         returned in all other instances.
          */
+        @Override
         public boolean accept(File file, String name) {
             return(name.endsWith(".xls") || name.endsWith(".xlsx"));
         }
