@@ -16,14 +16,6 @@
 ==================================================================== */
 package org.apache.poi.ss.examples.html;
 
-import org.apache.poi.hssf.usermodel.HSSFCell;
-import org.apache.poi.hssf.usermodel.HSSFFont;
-import org.apache.poi.hssf.usermodel.HSSFWorkbook;
-import org.apache.poi.ss.format.CellFormat;
-import org.apache.poi.ss.format.CellFormatResult;
-import org.apache.poi.ss.usermodel.*;
-import org.apache.poi.xssf.usermodel.XSSFWorkbook;
-
 import java.io.BufferedReader;
 import java.io.Closeable;
 import java.io.FileInputStream;
@@ -38,15 +30,28 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
+import java.util.TreeMap;
 
-import static org.apache.poi.ss.usermodel.CellStyle.*;
-import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
+import org.apache.poi.hssf.usermodel.HSSFWorkbook;
+import org.apache.poi.ss.format.CellFormat;
+import org.apache.poi.ss.format.CellFormatResult;
+import org.apache.poi.ss.usermodel.BorderStyle;
+import org.apache.poi.ss.usermodel.Cell;
+import org.apache.poi.ss.usermodel.CellStyle;
+import org.apache.poi.ss.usermodel.CellType;
+import org.apache.poi.ss.usermodel.Font;
+import org.apache.poi.ss.usermodel.HorizontalAlignment;
+import org.apache.poi.ss.usermodel.Row;
+import org.apache.poi.ss.usermodel.Sheet;
+import org.apache.poi.ss.usermodel.VerticalAlignment;
+import org.apache.poi.ss.usermodel.Workbook;
+import org.apache.poi.ss.usermodel.WorkbookFactory;
+import org.apache.poi.util.IOUtils;
+import org.apache.poi.xssf.usermodel.XSSFWorkbook;
 
 /**
  * This example shows how to display a spreadsheet in HTML using the classes for
  * spreadsheet display.
- *
- * @author Ken Arnold, Industrious Media LLC
  */
 public class ToHtml {
     private final Workbook wb;
@@ -62,26 +67,42 @@ public class ToHtml {
     private static final String COL_HEAD_CLASS = "colHeader";
     private static final String ROW_HEAD_CLASS = "rowHeader";
 
-    private static final Map<Short, String> ALIGN = mapFor(ALIGN_LEFT, "left",
-            ALIGN_CENTER, "center", ALIGN_RIGHT, "right", ALIGN_FILL, "left",
-            ALIGN_JUSTIFY, "left", ALIGN_CENTER_SELECTION, "center");
+    private static final Map<HorizontalAlignment, String> HALIGN = mapFor(
+            HorizontalAlignment.LEFT, "left",
+            HorizontalAlignment.CENTER, "center",
+            HorizontalAlignment.RIGHT, "right",
+            HorizontalAlignment.FILL, "left",
+            HorizontalAlignment.JUSTIFY, "left",
+            HorizontalAlignment.CENTER_SELECTION, "center");
 
-    private static final Map<Short, String> VERTICAL_ALIGN = mapFor(
-            VERTICAL_BOTTOM, "bottom", VERTICAL_CENTER, "middle", VERTICAL_TOP,
-            "top");
+    private static final Map<VerticalAlignment, String> VALIGN = mapFor(
+            VerticalAlignment.BOTTOM, "bottom",
+            VerticalAlignment.CENTER, "middle",
+            VerticalAlignment.TOP, "top");
+
+    private static final Map<BorderStyle, String> BORDER = mapFor(
+            BorderStyle.DASH_DOT, "dashed 1pt",
+            BorderStyle.DASH_DOT_DOT, "dashed 1pt",
+            BorderStyle.DASHED, "dashed 1pt",
+            BorderStyle.DOTTED, "dotted 1pt",
+            BorderStyle.DOUBLE, "double 3pt",
+            BorderStyle.HAIR, "solid 1px",
+            BorderStyle.MEDIUM, "solid 2pt",
+            BorderStyle.MEDIUM_DASH_DOT, "dashed 2pt",
+            BorderStyle.MEDIUM_DASH_DOT_DOT, "dashed 2pt",
+            BorderStyle.MEDIUM_DASHED, "dashed 2pt",
+            BorderStyle.NONE, "none",
+            BorderStyle.SLANTED_DASH_DOT, "dashed 2pt",
+            BorderStyle.THICK, "solid 3pt",
+            BorderStyle.THIN, "dashed 1pt");
+
+    private static final int IDX_TABLE_WIDTH = -2;
+    private static final int IDX_HEADER_COL_WIDTH = -1;
 
-    private static final Map<Short, String> BORDER = mapFor(BORDER_DASH_DOT,
-            "dashed 1pt", BORDER_DASH_DOT_DOT, "dashed 1pt", BORDER_DASHED,
-            "dashed 1pt", BORDER_DOTTED, "dotted 1pt", BORDER_DOUBLE,
-            "double 3pt", BORDER_HAIR, "solid 1px", BORDER_MEDIUM, "solid 2pt",
-            BORDER_MEDIUM_DASH_DOT, "dashed 2pt", BORDER_MEDIUM_DASH_DOT_DOT,
-            "dashed 2pt", BORDER_MEDIUM_DASHED, "dashed 2pt", BORDER_NONE,
-            "none", BORDER_SLANTED_DASH_DOT, "dashed 2pt", BORDER_THICK,
-            "solid 3pt", BORDER_THIN, "dashed 1pt");
 
     @SuppressWarnings({"unchecked"})
     private static <K, V> Map<K, V> mapFor(Object... mapping) {
-        Map<K, V> map = new HashMap<K, V>();
+        Map<K, V> map = new HashMap<>();
         for (int i = 0; i < mapping.length; i += 2) {
             map.put((K) mapping[i], (V) mapping[i + 1]);
         }
@@ -89,7 +110,7 @@ public class ToHtml {
     }
 
     /**
-     * Creates a new converter to HTML for the given workbook.
+     * Creates a new examples to HTML for the given workbook.
      *
      * @param wb     The workbook.
      * @param output Where the HTML output will be written.
@@ -101,7 +122,7 @@ public class ToHtml {
     }
 
     /**
-     * Creates a new converter to HTML for the given workbook.  If the path ends
+     * Creates a new examples to HTML for the given workbook.  If the path ends
      * with "<tt>.xlsx</tt>" an {@link XSSFWorkbook} will be used; otherwise
      * this will use an {@link HSSFWorkbook}.
      *
@@ -116,7 +137,7 @@ public class ToHtml {
     }
 
     /**
-     * Creates a new converter to HTML for the given workbook.  This attempts to
+     * Creates a new examples to HTML for the given workbook.  This attempts to
      * detect whether the input is XML (so it should create an {@link
      * XSSFWorkbook} or not (so it should create an {@link HSSFWorkbook}).
      *
@@ -127,32 +148,31 @@ public class ToHtml {
      */
     public static ToHtml create(InputStream in, Appendable output)
             throws IOException {
-        try {
-            Workbook wb = WorkbookFactory.create(in);
-            return create(wb, output);
-        } catch (InvalidFormatException e){
-            throw new IllegalArgumentException("Cannot create workbook from stream", e);
-        }
+        Workbook wb = WorkbookFactory.create(in);
+        return create(wb, output);
     }
 
     private ToHtml(Workbook wb, Appendable output) {
-        if (wb == null)
+        if (wb == null) {
             throw new NullPointerException("wb");
-        if (output == null)
+        }
+        if (output == null) {
             throw new NullPointerException("output");
+        }
         this.wb = wb;
         this.output = output;
         setupColorMap();
     }
 
     private void setupColorMap() {
-        if (wb instanceof HSSFWorkbook)
+        if (wb instanceof HSSFWorkbook) {
             helper = new HSSFHtmlHelper((HSSFWorkbook) wb);
-        else if (wb instanceof XSSFWorkbook)
-            helper = new XSSFHtmlHelper((XSSFWorkbook) wb);
-        else
+        } else if (wb instanceof XSSFWorkbook) {
+            helper = new XSSFHtmlHelper();
+        } else {
             throw new IllegalArgumentException(
                     "unknown workbook type: " + wb.getClass().getSimpleName());
+        }
     }
 
     /**
@@ -168,9 +188,14 @@ public class ToHtml {
             return;
         }
 
-        ToHtml toHtml = create(args[0], new PrintWriter(new FileWriter(args[1])));
-        toHtml.setCompleteHTML(true);
-        toHtml.printPage();
+        try (
+                FileWriter fw = new FileWriter(args[1]);
+                PrintWriter pw = new PrintWriter(fw)
+            ) {
+            ToHtml toHtml = create(args[0], pw);
+            toHtml.setCompleteHTML(true);
+            toHtml.printPage();
+        }
     }
 
     public void setCompleteHTML(boolean completeHTML) {
@@ -196,11 +221,9 @@ public class ToHtml {
                 out.format("</html>%n");
             }
         } finally {
-            if (out != null)
-                out.close();
+            IOUtils.closeQuietly(out);
             if (output instanceof Closeable) {
-                Closeable closeable = (Closeable) output;
-                closeable.close();
+                IOUtils.closeQuietly((Closeable) output);
             }
         }
     }
@@ -218,37 +241,27 @@ public class ToHtml {
     }
 
     private void ensureOut() {
-        if (out == null)
+        if (out == null) {
             out = new Formatter(output);
+        }
     }
 
     public void printStyles() {
         ensureOut();
 
         // First, copy the base css
-        BufferedReader in = null;
-        try {
-            in = new BufferedReader(new InputStreamReader(
-                    getClass().getResourceAsStream("excelStyle.css")));
+        try (BufferedReader in = new BufferedReader(new InputStreamReader(
+                getClass().getResourceAsStream("excelStyle.css")))){
             String line;
             while ((line = in.readLine()) != null) {
                 out.format("%s%n", line);
             }
         } catch (IOException e) {
             throw new IllegalStateException("Reading standard css", e);
-        } finally {
-            if (in != null) {
-                try {
-                    in.close();
-                } catch (IOException e) {
-                    //noinspection ThrowFromFinallyBlock
-                    throw new IllegalStateException("Reading standard css", e);
-                }
-            }
         }
 
         // now add css for each used style
-        Set<CellStyle> seen = new HashSet<CellStyle>();
+        Set<CellStyle> seen = new HashSet<>();
         for (int i = 0; i < wb.getNumberOfSheets(); i++) {
             Sheet sheet = wb.getSheetAt(i);
             Iterator<Row> rows = sheet.rowIterator();
@@ -272,8 +285,8 @@ public class ToHtml {
     }
 
     private void styleContents(CellStyle style) {
-        styleOut("text-align", style.getAlignment(), ALIGN);
-        styleOut("vertical-align", style.getAlignment(), VERTICAL_ALIGN);
+        styleOut("text-align", style.getAlignment(), HALIGN);
+        styleOut("vertical-align", style.getVerticalAlignment(), VALIGN);
         fontStyle(style);
         borderStyles(style);
         helper.colorStyles(style, out);
@@ -287,12 +300,14 @@ public class ToHtml {
     }
 
     private void fontStyle(CellStyle style) {
-        Font font = wb.getFontAt(style.getFontIndex());
+        Font font = wb.getFontAt(style.getFontIndexAsInt());
 
-        if (font.getBoldweight() >= HSSFFont.BOLDWEIGHT_BOLD)
+        if (font.getBold()) {
             out.format("  font-weight: bold;%n");
-        if (font.getItalic())
+        }
+        if (font.getItalic()) {
             out.format("  font-style: italic;%n");
+        }
 
         int fontheight = font.getFontHeightInPoints();
         if (fontheight == 9) {
@@ -305,15 +320,13 @@ public class ToHtml {
     }
 
     private String styleName(CellStyle style) {
-        if (style == null)
+        if (style == null) {
             style = wb.getCellStyleAt((short) 0);
+        }
         StringBuilder sb = new StringBuilder();
-        Formatter fmt = new Formatter(sb);
-        try {
+        try (Formatter fmt = new Formatter(sb)) {
             fmt.format("style_%02x", style.getIndex());
             return fmt.toString();
-        } finally {
-            fmt.close();
         }
     }
 
@@ -324,10 +337,11 @@ public class ToHtml {
         }
     }
 
-    private static int ultimateCellType(Cell c) {
-        int type = c.getCellType();
-        if (type == Cell.CELL_TYPE_FORMULA)
+    private static CellType ultimateCellType(Cell c) {
+        CellType type = c.getCellType();
+        if (type == CellType.FORMULA) {
             type = c.getCachedFormulaResultType();
+        }
         return type;
     }
 
@@ -339,23 +353,68 @@ public class ToHtml {
 
     public void printSheet(Sheet sheet) {
         ensureOut();
-        out.format("<table class=%s>%n", DEFAULTS_CLASS);
-        printCols(sheet);
+        Map<Integer, Integer> widths = computeWidths(sheet);
+        int tableWidth = widths.get(IDX_TABLE_WIDTH);
+        out.format("<table class=%s style=\"width:%dpx;\">%n", DEFAULTS_CLASS, tableWidth);
+        printCols(widths);
         printSheetContent(sheet);
         out.format("</table>%n");
     }
 
-    private void printCols(Sheet sheet) {
-        out.format("<col/>%n");
+    /**
+     * computes the column widths, defined by the sheet.
+     *
+     * @param sheet The sheet for which to compute widths
+     * @return Map with key: column index; value: column width in pixels
+     *     <br>special keys:
+     *     <br>{@link #IDX_HEADER_COL_WIDTH} - width of the header column
+     *     <br>{@link #IDX_TABLE_WIDTH} - width of the entire table
+     */
+    private Map<Integer, Integer> computeWidths(Sheet sheet) {
+        Map<Integer, Integer> ret = new TreeMap<>();
+        int tableWidth = 0;
+
         ensureColumnBounds(sheet);
+
+        // compute width of the header column
+        int lastRowNum = sheet.getLastRowNum();
+        int headerCharCount = String.valueOf(lastRowNum).length();
+        int headerColWidth = widthToPixels((headerCharCount + 1) * 256.0);
+        ret.put(IDX_HEADER_COL_WIDTH, headerColWidth);
+        tableWidth += headerColWidth;
+
         for (int i = firstColumn; i < endColumn; i++) {
-            out.format("<col/>%n");
+            int colWidth = widthToPixels(sheet.getColumnWidth(i));
+            ret.put(i, colWidth);
+            tableWidth += colWidth;
+        }
+
+        ret.put(IDX_TABLE_WIDTH, tableWidth);
+        return ret ;
+    }
+
+    /**
+     * Probably platform-specific, but appears to be a close approximation on some systems
+     * @param widthUnits POI's native width unit (twips)
+     * @return the approximate number of pixels for a typical display
+     */
+    protected int widthToPixels(final double widthUnits) {
+        return (int) (Math.round(widthUnits * 9 / 256));
+    }
+
+    private void printCols(Map<Integer, Integer> widths) {
+        int headerColWidth = widths.get(IDX_HEADER_COL_WIDTH);
+        out.format("<col style=\"width:%dpx\"/>%n", headerColWidth);
+        for (int i = firstColumn; i < endColumn; i++) {
+            int colWidth = widths.get(i);
+            out.format("<col style=\"width:%dpx;\"/>%n", colWidth);
         }
     }
 
     private void ensureColumnBounds(Sheet sheet) {
-        if (gotBounds)
+        if (gotBounds) {
             return;
+        }
 
         Iterator<Row> iter = sheet.rowIterator();
         firstColumn = (iter.hasNext() ? Integer.MAX_VALUE : 0);
@@ -415,9 +474,10 @@ public class ToHtml {
                         CellFormat cf = CellFormat.getInstance(
                                 style.getDataFormatString());
                         CellFormatResult result = cf.apply(cell);
-                        content = result.text;
-                        if (content.equals(""))
+                        content = result.text; //never null
+                        if (content.isEmpty()) {
                             content = "&nbsp;";
+                        }
                     }
                 }
                 out.format("    <td class=%s %s>%s</td>%n", styleName(style),
@@ -429,14 +489,14 @@ public class ToHtml {
     }
 
     private String tagStyle(Cell cell, CellStyle style) {
-        if (style.getAlignment() == ALIGN_GENERAL) {
+        if (style.getAlignment() == HorizontalAlignment.GENERAL) {
             switch (ultimateCellType(cell)) {
-            case HSSFCell.CELL_TYPE_STRING:
+            case STRING:
                 return "style=\"text-align: left;\"";
-            case HSSFCell.CELL_TYPE_BOOLEAN:
-            case HSSFCell.CELL_TYPE_ERROR:
+            case BOOLEAN:
+            case ERROR:
                 return "style=\"text-align: center;\"";
-            case HSSFCell.CELL_TYPE_NUMERIC:
+            case NUMERIC:
             default:
                 // "right" is the default
                 break;
@@ -444,4 +504,4 @@ public class ToHtml {
         }
         return "";
     }
-}
\ No newline at end of file
+}
