@@ -19,12 +19,9 @@ package org.apache.poi.ss.excelant.util;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
-import java.util.ArrayList;
 import java.util.Date;
+import java.util.List;
 
-import junit.framework.TestCase;
-
-import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
 import org.apache.poi.ss.examples.formula.CalculateMortgageFunction;
 import org.apache.poi.ss.excelant.BuildFileTest;
 import org.apache.poi.ss.formula.udf.UDFFinder;
@@ -34,6 +31,8 @@ import org.apache.poi.ss.usermodel.Workbook;
 import org.apache.poi.ss.usermodel.WorkbookFactory;
 import org.apache.tools.ant.BuildException;
 
+import junit.framework.TestCase;
+
 public class TestExcelAntWorkbookUtil extends TestCase {
 	
     private static final String mortgageCalculatorFileName =
@@ -56,15 +55,14 @@ public class TestExcelAntWorkbookUtil extends TestCase {
 
 	public void testLoadNotExistingFile() {
 		try {
-			assertNotNull(new ExcelAntWorkbookUtilTestHelper(
-				                                  "notexistingFile" ));
+			new ExcelAntWorkbookUtilTestHelper("notexistingFile");
 			fail("Should catch exception here");
 		} catch (BuildException e) {
 			assertTrue(e.getMessage().contains("notexistingFile"));			
 		}
 	}
 	
-	public void testWorkbookConstructor() throws InvalidFormatException, IOException {
+	public void testWorkbookConstructor() throws IOException {
         File workbookFile = new File(mortgageCalculatorFileName);
         FileInputStream fis = new FileInputStream(workbookFile);
         Workbook workbook = WorkbookFactory.create(fis);
@@ -198,9 +196,10 @@ public class TestExcelAntWorkbookUtil extends TestCase {
 				                                                precision);
 
 		//System.out.println(result);
-		assertTrue(result.toString().contains("evaluationCompletedWithError=false"));
-		assertTrue(result.toString().contains("returnValue=790.79"));
-		assertTrue(result.toString().contains("cellName='MortgageCalculator'!B4"));
+		assertTrue("Had:" + result, result.toString().contains("evaluationCompletedWithError=false"));
+		assertTrue("Had:" + result, result.toString().contains("returnValue=790.79"));
+		assertTrue("Had:" + result, result.toString().contains("cellName='MortgageCalculator'!B4"));
+        assertFalse(result.toString().contains("#N/A"));
 
 		assertFalse(result.evaluationCompleteWithError());
 		assertTrue(result.didTestPass());
@@ -219,9 +218,10 @@ public class TestExcelAntWorkbookUtil extends TestCase {
                                                                 precision);
 
         //System.out.println(result);
-        assertTrue(result.toString().contains("evaluationCompletedWithError=false"));
-        assertTrue(result.toString().contains("returnValue=790.79"));
-        assertTrue(result.toString().contains("cellName='MortgageCalculator'!B4"));
+        assertTrue("Had:" + result, result.toString().contains("evaluationCompletedWithError=false"));
+        assertTrue("Had:" + result, result.toString().contains("returnValue=790.79"));
+        assertTrue("Had:" + result, result.toString().contains("cellName='MortgageCalculator'!B4"));
+        assertFalse("Should not see an error, but had:" + result, result.toString().contains("#"));
 
         assertFalse(result.evaluationCompleteWithError());
         assertFalse(result.didTestPass());
@@ -240,9 +240,10 @@ public class TestExcelAntWorkbookUtil extends TestCase {
                                                                 precision);
 
         System.out.println(result);
-        assertTrue(result.toString().contains("evaluationCompletedWithError=true"));
-        assertTrue(result.toString().contains("returnValue=0.0"));
-        assertTrue(result.toString().contains("cellName='ErrorCell'!A1"));
+        assertTrue("Had:" + result, result.toString().contains("evaluationCompletedWithError=true"));
+        assertTrue("Had:" + result, result.toString().contains("returnValue=0.0"));
+        assertTrue("Had:" + result, result.toString().contains("cellName='ErrorCell'!A1"));
+        assertTrue("Had:" + result, result.toString().contains("#N/A"));
 
         assertTrue(result.evaluationCompleteWithError());
         assertFalse(result.didTestPass());
@@ -252,7 +253,7 @@ public class TestExcelAntWorkbookUtil extends TestCase {
 		fixture = new ExcelAntWorkbookUtilTestHelper(
                 mortgageCalculatorFileName);
 		
-		ArrayList<String> sheets = fixture.getSheets();
+		List<String> sheets = fixture.getSheets();
 		
 		assertNotNull(sheets);
 		assertEquals(sheets.size(), 3); 
@@ -297,7 +298,6 @@ public class TestExcelAntWorkbookUtil extends TestCase {
         
         double value = fixture.getCellAsDouble(cell);
         
-        assertNotNull(value);
         assertEquals(0.0, value);
     }
     
@@ -327,7 +327,6 @@ public class TestExcelAntWorkbookUtil extends TestCase {
 		
 		double value = fixture.getCellAsDouble(cell);
 		
-		assertNotNull(value);
 		assertEquals(DateUtil.getExcelDate(cellValue, false), value);
 	}
 
