@@ -19,9 +19,9 @@ package org.apache.poi.ddf;
 
 import java.io.PrintWriter;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
-import java.util.NoSuchElementException;
 
 import org.apache.poi.util.HexDump;
 import org.apache.poi.util.LittleEndian;
@@ -33,10 +33,8 @@ import org.apache.poi.util.POILogger;
  * The container records themselves never store any information beyond
  * the standard header used by all escher records.  This one record is
  * used to represent many different types of records.
- *
- * @author Glen Stampoultzis
  */
-public final class EscherContainerRecord extends EscherRecord {
+public final class EscherContainerRecord extends EscherRecord implements Iterable<EscherRecord> {
     public static final short DGG_CONTAINER    = (short)0xF000;
     public static final short BSTORE_CONTAINER = (short)0xF001;
     public static final short DG_CONTAINER     = (short)0xF002;
@@ -44,7 +42,7 @@ public final class EscherContainerRecord extends EscherRecord {
     public static final short SP_CONTAINER     = (short)0xF004;
     public static final short SOLVER_CONTAINER = (short)0xF005;
 
-    private static POILogger log = POILogFactory.getLogger(EscherContainerRecord.class);
+    private static final POILogger log = POILogFactory.getLogger(EscherContainerRecord.class);
 
     /**
      * in case if document contains any charts we have such document structure:
@@ -70,8 +68,9 @@ public final class EscherContainerRecord extends EscherRecord {
      */
     private int _remainingLength;
 
-    private final List<EscherRecord> _childRecords = new ArrayList<EscherRecord>();
+    private final List<EscherRecord> _childRecords = new ArrayList<>();
 
+    @Override
     public int fillFields(byte[] data, int pOffset, EscherRecordFactory recordFactory) {
         int bytesRemaining = readHeader(data, pOffset);
         int bytesWritten = 8;
@@ -93,6 +92,7 @@ public final class EscherContainerRecord extends EscherRecord {
         return bytesWritten;
     }
 
+    @Override
     public int serialize( int offset, byte[] data, EscherSerializationListener listener )
     {
         listener.beforeRecordSerialize( offset, getRecordId(), this );
@@ -100,17 +100,13 @@ public final class EscherContainerRecord extends EscherRecord {
         LittleEndian.putShort(data, offset, getOptions());
         LittleEndian.putShort(data, offset+2, getRecordId());
         int remainingBytes = 0;
-        Iterator<EscherRecord> iterator = _childRecords.iterator();
-        while (iterator.hasNext()) {
-            EscherRecord r = iterator.next();
+        for (EscherRecord r : this) {
             remainingBytes += r.getRecordSize();
         }
         remainingBytes += _remainingLength;
         LittleEndian.putInt(data, offset+4, remainingBytes);
         int pos = offset+8;
-        iterator = _childRecords.iterator();
-        while (iterator.hasNext()) {
-            EscherRecord r = iterator.next();
+        for (EscherRecord r : this) {
             pos += r.serialize(pos, data, listener );
         }
 
@@ -118,30 +114,31 @@ public final class EscherContainerRecord extends EscherRecord {
         return pos - offset;
     }
 
+    @Override
     public int getRecordSize() {
         int childRecordsSize = 0;
-        Iterator<EscherRecord> iterator = _childRecords.iterator();
-        while (iterator.hasNext()) {
-            EscherRecord r = iterator.next();
+        for (EscherRecord r : this) {
             childRecordsSize += r.getRecordSize();
         }
         return 8 + childRecordsSize;
     }
 
     /**
-     * Do any of our (top level) children have the
-     *  given recordId?
+     * Do any of our (top level) children have the given recordId?
+     *
+     * @param recordId the recordId of the child
+     *
+     * @return true, if any child has the given recordId
      */
     public boolean hasChildOfType(short recordId) {
-        Iterator<EscherRecord> iterator = _childRecords.iterator();
-        while (iterator.hasNext()) {
-            EscherRecord r = iterator.next();
+        for (EscherRecord r : this) {
             if(r.getRecordId() == recordId) {
                 return true;
             }
         }
         return false;
     }
+    @Override
     public EscherRecord getChild( int index ) {
         return _childRecords.get(index);
     }
@@ -149,38 +146,23 @@ public final class EscherContainerRecord extends EscherRecord {
     /**
      * @return a copy of the list of all the child records of the container.
      */
+    @Override
     public List<EscherRecord> getChildRecords() {
-        return new ArrayList<EscherRecord>(_childRecords);
+        return new ArrayList<>(_childRecords);
     }
 
-    public Iterator<EscherRecord> getChildIterator() {
-        return new ReadOnlyIterator(_childRecords);
+    /**
+     * @return an iterator over the child records
+     */
+    @Override
+    public Iterator<EscherRecord> iterator() {
+        return Collections.unmodifiableList(_childRecords).iterator();
     }
-    private static final class ReadOnlyIterator implements Iterator<EscherRecord> {
-        private final List<EscherRecord> _list;
-        private int _index;
 
-        public ReadOnlyIterator(List<EscherRecord> list) {
-            _list = list;
-            _index = 0;
-        }
-
-        public boolean hasNext() {
-            return _index < _list.size();
-        }
-        public EscherRecord next() {
-            if (!hasNext()) {
-                throw new NoSuchElementException();
-            }
-            return _list.get(_index++);
-        }
-        public void remove() {
-            throw new UnsupportedOperationException();
-        }
-    }
     /**
      * replaces the internal child list with the contents of the supplied <tt>childRecords</tt>
      */
+    @Override
     public void setChildRecords(List<EscherRecord> childRecords) {
         if (childRecords == _childRecords) {
             throw new IllegalStateException("Child records private data member has escaped");
@@ -189,6 +171,12 @@ public final class EscherContainerRecord extends EscherRecord {
         _childRecords.addAll(childRecords);
     }
 
+    /**
+     * Removes the given escher record from the child list
+     *
+     * @param toBeRemoved the escher record to be removed
+     * @return true, if the record was found and removed
+     */
     public boolean removeChildRecord(EscherRecord toBeRemoved) {
         return _childRecords.remove(toBeRemoved);
     }
@@ -197,14 +185,13 @@ public final class EscherContainerRecord extends EscherRecord {
 
     /**
      * Returns all of our children which are also
-     *  EscherContainers (may be 0, 1, or vary rarely
-     *   2 or 3)
+     * EscherContainers (may be 0, 1, or vary rarely 2 or 3)
+     *
+     * @return EscherContainer children
      */
     public List<EscherContainerRecord> getChildContainers() {
-        List<EscherContainerRecord> containers = new ArrayList<EscherContainerRecord>();
-        Iterator<EscherRecord> iterator = _childRecords.iterator();
-        while (iterator.hasNext()) {
-            EscherRecord r = iterator.next();
+        List<EscherContainerRecord> containers = new ArrayList<>();
+        for (EscherRecord r : this) {
             if(r instanceof EscherContainerRecord) {
                 containers.add((EscherContainerRecord) r);
             }
@@ -212,6 +199,7 @@ public final class EscherContainerRecord extends EscherRecord {
         return containers;
     }
 
+    @Override
     public String getRecordName() {
         switch (getRecordId()) {
             case DGG_CONTAINER:
@@ -231,82 +219,44 @@ public final class EscherContainerRecord extends EscherRecord {
         }
     }
 
+    @Override
     public void display(PrintWriter w, int indent) {
         super.display(w, indent);
-        for (Iterator<EscherRecord> iterator = _childRecords.iterator(); iterator.hasNext();)
-        {
-            EscherRecord escherRecord = iterator.next();
+        for (EscherRecord escherRecord : this) {
             escherRecord.display(w, indent + 1);
         }
     }
 
+    /**
+     * Append a child record
+     *
+     * @param record the record to be added
+     */
     public void addChildRecord(EscherRecord record) {
         _childRecords.add(record);
     }
 
+    /**
+     * Add a child record before the record with given recordId
+     *
+     * @param record the record to be added
+     * @param insertBeforeRecordId the recordId of the next sibling
+     */
     public void addChildBefore(EscherRecord record, int insertBeforeRecordId) {
-        for (int i = 0; i < _childRecords.size(); i++) {
-            EscherRecord rec = _childRecords.get(i);
-            if(rec.getRecordId() == insertBeforeRecordId){
-                _childRecords.add(i++, record);
-                // TODO - keep looping? Do we expect multiple matches?
+        int idx = 0;
+        for (EscherRecord rec : this) {
+            if(rec.getRecordId() == (short)insertBeforeRecordId) {
+                break;
             }
+            // TODO - keep looping? Do we expect multiple matches?
+            idx++;
         }
+        _childRecords.add(idx, record);
     }
 
-    public String toString()
-    {
-        String nl = System.getProperty( "line.separator" );
-
-        StringBuffer children = new StringBuffer();
-        if ( _childRecords.size() > 0 )
-        {
-            children.append( "  children: " + nl );
-
-            int count = 0;
-            for ( Iterator<EscherRecord> iterator = _childRecords.iterator(); iterator
-                    .hasNext(); )
-            {
-                EscherRecord record = iterator.next();
-                children.append( "   Child " + count + ":" + nl );
-                String childResult = String.valueOf( record );
-                childResult = childResult.replaceAll( "\n", "\n    " );
-                children.append( "    " );
-                children.append( childResult );
-                children.append( nl );
-                count++;
-            }
-        }
-
-        return getClass().getName() + " (" + getRecordName() + "):" + nl
-                + "  isContainer: " + isContainerRecord() + nl
-                + "  version: 0x" + HexDump.toHex( getVersion() ) + nl
-                + "  instance: 0x" + HexDump.toHex( getInstance() ) + nl
-                + "  recordId: 0x" + HexDump.toHex( getRecordId() ) + nl
-                + "  numchildren: " + _childRecords.size() + nl
-                + children.toString();
-    }
-
-    @Override
-    public String toXml(String tab) {
-        StringBuilder builder = new StringBuilder();
-        builder.append(tab).append(formatXmlRecordHeader(getRecordName(), HexDump.toHex(getRecordId()), HexDump.toHex(getVersion()), HexDump.toHex(getInstance())));
-        for ( Iterator<EscherRecord> iterator = _childRecords.iterator(); iterator
-                .hasNext(); )
-        {
-            EscherRecord record = iterator.next();
-            builder.append(record.toXml(tab+"\t"));
-        }
-        builder.append(tab).append("</").append(getRecordName()).append(">\n");
-        return builder.toString();
-    }
-
-    public <T extends EscherRecord> T getChildById( short recordId )
-    {
-        for ( EscherRecord childRecord : _childRecords )
-        {
-            if ( childRecord.getRecordId() == recordId )
-            {
+    public <T extends EscherRecord> T getChildById( short recordId ) {
+        for ( EscherRecord childRecord : this ) {
+            if ( childRecord.getRecordId() == recordId ) {
                 @SuppressWarnings( "unchecked" )
                 final T result = (T) childRecord;
                 return result;
@@ -318,12 +268,11 @@ public final class EscherContainerRecord extends EscherRecord {
     /**
      * Recursively find records with the specified record ID
      *
+     * @param recordId the recordId to be searched for
      * @param out - list to store found records
      */
     public void getRecordsById(short recordId, List<EscherRecord> out){
-        Iterator<EscherRecord> iterator = _childRecords.iterator();
-        while (iterator.hasNext()) {
-            EscherRecord r = iterator.next();
+        for (EscherRecord r : this) {
             if(r instanceof EscherContainerRecord) {
                 EscherContainerRecord c = (EscherContainerRecord)r;
                 c.getRecordsById(recordId, out );
@@ -332,4 +281,21 @@ public final class EscherContainerRecord extends EscherRecord {
             }
         }
     }
+
+    @Override
+    protected Object[][] getAttributeMap() {
+        List<Object> chList = new ArrayList<>(_childRecords.size() * 2 + 2);
+        chList.add("children");
+        chList.add(_childRecords.size());
+        int count = 0;
+        for ( EscherRecord record : this ) {
+            chList.add("Child "+count);
+            chList.add(record);
+            count++;
+        }
+        return new Object[][] {
+        	{ "isContainer", isContainerRecord() },
+            chList.toArray()
+        };
+    }
 }
