@@ -17,17 +17,15 @@
 package org.apache.poi.hpsf;
 
 import org.apache.poi.util.Internal;
-import org.apache.poi.util.LittleEndian;
+import org.apache.poi.util.LittleEndianByteArrayInputStream;
 
 @Internal
-class Currency
-{
-    static final int SIZE = 8;
+public class Currency {
+    private static final int SIZE = 8;
 
-    private byte[] _value;
+    private final byte[] _value = new byte[SIZE];
 
-    Currency( byte[] data, int offset )
-    {
-        _value = LittleEndian.getByteArray( data, offset, SIZE );
+    public void read( LittleEndianByteArrayInputStream lei ) {
+        lei.readFully(_value);
     }
 }
