@@ -17,8 +17,10 @@
 
 package org.apache.poi.hssf.dev;
 
+import java.io.ByteArrayOutputStream;
 import java.io.FileInputStream;
 import java.io.FileOutputStream;
+import java.io.OutputStream;
 
 import org.apache.poi.hssf.usermodel.HSSFSheet;
 import org.apache.poi.hssf.usermodel.HSSFWorkbook;
@@ -29,15 +31,21 @@ import org.apache.poi.hssf.usermodel.HSSFWorkbook;
  *
  *  Usage: ReSave [-dg] input.xls
  *    -dg    initialize drawings, causes to re-build escher aggregates in all sheets
+ *    -bos   only write to memory instead of a file
  */
 public class ReSave {
     public static void main(String[] args) throws Exception {
         boolean initDrawing = false;
-        for(String arg : args) {
-            if(arg.equals("-dg")) initDrawing = true;
-            else {
-                System.out.print("reading " + arg + "...");
-                FileInputStream is = new FileInputStream(arg);
+        boolean saveToMemory = false;
+        ByteArrayOutputStream bos = new ByteArrayOutputStream();
+        for(String filename : args) {
+            if(filename.equals("-dg")) {
+                initDrawing = true;
+            } else if(filename.equals("-bos")) {
+                saveToMemory = true;
+            } else {
+                System.out.print("reading " + filename + "...");
+                FileInputStream is = new FileInputStream(filename);
                 HSSFWorkbook wb = new HSSFWorkbook(is);
                 try {
                     System.out.println("done");
@@ -48,18 +56,26 @@ public class ReSave {
                             /*HSSFPatriarch dg =*/ sheet.getDrawingPatriarch();
                         }
                     }
-    
-                    String outputFile = arg.replace(".xls", "-saved.xls");
-                    System.out.print("saving to " + outputFile + "...");
-                    FileOutputStream out = new FileOutputStream(outputFile);
+
+                    OutputStream os;
+                    if (saveToMemory) {
+                        bos.reset();
+                        os = bos;
+                    } else {
+                        String outputFile = filename.replace(".xls", "-saved.xls");
+                        System.out.print("saving to " + outputFile + "...");
+                        os = new FileOutputStream(outputFile);
+                    }
+                    
                     try {
-                        wb.write(out);
+                        wb.write(os);
                     } finally {
-                        out.close();
+                        os.close();
                     }
                     System.out.println("done");
                 } finally {
                     wb.close();
+                    is.close();
                 }
             }
         }
