@@ -26,13 +26,11 @@ import org.apache.poi.util.IntMapper;
 import org.apache.poi.util.LittleEndianConsts;
 
 /**
- * Title:        Static String Table Record (0x00FC)<p/>
+ * Title:        Static String Table Record (0x00FC)<p>
  *
- * Description:  This holds all the strings for LabelSSTRecords.
- * <P>
- * REFERENCE:    PG 389 Microsoft Excel 97 Developer's Kit (ISBN:
- *               1-57231-498-2)
- * <P>
+ * Description:  This holds all the strings for LabelSSTRecords.<p>
+ * 
+ * REFERENCE:    PG 389 Microsoft Excel 97 Developer's Kit (ISBN: 1-57231-498-2)
  *
  * @see org.apache.poi.hssf.record.LabelSSTRecord
  * @see org.apache.poi.hssf.record.ContinueRecord
@@ -70,7 +68,7 @@ public final class SSTRecord extends ContinuableRecord {
     {
         field_1_num_strings = 0;
         field_2_num_unique_strings = 0;
-        field_3_strings = new IntMapper<UnicodeString>();
+        field_3_strings = new IntMapper<>();
         deserializer = new SSTDeserializer(field_3_strings);
     }
 
@@ -163,8 +161,8 @@ public final class SSTRecord extends ContinuableRecord {
      * <P>
      * The data consists of sets of string data. This string data is
      * arranged as follows:
-     * <P>
-     * <CODE><pre>
+     * </P><P>
+     * <pre>
      * short  string_length;   // length of string data
      * byte   string_flag;     // flag specifying special string
      *                         // handling
@@ -177,11 +175,11 @@ public final class SSTRecord extends ContinuableRecord {
      *                         // array is run_count)
      * byte[] extension;       // optional extension (length of array
      *                         // is extend_length)
-     * </pre></CODE>
-     * <P>
+     * </pre>
+     * </P><P>
      * The string_flag is bit mapped as follows:
-     * <P>
-     * <TABLE>
+     * </P><P>
+     * <TABLE summary="string_flag mapping">
      *   <TR>
      *      <TH>Bit number</TH>
      *      <TH>Meaning if 0</TH>
@@ -190,42 +188,42 @@ public final class SSTRecord extends ContinuableRecord {
      *   <TR>
      *      <TD>0</TD>
      *      <TD>string_data is byte[]</TD>
-     *      <TD>string_data is short[]</TH>
+     *      <TD>string_data is short[]</TD>
      *   <TR>
      *   <TR>
      *      <TD>1</TD>
      *      <TD>Should always be 0</TD>
-     *      <TD>string_flag is defective</TH>
+     *      <TD>string_flag is defective</TD>
      *   <TR>
      *   <TR>
      *      <TD>2</TD>
      *      <TD>extension is not included</TD>
-     *      <TD>extension is included</TH>
+     *      <TD>extension is included</TD>
      *   <TR>
      *   <TR>
      *      <TD>3</TD>
      *      <TD>formatting run data is not included</TD>
-     *      <TD>formatting run data is included</TH>
+     *      <TD>formatting run data is included</TD>
      *   <TR>
      *   <TR>
      *      <TD>4</TD>
      *      <TD>Should always be 0</TD>
-     *      <TD>string_flag is defective</TH>
+     *      <TD>string_flag is defective</TD>
      *   <TR>
      *   <TR>
      *      <TD>5</TD>
      *      <TD>Should always be 0</TD>
-     *      <TD>string_flag is defective</TH>
+     *      <TD>string_flag is defective</TD>
      *   <TR>
      *   <TR>
      *      <TD>6</TD>
      *      <TD>Should always be 0</TD>
-     *      <TD>string_flag is defective</TH>
+     *      <TD>string_flag is defective</TD>
      *   <TR>
      *   <TR>
      *      <TD>7</TD>
      *      <TD>Should always be 0</TD>
-     *      <TD>string_flag is defective</TH>
+     *      <TD>string_flag is defective</TD>
      *   <TR>
      * </TABLE>
      * <P>
@@ -234,7 +232,7 @@ public final class SSTRecord extends ContinuableRecord {
      * associated data. The UnicodeString class can handle the byte[]
      * vs short[] nature of the actual string data
      *
-     * @param in the RecordInputstream to read the record from
+     * @param in the RecordInputStream to read the record from
      */
     public SSTRecord(RecordInputStream in) {
         // this method is ALWAYS called after construction -- using
@@ -242,7 +240,7 @@ public final class SSTRecord extends ContinuableRecord {
         // we initialize our fields
         field_1_num_strings = in.readInt();
         field_2_num_unique_strings = in.readInt();
-        field_3_strings = new IntMapper<UnicodeString>();
+        field_3_strings = new IntMapper<>();
         
         deserializer = new SSTDeserializer(field_3_strings);
         // Bug 57456: some Excel Sheets send 0 as field=1, but have some random number in field_2,
@@ -296,15 +294,17 @@ public final class SSTRecord extends ContinuableRecord {
      * @return  The new SST record.
      */
     public ExtSSTRecord createExtSSTRecord(int sstOffset) {
-        if (bucketAbsoluteOffsets == null || bucketAbsoluteOffsets == null)
+        if (bucketAbsoluteOffsets == null || bucketRelativeOffsets == null) {
             throw new IllegalStateException("SST record has not yet been serialized.");
+        }
 
         ExtSSTRecord extSST = new ExtSSTRecord();
         extSST.setNumStringsPerBucket((short)8);
         int[] absoluteOffsets = bucketAbsoluteOffsets.clone();
         int[] relativeOffsets = bucketRelativeOffsets.clone();
-        for ( int i = 0; i < absoluteOffsets.length; i++ )
+        for ( int i = 0; i < absoluteOffsets.length; i++ ) {
             absoluteOffsets[i] += sstOffset;
+        }
         extSST.setBucketOffsets(absoluteOffsets, relativeOffsets);
         return extSST;
     }
