@@ -29,11 +29,9 @@ import org.apache.poi.hssf.record.*;
 import org.apache.poi.util.HexDump;
 
 /**
- * Groups the page settings records for a worksheet.<p/>
+ * Groups the page settings records for a worksheet.<p>
  *
  * See OOO excelfileformat.pdf sec 4.4 'Page Settings Block'
- *
- * @author Josh Micich
  */
 public final class PageSettingsBlock extends RecordAggregate {
 
@@ -44,7 +42,7 @@ public final class PageSettingsBlock extends RecordAggregate {
         private static final ContinueRecord[] EMPTY_CONTINUE_RECORD_ARRAY = { };
         private final Record _pls;
         /**
-         * holds any continue records found after the PLS record.<br/>
+         * holds any continue records found after the PLS record.<br>
          * This would not be required if PLS was properly interpreted.
          * Currently, PLS is an {@link UnknownRecord} and does not automatically
          * include any trailing {@link ContinueRecord}s.
@@ -54,7 +52,7 @@ public final class PageSettingsBlock extends RecordAggregate {
         public PLSAggregate(RecordStream rs) {
             _pls = rs.getNext();
             if (rs.peekNextSid()==ContinueRecord.sid) {
-                List<ContinueRecord> temp = new ArrayList<ContinueRecord>();
+                List<ContinueRecord> temp = new ArrayList<>();
                 while (rs.peekNextSid()==ContinueRecord.sid) {
                     temp.add((ContinueRecord)rs.getNext());
                 }
@@ -68,8 +66,8 @@ public final class PageSettingsBlock extends RecordAggregate {
         @Override
         public void visitContainedRecords(RecordVisitor rv) {
             rv.visitRecord(_pls);
-            for (int i = 0; i < _plsContinues.length; i++) {
-                rv.visitRecord(_plsContinues[i]);
+            for (ContinueRecord _plsContinue : _plsContinues) {
+                rv.visitRecord(_plsContinue);
             }
         }
     }
@@ -95,11 +93,11 @@ public final class PageSettingsBlock extends RecordAggregate {
      * The indicator of such records is a non-zero GUID,
      *  see {@link  org.apache.poi.hssf.record.HeaderFooterRecord#getGuid()}
      */
-    private List<HeaderFooterRecord> _sviewHeaderFooters = new ArrayList<HeaderFooterRecord>();
+    private final List<HeaderFooterRecord> _sviewHeaderFooters = new ArrayList<>();
     private Record _printSize;
 
     public PageSettingsBlock(RecordStream rs) {
-        _plsRecords = new ArrayList<PLSAggregate>();
+        _plsRecords = new ArrayList<>();
         while(true) {
             if (!readARecord(rs)) {
                 break;
@@ -111,7 +109,7 @@ public final class PageSettingsBlock extends RecordAggregate {
      * Creates a PageSettingsBlock with default settings
      */
     public PageSettingsBlock() {
-        _plsRecords = new ArrayList<PLSAggregate>();
+        _plsRecords = new ArrayList<>();
         _rowBreaksRecord = new HorizontalPageBreakRecord();
         _columnBreaksRecord = new VerticalPageBreakRecord();
         _header = new HeaderRecord("");
@@ -122,6 +120,8 @@ public final class PageSettingsBlock extends RecordAggregate {
     }
 
     /**
+     * @param sid the record sid
+     * 
      * @return <code>true</code> if the specified Record sid is one belonging to the
      * 'Page Settings Block'.
      */
@@ -207,8 +207,9 @@ public final class PageSettingsBlock extends RecordAggregate {
             case HeaderFooterRecord.sid:
                 //there can be multiple HeaderFooterRecord records belonging to different sheet views
                 HeaderFooterRecord hf = (HeaderFooterRecord)rs.getNext();
-                if(hf.isCurrentSheet()) _headerFooter = hf;
-                else {
+                if(hf.isCurrentSheet()) {
+                    _headerFooter = hf;
+                } else {
                     _sviewHeaderFooters.add(hf);
                 }
                 break;
@@ -221,7 +222,7 @@ public final class PageSettingsBlock extends RecordAggregate {
 
     private void checkNotPresent(Record rec) {
         if (rec != null) {
-            throw new RecordFormatException("Duplicate PageSettingsBlock record (sid=0x"
+            throw new org.apache.poi.util.RecordFormatException("Duplicate PageSettingsBlock record (sid=0x"
                     + Integer.toHexString(rec.getSid()) + ")");
         }
     }
@@ -244,6 +245,9 @@ public final class PageSettingsBlock extends RecordAggregate {
     /**
      * Sets a page break at the indicated column
      *
+     * @param column the column to add page breaks to
+     * @param fromRow the starting row
+     * @param toRow the ending row
      */
     public void setColumnBreak(short column, short fromRow, short toRow) {
         getColumnBreaksRecord().addBreak(column, fromRow, toRow);
@@ -252,6 +256,7 @@ public final class PageSettingsBlock extends RecordAggregate {
     /**
      * Removes a page break at the indicated column
      *
+     * @param column the column to check for page breaks
      */
     public void removeColumnBreak(int column) {
         getColumnBreaksRecord().removeBreak(column);
@@ -260,6 +265,7 @@ public final class PageSettingsBlock extends RecordAggregate {
 
 
 
+    @Override
     public void visitContainedRecords(RecordVisitor rv) {
         // Replicates record order from Excel 2007, though this is not critical
 
@@ -476,15 +482,16 @@ public final class PageSettingsBlock extends RecordAggregate {
     private static void shiftBreaks(PageBreakRecord breaks, int start, int stop, int count) {
 
         Iterator<PageBreakRecord.Break> iterator = breaks.getBreaksIterator();
-        List<PageBreakRecord.Break> shiftedBreak = new ArrayList<PageBreakRecord.Break>();
+        List<PageBreakRecord.Break> shiftedBreak = new ArrayList<>();
         while(iterator.hasNext())
         {
             PageBreakRecord.Break breakItem = iterator.next();
             int breakLocation = breakItem.main;
             boolean inStart = (breakLocation >= start);
             boolean inEnd = (breakLocation <= stop);
-            if(inStart && inEnd)
+            if(inStart && inEnd) {
                 shiftedBreak.add(breakItem);
+            }
         }
 
         iterator = shiftedBreak.iterator();
@@ -498,7 +505,9 @@ public final class PageSettingsBlock extends RecordAggregate {
 
     /**
      * Sets a page break at the indicated row
-     * @param row
+     * @param row the row
+     * @param fromCol the starting column
+     * @param toCol the ending column
      */
     public void setRowBreak(int row, short fromCol, short toCol) {
         getRowBreaksRecord().addBreak((short)row, fromCol, toCol);
@@ -506,17 +515,20 @@ public final class PageSettingsBlock extends RecordAggregate {
 
     /**
      * Removes a page break at the indicated row
-     * @param row
+     * @param row the row
      */
     public void removeRowBreak(int row) {
-        if (getRowBreaksRecord().getBreaks().length < 1)
+        if (getRowBreaksRecord().getBreaks().length < 1) {
             throw new IllegalArgumentException("Sheet does not define any row breaks");
+        }
         getRowBreaksRecord().removeBreak((short)row);
     }
 
     /**
      * Queries if the specified row has a page break
-     * @param row
+     * 
+     * @param row the row to check for
+     * 
      * @return true if the specified row has a page break
      */
     public boolean isRowBroken(int row) {
@@ -526,6 +538,8 @@ public final class PageSettingsBlock extends RecordAggregate {
 
     /**
      * Queries if the specified column has a page break
+     * 
+     * @param column the column to check for
      *
      * @return <code>true</code> if the specified column has a page break
      */
@@ -535,9 +549,9 @@ public final class PageSettingsBlock extends RecordAggregate {
 
     /**
      * Shifts the horizontal page breaks for the indicated count
-     * @param startingRow
-     * @param endingRow
-     * @param count
+     * @param startingRow the starting row
+     * @param endingRow the ending row
+     * @param count the number of rows to shift by
      */
     public void shiftRowBreaks(int startingRow, int endingRow, int count) {
         shiftBreaks(getRowBreaksRecord(), startingRow, endingRow, count);
@@ -545,9 +559,9 @@ public final class PageSettingsBlock extends RecordAggregate {
 
     /**
      * Shifts the vertical page breaks for the indicated count
-     * @param startingCol
-     * @param endingCol
-     * @param count
+     * @param startingCol the starting column
+     * @param endingCol the ending column
+     * @param count the number of columns to shift by
      */
     public void shiftColumnBreaks(short startingCol, short endingCol, short count) {
         shiftBreaks(getColumnBreaksRecord(), startingCol, endingCol, count);
@@ -592,13 +606,15 @@ public final class PageSettingsBlock extends RecordAggregate {
     /**
      * HEADERFOOTER is new in 2007.  Some apps seem to have scattered this record long after
      * the {@link PageSettingsBlock} where it belongs.
+     * 
+     * @param rec the HeaderFooterRecord to set
      */
     public void addLateHeaderFooter(HeaderFooterRecord rec) {
         if (_headerFooter != null) {
             throw new IllegalStateException("This page settings block already has a header/footer record");
         }
         if (rec.getSid() != HeaderFooterRecord.sid) {
-            throw new RecordFormatException("Unexpected header-footer record sid: 0x" + Integer.toHexString(rec.getSid()));
+            throw new org.apache.poi.util.RecordFormatException("Unexpected header-footer record sid: 0x" + Integer.toHexString(rec.getSid()));
         }
         _headerFooter = rec;
     }
@@ -606,10 +622,11 @@ public final class PageSettingsBlock extends RecordAggregate {
     /**
      * This method reads PageSettingsBlock records from the supplied RecordStream until the first
      * non-PageSettingsBlock record is encountered.  As each record is read, it is incorporated
-     * into this PageSettingsBlock.
-     * <p/>
+     * into this PageSettingsBlock.<p>
+     * 
      * The latest Excel version seems to write the PageSettingsBlock uninterrupted. However there
      * are several examples (that Excel reads OK) where these records are not written together:
+     * 
      * <ul>
      * <li><b>HEADER_FOOTER(0x089C) after WINDOW2</b> - This record is new in 2007.  Some apps
      * seem to have scattered this record long after the PageSettingsBlock where it belongs
@@ -618,17 +635,19 @@ public final class PageSettingsBlock extends RecordAggregate {
      * This happens in the test sample file "NoGutsRecords.xls" and "WORKBOOK_in_capitals.xls"</li>
      * <li><b>Margins after DIMENSION</b> - All of PSB should be before DIMENSION. (Bug-47199)</li>
      * </ul>
+     * 
      * These were probably written by other applications (or earlier versions of Excel). It was
      * decided to not write specific code for detecting each of these cases.  POI now tolerates
      * PageSettingsBlock records scattered all over the sheet record stream, and in any order, but
-     * does not allow duplicates of any of those records.
+     * does not allow duplicates of any of those records.<p>
      *
-     * <p/>
      * <b>Note</b> - when POI writes out this PageSettingsBlock, the records will always be written
      * in one consolidated block (in the standard ordering) regardless of how scattered the records
      * were when they were originally read.
      *
-     * @throws  RecordFormatException if any PSB record encountered has the same type (sid) as
+     * @param rs the RecordStream to read from
+     * 
+     * @throws  org.apache.poi.util.RecordFormatException if any PSB record encountered has the same type (sid) as
      * a record that is already part of this PageSettingsBlock
      */
     public void addLateRecords(RecordStream rs) {
@@ -653,9 +672,9 @@ public final class PageSettingsBlock extends RecordAggregate {
     public void positionRecords(List<RecordBase> sheetRecords) {
         // Take a copy to loop over, so we can update the real one
         //  without concurrency issues
-        List<HeaderFooterRecord> hfRecordsToIterate = new ArrayList<HeaderFooterRecord>(_sviewHeaderFooters);
+        List<HeaderFooterRecord> hfRecordsToIterate = new ArrayList<>(_sviewHeaderFooters);
 
-        final Map<String, HeaderFooterRecord> hfGuidMap = new HashMap<String, HeaderFooterRecord>();
+        final Map<String, HeaderFooterRecord> hfGuidMap = new HashMap<>();
 
         for(final HeaderFooterRecord hf : hfRecordsToIterate) {
             hfGuidMap.put(HexDump.toHex(hf.getGuid()), hf);
@@ -667,6 +686,7 @@ public final class PageSettingsBlock extends RecordAggregate {
             if (rb instanceof CustomViewSettingsRecordAggregate) {
                 final CustomViewSettingsRecordAggregate cv = (CustomViewSettingsRecordAggregate) rb;
                 cv.visitContainedRecords(new RecordVisitor() {
+                    @Override
                     public void visitRecord(Record r) {
                         if (r.getSid() == UserSViewBegin.sid) {
                             String guid = HexDump.toHex(((UserSViewBegin) r).getGuid());
