@@ -17,7 +17,6 @@
 
 package org.apache.poi.hssf.usermodel;
 
-import java.text.MessageFormat;
 import java.text.ParseException;
 import java.text.SimpleDateFormat;
 import java.util.Date;
@@ -32,19 +31,20 @@ import org.apache.poi.ss.formula.ptg.NumberPtg;
 import org.apache.poi.ss.formula.ptg.Ptg;
 import org.apache.poi.ss.formula.ptg.StringPtg;
 import org.apache.poi.ss.usermodel.DataValidationConstraint;
+import org.apache.poi.util.LocaleUtil;
 
 /**
  * Data Validation Constraint
  */
 public class DVConstraint implements DataValidationConstraint {
-	/* package */ public static final class FormulaPair {
+	/* package */ static final class FormulaPair {
 
 		private final Ptg[] _formula1;
 		private final Ptg[] _formula2;
 
-		public FormulaPair(Ptg[] formula1, Ptg[] formula2) {
-			_formula1 = formula1;
-			_formula2 = formula2;
+		FormulaPair(Ptg[] formula1, Ptg[] formula2) {
+			_formula1 = (formula1 == null) ? null : formula1.clone();
+			_formula2 = (formula2 == null) ? null : formula2.clone();
 		}
 		public Ptg[] getFormula1() {
 			return _formula1;
@@ -55,10 +55,6 @@ public class DVConstraint implements DataValidationConstraint {
 		
 	}
 	
-	// convenient access to ValidationType namespace
-	private static final ValidationType VT = null;
-
-	
 	private final int _validationType;
 	private int _operator;
 	private String[] _explicitListValues;
@@ -70,23 +66,23 @@ public class DVConstraint implements DataValidationConstraint {
 
 	
 	private DVConstraint(int validationType, int comparisonOperator, String formulaA,
-			String formulaB, Double value1, Double value2, String[] excplicitListValues) {
+			String formulaB, Double value1, Double value2, String[] explicitListValues) {
 		_validationType = validationType;
 		_operator = comparisonOperator;
 		_formula1 = formulaA;
 		_formula2 = formulaB;
 		_value1 = value1;
 		_value2 = value2;
-		_explicitListValues = excplicitListValues;
+		_explicitListValues = (explicitListValues == null) ? null : explicitListValues.clone();
 	}
 	
 	
 	/**
 	 * Creates a list constraint
 	 */
-	private DVConstraint(String listFormula, String[] excplicitListValues) {
+	private DVConstraint(String listFormula, String[] explicitListValues) {
 		this(ValidationType.LIST, OperatorType.IGNORED,
-			listFormula, null, null, null, excplicitListValues);
+			listFormula, null, null, null, explicitListValues);
 	}
 
 	/**
@@ -184,7 +180,11 @@ public class DVConstraint implements DataValidationConstraint {
 			throw new IllegalArgumentException("expr1 must be supplied");
 		}
 		OperatorType.validateSecondArg(comparisonOperator, expr2);
-		SimpleDateFormat df = dateFormat == null ? null : new SimpleDateFormat(dateFormat);
+		SimpleDateFormat df = null;
+		if (dateFormat != null) {
+		    df = new SimpleDateFormat(dateFormat, LocaleUtil.getUserLocale());
+		    df.setTimeZone(LocaleUtil.getUserTimeZone());
+		}
 		
 		// formula1 and value1 are mutually exclusive
 		String formula1 = getFormulaFromTextExpression(expr1);
@@ -228,7 +228,7 @@ public class DVConstraint implements DataValidationConstraint {
 			return null;
 		}
 		try {
-			return new Double(numberStr);
+			return Double.valueOf(numberStr);
 		} catch (NumberFormatException e) {
 			throw new RuntimeException("The supplied text '" + numberStr 
 					+ "' could not be parsed as a number");
@@ -242,7 +242,7 @@ public class DVConstraint implements DataValidationConstraint {
 		if (timeStr == null) {
 			return null;
 		}
-		return new Double(HSSFDateUtil.convertTime(timeStr));
+		return Double.valueOf(HSSFDateUtil.convertTime(timeStr));
 	}
 	/**
 	 * @param dateFormat pass <code>null</code> for default YYYYMMDD
@@ -263,7 +263,7 @@ public class DVConstraint implements DataValidationConstraint {
 						+ "' using specified format '" + dateFormat + "'", e);
 			}
 		}
-		return new Double(HSSFDateUtil.getExcelDate(dateVal));
+		return Double.valueOf(HSSFDateUtil.getExcelDate(dateVal));
 	}
 
 	public static DVConstraint createCustomFormulaConstraint(String formula) {
@@ -363,7 +363,7 @@ public class DVConstraint implements DataValidationConstraint {
 	 */
 	public void setValue1(double value1) {
 		_formula1 = null;
-		_value1 = new Double(value1);
+		_value1 = Double.valueOf(value1);
 	}
 
 	/**
@@ -377,7 +377,7 @@ public class DVConstraint implements DataValidationConstraint {
 	 */
 	public void setValue2(double value2) {
 		_formula2 = null;
-		_value2 = new Double(value2);
+		_value2 = Double.valueOf(value2);
 	}
 	
 	/**
@@ -396,7 +396,8 @@ public class DVConstraint implements DataValidationConstraint {
 		return new FormulaPair(formula1, formula2);
 	}
 
-	private Ptg[] createListFormula(HSSFSheet sheet) {
+    @SuppressWarnings("resource")
+    private Ptg[] createListFormula(HSSFSheet sheet) {
 
 		if (_explicitListValues == null) {
             HSSFWorkbook wb = sheet.getWorkbook();
@@ -406,7 +407,7 @@ public class DVConstraint implements DataValidationConstraint {
 			// Some things like union and intersection are not allowed.
 		}
 		// explicit list was provided
-		StringBuffer sb = new StringBuffer(_explicitListValues.length * 16);
+		StringBuilder sb = new StringBuilder(_explicitListValues.length * 16);
 		for (int i = 0; i < _explicitListValues.length; i++) {
 			if (i > 0) {
 				sb.append('\0'); // list delimiter is the nul char
@@ -421,6 +422,7 @@ public class DVConstraint implements DataValidationConstraint {
 	 * @return The parsed token array representing the formula or value specified. 
 	 * Empty array if both formula and value are <code>null</code>
 	 */
+    @SuppressWarnings("resource")
 	private static Ptg[] convertDoubleFormula(String formula, Double value, HSSFSheet sheet) {
 		if (formula == null) {
 			if (value == null) {
@@ -466,7 +468,7 @@ public class DVConstraint implements DataValidationConstraint {
         case ValidationType.FORMULA:
             return createCustomFormulaConstraint(toFormulaString(dvRecord.getFormula1(), book).string());
         default:
-            throw new UnsupportedOperationException(MessageFormat.format("validationType={0}", dvRecord.getDataType()));
+            throw new UnsupportedOperationException("validationType="+dvRecord.getDataType());
         }
     }
 
@@ -482,7 +484,7 @@ public class DVConstraint implements DataValidationConstraint {
             if (_value == null) {
                 return null;
             }
-            return new Double(_value);
+            return Double.valueOf(_value);
         }
 
         public String string() {
