@@ -89,7 +89,7 @@ public final class EscherGraphics2d extends Graphics2D {
         setColor(Color.black);
     }
 
-    public void addRenderingHints(Map map)
+    public void addRenderingHints(Map<?, ?> map)
     {
         getG2D().addRenderingHints(map);
     }
@@ -127,8 +127,7 @@ public final class EscherGraphics2d extends Graphics2D {
 
     public Graphics create()
     {
-        EscherGraphics2d g2d = new EscherGraphics2d(_escherGraphics);
-        return g2d;
+        return new EscherGraphics2d(_escherGraphics);
     }
 
     public void dispose()
@@ -380,7 +379,8 @@ public final class EscherGraphics2d extends Graphics2D {
     public Rectangle getClipBounds()
     {
         if(getDeviceclip() != null) {
-            return getClip().getBounds();
+            final Shape clip = getClip();
+            return clip != null ? clip.getBounds() : null;
         }
         return null;
     }
@@ -514,7 +514,7 @@ public final class EscherGraphics2d extends Graphics2D {
         getG2D().setRenderingHint(key, obj);
     }
 
-    public void setRenderingHints(Map map)
+    public void setRenderingHints(Map<?, ?> map)
     {
         getG2D().setRenderingHints(map);
     }
