@@ -17,7 +17,6 @@
 
 package org.apache.poi.hssf.usermodel;
 
-import java.text.DateFormat;
 import java.text.SimpleDateFormat;
 import java.util.Calendar;
 import java.util.Date;
@@ -45,15 +44,17 @@ import org.apache.poi.ss.formula.ptg.ExpPtg;
 import org.apache.poi.ss.formula.ptg.Ptg;
 import org.apache.poi.ss.usermodel.Cell;
 import org.apache.poi.ss.usermodel.CellStyle;
+import org.apache.poi.ss.usermodel.CellType;
 import org.apache.poi.ss.usermodel.Comment;
 import org.apache.poi.ss.usermodel.FormulaError;
 import org.apache.poi.ss.usermodel.Hyperlink;
 import org.apache.poi.ss.usermodel.RichTextString;
+import org.apache.poi.ss.util.CellAddress;
 import org.apache.poi.ss.util.CellRangeAddress;
 import org.apache.poi.ss.util.CellReference;
 import org.apache.poi.ss.util.NumberToTextConverter;
-import org.apache.poi.util.POILogFactory;
-import org.apache.poi.util.POILogger;
+import org.apache.poi.util.LocaleUtil;
+import org.apache.poi.util.Removal;
 
 /**
  * High level representation of a cell in a row of a spreadsheet.
@@ -68,8 +69,6 @@ import org.apache.poi.util.POILogger;
  * <p>
  */
 public class HSSFCell implements Cell {
-    private static POILogger log = POILogFactory.getLogger(HSSFCell.class);
-
     private static final String FILE_FORMAT_NAME  = "BIFF8";
     /**
      * The maximum  number of columns in BIFF8
@@ -83,7 +82,7 @@ public class HSSFCell implements Cell {
 
     private final HSSFWorkbook       _book;
     private final HSSFSheet          _sheet;
-    private int                      _cellType;
+    private CellType                 _cellType;
     private HSSFRichTextString       _stringValue;
     private CellValueRecordInterface _record;
     private HSSFComment              _comment;
@@ -92,7 +91,7 @@ public class HSSFCell implements Cell {
      * Creates new Cell - Should only be called by HSSFRow.  This creates a cell
      * from scratch.
      * <p>
-     * When the cell is initially created it is set to CELL_TYPE_BLANK. Cell types
+     * When the cell is initially created it is set to {@link CellType#BLANK}. Cell types
      * can be changed/overwritten by calling setCellValue with the appropriate
      * type as a parameter although conversions from one type to another may be
      * prohibited.
@@ -102,7 +101,7 @@ public class HSSFCell implements Cell {
      * @param row   - the row of this cell
      * @param col   - the column for this cell
      *
-     * @see org.apache.poi.hssf.usermodel.HSSFRow#createCell(short)
+     * @see org.apache.poi.hssf.usermodel.HSSFRow#createCell(int)
      */
     protected HSSFCell(HSSFWorkbook book, HSSFSheet sheet, int row, short col)
     {
@@ -112,10 +111,10 @@ public class HSSFCell implements Cell {
         _sheet   = sheet;
 
         // Relying on the fact that by default the cellType is set to 0 which
-        // is different to CELL_TYPE_BLANK hence the following method call correctly
+        // is different to {@link CellType#BLANK} hence the following method call correctly
         // creates a new blank cell.
         short xfindex = sheet.getSheet().getXFIndexForColAt(col);
-        setCellType(CELL_TYPE_BLANK, false, row, col,xfindex);
+        setCellType(CellType.BLANK, false, row, col,xfindex);
     }
 
     /**
@@ -145,16 +144,14 @@ public class HSSFCell implements Cell {
      * @param sheet - Sheet record of the sheet containing this cell
      * @param row   - the row of this cell
      * @param col   - the column for this cell
-     * @param type  - CELL_TYPE_NUMERIC, CELL_TYPE_STRING, CELL_TYPE_FORMULA, CELL_TYPE_BLANK,
-     *                CELL_TYPE_BOOLEAN, CELL_TYPE_ERROR
-     *                Type of cell
-     * @see org.apache.poi.hssf.usermodel.HSSFRow#createCell(short,int)
+     * @param type  - Type of cell
+     * @see org.apache.poi.hssf.usermodel.HSSFRow#createCell(int,CellType)
      */
     protected HSSFCell(HSSFWorkbook book, HSSFSheet sheet, int row, short col,
-                       int type)
+                       CellType type)
     {
         checkBounds(col);
-        _cellType     = -1; // Force 'setCellType' to create a first Record
+        _cellType     = CellType._NONE; // Force 'setCellType' to create a first Record
         _stringValue  = null;
         _book    = book;
         _sheet   = sheet;
@@ -179,16 +176,19 @@ public class HSSFCell implements Cell {
         _sheet  = sheet;
         switch (_cellType)
         {
-            case CELL_TYPE_STRING :
+            case STRING :
                 _stringValue = new HSSFRichTextString(book.getWorkbook(), (LabelSSTRecord ) cval);
                 break;
 
-            case CELL_TYPE_BLANK :
+            case BLANK :
                 break;
 
-            case CELL_TYPE_FORMULA :
+            case FORMULA :
                 _stringValue=new HSSFRichTextString(((FormulaRecordAggregate) cval).getStringValue());
                 break;
+
+            default :
+                break;
         }
     }
 
@@ -196,23 +196,23 @@ public class HSSFCell implements Cell {
     /**
      * used internally -- given a cell value record, figure out its type
      */
-    private static int determineType(CellValueRecordInterface cval) {
+    private static CellType determineType(CellValueRecordInterface cval) {
         if (cval instanceof FormulaRecordAggregate) {
-            return HSSFCell.CELL_TYPE_FORMULA;
+            return CellType.FORMULA;
         }
         // all others are plain BIFF records
         Record record = ( Record ) cval;
         switch (record.getSid()) {
 
-            case NumberRecord.sid :   return HSSFCell.CELL_TYPE_NUMERIC;
-            case BlankRecord.sid :    return HSSFCell.CELL_TYPE_BLANK;
-            case LabelSSTRecord.sid : return HSSFCell.CELL_TYPE_STRING;
+            case NumberRecord.sid :   return CellType.NUMERIC;
+            case BlankRecord.sid :    return CellType.BLANK;
+            case LabelSSTRecord.sid : return CellType.STRING;
             case BoolErrRecord.sid :
                 BoolErrRecord boolErrRecord = ( BoolErrRecord ) record;
 
                 return boolErrRecord.isBoolean()
-                         ? HSSFCell.CELL_TYPE_BOOLEAN
-                         : HSSFCell.CELL_TYPE_ERROR;
+                         ? CellType.BOOLEAN
+                         : CellType.ERROR;
         }
         throw new RuntimeException("Bad cell value rec (" + cval.getClass().getName() + ")");
     }
@@ -227,18 +227,10 @@ public class HSSFCell implements Cell {
     /**
      * @return the (zero based) index of the row containing this cell
      */
+    @Override
     public int getRowIndex() {
         return _record.getRow();
     }
-    /**
-     * Set the cell's number within the row (0 based).
-     * @param num  short the cell number
-     * @deprecated (Jan 2008) Doesn't update the row's idea of what cell this is, use {@link HSSFRow#moveCell(HSSFCell, short)} instead
-     */
-    public void setCellNum(short num)
-    {
-        _record.setColumn(num);
-    }
 
     /**
      * Updates the cell record's idea of what
@@ -250,29 +242,26 @@ public class HSSFCell implements Cell {
         _record.setColumn(num);
     }
 
-    /**
-     * @deprecated (Oct 2008) use {@link #getColumnIndex()}
-     */
-    public short getCellNum() {
-        return (short) getColumnIndex();
-    }
-
+    @Override
     public int getColumnIndex() {
         return _record.getColumn() & 0xFFFF;
     }
 
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public CellAddress getAddress() {
+        return new CellAddress(this);
+    }
+    
     /**
      * Set the cells type (numeric, formula or string).
      * If the cell currently contains a value, the value will
      *  be converted to match the new type, if possible.
-     * @see #CELL_TYPE_NUMERIC
-     * @see #CELL_TYPE_STRING
-     * @see #CELL_TYPE_FORMULA
-     * @see #CELL_TYPE_BLANK
-     * @see #CELL_TYPE_BOOLEAN
-     * @see #CELL_TYPE_ERROR
      */
-    public void setCellType(int cellType) {
+    @Override
+    public void setCellType(CellType cellType) {
         notifyFormulaChanging();
         if(isPartOfArrayFormulaGroup()){
             notifyArrayFormulaChanging();
@@ -292,17 +281,12 @@ public class HSSFCell implements Cell {
      *
      */
 
-    private void setCellType(int cellType, boolean setValue, int row,short col, short styleIndex)
+    private void setCellType(CellType cellType, boolean setValue, int row,short col, short styleIndex)
     {
-
-        if (cellType > CELL_TYPE_ERROR)
-        {
-            throw new RuntimeException("I have no idea what type that is!");
-        }
         switch (cellType)
         {
 
-            case CELL_TYPE_FORMULA :
+            case FORMULA :
                 FormulaRecordAggregate frec;
 
                 if (cellType != _cellType) {
@@ -320,8 +304,8 @@ public class HSSFCell implements Cell {
                 _record = frec;
                 break;
 
-            case CELL_TYPE_NUMERIC :
-                NumberRecord nrec = null;
+            case NUMERIC :
+                NumberRecord nrec;
 
                 if (cellType != _cellType)
                 {
@@ -341,7 +325,7 @@ public class HSSFCell implements Cell {
                 _record = nrec;
                 break;
 
-            case CELL_TYPE_STRING :
+            case STRING :
                 LabelSSTRecord lrec;
 
                 if (cellType == _cellType) {
@@ -354,17 +338,24 @@ public class HSSFCell implements Cell {
                 }
                 if (setValue) {
                     String str = convertCellValueToString();
-                    int sstIndex = _book.getWorkbook().addSSTString(new UnicodeString(str));
-                    lrec.setSSTIndex(sstIndex);
-                    UnicodeString us = _book.getWorkbook().getSSTString(sstIndex);
-                    _stringValue = new HSSFRichTextString();
-                    _stringValue.setUnicodeString(us);
+                    if(str == null) {
+                        // bug 55668: don't try to store null-string when formula
+                        // results in empty/null value
+                        setCellType(CellType.BLANK, false, row, col, styleIndex);
+                        return;
+                    } else {
+                        int sstIndex = _book.getWorkbook().addSSTString(new UnicodeString(str));
+                        lrec.setSSTIndex(sstIndex);
+                        UnicodeString us = _book.getWorkbook().getSSTString(sstIndex);
+                        _stringValue = new HSSFRichTextString();
+                        _stringValue.setUnicodeString(us);
+                    }
                 }
                 _record = lrec;
                 break;
 
-            case CELL_TYPE_BLANK :
-                BlankRecord brec = null;
+            case BLANK :
+                BlankRecord brec;
 
                 if (cellType != _cellType)
                 {
@@ -382,8 +373,8 @@ public class HSSFCell implements Cell {
                 _record = brec;
                 break;
 
-            case CELL_TYPE_BOOLEAN :
-                BoolErrRecord boolRec = null;
+            case BOOLEAN :
+                BoolErrRecord boolRec;
 
                 if (cellType != _cellType)
                 {
@@ -403,8 +394,8 @@ public class HSSFCell implements Cell {
                 _record = boolRec;
                 break;
 
-            case CELL_TYPE_ERROR :
-                BoolErrRecord errRec = null;
+            case ERROR :
+                BoolErrRecord errRec;
 
                 if (cellType != _cellType)
                 {
@@ -417,15 +408,17 @@ public class HSSFCell implements Cell {
                 errRec.setColumn(col);
                 if (setValue)
                 {
-                    errRec.setValue((byte)HSSFErrorConstants.ERROR_VALUE);
+                    errRec.setValue(FormulaError.VALUE.getCode());
                 }
                 errRec.setXFIndex(styleIndex);
                 errRec.setRow(row);
                 _record = errRec;
                 break;
+            default :
+                throw new IllegalStateException("Invalid cell type: " + cellType);
         }
         if (cellType != _cellType &&
-            _cellType!=-1 )  // Special Value to indicate an uninitialized Cell
+            _cellType != CellType._NONE )  // Special Value to indicate an uninitialized Cell
         {
             _sheet.getSheet().replaceValueRecord(_record);
         }
@@ -434,17 +427,24 @@ public class HSSFCell implements Cell {
 
     /**
      * get the cells type (numeric, formula or string)
-     * @see #CELL_TYPE_STRING
-     * @see #CELL_TYPE_NUMERIC
-     * @see #CELL_TYPE_FORMULA
-     * @see #CELL_TYPE_BOOLEAN
-     * @see #CELL_TYPE_ERROR
      */
-
-    public int getCellType()
+    @Override
+    public CellType getCellType()
     {
         return _cellType;
     }
+    
+    /**
+     * get the cells type (numeric, formula or string)
+     * @since POI 3.15 beta 3
+     */
+    @Deprecated
+    @Removal(version = "4.2")
+    @Override
+    public CellType getCellTypeEnum()
+    {
+        return getCellType();
+    }
 
     /**
      * set a numeric value for the cell
@@ -453,6 +453,8 @@ public class HSSFCell implements Cell {
      *        precalculated value, for numerics we'll set its value. For other types we
      *        will change the cell to a numeric cell and set its value.
      */
+    @SuppressWarnings("fallthrough")
+    @Override
     public void setCellValue(double value) {
         if(Double.isInfinite(value)) {
             // Excel does not support positive/negative infinities,
@@ -469,11 +471,12 @@ public class HSSFCell implements Cell {
 
             switch (_cellType) {
                 default:
-                    setCellType(CELL_TYPE_NUMERIC, false, row, col, styleIndex);
-                case CELL_TYPE_NUMERIC:
+                    setCellType(CellType.NUMERIC, false, row, col, styleIndex);
+                    // fall through
+                case NUMERIC:
                     (( NumberRecord ) _record).setValue(value);
                     break;
-                case CELL_TYPE_FORMULA:
+                case FORMULA:
                     ((FormulaRecordAggregate)_record).setCachedDoubleResult(value);
                     break;
             }
@@ -544,7 +547,7 @@ public class HSSFCell implements Cell {
         if (value == null)
         {
             notifyFormulaChanging();
-            setCellType(CELL_TYPE_BLANK, false, row, col, styleIndex);
+            setCellType(CellType.BLANK, false, row, col, styleIndex);
             return;
         }
 
@@ -552,7 +555,7 @@ public class HSSFCell implements Cell {
             throw new IllegalArgumentException("The maximum length of cell contents (text) is 32,767 characters");
         }
 
-        if (_cellType == CELL_TYPE_FORMULA) {
+        if (_cellType == CellType.FORMULA) {
             // Set the 'pre-evaluated result' for the formula
             // note - formulas do not preserve text formatting.
             FormulaRecordAggregate fr = (FormulaRecordAggregate) _record;
@@ -567,10 +570,10 @@ public class HSSFCell implements Cell {
         // If we get here, we're not dealing with a formula,
         //  so handle things as a normal rich text cell
 
-        if (_cellType != CELL_TYPE_STRING) {
-            setCellType(CELL_TYPE_STRING, false, row, col, styleIndex);
+        if (_cellType != CellType.STRING) {
+            setCellType(CellType.STRING, false, row, col, styleIndex);
         }
-        int index = 0;
+        int index;
 
         HSSFRichTextString hvalue = (HSSFRichTextString) value;
         UnicodeString str = hvalue.getUnicodeString();
@@ -592,12 +595,12 @@ public class HSSFCell implements Cell {
 
         if (formula==null) {
             notifyFormulaChanging();
-            setCellType(CELL_TYPE_BLANK, false, row, col, styleIndex);
+            setCellType(CellType.BLANK, false, row, col, styleIndex);
             return;
         }
         int sheetIndex = _book.getSheetIndex(_sheet);
         Ptg[] ptgs = HSSFFormulaParser.parse(formula, _book, FormulaType.CELL, sheetIndex);
-        setCellType(CELL_TYPE_FORMULA, false, row, col, styleIndex);
+        setCellType(CellType.FORMULA, false, row, col, styleIndex);
         FormulaRecordAggregate agg = (FormulaRecordAggregate) _record;
         FormulaRecord frec = agg.getFormulaRecord();
         frec.setOptions((short) 2);
@@ -621,34 +624,18 @@ public class HSSFCell implements Cell {
 
     public String getCellFormula() {
         if (!(_record instanceof FormulaRecordAggregate)) {
-            throw typeMismatch(CELL_TYPE_FORMULA, _cellType, true);
+            throw typeMismatch(CellType.FORMULA, _cellType, true);
         }
         return HSSFFormulaParser.toFormulaString(_book, ((FormulaRecordAggregate)_record).getFormulaTokens());
     }
 
-    /**
-     * Used to help format error messages
-     */
-    private static String getCellTypeName(int cellTypeCode) {
-        switch (cellTypeCode) {
-            case CELL_TYPE_BLANK:   return "blank";
-            case CELL_TYPE_STRING:  return "text";
-            case CELL_TYPE_BOOLEAN: return "boolean";
-            case CELL_TYPE_ERROR:   return "error";
-            case CELL_TYPE_NUMERIC: return "numeric";
-            case CELL_TYPE_FORMULA: return "formula";
-        }
-        return "#unknown cell type (" + cellTypeCode + ")#";
-    }
-
-    private static RuntimeException typeMismatch(int expectedTypeCode, int actualTypeCode, boolean isFormulaCell) {
-        String msg = "Cannot get a "
-            + getCellTypeName(expectedTypeCode) + " value from a "
-            + getCellTypeName(actualTypeCode) + " " + (isFormulaCell ? "formula " : "") + "cell";
+    private static RuntimeException typeMismatch(CellType expectedTypeCode, CellType actualTypeCode, boolean isFormulaCell) {
+        String msg = "Cannot get a " + expectedTypeCode + " value from a " + actualTypeCode
+            + " " + (isFormulaCell ? "formula " : "") + "cell";
         return new IllegalStateException(msg);
     }
-    private static void checkFormulaCachedValueType(int expectedTypeCode, FormulaRecord fr) {
-        int cachedValueType = fr.getCachedResultType();
+    private static void checkFormulaCachedValueType(CellType expectedTypeCode, FormulaRecord fr) {
+        CellType cachedValueType = CellType.forInt(fr.getCachedResultType());
         if (cachedValueType != expectedTypeCode) {
             throw typeMismatch(expectedTypeCode, cachedValueType, true);
         }
@@ -665,17 +652,17 @@ public class HSSFCell implements Cell {
     public double getNumericCellValue() {
 
         switch(_cellType) {
-            case CELL_TYPE_BLANK:
+            case BLANK:
                 return 0.0;
-            case CELL_TYPE_NUMERIC:
+            case NUMERIC:
                 return ((NumberRecord)_record).getValue();
             default:
-                throw typeMismatch(CELL_TYPE_NUMERIC, _cellType, false);
-            case CELL_TYPE_FORMULA:
+                throw typeMismatch(CellType.NUMERIC, _cellType, false);
+            case FORMULA:
                 break;
         }
         FormulaRecord fr = ((FormulaRecordAggregate)_record).getFormulaRecord();
-        checkFormulaCachedValueType(CELL_TYPE_NUMERIC, fr);
+        checkFormulaCachedValueType(CellType.NUMERIC, fr);
         return fr.getValue();
     }
 
@@ -688,7 +675,7 @@ public class HSSFCell implements Cell {
      */
     public Date getDateCellValue() {
 
-        if (_cellType == CELL_TYPE_BLANK) {
+        if (_cellType == CellType.BLANK) {
             return null;
         }
         double value = getNumericCellValue();
@@ -717,17 +704,17 @@ public class HSSFCell implements Cell {
     public HSSFRichTextString getRichStringCellValue() {
 
         switch(_cellType) {
-            case CELL_TYPE_BLANK:
+            case BLANK:
                 return new HSSFRichTextString("");
-            case CELL_TYPE_STRING:
+            case STRING:
                 return _stringValue;
             default:
-                throw typeMismatch(CELL_TYPE_STRING, _cellType, false);
-            case CELL_TYPE_FORMULA:
+                throw typeMismatch(CellType.STRING, _cellType, false);
+            case FORMULA:
                 break;
         }
         FormulaRecordAggregate fra = ((FormulaRecordAggregate)_record);
-        checkFormulaCachedValueType(CELL_TYPE_STRING, fra.getFormulaRecord());
+        checkFormulaCachedValueType(CellType.STRING, fra.getFormulaRecord());
         String strVal = fra.getStringValue();
         return new HSSFRichTextString(strVal == null ? "" : strVal);
     }
@@ -739,6 +726,7 @@ public class HSSFCell implements Cell {
      *        precalculated value, for booleans we'll set its value. For other types we
      *        will change the cell to a boolean cell and set its value.
      */
+    @SuppressWarnings("fallthrough")
     public void setCellValue(boolean value) {
         int row=_record.getRow();
         short col=_record.getColumn();
@@ -746,11 +734,12 @@ public class HSSFCell implements Cell {
 
         switch (_cellType) {
             default:
-                setCellType(CELL_TYPE_BOOLEAN, false, row, col, styleIndex);
-            case CELL_TYPE_BOOLEAN:
+                setCellType(CellType.BOOLEAN, false, row, col, styleIndex);
+                // fall through
+            case BOOLEAN:
                 (( BoolErrRecord ) _record).setValue(value);
                 break;
-            case CELL_TYPE_FORMULA:
+            case FORMULA:
                 ((FormulaRecordAggregate)_record).setCachedBooleanResult(value);
                 break;
         }
@@ -763,24 +752,42 @@ public class HSSFCell implements Cell {
      *        precalculated value , for errors we'll set
      *        its value. For other types we will change the cell to an error
      *        cell and set its value.
+     *        For error code byte, see {@link FormulaError}.
+     * @deprecated 3.15 beta 2. Use {@link #setCellErrorValue(FormulaError)} instead.
      */
     public void setCellErrorValue(byte errorCode) {
+        FormulaError error = FormulaError.forInt(errorCode);
+        setCellErrorValue(error);
+    }
+    /**
+     * set a error value for the cell
+     *
+     * @param error the error value to set this cell to.  For formulas we'll set the
+     *        precalculated value , for errors we'll set
+     *        its value. For other types we will change the cell to an error
+     *        cell and set its value.
+     */
+    @SuppressWarnings("fallthrough")
+    public void setCellErrorValue(FormulaError error) {
         int row=_record.getRow();
         short col=_record.getColumn();
         short styleIndex=_record.getXFIndex();
         switch (_cellType) {
             default:
-                setCellType(CELL_TYPE_ERROR, false, row, col, styleIndex);
-            case CELL_TYPE_ERROR:
-                (( BoolErrRecord ) _record).setValue(errorCode);
+                setCellType(CellType.ERROR, false, row, col, styleIndex);
+                // fall through
+            case ERROR:
+                (( BoolErrRecord ) _record).setValue(error);
                 break;
-            case CELL_TYPE_FORMULA:
-                ((FormulaRecordAggregate)_record).setCachedErrorResult(errorCode);
+            case FORMULA:
+                ((FormulaRecordAggregate)_record).setCachedErrorResult(error.getCode());
                 break;
         }
     }
+
+
     /**
-     * Chooses a new boolean value for the cell when its type is changing.<p/>
+     * Chooses a new boolean value for the cell when its type is changing.<p>
      *
      * Usually the caller is calling setCellType() with the intention of calling
      * setCellValue(boolean) straight afterwards.  This method only exists to give
@@ -790,24 +797,24 @@ public class HSSFCell implements Cell {
     private boolean convertCellValueToBoolean() {
 
         switch (_cellType) {
-            case CELL_TYPE_BOOLEAN:
+            case BOOLEAN:
                 return (( BoolErrRecord ) _record).getBooleanValue();
-            case CELL_TYPE_STRING:
+            case STRING:
                 int sstIndex = ((LabelSSTRecord)_record).getSSTIndex();
                 String text = _book.getWorkbook().getSSTString(sstIndex).getString();
                 return Boolean.valueOf(text).booleanValue();
-            case CELL_TYPE_NUMERIC:
+            case NUMERIC:
                 return ((NumberRecord)_record).getValue() != 0;
 
-            case CELL_TYPE_FORMULA:
+            case FORMULA:
                 // use cached formula result if it's the right type:
                 FormulaRecord fr = ((FormulaRecordAggregate)_record).getFormulaRecord();
-                checkFormulaCachedValueType(CELL_TYPE_BOOLEAN, fr);
+                checkFormulaCachedValueType(CellType.BOOLEAN, fr);
                 return fr.getCachedBooleanValue();
             // Other cases convert to false
             // These choices are not well justified.
-            case CELL_TYPE_ERROR:
-            case CELL_TYPE_BLANK:
+            case ERROR:
+            case BLANK:
                 return false;
         }
         throw new RuntimeException("Unexpected cell type (" + _cellType + ")");
@@ -815,18 +822,18 @@ public class HSSFCell implements Cell {
     private String convertCellValueToString() {
 
         switch (_cellType) {
-            case CELL_TYPE_BLANK:
+            case BLANK:
                 return "";
-            case CELL_TYPE_BOOLEAN:
+            case BOOLEAN:
                 return ((BoolErrRecord) _record).getBooleanValue() ? "TRUE" : "FALSE";
-            case CELL_TYPE_STRING:
+            case STRING:
                 int sstIndex = ((LabelSSTRecord)_record).getSSTIndex();
                 return _book.getWorkbook().getSSTString(sstIndex).getString();
-            case CELL_TYPE_NUMERIC:
+            case NUMERIC:
                 return NumberToTextConverter.toText(((NumberRecord)_record).getValue());
-            case CELL_TYPE_ERROR:
-                   return HSSFErrorConstants.getText(((BoolErrRecord) _record).getErrorValue());
-            case CELL_TYPE_FORMULA:
+            case ERROR:
+                   return FormulaError.forInt(((BoolErrRecord)_record).getErrorValue()).getString();
+            case FORMULA:
                 // should really evaluate, but HSSFCell can't call HSSFFormulaEvaluator
                 // just use cached formula result instead
                 break;
@@ -835,37 +842,40 @@ public class HSSFCell implements Cell {
         }
         FormulaRecordAggregate fra = ((FormulaRecordAggregate)_record);
         FormulaRecord fr = fra.getFormulaRecord();
-        switch (fr.getCachedResultType()) {
-            case CELL_TYPE_BOOLEAN:
+        switch (CellType.forInt(fr.getCachedResultType())) {
+            case BOOLEAN:
                 return fr.getCachedBooleanValue() ? "TRUE" : "FALSE";
-            case CELL_TYPE_STRING:
+            case STRING:
                 return fra.getStringValue();
-            case CELL_TYPE_NUMERIC:
+            case NUMERIC:
                 return NumberToTextConverter.toText(fr.getValue());
-            case CELL_TYPE_ERROR:
-                   return HSSFErrorConstants.getText(fr.getCachedErrorValue());
+            case ERROR:
+                return FormulaError.forInt(fr.getCachedErrorValue()).getString();
+            default:
+                throw new IllegalStateException("Unexpected formula result type (" + _cellType + ")");
         }
-        throw new IllegalStateException("Unexpected formula result type (" + _cellType + ")");
+        
     }
 
     /**
      * get the value of the cell as a boolean.  For strings, numbers, and errors, we throw an exception.
      * For blank cells we return a false.
      */
+    @Override
     public boolean getBooleanCellValue() {
 
         switch(_cellType) {
-            case CELL_TYPE_BLANK:
+            case BLANK:
                 return false;
-            case CELL_TYPE_BOOLEAN:
+            case BOOLEAN:
                 return (( BoolErrRecord ) _record).getBooleanValue();
-            default:
-                throw typeMismatch(CELL_TYPE_BOOLEAN, _cellType, false);
-            case CELL_TYPE_FORMULA:
+            case FORMULA:
                 break;
+            default:
+                throw typeMismatch(CellType.BOOLEAN, _cellType, false);
         }
         FormulaRecord fr = ((FormulaRecordAggregate)_record).getFormulaRecord();
-        checkFormulaCachedValueType(CELL_TYPE_BOOLEAN, fr);
+        checkFormulaCachedValueType(CellType.BOOLEAN, fr);
         return fr.getCachedBooleanValue();
     }
 
@@ -873,27 +883,30 @@ public class HSSFCell implements Cell {
      * get the value of the cell as an error code.  For strings, numbers, and booleans, we throw an exception.
      * For blank cells we return a 0.
      */
+    @Override
     public byte getErrorCellValue() {
         switch(_cellType) {
-            case CELL_TYPE_ERROR:
+            case ERROR:
                 return (( BoolErrRecord ) _record).getErrorValue();
+            case FORMULA:
+                FormulaRecord fr = ((FormulaRecordAggregate)_record).getFormulaRecord();
+                checkFormulaCachedValueType(CellType.ERROR, fr);
+                return (byte) fr.getCachedErrorValue();
             default:
-                throw typeMismatch(CELL_TYPE_ERROR, _cellType, false);
-            case CELL_TYPE_FORMULA:
-                break;
+                throw typeMismatch(CellType.ERROR, _cellType, false);
         }
-        FormulaRecord fr = ((FormulaRecordAggregate)_record).getFormulaRecord();
-        checkFormulaCachedValueType(CELL_TYPE_ERROR, fr);
-        return (byte) fr.getCachedErrorValue();
     }
 
     /**
-     * set the style for the cell.  The style should be an HSSFCellStyle created/retreived from
-     * the HSSFWorkbook.
+     * <p>Set the style for the cell.  The style should be an HSSFCellStyle created/retreived from
+     * the HSSFWorkbook.</p>
+     * 
+     * <p>To change the style of a cell without affecting other cells that use the same style,
+     * use {@link org.apache.poi.ss.util.CellUtil#setCellStyleProperties(org.apache.poi.ss.usermodel.Cell, java.util.Map)}</p>
      *
      * @param style  reference contained in the workbook
      * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#createCellStyle()
-     * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#getCellStyleAt(short)
+     * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#getCellStyleAt(int)
      */
     public void setCellStyle(CellStyle style) {
         setCellStyle( (HSSFCellStyle)style );
@@ -922,7 +935,7 @@ public class HSSFCell implements Cell {
     /**
      * get the style for the cell.  This is a reference to a cell style contained in the workbook
      * object.
-     * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#getCellStyleAt(short)
+     * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#getCellStyleAt(int)
      */
     public HSSFCellStyle getCellStyle()
     {
@@ -954,8 +967,9 @@ public class HSSFCell implements Cell {
     }
 
     /**
-     * Sets this cell as the active cell for the worksheet
+     * {@inheritDoc}
      */
+    @Override
     public void setAsActiveCell()
     {
         int row=_record.getRow();
@@ -968,7 +982,7 @@ public class HSSFCell implements Cell {
      * Returns a string representation of the cell
      *
      * This method returns a simple representation,
-     * anthing more complex should be in user code, with
+     * anything more complex should be in user code, with
      * knowledge of the semantics of the sheet being processed.
      *
      * Formula cells return the formula string,
@@ -977,23 +991,24 @@ public class HSSFCell implements Cell {
      * Errors are displayed as #ERR&lt;errIdx&gt;
      */
     public String toString() {
-        switch (getCellType()) {
-            case CELL_TYPE_BLANK:
+        switch (getCellTypeEnum()) {
+            case BLANK:
                 return "";
-            case CELL_TYPE_BOOLEAN:
+            case BOOLEAN:
                 return getBooleanCellValue()?"TRUE":"FALSE";
-            case CELL_TYPE_ERROR:
+            case ERROR:
                 return ErrorEval.getText((( BoolErrRecord ) _record).getErrorValue());
-            case CELL_TYPE_FORMULA:
+            case FORMULA:
                 return getCellFormula();
-            case CELL_TYPE_NUMERIC:
+            case NUMERIC:
                 //TODO apply the dataformat for this cell
                 if (HSSFDateUtil.isCellDateFormatted(this)) {
-                    DateFormat sdf = new SimpleDateFormat("dd-MMM-yyyy");
+                    SimpleDateFormat sdf = new SimpleDateFormat("dd-MMM-yyyy", LocaleUtil.getUserLocale());
+                    sdf.setTimeZone(LocaleUtil.getUserTimeZone());
                     return sdf.format(getDateCellValue());
                 }
 				return  String.valueOf(getNumericCellValue());
-            case CELL_TYPE_STRING:
+            case STRING:
                 return getStringCellValue();
             default:
                 return "Unknown Cell Type: " + getCellType();
@@ -1048,17 +1063,9 @@ public class HSSFCell implements Cell {
     /**
      * @return hyperlink associated with this cell or <code>null</code> if not found
      */
+    @Override
     public HSSFHyperlink getHyperlink(){
-        for (Iterator<RecordBase> it = _sheet.getSheet().getRecords().iterator(); it.hasNext(); ) {
-            RecordBase rec = it.next();
-            if (rec instanceof HyperlinkRecord){
-                HyperlinkRecord link = (HyperlinkRecord)rec;
-                if(link.getFirstColumn() == _record.getColumn() && link.getFirstRow() == _record.getRow()){
-                    return new HSSFHyperlink(link);
-                }
-            }
-        }
-        return null;
+        return _sheet.getHyperlink(_record.getRow(), _record.getColumn());
     }
 
     /**
@@ -1067,6 +1074,7 @@ public class HSSFCell implements Cell {
      *
      * @param hyperlink hyperlink associated with this cell
      */
+    @Override
     public void setHyperlink(Hyperlink hyperlink){
         if (hyperlink == null) {
             removeHyperlink();
@@ -1080,17 +1088,19 @@ public class HSSFCell implements Cell {
         link.setFirstColumn(_record.getColumn());
         link.setLastColumn(_record.getColumn());
 
-        switch(link.getType()){
-            case HSSFHyperlink.LINK_EMAIL:
-            case HSSFHyperlink.LINK_URL:
+        switch(link.getTypeEnum()){
+            case EMAIL:
+            case URL:
                 link.setLabel("url");
                 break;
-            case HSSFHyperlink.LINK_FILE:
+            case FILE:
                 link.setLabel("file");
                 break;
-            case HSSFHyperlink.LINK_DOCUMENT:
+            case DOCUMENT:
                 link.setLabel("place");
                 break;
+            default:
+                break;
         }
 
         List<RecordBase> records = _sheet.getSheet().getRecords();
@@ -1116,22 +1126,42 @@ public class HSSFCell implements Cell {
 
     /**
      * Only valid for formula cells
-     * @return one of ({@link #CELL_TYPE_NUMERIC}, {@link #CELL_TYPE_STRING},
-     *     {@link #CELL_TYPE_BOOLEAN}, {@link #CELL_TYPE_ERROR}) depending
+     * @return one of ({@link CellType#NUMERIC}, {@link CellType#STRING},
+     *     {@link CellType#BOOLEAN}, {@link CellType#ERROR}) depending
      * on the cached value of the formula
+     *
+     * @since POI 4.0
      */
-    public int getCachedFormulaResultType() {
-        if (_cellType != CELL_TYPE_FORMULA) {
+    @Override
+    public CellType getCachedFormulaResultType() {
+        if (_cellType != CellType.FORMULA) {
             throw new IllegalStateException("Only formula cells have cached results");
         }
-        return ((FormulaRecordAggregate)_record).getFormulaRecord().getCachedResultType();
+        int code = ((FormulaRecordAggregate)_record).getFormulaRecord().getCachedResultType();
+        return CellType.forInt(code);
+    }
+
+    /**
+     * Only valid for formula cells
+     * @return one of ({@link CellType#NUMERIC}, {@link CellType#STRING},
+     *     {@link CellType#BOOLEAN}, {@link CellType#ERROR}) depending
+     * on the cached value of the formula
+     * @since POI 3.15 beta 3
+     * @deprecated use <code>getCachedFormulaResultType</code>
+     * Will be deleted when we make the CellType enum transition. See bug 59791.
+     */
+    @Deprecated
+    @Removal(version="4.2")
+    @Override
+    public CellType getCachedFormulaResultTypeEnum() {
+        return getCachedFormulaResultType();
     }
 
     void setCellArrayFormula(CellRangeAddress range) {
         int row = _record.getRow();
         short col = _record.getColumn();
         short styleIndex = _record.getXFIndex();
-        setCellType(CELL_TYPE_FORMULA, false, row, col, styleIndex);
+        setCellType(CellType.FORMULA, false, row, col, styleIndex);
 
         // Billet for formula in rec
         Ptg[] ptgsForCell = {new ExpPtg(range.getFirstRow(), range.getFirstColumn())};
@@ -1140,7 +1170,7 @@ public class HSSFCell implements Cell {
     }
 
     public CellRangeAddress getArrayFormulaRange() {
-        if (_cellType != CELL_TYPE_FORMULA) {
+        if (_cellType != CellType.FORMULA) {
             String ref = new CellReference(this).formatAsString();
             throw new IllegalStateException("Cell " + ref
                     + " is not part of an array formula.");
@@ -1149,10 +1179,7 @@ public class HSSFCell implements Cell {
     }
 
     public boolean isPartOfArrayFormulaGroup() {
-        if (_cellType != CELL_TYPE_FORMULA) {
-            return false;
-        }
-        return ((FormulaRecordAggregate)_record).isPartOfArrayFormula();
+        return _cellType == CellType.FORMULA && ((FormulaRecordAggregate) _record).isPartOfArrayFormula();
     }
 
     /**
@@ -1175,7 +1202,6 @@ public class HSSFCell implements Cell {
      * The purpose of this method is to validate the cell state prior to modification.
      * </p>
      *
-     * @see #setCellType(int)
      * @see #setCellFormula(String)
      * @see HSSFRow#removeCell(org.apache.poi.ss.usermodel.Cell)
      * @see org.apache.poi.hssf.usermodel.HSSFSheet#removeRow(org.apache.poi.ss.usermodel.Row)
