@@ -26,26 +26,31 @@ import org.apache.poi.hssf.record.FontRecord;
 import org.apache.poi.hssf.record.FormatRecord;
 import org.apache.poi.hssf.record.StyleRecord;
 import org.apache.poi.hssf.util.HSSFColor;
+import org.apache.poi.hssf.util.HSSFColor.HSSFColorPredefined;
+import org.apache.poi.ss.usermodel.BorderStyle;
 import org.apache.poi.ss.usermodel.CellStyle;
+import org.apache.poi.ss.usermodel.FillPatternType;
 import org.apache.poi.ss.usermodel.Font;
+import org.apache.poi.ss.usermodel.HorizontalAlignment;
+import org.apache.poi.ss.usermodel.VerticalAlignment;
 
 /**
  * High level representation of the style of a cell in a sheet of a workbook.
  *
  * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#createCellStyle()
- * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#getCellStyleAt(short)
+ * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#getCellStyleAt(int)
  * @see org.apache.poi.hssf.usermodel.HSSFCell#setCellStyle(HSSFCellStyle)
  */
 public final class HSSFCellStyle implements CellStyle {
-    private ExtendedFormatRecord _format                     = null;
-    private short                _index                      = 0;
-    private InternalWorkbook             _workbook                   = null;
+    private final ExtendedFormatRecord _format;
+    private final short                _index;
+    private final InternalWorkbook     _workbook;
 
 
     /** Creates new HSSFCellStyle why would you want to do this?? */
     protected HSSFCellStyle(short index, ExtendedFormatRecord rec, HSSFWorkbook workbook)
     {
-    	this(index, rec, workbook.getWorkbook());
+        this(index, rec, workbook.getWorkbook());
     }
     protected HSSFCellStyle(short index, ExtendedFormatRecord rec, InternalWorkbook workbook)
     {
@@ -59,8 +64,8 @@ public final class HSSFCellStyle implements CellStyle {
      * @return unique index number of the underlying record this style represents (probably you don't care
      *  unless you're comparing which one is which)
      */
-    public short getIndex()
-    {
+    @Override
+    public short getIndex() {
         return _index;
     }
 
@@ -72,20 +77,21 @@ public final class HSSFCellStyle implements CellStyle {
     public HSSFCellStyle getParentStyle() {
         short parentIndex = _format.getParentIndex();
         // parentIndex equal 0xFFF indicates no inheritance from a cell style XF (See 2.4.353 XF)
-    	if(parentIndex == 0 || parentIndex == 0xFFF) {
-    		return null;
-    	}
-    	return new HSSFCellStyle(
-    			parentIndex,
-    			_workbook.getExFormatAt(parentIndex),
-    			_workbook
-    	);
+        if(parentIndex == 0 || parentIndex == 0xFFF) {
+            return null;
+        }
+        return new HSSFCellStyle(
+                parentIndex,
+                _workbook.getExFormatAt(parentIndex),
+                _workbook
+        );
     }
 
     /**
      * set the data format (must be a valid format)
      * @see org.apache.poi.hssf.usermodel.HSSFDataFormat
      */
+    @Override
     public void setDataFormat(short fmt)
     {
         _format.setFormatIndex(fmt);
@@ -95,36 +101,44 @@ public final class HSSFCellStyle implements CellStyle {
      * get the index of the format
      * @see org.apache.poi.hssf.usermodel.HSSFDataFormat
      */
-
+    @Override
     public short getDataFormat()
     {
         return _format.getFormatIndex();
     }
 
+    // we keep the cached data in ThreadLocal members in order to
+    // avoid multi-threading issues when different workbooks are accessed in 
+    // multiple threads at the same time
+    private static final ThreadLocal<Short> lastDateFormat = new ThreadLocal<Short>() {
+        @Override
+        protected Short initialValue() {
+            return Short.MIN_VALUE;
+        }
+    };
+    private static final ThreadLocal<List<FormatRecord>> lastFormats = new ThreadLocal<>();
+    private static final ThreadLocal<String> getDataFormatStringCache = new ThreadLocal<>();
+
     /**
      * Get the contents of the format string, by looking up
      *  the DataFormat against the bound workbook
      * @see org.apache.poi.hssf.usermodel.HSSFDataFormat
      * @return the format string or "General" if not found
      */
-     
-    private static short lastDateFormat = Short.MIN_VALUE;
-    private static List<FormatRecord> lastFormats = null;
-    private static String getDataFormatStringCache = null;
-    
+    @Override
     public String getDataFormatString() {
-        if (getDataFormatStringCache != null) {
-            if (lastDateFormat == getDataFormat() && _workbook.getFormats().equals(lastFormats)) {
-                return getDataFormatStringCache;
+        if (getDataFormatStringCache.get() != null) {
+            if (lastDateFormat.get() == getDataFormat() && _workbook.getFormats().equals(lastFormats.get())) {
+                return getDataFormatStringCache.get();
             }
         }
 
-        lastFormats = _workbook.getFormats();
-        lastDateFormat = getDataFormat();
+        lastFormats.set(_workbook.getFormats());
+        lastDateFormat.set(getDataFormat());
 
-        getDataFormatStringCache = getDataFormatString(_workbook);
+        getDataFormatStringCache.set(getDataFormatString(_workbook));
 
-        return getDataFormatStringCache;
+        return getDataFormatStringCache.get();
     }
 
     /**
@@ -135,7 +149,7 @@ public final class HSSFCellStyle implements CellStyle {
      * @return the format string or "General" if not found
      */
     public String getDataFormatString(org.apache.poi.ss.usermodel.Workbook workbook) {
-    	HSSFDataFormat format = new HSSFDataFormat( ((HSSFWorkbook)workbook).getWorkbook() );
+        HSSFDataFormat format = new HSSFDataFormat( ((HSSFWorkbook)workbook).getWorkbook() );
 
         int idx = getDataFormat();
         return idx == -1 ? "General" : format.getFormat(getDataFormat());
@@ -146,21 +160,22 @@ public final class HSSFCellStyle implements CellStyle {
      * @see org.apache.poi.hssf.usermodel.HSSFDataFormat
      */
     public String getDataFormatString(org.apache.poi.hssf.model.InternalWorkbook workbook) {
-    	HSSFDataFormat format = new HSSFDataFormat( workbook );
+        HSSFDataFormat format = new HSSFDataFormat( workbook );
 
         return format.getFormat(getDataFormat());
     }
 
     /**
      * set the font for this style
-     * @param font  a font object created or retreived from the HSSFWorkbook object
+     * @param font  a font object created or retrieved from the HSSFWorkbook object
      * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#createFont()
-     * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#getFontAt(short)
+     * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#getFontAt(int)
      */
+    @Override
     public void setFont(Font font) {
-		setFont((HSSFFont)font);
-	}
-	public void setFont(HSSFFont font) {
+        setFont((HSSFFont)font);
+    }
+    public void setFont(HSSFFont font) {
         _format.setIndentNotParentFont(true);
         short fontindex = font.getIndex();
         _format.setFontIndex(fontindex);
@@ -170,25 +185,39 @@ public final class HSSFCellStyle implements CellStyle {
      * gets the index of the font for this style
      * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#getFontAt(short)
      */
+    @Override
+    @Deprecated
     public short getFontIndex()
     {
         return _format.getFontIndex();
     }
 
+    /**
+     * gets the index of the font for this style
+     * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#getFontAt(int)
+     * @since 4.0.0
+     */
+    @Override
+    public int getFontIndexAsInt()
+    {
+        return _format.getFontIndex();
+    }
+
     /**
      * gets the font for this style
      * @param parentWorkbook The HSSFWorkbook that this style belongs to
-     * @see org.apache.poi.hssf.usermodel.HSSFCellStyle#getFontIndex()
-     * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#getFontAt(short)
+     * @see org.apache.poi.hssf.usermodel.HSSFCellStyle#getFontIndexAsInt()
+     * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#getFontAt(int)
      */
     public HSSFFont getFont(org.apache.poi.ss.usermodel.Workbook parentWorkbook) {
-    	return ((HSSFWorkbook) parentWorkbook).getFontAt(getFontIndex());
+        return ((HSSFWorkbook) parentWorkbook).getFontAt(getFontIndexAsInt());
     }
 
     /**
      * set the cell's using this style to be hidden
      * @param hidden - whether the cell using this style should be hidden
      */
+    @Override
     public void setHidden(boolean hidden)
     {
         _format.setIndentNotParentCellOptions(true);
@@ -199,6 +228,7 @@ public final class HSSFCellStyle implements CellStyle {
      * get whether the cell's using this style are to be hidden
      * @return hidden - whether the cell using this style should be hidden
      */
+    @Override
     public boolean getHidden()
     {
         return _format.isHidden();
@@ -208,6 +238,7 @@ public final class HSSFCellStyle implements CellStyle {
      * set the cell's using this style to be locked
      * @param locked - whether the cell using this style should be locked
      */
+    @Override
     public void setLocked(boolean locked)
     {
         _format.setIndentNotParentCellOptions(true);
@@ -218,48 +249,58 @@ public final class HSSFCellStyle implements CellStyle {
      * get whether the cell's using this style are to be locked
      * @return hidden - whether the cell using this style should be locked
      */
+    @Override
     public boolean getLocked()
     {
         return _format.isLocked();
     }
 
+    /**
+     * Turn on or off "Quote Prefix" or "123 Prefix" for the style,
+     *  which is used to tell Excel that the thing which looks like
+     *  a number or a formula shouldn't be treated as on.
+     */
+    @Override
+    public void setQuotePrefixed(boolean quotePrefix) {
+        _format.set123Prefix(quotePrefix);
+    }
+    
+    /**
+     * Is "Quote Prefix" or "123 Prefix" enabled for the cell?
+     */
+    @Override
+    public boolean getQuotePrefixed() {
+        return _format.get123Prefix();
+    }
+    
     /**
      * set the type of horizontal alignment for the cell
      * @param align - the type of alignment
-     * @see #ALIGN_GENERAL
-     * @see #ALIGN_LEFT
-     * @see #ALIGN_CENTER
-     * @see #ALIGN_RIGHT
-     * @see #ALIGN_FILL
-     * @see #ALIGN_JUSTIFY
-     * @see #ALIGN_CENTER_SELECTION
      */
-    public void setAlignment(short align)
+    @Override
+    public void setAlignment(HorizontalAlignment align)
     {
         _format.setIndentNotParentAlignment(true);
-        _format.setAlignment(align);
+        _format.setAlignment(align.getCode());
     }
 
-    /**
-     * get the type of horizontal alignment for the cell
-     * @return align - the type of alignment
-     * @see #ALIGN_GENERAL
-     * @see #ALIGN_LEFT
-     * @see #ALIGN_CENTER
-     * @see #ALIGN_RIGHT
-     * @see #ALIGN_FILL
-     * @see #ALIGN_JUSTIFY
-     * @see #ALIGN_CENTER_SELECTION
-     */
-    public short getAlignment()
+    @Override
+    public HorizontalAlignment getAlignment()
     {
-        return _format.getAlignment();
+        return HorizontalAlignment.forInt(_format.getAlignment());
+    }
+
+    @Override
+    public HorizontalAlignment getAlignmentEnum()
+    {
+        return getAlignment();
     }
 
     /**
      * set whether the text should be wrapped
      * @param wrapped  wrap text or not
      */
+    @Override
     public void setWrapText(boolean wrapped)
     {
         _format.setIndentNotParentAlignment(true);
@@ -270,6 +311,7 @@ public final class HSSFCellStyle implements CellStyle {
      * get whether the text should be wrapped
      * @return wrap text or not
      */
+    @Override
     public boolean getWrapText()
     {
         return _format.getWrapText();
@@ -278,33 +320,34 @@ public final class HSSFCellStyle implements CellStyle {
     /**
      * set the type of vertical alignment for the cell
      * @param align the type of alignment
-     * @see #VERTICAL_TOP
-     * @see #VERTICAL_CENTER
-     * @see #VERTICAL_BOTTOM
-     * @see #VERTICAL_JUSTIFY
      */
-    public void setVerticalAlignment(short align)
+    @Override
+    public void setVerticalAlignment(VerticalAlignment align)
     {
-        _format.setVerticalAlignment(align);
+        _format.setVerticalAlignment(align.getCode());
     }
 
-    /**
-     * get the type of vertical alignment for the cell
-     * @return align the type of alignment
-     * @see #VERTICAL_TOP
-     * @see #VERTICAL_CENTER
-     * @see #VERTICAL_BOTTOM
-     * @see #VERTICAL_JUSTIFY
-     */
-    public short getVerticalAlignment()
-    {
-        return _format.getVerticalAlignment();
+    @Override
+    public VerticalAlignment getVerticalAlignment() {
+        return VerticalAlignment.forInt(_format.getVerticalAlignment());
+    }
+
+    @Override
+    public VerticalAlignment getVerticalAlignmentEnum() {
+        return getVerticalAlignment();
     }
 
     /**
      * set the degree of rotation for the text in the cell
+     *
+     * Note: HSSF uses values from -90 to 90 degrees, whereas XSSF 
+     * uses values from 0 to 180 degrees. The implementations of this method will map between these two value-ranges 
+     * accordingly, however the corresponding getter is returning values in the range mandated by the current type
+     * of Excel file-format that this CellStyle is applied to.
+     *
      * @param rotation degrees (between -90 and 90 degrees, of 0xff for vertical)
      */
+    @Override
     public void setRotation(short rotation)
     {
       if (rotation == 0xff) {
@@ -315,7 +358,11 @@ public final class HSSFCellStyle implements CellStyle {
         //The 4th quadrant (-1 to -90) is stored as (91 to 180)
         rotation = (short)(90 - rotation);
       }
-      else if ((rotation < -90)  ||(rotation > 90)) {
+      else if (rotation > 90 && rotation <= 180) {
+          // stay compatible with the range used by XSSF, map from ]90..180] to ]0..-90]
+          // we actually don't need to do anything here as the internal value is stored in [0-180] anyway!
+      }
+      else if ((rotation < -90)  || (rotation > 90)) {
         //Do not allow an incorrect rotation to be set
         throw new IllegalArgumentException("The rotation must be between -90 and 90 degrees, or 0xff");
       }
@@ -326,6 +373,7 @@ public final class HSSFCellStyle implements CellStyle {
      * get the degree of rotation for the text in the cell
      * @return rotation degrees (between -90 and 90 degrees, or 0xff for vertical)
      */
+    @Override
     public short getRotation()
     {
       short rotation = _format.getRotation();
@@ -344,6 +392,7 @@ public final class HSSFCellStyle implements CellStyle {
      * set the number of spaces to indent the text in the cell
      * @param indent - number of spaces
      */
+    @Override
     public void setIndention(short indent)
     {
         _format.setIndent(indent);
@@ -353,203 +402,101 @@ public final class HSSFCellStyle implements CellStyle {
      * get the number of spaces to indent the text in the cell
      * @return indent - number of spaces
      */
+    @Override
     public short getIndention()
     {
         return _format.getIndent();
     }
-
+    
     /**
      * set the type of border to use for the left border of the cell
      * @param border type
-     * @see #BORDER_NONE
-     * @see #BORDER_THIN
-     * @see #BORDER_MEDIUM
-     * @see #BORDER_DASHED
-     * @see #BORDER_DOTTED
-     * @see #BORDER_THICK
-     * @see #BORDER_DOUBLE
-     * @see #BORDER_HAIR
-     * @see #BORDER_MEDIUM_DASHED
-     * @see #BORDER_DASH_DOT
-     * @see #BORDER_MEDIUM_DASH_DOT
-     * @see #BORDER_DASH_DOT_DOT
-     * @see #BORDER_MEDIUM_DASH_DOT_DOT
-     * @see #BORDER_SLANTED_DASH_DOT
+     * @since POI 3.15
      */
-    public void setBorderLeft(short border)
+    @Override
+    public void setBorderLeft(BorderStyle border)
     {
         _format.setIndentNotParentBorder(true);
-        _format.setBorderLeft(border);
+        _format.setBorderLeft(border.getCode());
     }
 
-    /**
-     * get the type of border to use for the left border of the cell
-     * @return border type
-     * @see #BORDER_NONE
-     * @see #BORDER_THIN
-     * @see #BORDER_MEDIUM
-     * @see #BORDER_DASHED
-     * @see #BORDER_DOTTED
-     * @see #BORDER_THICK
-     * @see #BORDER_DOUBLE
-     * @see #BORDER_HAIR
-     * @see #BORDER_MEDIUM_DASHED
-     * @see #BORDER_DASH_DOT
-     * @see #BORDER_MEDIUM_DASH_DOT
-     * @see #BORDER_DASH_DOT_DOT
-     * @see #BORDER_MEDIUM_DASH_DOT_DOT
-     * @see #BORDER_SLANTED_DASH_DOT
-     */
-    public short getBorderLeft()
+    @Override
+    public BorderStyle getBorderLeft()
     {
-        return _format.getBorderLeft();
+        return BorderStyle.valueOf(_format.getBorderLeft());
     }
 
+    @Override
+    public BorderStyle getBorderLeftEnum() { return getBorderLeft(); }
+
     /**
      * set the type of border to use for the right border of the cell
      * @param border type
-     * @see #BORDER_NONE
-     * @see #BORDER_THIN
-     * @see #BORDER_MEDIUM
-     * @see #BORDER_DASHED
-     * @see #BORDER_DOTTED
-     * @see #BORDER_THICK
-     * @see #BORDER_DOUBLE
-     * @see #BORDER_HAIR
-     * @see #BORDER_MEDIUM_DASHED
-     * @see #BORDER_DASH_DOT
-     * @see #BORDER_MEDIUM_DASH_DOT
-     * @see #BORDER_DASH_DOT_DOT
-     * @see #BORDER_MEDIUM_DASH_DOT_DOT
-     * @see #BORDER_SLANTED_DASH_DOT
+     * @since POI 3.15
      */
-    public void setBorderRight(short border)
+    @Override
+    public void setBorderRight(BorderStyle border)
     {
         _format.setIndentNotParentBorder(true);
-        _format.setBorderRight(border);
+        _format.setBorderRight(border.getCode());
     }
 
-    /**
-     * get the type of border to use for the right border of the cell
-     * @return border type
-     * @see #BORDER_NONE
-     * @see #BORDER_THIN
-     * @see #BORDER_MEDIUM
-     * @see #BORDER_DASHED
-     * @see #BORDER_DOTTED
-     * @see #BORDER_THICK
-     * @see #BORDER_DOUBLE
-     * @see #BORDER_HAIR
-     * @see #BORDER_MEDIUM_DASHED
-     * @see #BORDER_DASH_DOT
-     * @see #BORDER_MEDIUM_DASH_DOT
-     * @see #BORDER_DASH_DOT_DOT
-     * @see #BORDER_MEDIUM_DASH_DOT_DOT
-     * @see #BORDER_SLANTED_DASH_DOT
-     */
-    public short getBorderRight()
+    @Override
+    public BorderStyle getBorderRight()
     {
-        return _format.getBorderRight();
+        return BorderStyle.valueOf(_format.getBorderRight());
     }
 
+    @Override
+    public BorderStyle getBorderRightEnum() { return getBorderRight(); }
+
     /**
      * set the type of border to use for the top border of the cell
      * @param border type
-     * @see #BORDER_NONE
-     * @see #BORDER_THIN
-     * @see #BORDER_MEDIUM
-     * @see #BORDER_DASHED
-     * @see #BORDER_DOTTED
-     * @see #BORDER_THICK
-     * @see #BORDER_DOUBLE
-     * @see #BORDER_HAIR
-     * @see #BORDER_MEDIUM_DASHED
-     * @see #BORDER_DASH_DOT
-     * @see #BORDER_MEDIUM_DASH_DOT
-     * @see #BORDER_DASH_DOT_DOT
-     * @see #BORDER_MEDIUM_DASH_DOT_DOT
-     * @see #BORDER_SLANTED_DASH_DOT
+     * @since POI 3.15
      */
-    public void setBorderTop(short border)
+    @Override
+    public void setBorderTop(BorderStyle border)
     {
         _format.setIndentNotParentBorder(true);
-        _format.setBorderTop(border);
+        _format.setBorderTop(border.getCode());
     }
 
-    /**
-     * get the type of border to use for the top border of the cell
-     * @return border type
-     * @see #BORDER_NONE
-     * @see #BORDER_THIN
-     * @see #BORDER_MEDIUM
-     * @see #BORDER_DASHED
-     * @see #BORDER_DOTTED
-     * @see #BORDER_THICK
-     * @see #BORDER_DOUBLE
-     * @see #BORDER_HAIR
-     * @see #BORDER_MEDIUM_DASHED
-     * @see #BORDER_DASH_DOT
-     * @see #BORDER_MEDIUM_DASH_DOT
-     * @see #BORDER_DASH_DOT_DOT
-     * @see #BORDER_MEDIUM_DASH_DOT_DOT
-     * @see #BORDER_SLANTED_DASH_DOT
-     */
-    public short getBorderTop()
+    @Override
+    public BorderStyle getBorderTop()
     {
-        return _format.getBorderTop();
+        return BorderStyle.valueOf(_format.getBorderTop());
     }
 
+    @Override
+    public BorderStyle getBorderTopEnum() { return getBorderTop(); }
+
     /**
      * set the type of border to use for the bottom border of the cell
      * @param border type
-     * @see #BORDER_NONE
-     * @see #BORDER_THIN
-     * @see #BORDER_MEDIUM
-     * @see #BORDER_DASHED
-     * @see #BORDER_DOTTED
-     * @see #BORDER_THICK
-     * @see #BORDER_DOUBLE
-     * @see #BORDER_HAIR
-     * @see #BORDER_MEDIUM_DASHED
-     * @see #BORDER_DASH_DOT
-     * @see #BORDER_MEDIUM_DASH_DOT
-     * @see #BORDER_DASH_DOT_DOT
-     * @see #BORDER_MEDIUM_DASH_DOT_DOT
-     * @see #BORDER_SLANTED_DASH_DOT
+     * @since 3.15 beta 2
      */
-    public void setBorderBottom(short border)
+    @Override
+    public void setBorderBottom(BorderStyle border)
     {
         _format.setIndentNotParentBorder(true);
-        _format.setBorderBottom(border);
+        _format.setBorderBottom(border.getCode());
     }
 
-    /**
-     * get the type of border to use for the bottom border of the cell
-     * @return border type
-     * @see #BORDER_NONE
-     * @see #BORDER_THIN
-     * @see #BORDER_MEDIUM
-     * @see #BORDER_DASHED
-     * @see #BORDER_DOTTED
-     * @see #BORDER_THICK
-     * @see #BORDER_DOUBLE
-     * @see #BORDER_HAIR
-     * @see #BORDER_MEDIUM_DASHED
-     * @see #BORDER_DASH_DOT
-     * @see #BORDER_MEDIUM_DASH_DOT
-     * @see #BORDER_DASH_DOT_DOT
-     * @see #BORDER_MEDIUM_DASH_DOT_DOT
-     * @see #BORDER_SLANTED_DASH_DOT
-     */
-    public short getBorderBottom()
+    @Override
+    public BorderStyle getBorderBottom()
     {
-        return _format.getBorderBottom();
+        return BorderStyle.valueOf(_format.getBorderBottom());
     }
 
+    @Override
+    public BorderStyle getBorderBottomEnum() { return getBorderBottom(); }
+
     /**
      * set the color to use for the left border
      * @param color The index of the color definition
      */
+    @Override
     public void setLeftBorderColor(short color)
     {
         _format.setLeftBorderPaletteIdx(color);
@@ -560,6 +507,7 @@ public final class HSSFCellStyle implements CellStyle {
      * @see org.apache.poi.hssf.usermodel.HSSFPalette#getColor(short)
      * @return The index of the color definition
      */
+    @Override
     public short getLeftBorderColor()
     {
         return _format.getLeftBorderPaletteIdx();
@@ -569,6 +517,7 @@ public final class HSSFCellStyle implements CellStyle {
      * set the color to use for the right border
      * @param color The index of the color definition
      */
+    @Override
     public void setRightBorderColor(short color)
     {
         _format.setRightBorderPaletteIdx(color);
@@ -579,6 +528,7 @@ public final class HSSFCellStyle implements CellStyle {
      * @see org.apache.poi.hssf.usermodel.HSSFPalette#getColor(short)
      * @return The index of the color definition
      */
+    @Override
     public short getRightBorderColor()
     {
         return _format.getRightBorderPaletteIdx();
@@ -588,6 +538,7 @@ public final class HSSFCellStyle implements CellStyle {
      * set the color to use for the top border
      * @param color The index of the color definition
      */
+    @Override
     public void setTopBorderColor(short color)
     {
         _format.setTopBorderPaletteIdx(color);
@@ -598,6 +549,7 @@ public final class HSSFCellStyle implements CellStyle {
      * @see org.apache.poi.hssf.usermodel.HSSFPalette#getColor(short)
      * @return The index of the color definition
      */
+    @Override
     public short getTopBorderColor()
     {
         return _format.getTopBorderPaletteIdx();
@@ -607,6 +559,7 @@ public final class HSSFCellStyle implements CellStyle {
      * set the color to use for the bottom border
      * @param color The index of the color definition
      */
+    @Override
     public void setBottomBorderColor(short color)
     {
         _format.setBottomBorderPaletteIdx(color);
@@ -617,49 +570,33 @@ public final class HSSFCellStyle implements CellStyle {
      * @see org.apache.poi.hssf.usermodel.HSSFPalette#getColor(short)
      * @return The index of the color definition
      */
+    @Override
     public short getBottomBorderColor()
     {
         return _format.getBottomBorderPaletteIdx();
     }
-
+    
     /**
      * setting to one fills the cell with the foreground color... No idea about
      * other values
      *
-     * @see #NO_FILL
-     * @see #SOLID_FOREGROUND
-     * @see #FINE_DOTS
-     * @see #ALT_BARS
-     * @see #SPARSE_DOTS
-     * @see #THICK_HORZ_BANDS
-     * @see #THICK_VERT_BANDS
-     * @see #THICK_BACKWARD_DIAG
-     * @see #THICK_FORWARD_DIAG
-     * @see #BIG_SPOTS
-     * @see #BRICKS
-     * @see #THIN_HORZ_BANDS
-     * @see #THIN_VERT_BANDS
-     * @see #THIN_BACKWARD_DIAG
-     * @see #THIN_FORWARD_DIAG
-     * @see #SQUARES
-     * @see #DIAMONDS
-     *
-     * @param fp  fill pattern (set to 1 to fill w/foreground color)
+     * @param fp  fill pattern (set to {@link FillPatternType#SOLID_FOREGROUND} to fill w/foreground color)
      */
-    public void setFillPattern(short fp)
+    @Override
+    public void setFillPattern(FillPatternType fp)
     {
-        _format.setAdtlFillPattern(fp);
+        _format.setAdtlFillPattern(fp.getCode());
     }
 
-    /**
-     * get the fill pattern (??) - set to 1 to fill with foreground color
-     * @return fill pattern
-     */
-    public short getFillPattern()
+    @Override
+    public FillPatternType getFillPattern()
     {
-        return _format.getAdtlFillPattern();
+        return FillPatternType.forInt(_format.getAdtlFillPattern());
     }
 
+    @Override
+    public FillPatternType getFillPatternEnum() { return getFillPattern(); }
+
     /**
      * Checks if the background and foreground fills are set correctly when one
      * or the other is set to the default color.
@@ -671,16 +608,20 @@ public final class HSSFCellStyle implements CellStyle {
      * <p>0x40         0xSOMETHING</p>
      */
     private void checkDefaultBackgroundFills() {
-      if (_format.getFillForeground() == org.apache.poi.hssf.util.HSSFColor.AUTOMATIC.index) {
-    	  //JMH: Why +1, hell why not. I guess it made some sense to someone at the time. Doesnt
-    	  //to me now.... But experience has shown that when the fore is set to AUTOMATIC then the
-    	  //background needs to be incremented......
-    	  if (_format.getFillBackground() != (org.apache.poi.hssf.util.HSSFColor.AUTOMATIC.index+1))
-    		  setFillBackgroundColor((short)(org.apache.poi.hssf.util.HSSFColor.AUTOMATIC.index+1));
-      } else if (_format.getFillBackground() == org.apache.poi.hssf.util.HSSFColor.AUTOMATIC.index+1)
-    	  //Now if the forground changes to a non-AUTOMATIC color the background resets itself!!!
-    	  if (_format.getFillForeground() != org.apache.poi.hssf.util.HSSFColor.AUTOMATIC.index)
-    		  setFillBackgroundColor(org.apache.poi.hssf.util.HSSFColor.AUTOMATIC.index);
+        final short autoIdx = HSSFColorPredefined.AUTOMATIC.getIndex();
+        if (_format.getFillForeground() == autoIdx) {
+            //JMH: Why +1, hell why not. I guess it made some sense to someone at the time. Doesnt
+            //to me now.... But experience has shown that when the fore is set to AUTOMATIC then the
+            //background needs to be incremented......
+            if (_format.getFillBackground() != autoIdx+1) {
+                setFillBackgroundColor((short)(autoIdx+1));
+            }
+        } else if (_format.getFillBackground() == autoIdx+1) {
+            //Now if the forground changes to a non-AUTOMATIC color the background resets itself!!!
+            if (_format.getFillForeground() != autoIdx) {
+                setFillBackgroundColor(autoIdx);
+            }
+        }
     }
 
     /**
@@ -708,6 +649,7 @@ public final class HSSFCellStyle implements CellStyle {
      *
      * @param bg  color
      */
+    @Override
     public void setFillBackgroundColor(short bg)
     {
         _format.setFillBackground(bg);
@@ -721,17 +663,19 @@ public final class HSSFCellStyle implements CellStyle {
      * @see org.apache.poi.hssf.usermodel.HSSFPalette#getColor(short)
      * @return fill color
      */
-    public short getFillBackgroundColor()
-    {
-    	short result = _format.getFillBackground();
-    	//JMH: Do this ridiculous conversion, and let HSSFCellStyle
-    	//internally migrate back and forth
-    	if (result == (HSSFColor.AUTOMATIC.index+1)) {
-			return HSSFColor.AUTOMATIC.index;
-		}
-    	return result;
+    @Override
+    public short getFillBackgroundColor() {
+        final short autoIndex = HSSFColorPredefined.AUTOMATIC.getIndex();
+        short result = _format.getFillBackground();
+        //JMH: Do this ridiculous conversion, and let HSSFCellStyle
+        //internally migrate back and forth
+        if (result == autoIndex+1) {
+            return autoIndex;
+        }
+        return result;
     }
     
+    @Override
     public HSSFColor getFillBackgroundColorColor() {
        HSSFPalette pallette = new HSSFPalette(
              _workbook.getCustomPalette()
@@ -746,6 +690,7 @@ public final class HSSFCellStyle implements CellStyle {
      * <i>Note: Ensure Foreground color is set prior to background color.</i>
      * @param bg  color
      */
+    @Override
     public void setFillForegroundColor(short bg)
     {
         _format.setFillForeground(bg);
@@ -759,11 +704,13 @@ public final class HSSFCellStyle implements CellStyle {
      * @see org.apache.poi.hssf.usermodel.HSSFPalette#getColor(short)
      * @return fill color
      */
+    @Override
     public short getFillForegroundColor()
     {
         return _format.getFillForeground();
     }
 
+    @Override
     public HSSFColor getFillForegroundColorColor() {
        HSSFPalette pallette = new HSSFPalette(
              _workbook.getCustomPalette()
@@ -779,14 +726,14 @@ public final class HSSFCellStyle implements CellStyle {
      *  styles where no name has been defined
      */
     public String getUserStyleName() {
-    	StyleRecord sr = _workbook.getStyleRecord(_index);
-    	if(sr == null) {
-    		return null;
-    	}
-    	if(sr.isBuiltin()) {
-    		return null;
-    	}
-    	return sr.getName();
+        StyleRecord sr = _workbook.getStyleRecord(_index);
+        if(sr == null) {
+            return null;
+        }
+        if(sr.isBuiltin()) {
+            return null;
+        }
+        return sr.getName();
     }
 
     /**
@@ -794,33 +741,58 @@ public final class HSSFCellStyle implements CellStyle {
      * Will complain if you try this on a built in style.
      */
     public void setUserStyleName(String styleName) {
-    	StyleRecord sr = _workbook.getStyleRecord(_index);
-    	if(sr == null) {
-    		sr = _workbook.createStyleRecord(_index);
-    	}
-    	// All Style records start as "builtin", but generally
-    	//  only 20 and below really need to be
-    	if(sr.isBuiltin() && _index <= 20) {
-    		throw new IllegalArgumentException("Unable to set user specified style names for built in styles!");
-    	}
-    	sr.setName(styleName);
+        StyleRecord sr = _workbook.getStyleRecord(_index);
+        if(sr == null) {
+            sr = _workbook.createStyleRecord(_index);
+        }
+        // All Style records start as "builtin", but generally
+        //  only 20 and below really need to be
+        if(sr.isBuiltin() && _index <= 20) {
+            throw new IllegalArgumentException("Unable to set user specified style names for built in styles!");
+        }
+        sr.setName(styleName);
     }
 
     /**
      * Controls if the Cell should be auto-sized
      *  to shrink to fit if the text is too long
      */
+    @Override
     public void setShrinkToFit(boolean shrinkToFit) {
-    	_format.setShrinkToFit(shrinkToFit);
+        _format.setShrinkToFit(shrinkToFit);
     }
     /**
      * Should the Cell be auto-sized by Excel to shrink
      *  it to fit if this text is too long?
      */
+    @Override
     public boolean getShrinkToFit() {
-    	return _format.getShrinkToFit();
+        return _format.getShrinkToFit();
     }
-	
+    
+    /**
+     * Get the reading order, for RTL/LTR ordering of
+     *  the text.
+     * <p>0 means Context (Default), 1 means Left To Right,
+     *  and 2 means Right to Left</p>
+     *
+     * @return order - the reading order (0,1,2)
+     */
+    public short getReadingOrder() {
+        return _format.getReadingOrder();
+    }
+    /**
+     * Sets the reading order, for RTL/LTR ordering of
+     *  the text.
+     * <p>0 means Context (Default), 1 means Left To Right,
+     *  and 2 means Right to Left</p>
+     *
+     * @param order - the reading order (0,1,2)
+     */
+    public void setReadingOrder(short order) {
+        _format.setReadingOrder(order);
+    }
+    
     /**
      * Verifies that this style belongs to the supplied Workbook.
      * Will throw an exception if it belongs to a different one.
@@ -830,10 +802,10 @@ public final class HSSFCellStyle implements CellStyle {
      * @throws IllegalArgumentException if there's a workbook mis-match
      */
     public void verifyBelongsToWorkbook(HSSFWorkbook wb) {
-		if(wb.getWorkbook() != _workbook) {
-			throw new IllegalArgumentException("This Style does not belong to the supplied Workbook. Are you trying to assign a style from one workbook to the cell of a differnt workbook?");
-		}
-	}
+        if(wb.getWorkbook() != _workbook) {
+            throw new IllegalArgumentException("This Style does not belong to the supplied Workbook. Are you trying to assign a style from one workbook to the cell of a differnt workbook?");
+        }
+    }
 
     /**
      * Clones all the style information from another
@@ -847,70 +819,80 @@ public final class HSSFCellStyle implements CellStyle {
      *  HSSFWorkbook if you like. This allows you to
      *  copy styles from one HSSFWorkbook to another.
      */
+    @Override
     public void cloneStyleFrom(CellStyle source) {
-		if(source instanceof HSSFCellStyle) {
-			this.cloneStyleFrom((HSSFCellStyle)source);
-		} else {
-		    throw new IllegalArgumentException("Can only clone from one HSSFCellStyle to another, not between HSSFCellStyle and XSSFCellStyle");
-		}
-	}
+        if(source instanceof HSSFCellStyle) {
+            this.cloneStyleFrom((HSSFCellStyle)source);
+        } else {
+            throw new IllegalArgumentException("Can only clone from one HSSFCellStyle to another, not between HSSFCellStyle and XSSFCellStyle");
+        }
+    }
     public void cloneStyleFrom(HSSFCellStyle source) {
-    	// First we need to clone the extended format
-    	//  record
-    	_format.cloneStyleFrom(source._format);
+        // First we need to clone the extended format
+        //  record
+        _format.cloneStyleFrom(source._format);
 
-    	// Handle matching things if we cross workbooks
-    	if(_workbook != source._workbook) {
+        // Handle matching things if we cross workbooks
+        if(_workbook != source._workbook) {
 
-            lastDateFormat = Short.MIN_VALUE;
-            lastFormats = null;
-            getDataFormatStringCache = null;
-    	   
-			// Then we need to clone the format string,
-			//  and update the format record for this
-    		short fmt = (short)_workbook.createFormat(source.getDataFormatString() );
-    		setDataFormat(fmt);
+            lastDateFormat.set(Short.MIN_VALUE);
+            lastFormats.set(null);
+            getDataFormatStringCache.set(null);
+           
+            // Then we need to clone the format string,
+            //  and update the format record for this
+            short fmt = (short)_workbook.createFormat(source.getDataFormatString() );
+            setDataFormat(fmt);
 
-			// Finally we need to clone the font,
-			//  and update the format record for this
-    		FontRecord fr = _workbook.createNewFont();
-    		fr.cloneStyleFrom(
-    				source._workbook.getFontRecordAt(
-    						source.getFontIndex()
-    				)
-    		);
+            // Finally we need to clone the font,
+            //  and update the format record for this
+            FontRecord fr = _workbook.createNewFont();
+            fr.cloneStyleFrom(
+                    source._workbook.getFontRecordAt(
+                            source.getFontIndexAsInt()
+                    )
+            );
 
-    		HSSFFont font = new HSSFFont(
-    				(short)_workbook.getFontIndex(fr), fr
-    		);
-    		setFont(font);
-    	}
+            HSSFFont font = new HSSFFont(
+                    (short)_workbook.getFontIndex(fr), fr
+            );
+            setFont(font);
+        }
     }
 
 
-	public int hashCode() {
-		final int prime = 31;
-		int result = 1;
-		result = prime * result + ((_format == null) ? 0 : _format.hashCode());
-		result = prime * result + _index;
-		return result;
-	}
+    @Override
+    public int hashCode() {
+        final int prime = 31;
+        int result = 1;
+        result = prime * result + ((_format == null) ? 0 : _format.hashCode());
+        result = prime * result + _index;
+        return result;
+    }
 
-	public boolean equals(Object obj) {
-		if (this == obj) return true;
-		if (obj == null) return false;
-		if (obj instanceof HSSFCellStyle) {
-			final HSSFCellStyle other = (HSSFCellStyle) obj;
-			if (_format == null) {
-				if (other._format != null)
-					return false;
-			} else if (!_format.equals(other._format))
-				return false;
-			if (_index != other._index)
-				return false;
-			return true;
-		}
-		return false;
-	}
-	
+    @Override
+    public boolean equals(Object obj) {
+        if (this == obj) {
+            return true;
+        }
+        if (obj == null) {
+            return false;
+        }
+        if (obj instanceof HSSFCellStyle) {
+            final HSSFCellStyle other = (HSSFCellStyle) obj;
+            if (_format == null) {
+                if (other._format != null) {
+                    return false;
+                }
+            } else if (!_format.equals(other._format)) {
+                return false;
+            }
+            if (_index != other._index) {
+                return false;
+            }
+            return true;
+        }
+        return false;
+    }
+    
 }
