@@ -30,6 +30,7 @@ import org.apache.poi.hssf.record.ObjRecord;
 import org.apache.poi.hssf.record.TextObjectRecord;
 import org.apache.poi.ss.usermodel.ClientAnchor;
 import org.apache.poi.ss.usermodel.Comment;
+import org.apache.poi.ss.util.CellAddress;
 
 /**
  * Represents a cell comment - a sticky note associated with a cell.
@@ -53,11 +54,11 @@ public class HSSFComment extends HSSFTextbox implements Comment {
       * It seems like HSSFRow should manage a collection of local HSSFComments
       */
 
-    private NoteRecord _note;
+    private final NoteRecord _note;
 
-    public HSSFComment(EscherContainerRecord spContainer, ObjRecord objRecord, TextObjectRecord textObjectRecord, NoteRecord _note) {
+    public HSSFComment(EscherContainerRecord spContainer, ObjRecord objRecord, TextObjectRecord textObjectRecord, NoteRecord note) {
         super(spContainer, objRecord, textObjectRecord);
-        this._note = _note;
+        _note = note;
     }
 
     /**
@@ -67,8 +68,12 @@ public class HSSFComment extends HSSFTextbox implements Comment {
      * @param anchor defines position of this anchor in the sheet
      */
     public HSSFComment(HSSFShape parent, HSSFAnchor anchor) {
+        this(parent, anchor, createNoteRecord());
+    }
+
+    private HSSFComment(HSSFShape parent, HSSFAnchor anchor, NoteRecord note) {
         super(parent, anchor);
-        _note = createNoteRecord();
+        _note = note;
         //default color for comments
         setFillColor(0x08000050);
 
@@ -80,14 +85,13 @@ public class HSSFComment extends HSSFTextbox implements Comment {
     }
 
     protected HSSFComment(NoteRecord note, TextObjectRecord txo) {
-        this(null, new HSSFClientAnchor());
-        _note = note;
+        this(null, new HSSFClientAnchor(), note);
     }
 
     @Override
     void afterInsert(HSSFPatriarch patriarch) {
         super.afterInsert(patriarch);
-        patriarch._getBoundAggregate().addTailRecord(getNoteRecord());
+        patriarch.getBoundAggregate().addTailRecord(getNoteRecord());
     }
 
     @Override
@@ -120,7 +124,7 @@ public class HSSFComment extends HSSFTextbox implements Comment {
         return obj;
     }
 
-    private NoteRecord createNoteRecord(){
+    private static NoteRecord createNoteRecord() {
         NoteRecord note = new NoteRecord();
         note.setFlags(NoteRecord.NOTE_HIDDEN);
         note.setAuthor("");
@@ -129,9 +133,9 @@ public class HSSFComment extends HSSFTextbox implements Comment {
 
     @Override
     void setShapeId(int shapeId) {
-    	if(shapeId > 65535) {
-    		throw new IllegalArgumentException("Cannot add more than " + 65535 + " shapes");
-    	}
+        if(shapeId > 65535) {
+            throw new IllegalArgumentException("Cannot add more than " + 65535 + " shapes");
+        }
         super.setShapeId(shapeId);
         CommonObjectDataSubRecord cod = (CommonObjectDataSubRecord) getObjRecord().getSubRecords().get(0);
         cod.setObjectId(shapeId);
@@ -139,29 +143,49 @@ public class HSSFComment extends HSSFTextbox implements Comment {
     }
 
     /**
-     * Returns whether this comment is visible.
+     * Sets whether this comment is visible.
      *
      * @param visible <code>true</code> if the comment is visible, <code>false</code> otherwise
      */
+    @Override
     public void setVisible(boolean visible) {
         _note.setFlags(visible ? NoteRecord.NOTE_VISIBLE : NoteRecord.NOTE_HIDDEN);
         setHidden(!visible);
     }
 
     /**
-     * Sets whether this comment is visible.
+     * Returns whether this comment is visible.
      *
      * @return <code>true</code> if the comment is visible, <code>false</code> otherwise
      */
+    @Override
     public boolean isVisible() {
         return _note.getFlags() == NoteRecord.NOTE_VISIBLE;
     }
+    
+    @Override
+    public CellAddress getAddress() {
+        return new CellAddress(getRow(), getColumn());
+    }
+    
+    @Override
+    public void setAddress(CellAddress address) {
+        setRow(address.getRow());
+        setColumn(address.getColumn());
+    }
+    
+    @Override
+    public void setAddress(int row, int col) {
+        setRow(row);
+        setColumn(col);
+    }
 
     /**
      * Return the row of the cell that contains the comment
      *
      * @return the 0-based row of the cell that contains the comment
      */
+    @Override
     public int getRow() {
         return _note.getRow();
     }
@@ -171,6 +195,7 @@ public class HSSFComment extends HSSFTextbox implements Comment {
      *
      * @param row the 0-based row of the cell that contains the comment
      */
+    @Override
     public void setRow(int row) {
         _note.setRow(row);
     }
@@ -180,6 +205,7 @@ public class HSSFComment extends HSSFTextbox implements Comment {
      *
      * @return the 0-based column of the cell that contains the comment
      */
+    @Override
     public int getColumn() {
         return _note.getColumn();
     }
@@ -189,23 +215,17 @@ public class HSSFComment extends HSSFTextbox implements Comment {
      *
      * @param col the 0-based column of the cell that contains the comment
      */
+    @Override
     public void setColumn(int col) {
         _note.setColumn(col);
     }
 
-    /**
-     * @deprecated (Nov 2009) use {@link HSSFComment#setColumn(int)} }
-     */
-    @Deprecated
-    public void setColumn(short col) {
-        setColumn((int) col);
-    }
-
     /**
      * Name of the original comment author
      *
      * @return the name of the original author of the comment
      */
+    @Override
     public String getAuthor() {
         return _note.getAuthor();
     }
@@ -215,6 +235,7 @@ public class HSSFComment extends HSSFTextbox implements Comment {
      *
      * @param author the name of the original author of the comment
      */
+    @Override
     public void setAuthor(String author) {
         if (_note != null) _note.setAuthor(author);
     }
@@ -251,9 +272,10 @@ public class HSSFComment extends HSSFTextbox implements Comment {
         throw new IllegalStateException("Shape type can not be changed in "+this.getClass().getSimpleName());
     }
 
+    @Override
     public void afterRemove(HSSFPatriarch patriarch){
         super.afterRemove(patriarch);
-        patriarch._getBoundAggregate().removeTailRecord(getNoteRecord());
+        patriarch.getBoundAggregate().removeTailRecord(getNoteRecord());
     }
 
     @Override
@@ -298,4 +320,18 @@ public class HSSFComment extends HSSFTextbox implements Comment {
             setPropertyValue(new EscherSimpleProperty(EscherProperties.GROUPSHAPE__PRINT, false, false, property.getPropertyValue() & GROUP_SHAPE_NOT_HIDDEN_MASK));
         }
     }
+
+    @Override
+    public boolean equals(Object obj) {
+        if (!(obj instanceof HSSFComment)) {
+            return false;
+        }
+        HSSFComment other = (HSSFComment) obj;
+        return getNoteRecord().equals(other.getNoteRecord());
+    }
+
+    @Override
+    public int hashCode() {
+        return ((getRow()*17) + getColumn())*31;
+    }
 }
