@@ -34,6 +34,7 @@ import org.apache.poi.hssf.model.InternalWorkbook;
 import org.apache.poi.hssf.record.CommonObjectDataSubRecord;
 import org.apache.poi.hssf.record.EscherAggregate;
 import org.apache.poi.hssf.record.ObjRecord;
+import org.apache.poi.ss.usermodel.ClientAnchor.AnchorType;
 import org.apache.poi.ss.usermodel.Picture;
 import org.apache.poi.ss.util.ImageUtils;
 import org.apache.poi.util.POILogFactory;
@@ -102,6 +103,7 @@ public class HSSFPicture extends HSSFSimpleShape implements Picture {
      * If the default font is changed the resized image can be streched vertically or horizontally.
      * </p>
      */
+    @Override
     public void resize(){
         resize(Double.MAX_VALUE);
     }
@@ -111,6 +113,7 @@ public class HSSFPicture extends HSSFSimpleShape implements Picture {
      *
      * @see #resize(double, double)
      */
+    @Override
     public void resize(double scale) {
         resize(scale,scale);
     }
@@ -123,18 +126,19 @@ public class HSSFPicture extends HSSFSimpleShape implements Picture {
      * If the default font is changed the resized image can be streched vertically or horizontally.
      * </p>
      * <p>
-     * <code>resize(1.0,1.0)</code> keeps the original size,<br/>
-     * <code>resize(0.5,0.5)</code> resize to 50% of the original,<br/>
-     * <code>resize(2.0,2.0)</code> resizes to 200% of the original.<br/>
+     * <code>resize(1.0,1.0)</code> keeps the original size,<br>
+     * <code>resize(0.5,0.5)</code> resize to 50% of the original,<br>
+     * <code>resize(2.0,2.0)</code> resizes to 200% of the original.<br>
      * <code>resize({@link Double#MAX_VALUE},{@link Double#MAX_VALUE})</code> resizes to the dimension of the embedded image. 
      * </p>
      *
      * @param scaleX the amount by which the image width is multiplied relative to the original width.
      * @param scaleY the amount by which the image height is multiplied relative to the original height.
      */
+    @Override
     public void resize(double scaleX, double scaleY) {
         HSSFClientAnchor anchor = getClientAnchor();
-        anchor.setAnchorType(2);
+        anchor.setAnchorType(AnchorType.MOVE_DONT_RESIZE);
 
         HSSFClientAnchor pref = getPreferredSize(scaleX,scaleY);
 
@@ -156,6 +160,7 @@ public class HSSFPicture extends HSSFSimpleShape implements Picture {
      * @return HSSFClientAnchor with the preferred size for this image
      * @since POI 3.0.2
      */
+    @Override
     public HSSFClientAnchor getPreferredSize(){
         return getPreferredSize(1.0);
     }
@@ -179,6 +184,7 @@ public class HSSFPicture extends HSSFSimpleShape implements Picture {
      * @return HSSFClientAnchor with the preferred size for this image
      * @since POI 3.11
      */
+    @Override
     public HSSFClientAnchor getPreferredSize(double scaleX, double scaleY){
         ImageUtils.setPreferredSize(this, scaleX, scaleY);
         return getClientAnchor();
@@ -189,6 +195,7 @@ public class HSSFPicture extends HSSFSimpleShape implements Picture {
      *
      * @return image dimension in pixels
      */
+    @Override
     public Dimension getImageDimension(){
         InternalWorkbook iwb = getPatriarch().getSheet().getWorkbook().getWorkbook();
         EscherBSERecord bse = iwb.getBSERecord(getPictureIndex());
@@ -200,29 +207,47 @@ public class HSSFPicture extends HSSFSimpleShape implements Picture {
     /**
      * Return picture data for this shape
      *
-     * @return picture data for this shape
+     * @return picture data for this shape or {@code null} if picture wasn't embedded, i.e. external linked
      */
+    @Override
     public HSSFPictureData getPictureData(){
-        InternalWorkbook iwb = getPatriarch().getSheet().getWorkbook().getWorkbook();
-        EscherBSERecord bse = iwb.getBSERecord(getPictureIndex());
+        int picIdx = getPictureIndex();
+        if (picIdx == -1) {
+            return null;
+        }
+        
+        HSSFPatriarch patriarch = getPatriarch();
+        HSSFShape parent = getParent();
+        while(patriarch == null && parent != null) {
+            patriarch = parent.getPatriarch();
+            parent = parent.getParent();
+        }
+        if(patriarch == null) {
+            throw new IllegalStateException("Could not find a patriarch for a HSSPicture");
+        }
+
+        InternalWorkbook iwb = patriarch.getSheet().getWorkbook().getWorkbook();
+        EscherBSERecord bse = iwb.getBSERecord(picIdx);
     	EscherBlipRecord blipRecord = bse.getBlipRecord();
     	return new HSSFPictureData(blipRecord);
     }
 
     @Override
     void afterInsert(HSSFPatriarch patriarch) {
-        EscherAggregate agg = patriarch._getBoundAggregate();
+        EscherAggregate agg = patriarch.getBoundAggregate();
         agg.associateShapeToObjRecord(getEscherContainer().getChildById(EscherClientDataRecord.RECORD_ID), getObjRecord());
-        EscherBSERecord bse =
-                patriarch.getSheet().getWorkbook().getWorkbook().getBSERecord(getPictureIndex());
-        bse.setRef(bse.getRef() + 1);
+        if(getPictureIndex() != -1) {
+            EscherBSERecord bse =
+                    patriarch.getSheet().getWorkbook().getWorkbook().getBSERecord(getPictureIndex());
+            bse.setRef(bse.getRef() + 1);
+        }
     }
 
     /**
      * The filename of the embedded image
      */
     public String getFileName() {
-        EscherComplexProperty propFile = (EscherComplexProperty) getOptRecord().lookup(
+        EscherComplexProperty propFile = getOptRecord().lookup(
                       EscherProperties.BLIP__BLIPFILENAME);
         return (null == propFile)
             ? ""
