@@ -30,7 +30,7 @@ import java.util.Iterator;
  * sheet.
  */
 public class HSSFShapeGroup extends HSSFShape implements HSSFShapeContainer {
-    private final List<HSSFShape> shapes = new ArrayList<HSSFShape>();
+    private final List<HSSFShape> shapes = new ArrayList<>();
     private EscherSpgrRecord _spgrRecord;
 
     public HSSFShapeGroup(EscherContainerRecord spgrContainer, ObjRecord objRecord) {
@@ -49,6 +49,8 @@ public class HSSFShapeGroup extends HSSFShape implements HSSFShapeContainer {
                 case EscherChildAnchorRecord.RECORD_ID:
                     anchor = new HSSFChildAnchor((EscherChildAnchorRecord) ch);
                     break;
+                default:
+                    break;
             }
         }
     }
@@ -122,7 +124,7 @@ public class HSSFShapeGroup extends HSSFShape implements HSSFShapeContainer {
 
     @Override
     protected void afterRemove(HSSFPatriarch patriarch) {
-        patriarch._getBoundAggregate().removeShapeToObjRecord(getEscherContainer().getChildContainers().get(0)
+        patriarch.getBoundAggregate().removeShapeToObjRecord(getEscherContainer().getChildContainers().get(0)
                 .getChildById(EscherClientDataRecord.RECORD_ID));
         for ( int i=0; i<shapes.size(); i++ ) {
             HSSFShape shape = shapes.get(i);
@@ -266,7 +268,7 @@ public class HSSFShapeGroup extends HSSFShape implements HSSFShapeContainer {
     }
 
     public void clear() {
-        ArrayList <HSSFShape> copy = new ArrayList<HSSFShape>(shapes);
+        ArrayList <HSSFShape> copy = new ArrayList<>(shapes);
         for (HSSFShape shape: copy){
             removeShape(shape);
         }
@@ -314,7 +316,7 @@ public class HSSFShapeGroup extends HSSFShape implements HSSFShapeContainer {
 
     @Override
     void afterInsert(HSSFPatriarch patriarch){
-        EscherAggregate agg = patriarch._getBoundAggregate();
+        EscherAggregate agg = patriarch.getBoundAggregate();
         EscherContainerRecord containerRecord = getEscherContainer().getChildById(EscherContainerRecord.SP_CONTAINER);
         agg.associateShapeToObjRecord(containerRecord.getChildById(EscherClientDataRecord.RECORD_ID), getObjRecord());
     }
@@ -379,6 +381,7 @@ public class HSSFShapeGroup extends HSSFShape implements HSSFShapeContainer {
         return isRemoved;
     }
 
+    @Override
     public Iterator<HSSFShape> iterator() {
         return shapes.iterator();
     }
