@@ -18,7 +18,7 @@
 package org.apache.poi.poifs.crypt;
 
 import java.io.IOException;
-import java.nio.charset.Charset;
+import java.nio.charset.StandardCharsets;
 
 import org.apache.poi.EncryptedDocumentException;
 import org.apache.poi.poifs.crypt.standard.EncryptionRecord;
@@ -26,6 +26,7 @@ import org.apache.poi.poifs.filesystem.DirectoryEntry;
 import org.apache.poi.poifs.filesystem.DocumentEntry;
 import org.apache.poi.poifs.filesystem.POIFSWriterEvent;
 import org.apache.poi.poifs.filesystem.POIFSWriterListener;
+import org.apache.poi.util.IOUtils;
 import org.apache.poi.util.LittleEndianByteArrayOutputStream;
 import org.apache.poi.util.LittleEndianConsts;
 import org.apache.poi.util.LittleEndianInput;
@@ -33,6 +34,10 @@ import org.apache.poi.util.LittleEndianOutput;
 import org.apache.poi.util.StringUtil;
 
 public class DataSpaceMapUtils {
+
+    //arbitrarily selected; may need to increase
+    private static final int MAX_RECORD_LENGTH = 100_000;
+
     public static void addDefaultDataSpace(DirectoryEntry dir) throws IOException {
         DataSpaceMapEntry dsme = new DataSpaceMapEntry(
                 new int[]{ 0 }
@@ -91,12 +96,11 @@ public class DataSpaceMapUtils {
         DataSpaceMapEntry entries[];
         
         public DataSpaceMap(DataSpaceMapEntry entries[]) {
-            this.entries = entries;
+            this.entries = entries.clone();
         }
         
         public DataSpaceMap(LittleEndianInput is) {
-            @SuppressWarnings("unused")
-            int length = is.readInt();
+            /*int length = */ is.readInt();
             int entryCount = is.readInt();
             entries = new DataSpaceMapEntry[entryCount];
             for (int i=0; i<entryCount; i++) {
@@ -114,19 +118,18 @@ public class DataSpaceMapUtils {
     }
     
     public static class DataSpaceMapEntry implements EncryptionRecord {
-        int referenceComponentType[];
-        String referenceComponent[];
-        String dataSpaceName;
+        final int referenceComponentType[];
+        final String referenceComponent[];
+        final String dataSpaceName;
         
         public DataSpaceMapEntry(int referenceComponentType[], String referenceComponent[], String dataSpaceName) {
-            this.referenceComponentType = referenceComponentType;
-            this.referenceComponent = referenceComponent;
+            this.referenceComponentType = referenceComponentType.clone();
+            this.referenceComponent = referenceComponent.clone();
             this.dataSpaceName = dataSpaceName;
         }
         
         public DataSpaceMapEntry(LittleEndianInput is) {
-            @SuppressWarnings("unused")
-            int length = is.readInt();
+            /*int length = */ is.readInt();
             int referenceComponentCount = is.readInt();
             referenceComponentType = new int[referenceComponentCount];
             referenceComponent = new String[referenceComponentCount];
@@ -154,12 +157,11 @@ public class DataSpaceMapUtils {
         String transformer[];
         
         public DataSpaceDefinition(String transformer[]) {
-            this.transformer = transformer;
+            this.transformer = transformer.clone();
         }
         
         public DataSpaceDefinition(LittleEndianInput is) {
-            @SuppressWarnings("unused")
-            int headerLength = is.readInt();
+            /* int headerLength = */ is.readInt();
             int transformReferenceCount = is.readInt();
             transformer = new String[transformReferenceCount];
             for (int i=0; i<transformReferenceCount; i++) {
@@ -206,9 +208,9 @@ public class DataSpaceMapUtils {
         int transformType;
         String transformerId;
         String transformerName;
-        int readerVersionMajor = 1, readerVersionMinor = 0;
-        int updaterVersionMajor = 1, updaterVersionMinor = 0;
-        int writerVersionMajor = 1, writerVersionMinor = 0;
+        int readerVersionMajor = 1, readerVersionMinor;
+        int updaterVersionMajor = 1, updaterVersionMinor;
+        int writerVersionMajor = 1, writerVersionMinor;
 
         public TransformInfoHeader(
             int transformType,
@@ -230,8 +232,7 @@ public class DataSpaceMapUtils {
         }
         
         public TransformInfoHeader(LittleEndianInput is) {
-            @SuppressWarnings("unused")
-            int length = is.readInt();
+            /* int length = */ is.readInt();
             transformType = is.readInt();
             transformerId = readUnicodeLPP4(is);
             transformerName = readUnicodeLPP4(is);
@@ -261,9 +262,9 @@ public class DataSpaceMapUtils {
     
     public static class DataSpaceVersionInfo implements EncryptionRecord {
         String featureIdentifier;
-        int readerVersionMajor = 1, readerVersionMinor = 0;
-        int updaterVersionMajor = 1, updaterVersionMinor = 0;
-        int writerVersionMajor = 1, writerVersionMinor = 0;
+        int readerVersionMajor = 1, readerVersionMinor;
+        int updaterVersionMajor = 1, updaterVersionMinor;
+        int writerVersionMajor = 1, writerVersionMinor;
         
         public DataSpaceVersionInfo(LittleEndianInput is) {
             featureIdentifier = readUnicodeLPP4(is);
@@ -332,12 +333,11 @@ public class DataSpaceMapUtils {
     public static String readUtf8LPP4(LittleEndianInput is) {
         int length = is.readInt();
         if (length == 0 || length == 4) {
-            @SuppressWarnings("unused")
-            int skip = is.readInt(); // ignore
+            /* int skip = */ is.readInt();
             return length == 0 ? null : "";
         }
         
-        byte data[] = new byte[length];
+        byte data[] = IOUtils.safelyAllocate(length, MAX_RECORD_LENGTH);
         is.readFully(data);
 
         // Padding (variable): A set of bytes that MUST be of correct size such that the size of the UTF-8-LP-P4
@@ -352,15 +352,15 @@ public class DataSpaceMapUtils {
             }
         }
 
-        return new String(data, 0, data.length, Charset.forName("UTF-8"));
+        return new String(data, 0, data.length, StandardCharsets.UTF_8);
     }
     
     public static void writeUtf8LPP4(LittleEndianOutput os, String str) {
-        if (str == null || "".equals(str)) {
+        if (str == null || str.isEmpty()) {
             os.writeInt(str == null ? 0 : 4);
             os.writeInt(0);
         } else {
-            byte buf[] = str.getBytes(Charset.forName("UTF-8"));
+            byte buf[] = str.getBytes(StandardCharsets.UTF_8);
             os.writeInt(buf.length);
             os.write(buf);
             int scratchBytes = buf.length%4;
