@@ -18,13 +18,16 @@ package org.apache.poi.poifs.crypt;
 
 import java.io.IOException;
 
-import org.apache.poi.poifs.filesystem.DocumentInputStream;
+import org.apache.poi.util.LittleEndianInput;
 
 public interface EncryptionInfoBuilder {
-    void initialize(EncryptionInfo ei, DocumentInputStream dis) throws IOException;
+    /**
+     * initialize the builder from a stream
+     */
+    void initialize(EncryptionInfo ei, LittleEndianInput dis) throws IOException;
+
+    /**
+     * initialize the builder from scratch
+     */
     void initialize(EncryptionInfo ei, CipherAlgorithm cipherAlgorithm, HashAlgorithm hashAlgorithm, int keyBits, int blockSize, ChainingMode chainingMode);
-    EncryptionHeader getHeader();
-    EncryptionVerifier getVerifier();
-    Decryptor getDecryptor();
-    Encryptor getEncryptor();
 }
