@@ -16,11 +16,10 @@
 ==================================================================== */
 package org.apache.poi.poifs.crypt;
 
-
 /**
  * Used when checking if a key is valid for a document 
  */
-public abstract class EncryptionVerifier {
+public abstract class EncryptionVerifier implements Cloneable {
     private byte[] salt;
     private byte[] encryptedVerifier;
     private byte[] encryptedVerifierHash;
@@ -37,28 +36,10 @@ public abstract class EncryptionVerifier {
         return salt;
     }
 
-    /**
-     * The method name is misleading - you'll get the encrypted verifier, not the plain verifier
-     * @deprecated use getEncryptedVerifier()
-     */
-    @Deprecated
-    public byte[] getVerifier() {
-        return encryptedVerifier;
-    }
-
     public byte[] getEncryptedVerifier() {
         return encryptedVerifier;
     }    
     
-    /**
-     * The method name is misleading - you'll get the encrypted verifier hash, not the plain verifier hash
-     * @deprecated use getEnryptedVerifierHash
-     */
-    @Deprecated
-    public byte[] getVerifierHash() {
-        return encryptedVerifierHash;
-    }
-
     public byte[] getEncryptedVerifierHash() {
         return encryptedVerifierHash;
     }    
@@ -67,22 +48,6 @@ public abstract class EncryptionVerifier {
         return spinCount;
     }
 
-    public int getCipherMode() {
-        return chainingMode.ecmaId;
-    }
-
-    public int getAlgorithm() {
-        return cipherAlgorithm.ecmaId;
-    }
-
-    /**
-     * @deprecated use getCipherAlgorithm().jceId
-     */
-    @Deprecated
-    public String getAlgorithmName() {
-        return cipherAlgorithm.jceId;
-    }
-
     public byte[] getEncryptedKey() {
         return encryptedKey;
     }
@@ -100,19 +65,19 @@ public abstract class EncryptionVerifier {
     }
 
     protected void setSalt(byte[] salt) {
-        this.salt = salt;
+        this.salt = (salt == null) ? null : salt.clone();
     }
 
     protected void setEncryptedVerifier(byte[] encryptedVerifier) {
-        this.encryptedVerifier = encryptedVerifier;
+        this.encryptedVerifier = (encryptedVerifier == null) ? null : encryptedVerifier.clone();
     }
 
     protected void setEncryptedVerifierHash(byte[] encryptedVerifierHash) {
-        this.encryptedVerifierHash = encryptedVerifierHash;
+        this.encryptedVerifierHash = (encryptedVerifierHash == null) ? null : encryptedVerifierHash.clone();
     }
 
     protected void setEncryptedKey(byte[] encryptedKey) {
-        this.encryptedKey = encryptedKey;
+        this.encryptedKey = (encryptedKey == null) ? null : encryptedKey.clone();
     }
 
     protected void setSpinCount(int spinCount) {
@@ -131,5 +96,13 @@ public abstract class EncryptionVerifier {
         this.hashAlgorithm = hashAlgorithm;
     }
     
-    
+    @Override
+    public EncryptionVerifier clone() throws CloneNotSupportedException {
+        EncryptionVerifier other = (EncryptionVerifier)super.clone();
+        other.salt = (salt == null) ? null : salt.clone();
+        other.encryptedVerifier = (encryptedVerifier == null) ? null : encryptedVerifier.clone();
+        other.encryptedVerifierHash = (encryptedVerifierHash == null) ? null : encryptedVerifierHash.clone();
+        other.encryptedKey = (encryptedKey == null) ? null : encryptedKey.clone();
+        return other;
+    }
 }
