@@ -37,8 +37,6 @@ import org.apache.poi.poifs.property.Property;
 
 /**
  * Simple implementation of DirectoryEntry
- *
- * @author Marc Johnson (mjohnson at apache dot org)
  */
 public class DirectoryNode
     extends EntryNode
@@ -46,33 +44,16 @@ public class DirectoryNode
 {
 
     // Map of Entry instances, keyed by their names
-    private Map<String,Entry> _byname;
+    private final Map<String,Entry> _byname = new HashMap<>();
+
     // Our list of entries, kept sorted to preserve order
-    private ArrayList<Entry> _entries;
+    private final ArrayList<Entry> _entries = new ArrayList<>();
 
-   // Only one of these two will exist
-    // the POIFSFileSystem we belong to
-    private POIFSFileSystem   _ofilesystem;
     // the NPOIFSFileSytem we belong to
-    private NPOIFSFileSystem  _nfilesystem;
+    private final POIFSFileSystem _nfilesystem;
 
     // the path described by this document
-    private POIFSDocumentPath _path;
-
-    /**
-     * create a DirectoryNode. This method is not public by design; it
-     * is intended strictly for the internal use of this package
-     *
-     * @param property the DirectoryProperty for this DirectoryEntry
-     * @param filesystem the POIFSFileSystem we belong to
-     * @param parent the parent of this entry
-     */
-    DirectoryNode(final DirectoryProperty property,
-                  final POIFSFileSystem filesystem,
-                  final DirectoryNode parent)
-    {
-       this(property, parent, filesystem, (NPOIFSFileSystem)null);
-    }
+    private final POIFSDocumentPath _path;
 
     /**
      * create a DirectoryNode. This method is not public by design; it
@@ -83,19 +64,10 @@ public class DirectoryNode
      * @param parent the parent of this entry
      */
     DirectoryNode(final DirectoryProperty property,
-                  final NPOIFSFileSystem nfilesystem,
+                  final POIFSFileSystem nfilesystem,
                   final DirectoryNode parent)
-    {
-       this(property, parent, (POIFSFileSystem)null, nfilesystem);
-    }
-
-    private DirectoryNode(final DirectoryProperty property,
-                          final DirectoryNode parent,
-                          final POIFSFileSystem ofilesystem,
-                          final NPOIFSFileSystem nfilesystem)
     {
         super(property, parent);
-        this._ofilesystem = ofilesystem;
         this._nfilesystem = nfilesystem;
 
         if (parent == null)
@@ -105,27 +77,21 @@ public class DirectoryNode
         else
         {
             _path = new POIFSDocumentPath(parent._path, new String[]
-            {
-                property.getName()
-            });
+                    {
+                            property.getName()
+                    });
         }
-        _byname     = new HashMap<String, Entry>();
-        _entries    = new ArrayList<Entry>();
         Iterator<Property> iter = property.getChildren();
 
         while (iter.hasNext())
         {
             Property child     = iter.next();
-            Entry    childNode = null;
+            Entry    childNode;
 
             if (child.isDirectory())
             {
                 DirectoryProperty childDir = (DirectoryProperty) child;
-                if(_ofilesystem != null) {
-                   childNode = new DirectoryNode(childDir, _ofilesystem, this);
-                } else {
-                   childNode = new DirectoryNode(childDir, _nfilesystem, this);
-                }
+                childNode = new DirectoryNode(childDir, _nfilesystem, this);
             }
             else
             {
@@ -150,13 +116,16 @@ public class DirectoryNode
      */
     public POIFSFileSystem getFileSystem()
     {
-        return _ofilesystem;
+        return _nfilesystem;
     }
 
+
     /**
+     * If this is NPOIFS based, return the NPOIFSFileSystem
+     *  that this belong to, otherwise Null if OPOIFS based
      * @return the filesystem that this belongs to
      */
-    public NPOIFSFileSystem getNFileSystem()
+    public POIFSFileSystem getNFileSystem()
     {
         return _nfilesystem;
     }
@@ -183,7 +152,7 @@ public class DirectoryNode
      *
      * @param document the document to be opened
      *
-     * @return a newly opened DocumentInputStream or NDocumentInputStream
+     * @return a newly opened DocumentInputStream or DocumentInputStream
      *
      * @exception IOException if the document does not exist or the
      *            name is that of a DirectoryEntry
@@ -208,7 +177,7 @@ public class DirectoryNode
      *
      * @return the new DocumentEntry
      *
-     * @exception IOException
+     * @exception IOException if the document can't be created
      */
     DocumentEntry createDocument(final POIFSDocument document)
         throws IOException
@@ -216,29 +185,6 @@ public class DirectoryNode
         DocumentProperty property = document.getDocumentProperty();
         DocumentNode     rval     = new DocumentNode(property, this);
 
-        (( DirectoryProperty ) getProperty()).addChild(property);
-        _ofilesystem.addDocument(document);
-
-        _entries.add(rval);
-        _byname.put(property.getName(), rval);
-        return rval;
-    }
-
-    /**
-     * create a new DocumentEntry
-     *
-     * @param document the new document
-     *
-     * @return the new DocumentEntry
-     *
-     * @exception IOException
-     */
-    DocumentEntry createDocument(final NPOIFSDocument document)
-        throws IOException
-    {
-        DocumentProperty property = document.getDocumentProperty();
-        DocumentNode     rval     = new DocumentNode(property, this);
-
         (( DirectoryProperty ) getProperty()).addChild(property);
         _nfilesystem.addDocument(document);
 
@@ -292,14 +238,11 @@ public class DirectoryNode
             _entries.remove(entry);
             _byname.remove(entry.getName());
 
-            if(_ofilesystem != null) {
-                _ofilesystem.remove(entry);
-            } else {
-                try {
-                    _nfilesystem.remove(entry);
-                } catch (IOException e) {
-                    // TODO Work out how to report this, given we can't change the method signature...
-                }
+            try {
+                _nfilesystem.remove(entry);
+            } catch (IOException e) {
+                // TODO Work out how to report this, given we can't change the method signature...
+                throw new RuntimeException(e);
             }
         }
         return rval;
@@ -401,18 +344,14 @@ public class DirectoryNode
      *
      * @return the new DocumentEntry
      *
-     * @exception IOException
+     * @exception IOException if the document can't be created
      */
 
     public DocumentEntry createDocument(final String name,
                                         final InputStream stream)
         throws IOException
     {
-        if(_nfilesystem != null) {
-           return createDocument(new NPOIFSDocument(name, _nfilesystem, stream));
-        } else {
-           return createDocument(new POIFSDocument(name, stream));
-        }
+        return createDocument(new POIFSDocument(name, _nfilesystem, stream));
     }
 
     /**
@@ -424,18 +363,14 @@ public class DirectoryNode
      *
      * @return the new DocumentEntry
      *
-     * @exception IOException
+     * @exception IOException if the document can't be created
      */
 
     public DocumentEntry createDocument(final String name, final int size,
                                         final POIFSWriterListener writer)
         throws IOException
     {
-        if(_nfilesystem != null) {
-            return createDocument(new NPOIFSDocument(name, size, _nfilesystem, writer));
-         } else {
-            return createDocument(new POIFSDocument(name, size, _path, writer));
-         }
+        return createDocument(new POIFSDocument(name, size, _nfilesystem, writer));
     }
 
     /**
@@ -445,22 +380,16 @@ public class DirectoryNode
      *
      * @return the new DirectoryEntry
      *
-     * @exception IOException
+     * @exception IOException if the directory can't be created
      */
 
     public DirectoryEntry createDirectory(final String name)
         throws IOException
     {
-        DirectoryNode rval;
         DirectoryProperty property = new DirectoryProperty(name);
 
-        if(_ofilesystem != null) {
-           rval = new DirectoryNode(property, _ofilesystem, this);
-           _ofilesystem.addDirectory(property);
-        } else {
-           rval = new DirectoryNode(property, _nfilesystem, this);
-           _nfilesystem.addDirectory(property);
-        }
+        DirectoryNode rval = new DirectoryNode(property, _nfilesystem, this);
+       _nfilesystem.addDirectory(property);
 
         (( DirectoryProperty ) getProperty()).addChild(property);
         _entries.add(rval);
@@ -468,6 +397,32 @@ public class DirectoryNode
         return rval;
     }
 
+    /**
+     * Set the contents of a document, creating if needed, 
+     *  otherwise updating. Returns the created / updated DocumentEntry
+     *
+     * @param name the name of the new or existing DocumentEntry
+     * @param stream the InputStream from which to populate the DocumentEntry
+     *
+     * @return the new or updated DocumentEntry
+     *
+     * @exception IOException if the document can't be created or its content be replaced
+     */
+    @SuppressWarnings("WeakerAccess")
+    public DocumentEntry createOrUpdateDocument(final String name,
+                                                final InputStream stream)
+        throws IOException
+    {
+        if (! hasEntry(name)) {
+            return createDocument(name, stream);
+        } else {
+            DocumentNode existing = (DocumentNode)getEntry(name);
+            POIFSDocument nDoc = new POIFSDocument(existing);
+            nDoc.replaceContents(stream);
+            return existing;
+        }
+    }
+    
     /**
      * Gets the storage clsid of the directory entry
      *
@@ -544,16 +499,11 @@ public class DirectoryNode
      * @return an Iterator; may not be null, but may have an empty
      * back end store
      */
-    public Iterator<Object> getViewableIterator()
-    {
-        List<Object> components = new ArrayList<Object>();
+    public Iterator<Object> getViewableIterator() {
+        List<Object> components = new ArrayList<>();
 
         components.add(getProperty());
-        Iterator<Entry> iter = _entries.iterator();
-        while (iter.hasNext())
-        {
-            components.add(iter.next());
-        }
+        components.addAll(_entries);
         return components.iterator();
     }
 
