@@ -17,12 +17,14 @@
         
 package org.apache.poi.poifs.filesystem;
 
+import org.apache.poi.UnsupportedFileFormatException;
+
 /**
  * This exception is thrown when we try to open a file that's actually
  *  an Office 2007+ XML file, rather than an OLE2 file (which is what
  *  POIFS works with)
  */
-public class OfficeXmlFileException extends IllegalArgumentException {
+public class OfficeXmlFileException extends UnsupportedFileFormatException {
 	public OfficeXmlFileException(String s) {
 		super(s);
 	}
