@@ -17,6 +17,10 @@
 
 package org.apache.poi.ss.formula.functions;
 
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
+
+import org.apache.poi.ss.formula.TwoDEval;
 import org.apache.poi.ss.formula.eval.BlankEval;
 import org.apache.poi.ss.formula.eval.BoolEval;
 import org.apache.poi.ss.formula.eval.ErrorEval;
@@ -27,10 +31,6 @@ import org.apache.poi.ss.formula.eval.OperandResolver;
 import org.apache.poi.ss.formula.eval.RefEval;
 import org.apache.poi.ss.formula.eval.StringEval;
 import org.apache.poi.ss.formula.eval.ValueEval;
-import org.apache.poi.ss.formula.TwoDEval;
-
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
 
 /**
  * Common functionality used by VLOOKUP, HLOOKUP, LOOKUP and MATCH
@@ -104,6 +104,28 @@ final class LookupUtils {
 		}
 	}
 
+    private static final class SheetVector implements ValueVector {
+        private final RefEval _re;
+        private final int _size;
+
+        public SheetVector(RefEval re) {
+            _size = re.getNumberOfSheets();
+            _re = re;
+        }
+
+        public ValueEval getItem(int index) {
+            if(index >= _size) {
+                throw new ArrayIndexOutOfBoundsException("Specified index (" + index
+                        + ") is outside the allowed range (0.." + (_size-1) + ")");
+            }
+            int sheetIndex = _re.getFirstSheetIndex() + index;
+            return _re.getInnerValueEval(sheetIndex);
+        }
+        public int getSize() {
+            return _size;
+        }
+    }
+
 	public static ValueVector createRowVector(TwoDEval tableArray, int relativeRowIndex) {
 		return new RowVector(tableArray, relativeRowIndex);
 	}
@@ -122,13 +144,17 @@ final class LookupUtils {
 		}
 		return null;
 	}
+	
+	public static ValueVector createVector(RefEval re) {
+	    return new SheetVector(re);
+	}
 
 	/**
-	 * Enumeration to support <b>4</b> valued comparison results.<p/>
+	 * Enumeration to support <b>4</b> valued comparison results.<p>
 	 * Excel lookup functions have complex behaviour in the case where the lookup array has mixed
 	 * types, and/or is unordered.  Contrary to suggestions in some Excel documentation, there
 	 * does not appear to be a universal ordering across types.  The binary search algorithm used
-	 * changes behaviour when the evaluated 'mid' value has a different type to the lookup value.<p/>
+	 * changes behaviour when the evaluated 'mid' value has a different type to the lookup value.<p>
 	 *
 	 * A simple int might have done the same job, but there is risk in confusion with the well
 	 * known <tt>Comparable.compareTo()</tt> and <tt>Comparator.compare()</tt> which both use
@@ -158,7 +184,7 @@ final class LookupUtils {
 		public static final CompareResult EQUAL = new CompareResult(false, 0);
 		public static final CompareResult GREATER_THAN = new CompareResult(false, +1);
 
-		public static final CompareResult valueOf(int simpleCompareResult) {
+		public static CompareResult valueOf(int simpleCompareResult) {
 			if(simpleCompareResult < 0) {
 				return LESS_THAN;
 			}
@@ -168,7 +194,7 @@ final class LookupUtils {
 			return EQUAL;
 		}
 
-        public static final CompareResult valueOf(boolean matches) {
+        public static CompareResult valueOf(boolean matches) {
             if(matches) {
                 return EQUAL ;
             }
@@ -189,11 +215,9 @@ final class LookupUtils {
 			return _isGreaterThan;
 		}
 		public String toString() {
-			StringBuffer sb = new StringBuffer(64);
-			sb.append(getClass().getName()).append(" [");
-			sb.append(formatAsString());
-			sb.append("]");
-			return sb.toString();
+			return getClass().getName() + " [" +
+					formatAsString() +
+					"]";
 		}
 
 		private String formatAsString() {
@@ -241,11 +265,9 @@ final class LookupUtils {
 			return compareSameType(other);
 		}
 		public String toString() {
-			StringBuffer sb = new StringBuffer(64);
-			sb.append(getClass().getName()).append(" [");
-			sb.append(getValueAsString());
-			sb.append("]");
-			return sb.toString();
+			return getClass().getName() + " [" +
+					getValueAsString() +
+					"]";
 		}
 		protected abstract CompareResult compareSameType(ValueEval other);
 		/** used only for debug purposes */
@@ -344,7 +366,7 @@ final class LookupUtils {
 	 *      <tr><td>"abc"</td><td>&nbsp;</td><td>#REF!</td></tr>
 	 *      <tr><td>""</td><td>&nbsp;</td><td>#REF!</td></tr>
 	 *      <tr><td>&lt;blank&gt;</td><td>&nbsp;</td><td>#VALUE!</td></tr>
-	 *    </table><br/>
+	 *    </table><br>
 	 *
 	 * Note - out of range errors (result index too high) are handled by the caller.
 	 * @return column or row index as a zero-based value, never negative.
@@ -449,7 +471,7 @@ final class LookupUtils {
 			// zero is FALSE, everything else is TRUE
 			return 0.0 != nve.getNumberValue();
 		}
-		throw new RuntimeException("Unexpected eval type (" + valEval.getClass().getName() + ")");
+		throw new RuntimeException("Unexpected eval type (" + valEval + ")");
 	}
 
 	public static int lookupIndexOfValue(ValueEval lookupValue, ValueVector vector, boolean isRangeLookup) throws EvaluationException {
