@@ -18,18 +18,9 @@
 package org.apache.poi.ss.usermodel;
 
 
+import org.apache.poi.util.Removal;
+
 public interface Font {
-    /**
-     * Normal boldness (not bold)
-     */
-
-    public final static short BOLDWEIGHT_NORMAL = 0x190;
-
-    /**
-     * Bold boldness (bold)
-     */
-
-    public final static short BOLDWEIGHT_BOLD = 0x2bc;
 
     /**
      * normal type of black color.
@@ -138,20 +129,25 @@ public interface Font {
     void setFontHeightInPoints(short height);
 
     /**
-     * get the font height in unit's of 1/20th of a point.  Maybe you might want to
-     * use the getFontHeightInPoints which matches to the familiar 10, 12, 14 etc..
+     * Get the font height in unit's of 1/20th of a point.
+     * <p>
+     * For many users, the related {@link #getFontHeightInPoints()}
+     *  will be more helpful, as that returns font heights in the
+     *  more familiar points units, eg 10, 12, 14.
+
      * @return short - height in 1/20ths of a point
      * @see #getFontHeightInPoints()
      */
-
     short getFontHeight();
 
     /**
-     * get the font height
+     * Get the font height in points.
+     * <p>
+     * This will return the same font height that is shown in Excel,
+     *  such as 10 or 14 or 28.
      * @return short - height in the familiar unit of measure - points
      * @see #getFontHeight()
      */
-
     short getFontHeightInPoints();
 
     /**
@@ -273,12 +269,21 @@ public interface Font {
      * 
      * @return unique index number of the underlying record this Font represents (probably you don't care
      *  unless you're comparing which one is which)
+     * @deprecated use <code>getIndexAsInt()</code> instead
      */
+    @Removal(version = "4.2")
     public short getIndex();
 
-    public void setBoldweight(short boldweight);
+    /**
+     * get the index within the XSSFWorkbook (sequence within the collection of Font objects)
+     *
+     * @return unique index number of the underlying record this Font represents (probably you don't care
+     *  unless you're comparing which one is which)
+     * @since 4.0.0
+     */
+    public int getIndexAsInt();
+
     public void setBold(boolean bold);
 
-    public short getBoldweight();
     public boolean getBold();
-}
\ No newline at end of file
+}
