@@ -40,11 +40,13 @@ import javax.crypto.spec.RC2ParameterSpec;
 import javax.crypto.spec.SecretKeySpec;
 
 import org.apache.poi.EncryptedDocumentException;
+import org.apache.poi.poifs.crypt.ChainingMode;
+import org.apache.poi.poifs.crypt.ChunkedCipherInputStream;
 import org.apache.poi.poifs.crypt.CipherAlgorithm;
 import org.apache.poi.poifs.crypt.CryptoFunctions;
 import org.apache.poi.poifs.crypt.Decryptor;
 import org.apache.poi.poifs.crypt.EncryptionHeader;
-import org.apache.poi.poifs.crypt.EncryptionVerifier;
+import org.apache.poi.poifs.crypt.EncryptionInfo;
 import org.apache.poi.poifs.crypt.HashAlgorithm;
 import org.apache.poi.poifs.crypt.agile.AgileEncryptionVerifier.AgileCertificateEntry;
 import org.apache.poi.poifs.filesystem.DirectoryNode;
@@ -54,17 +56,14 @@ import org.apache.poi.util.LittleEndian;
 /**
  * Decryptor implementation for Agile Encryption
  */
-public class AgileDecryptor extends Decryptor {
-    private final AgileEncryptionInfoBuilder builder;
-    
-
+public class AgileDecryptor extends Decryptor implements Cloneable {
     private long _length = -1;
 
-    protected static final byte[] kVerifierInputBlock;
-    protected static final byte[] kHashedVerifierBlock;
-    protected static final byte[] kCryptoKeyBlock;
-    protected static final byte[] kIntegrityKeyBlock;
-    protected static final byte[] kIntegrityValueBlock;
+    /* package */ static final byte[] kVerifierInputBlock;
+    /* package */ static final byte[] kHashedVerifierBlock;
+    /* package */ static final byte[] kCryptoKeyBlock;
+    /* package */ static final byte[] kIntegrityKeyBlock;
+    /* package */ static final byte[] kIntegrityValueBlock;
 
     static {
         kVerifierInputBlock =
@@ -84,21 +83,18 @@ public class AgileDecryptor extends Decryptor {
                          (byte)0xb2, (byte)0x2c, (byte)0x84, (byte)0x33 };
     }
 
-    protected AgileDecryptor(AgileEncryptionInfoBuilder builder) {
-        super(builder.getInfo());
-        this.builder = builder; 
+    protected AgileDecryptor() {
     }
     
     /**
      * set decryption password
      */
+    @Override
     public boolean verifyPassword(String password) throws GeneralSecurityException {
-        AgileEncryptionVerifier ver = builder.getVerifier();
-        AgileEncryptionHeader header = builder.getHeader(); 
-        HashAlgorithm hashAlgo = header.getHashAlgorithmEx();
-        CipherAlgorithm cipherAlgo = header.getCipherAlgorithm();
+        AgileEncryptionVerifier ver = (AgileEncryptionVerifier)getEncryptionInfo().getVerifier();
+        AgileEncryptionHeader header = (AgileEncryptionHeader)getEncryptionInfo().getHeader(); 
+
         int blockSize = header.getBlockSize();
-        int keySize = header.getKeySize()/8;
 
         byte[] pwHash = hashPassword(password, ver.getHashAlgorithm(), ver.getSalt(), ver.getSpinCount());
 
@@ -115,9 +111,9 @@ public class AgileDecryptor extends Decryptor {
          *    blockSize bytes.
          * 4. Use base64 to encode the result of step 3.
          */
-        byte verfierInputEnc[] = hashInput(builder, pwHash, kVerifierInputBlock, ver.getEncryptedVerifier(), Cipher.DECRYPT_MODE);
+        byte verfierInputEnc[] = hashInput(ver, pwHash, kVerifierInputBlock, ver.getEncryptedVerifier(), Cipher.DECRYPT_MODE);
         setVerifier(verfierInputEnc);
-        MessageDigest hashMD = getMessageDigest(hashAlgo);
+        MessageDigest hashMD = getMessageDigest(ver.getHashAlgorithm());
         byte[] verifierHash = hashMD.digest(verfierInputEnc);
 
         /**
@@ -132,8 +128,8 @@ public class AgileDecryptor extends Decryptor {
          *    blockSize bytes, pad the hash value with 0x00 to an integral multiple of blockSize bytes.
          * 4. Use base64 to encode the result of step 3.
          */
-        byte verifierHashDec[] = hashInput(builder, pwHash, kHashedVerifierBlock, ver.getEncryptedVerifierHash(), Cipher.DECRYPT_MODE);
-        verifierHashDec = getBlock0(verifierHashDec, hashAlgo.hashSize);
+        byte verifierHashDec[] = hashInput(ver, pwHash, kHashedVerifierBlock, ver.getEncryptedVerifierHash(), Cipher.DECRYPT_MODE);
+        verifierHashDec = getBlock0(verifierHashDec, ver.getHashAlgorithm().hashSize);
         
         /**
          * encryptedKeyValue: This attribute MUST be generated by using the following steps:
@@ -148,9 +144,9 @@ public class AgileDecryptor extends Decryptor {
          *    blockSize bytes.
          * 4. Use base64 to encode the result of step 3.
          */
-        byte keyspec[] = hashInput(builder, pwHash, kCryptoKeyBlock, ver.getEncryptedKey(), Cipher.DECRYPT_MODE);
-        keyspec = getBlock0(keyspec, keySize);
-        SecretKeySpec secretKey = new SecretKeySpec(keyspec, ver.getCipherAlgorithm().jceId);
+        byte keyspec[] = hashInput(ver, pwHash, kCryptoKeyBlock, ver.getEncryptedKey(), Cipher.DECRYPT_MODE);
+        keyspec = getBlock0(keyspec, header.getKeySize()/8);
+        SecretKeySpec secretKey = new SecretKeySpec(keyspec, header.getCipherAlgorithm().jceId);
 
         /**
          * 1. Obtain the intermediate key by decrypting the encryptedKeyValue from a KeyEncryptor
@@ -165,10 +161,11 @@ public class AgileDecryptor extends Decryptor {
          *    array with 0x00 to the next integral multiple of blockSize bytes.
          * 4. Assign the encryptedHmacKey attribute to the base64-encoded form of the result of step 3.
          */
-        byte vec[] = CryptoFunctions.generateIv(hashAlgo, header.getKeySalt(), kIntegrityKeyBlock, blockSize); 
-        Cipher cipher = getCipher(secretKey, cipherAlgo, ver.getChainingMode(), vec, Cipher.DECRYPT_MODE);
+        byte vec[] = CryptoFunctions.generateIv(header.getHashAlgorithm(), header.getKeySalt(), kIntegrityKeyBlock, blockSize);
+        CipherAlgorithm cipherAlgo = header.getCipherAlgorithm();
+        Cipher cipher = getCipher(secretKey, cipherAlgo, header.getChainingMode(), vec, Cipher.DECRYPT_MODE);
         byte hmacKey[] = cipher.doFinal(header.getEncryptedHmacKey());
-        hmacKey = getBlock0(hmacKey, hashAlgo.hashSize);
+        hmacKey = getBlock0(hmacKey, header.getHashAlgorithm().hashSize);
 
         /**
          * 5. Generate an HMAC, as specified in [RFC2104], of the encrypted form of the data (message),
@@ -179,10 +176,10 @@ public class AgileDecryptor extends Decryptor {
          *    0xa0, 0x67, 0x7f, 0x02, 0xb2, 0x2c, 0x84, and 0x33.
          * 7. Assign the encryptedHmacValue attribute to the base64-encoded form of the result of step 6.
          */
-        vec = CryptoFunctions.generateIv(hashAlgo, header.getKeySalt(), kIntegrityValueBlock, blockSize);
+        vec = CryptoFunctions.generateIv(header.getHashAlgorithm(), header.getKeySalt(), kIntegrityValueBlock, blockSize);
         cipher = getCipher(secretKey, cipherAlgo, ver.getChainingMode(), vec, Cipher.DECRYPT_MODE);
         byte hmacValue[] = cipher.doFinal(header.getEncryptedHmacValue());
-        hmacValue = getBlock0(hmacValue, hashAlgo.hashSize);
+        hmacValue = getBlock0(hmacValue, header.getHashAlgorithm().hashSize);
         
         if (Arrays.equals(verifierHashDec, verifierHash)) {
             setSecretKey(secretKey);
@@ -206,9 +203,9 @@ public class AgileDecryptor extends Decryptor {
      * @throws GeneralSecurityException
      */
     public boolean verifyPassword(KeyPair keyPair, X509Certificate x509) throws GeneralSecurityException {
-        AgileEncryptionVerifier ver = builder.getVerifier();
-        AgileEncryptionHeader header = builder.getHeader();
-        HashAlgorithm hashAlgo = header.getHashAlgorithmEx();
+        AgileEncryptionVerifier ver = (AgileEncryptionVerifier)getEncryptionInfo().getVerifier();
+        AgileEncryptionHeader header = (AgileEncryptionHeader)getEncryptionInfo().getHeader();
+        HashAlgorithm hashAlgo = header.getHashAlgorithm();
         CipherAlgorithm cipherAlgo = header.getCipherAlgorithm();
         int blockSize = header.getBlockSize();
         
@@ -219,7 +216,9 @@ public class AgileDecryptor extends Decryptor {
                 break;
             }
         }
-        if (ace == null) return false;
+        if (ace == null) {
+            return false;
+        }
         
         Cipher cipher = Cipher.getInstance("RSA");
         cipher.init(Cipher.DECRYPT_MODE, keyPair.getPrivate());
@@ -231,12 +230,12 @@ public class AgileDecryptor extends Decryptor {
         byte certVerifier[] = x509Hmac.doFinal(ace.x509.getEncoded());
 
         byte vec[] = CryptoFunctions.generateIv(hashAlgo, header.getKeySalt(), kIntegrityKeyBlock, blockSize); 
-        cipher = getCipher(secretKey, cipherAlgo, ver.getChainingMode(), vec, Cipher.DECRYPT_MODE);
+        cipher = getCipher(secretKey, cipherAlgo, header.getChainingMode(), vec, Cipher.DECRYPT_MODE);
         byte hmacKey[] = cipher.doFinal(header.getEncryptedHmacKey());
         hmacKey = getBlock0(hmacKey, hashAlgo.hashSize);
 
         vec = CryptoFunctions.generateIv(hashAlgo, header.getKeySalt(), kIntegrityValueBlock, blockSize);
-        cipher = getCipher(secretKey, cipherAlgo, ver.getChainingMode(), vec, Cipher.DECRYPT_MODE);
+        cipher = getCipher(secretKey, cipherAlgo, header.getChainingMode(), vec, Cipher.DECRYPT_MODE);
         byte hmacValue[] = cipher.doFinal(header.getEncryptedHmacValue());
         hmacValue = getBlock0(hmacValue, hashAlgo.hashSize);
         
@@ -257,17 +256,17 @@ public class AgileDecryptor extends Decryptor {
         return fillSize;
     }
 
-    protected static byte[] hashInput(AgileEncryptionInfoBuilder builder, byte pwHash[], byte blockKey[], byte inputKey[], int cipherMode) {
-        EncryptionVerifier ver = builder.getVerifier();
-        int keySize = builder.getDecryptor().getKeySizeInBytes();
-        int blockSize = builder.getDecryptor().getBlockSizeInBytes();
+    /* package */ static byte[] hashInput(AgileEncryptionVerifier ver, byte pwHash[], byte blockKey[], byte inputKey[], int cipherMode) {
+        CipherAlgorithm cipherAlgo = ver.getCipherAlgorithm();
+        ChainingMode chainMode = ver.getChainingMode();
+        int keySize = ver.getKeySize()/8;
+        int blockSize = ver.getBlockSize();
         HashAlgorithm hashAlgo = ver.getHashAlgorithm();
-        byte[] salt = ver.getSalt();
-
+        
         byte intermedKey[] = generateKey(pwHash, hashAlgo, blockKey, keySize);
-        SecretKey skey = new SecretKeySpec(intermedKey, ver.getCipherAlgorithm().jceId);
-        byte[] iv = generateIv(hashAlgo, salt, null, blockSize);
-        Cipher cipher = getCipher(skey, ver.getCipherAlgorithm(), ver.getChainingMode(), iv, cipherMode);
+        SecretKey skey = new SecretKeySpec(intermedKey, cipherAlgo.jceId);
+        byte[] iv = generateIv(hashAlgo, ver.getSalt(), null, blockSize);
+        Cipher cipher = getCipher(skey, cipherAlgo, chainMode, iv, cipherMode);
         byte[] hashFinal;
         
         try {
@@ -279,19 +278,46 @@ public class AgileDecryptor extends Decryptor {
         }
     }
 
+    @Override
     public InputStream getDataStream(DirectoryNode dir) throws IOException, GeneralSecurityException {
-        DocumentInputStream dis = dir.createDocumentInputStream("EncryptedPackage");
+        DocumentInputStream dis = dir.createDocumentInputStream(DEFAULT_POIFS_ENTRY);
         _length = dis.readLong();
-        
-        ChunkedCipherInputStream cipherStream = new ChunkedCipherInputStream(dis, _length);
-        return cipherStream;
+        return new AgileCipherInputStream(dis, _length);
     }
 
+    @Override
     public long getLength(){
-        if(_length == -1) throw new IllegalStateException("EcmaDecryptor.getDataStream() was not called");
+        if(_length == -1) {
+            throw new IllegalStateException("EcmaDecryptor.getDataStream() was not called");
+        }
         return _length;
     }
 
+
+    protected static Cipher initCipherForBlock(Cipher existing, int block, boolean lastChunk, EncryptionInfo encryptionInfo, SecretKey skey, int encryptionMode)
+    throws GeneralSecurityException {
+        EncryptionHeader header = encryptionInfo.getHeader();
+        String padding = (lastChunk ? "PKCS5Padding" : "NoPadding");
+        if (existing == null || !existing.getAlgorithm().endsWith(padding)) {
+            existing = getCipher(skey, header.getCipherAlgorithm(), header.getChainingMode(), header.getKeySalt(), encryptionMode, padding);
+        }
+
+        byte[] blockKey = new byte[4];
+        LittleEndian.putInt(blockKey, 0, block);
+        byte[] iv = generateIv(header.getHashAlgorithm(), header.getKeySalt(), blockKey, header.getBlockSize());
+
+        AlgorithmParameterSpec aps;
+        if (header.getCipherAlgorithm() == CipherAlgorithm.rc2) {
+            aps = new RC2ParameterSpec(skey.getEncoded().length*8, iv);
+        } else {
+            aps = new IvParameterSpec(iv);
+        }
+
+        existing.init(encryptionMode, skey, aps);
+        
+        return existing;
+    }
+
     /**
      * 2.3.4.15 Data Encryption (Agile Encryption)
      * 
@@ -307,107 +333,24 @@ public class AgileDecryptor extends Decryptor {
      * that the StreamSize field of the EncryptedPackage field specifies the number of bytes of
      * unencrypted data as specified in section 2.3.4.4.
      */
-    private class ChunkedCipherInputStream extends InputStream {
-        private int _lastIndex = 0;
-        private long _pos = 0;
-        private final long _size;
-        private final InputStream _stream;
-        private byte[] _chunk;
-        private Cipher _cipher;
-
-        public ChunkedCipherInputStream(DocumentInputStream stream, long size)
-            throws GeneralSecurityException {
-            EncryptionHeader header = info.getHeader();
-            _size = size;
-            _stream = stream;
-            _cipher = getCipher(getSecretKey(), header.getCipherAlgorithm(), header.getChainingMode(), header.getKeySalt(), Cipher.DECRYPT_MODE);
+    private class AgileCipherInputStream extends ChunkedCipherInputStream {
+        public AgileCipherInputStream(DocumentInputStream stream, long size)
+        throws GeneralSecurityException {
+            super(stream, size, 4096);
         }
 
-        public int read() throws IOException {
-            byte[] b = new byte[1];
-            if (read(b) == 1)
-                return b[0];
-            return -1;
+        // TODO: calculate integrity hmac while reading the stream
+        // for a post-validation of the data
+        
+        @Override
+        protected Cipher initCipherForBlock(Cipher cipher, int block)
+        throws GeneralSecurityException {
+            return AgileDecryptor.initCipherForBlock(cipher, block, false, getEncryptionInfo(), getSecretKey(), Cipher.DECRYPT_MODE);
         }
-
-        public int read(byte[] b) throws IOException {
-            return read(b, 0, b.length);
-        }
-
-        public int read(byte[] b, int off, int len) throws IOException {
-            int total = 0;
-            
-            if (available() <= 0) return -1;
-
-            while (len > 0) {
-                if (_chunk == null) {
-                    try {
-                        _chunk = nextChunk();
-                    } catch (GeneralSecurityException e) {
-                        throw new EncryptedDocumentException(e.getMessage());
-                    }
-                }
-                int count = (int)(4096L - (_pos & 0xfff));
-                int avail = available();
-                if (avail == 0) {
-                    return total;
-                }
-                count = Math.min(avail, Math.min(count, len));
-                System.arraycopy(_chunk, (int)(_pos & 0xfff), b, off, count);
-                off += count;
-                len -= count;
-                _pos += count;
-                if ((_pos & 0xfff) == 0)
-                    _chunk = null;
-                total += count;
-            }
-
-            return total;
-        }
-
-        public long skip(long n) throws IOException {
-            long start = _pos;
-            long skip = Math.min(available(), n);
-
-            if ((((_pos + skip) ^ start) & ~0xfff) != 0)
-                _chunk = null;
-            _pos += skip;
-            return skip;
-        }
-
-        public int available() throws IOException { return (int)(_size - _pos); }
-        public void close() throws IOException { _stream.close(); }
-        public boolean markSupported() { return false; }
-
-        private byte[] nextChunk() throws GeneralSecurityException, IOException {
-            int index = (int)(_pos >> 12);
-            byte[] blockKey = new byte[4];
-            LittleEndian.putInt(blockKey, 0, index);
-            EncryptionHeader header = info.getHeader();
-            byte[] iv = generateIv(header.getHashAlgorithmEx(), header.getKeySalt(), blockKey, getBlockSizeInBytes());
-            AlgorithmParameterSpec aps;
-            if (header.getCipherAlgorithm() == CipherAlgorithm.rc2) {
-                aps = new RC2ParameterSpec(getSecretKey().getEncoded().length*8, iv);
-            } else {
-                aps = new IvParameterSpec(iv);
-            }
-            
-            _cipher.init(Cipher.DECRYPT_MODE, getSecretKey(), aps);
-            if (_lastIndex != index)
-                _stream.skip((index - _lastIndex) << 12);
-
-            byte[] block = new byte[Math.min(_stream.available(), 4096)];
-            _stream.read(block);
-            _lastIndex = index + 1;
-            return _cipher.doFinal(block);
-        }
-    }
-
-    protected int getBlockSizeInBytes() {
-    	return info.getHeader().getBlockSize();
     }
     
-    protected int getKeySizeInBytes() {
-    	return info.getHeader().getKeySize()/8;
+    @Override
+    public AgileDecryptor clone() throws CloneNotSupportedException {
+        return (AgileDecryptor)super.clone();
     }
 }
