@@ -16,11 +16,11 @@
 ==================================================================== */
 package org.apache.poi.poifs.crypt.agile;
 
-import static org.apache.poi.poifs.crypt.CryptoFunctions.generateIv;
 import static org.apache.poi.poifs.crypt.CryptoFunctions.getBlock0;
 import static org.apache.poi.poifs.crypt.CryptoFunctions.getCipher;
 import static org.apache.poi.poifs.crypt.CryptoFunctions.getMessageDigest;
 import static org.apache.poi.poifs.crypt.CryptoFunctions.hashPassword;
+import static org.apache.poi.poifs.crypt.DataSpaceMapUtils.createEncryptionEntry;
 import static org.apache.poi.poifs.crypt.agile.AgileDecryptor.getNextBlockSize;
 import static org.apache.poi.poifs.crypt.agile.AgileDecryptor.hashInput;
 import static org.apache.poi.poifs.crypt.agile.AgileDecryptor.kCryptoKeyBlock;
@@ -32,8 +32,6 @@ import static org.apache.poi.poifs.crypt.agile.AgileDecryptor.kVerifierInputBloc
 import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.FileInputStream;
-import java.io.FileOutputStream;
-import java.io.FilterOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
@@ -41,7 +39,6 @@ import java.security.GeneralSecurityException;
 import java.security.MessageDigest;
 import java.security.SecureRandom;
 import java.security.cert.CertificateEncodingException;
-import java.security.spec.AlgorithmParameterSpec;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.Random;
@@ -49,28 +46,22 @@ import java.util.Random;
 import javax.crypto.Cipher;
 import javax.crypto.Mac;
 import javax.crypto.SecretKey;
-import javax.crypto.spec.IvParameterSpec;
-import javax.crypto.spec.RC2ParameterSpec;
 import javax.crypto.spec.SecretKeySpec;
 
 import org.apache.poi.EncryptedDocumentException;
-import org.apache.poi.poifs.crypt.CipherAlgorithm;
+import org.apache.poi.poifs.crypt.ChunkedCipherOutputStream;
 import org.apache.poi.poifs.crypt.CryptoFunctions;
 import org.apache.poi.poifs.crypt.DataSpaceMapUtils;
-import org.apache.poi.poifs.crypt.EncryptionHeader;
 import org.apache.poi.poifs.crypt.EncryptionInfo;
 import org.apache.poi.poifs.crypt.Encryptor;
 import org.apache.poi.poifs.crypt.HashAlgorithm;
 import org.apache.poi.poifs.crypt.agile.AgileEncryptionVerifier.AgileCertificateEntry;
+import org.apache.poi.poifs.crypt.standard.EncryptionRecord;
 import org.apache.poi.poifs.filesystem.DirectoryNode;
-import org.apache.poi.poifs.filesystem.POIFSWriterEvent;
-import org.apache.poi.poifs.filesystem.POIFSWriterListener;
 import org.apache.poi.util.IOUtils;
 import org.apache.poi.util.LittleEndian;
 import org.apache.poi.util.LittleEndianByteArrayOutputStream;
 import org.apache.poi.util.LittleEndianConsts;
-import org.apache.poi.util.LittleEndianOutputStream;
-import org.apache.poi.util.TempFile;
 import org.apache.xmlbeans.XmlOptions;
 
 import com.microsoft.schemas.office.x2006.encryption.CTDataIntegrity;
@@ -85,48 +76,51 @@ import com.microsoft.schemas.office.x2006.encryption.STHashAlgorithm;
 import com.microsoft.schemas.office.x2006.keyEncryptor.certificate.CTCertificateKeyEncryptor;
 import com.microsoft.schemas.office.x2006.keyEncryptor.password.CTPasswordKeyEncryptor;
 
-public class AgileEncryptor extends Encryptor {
-    private final AgileEncryptionInfoBuilder builder;
-    @SuppressWarnings("unused")
+public class AgileEncryptor extends Encryptor implements Cloneable {
+
+    //arbitrarily selected; may need to increase
+    private static final int MAX_RECORD_LENGTH = 1_000_000;
+
     private byte integritySalt[];
-    private Mac integrityMD;
 	private byte pwHash[];
     
-	protected AgileEncryptor(AgileEncryptionInfoBuilder builder) {
-		this.builder = builder;
+	protected AgileEncryptor() {
 	}
 
+    @Override
     public void confirmPassword(String password) {
         // see [MS-OFFCRYPTO] - 2.3.3 EncryptionVerifier
         Random r = new SecureRandom();
-        int blockSize = builder.getHeader().getBlockSize();
-        int keySize = builder.getHeader().getKeySize()/8;
-        int hashSize = builder.getHeader().getHashAlgorithmEx().hashSize;
+        AgileEncryptionHeader header = (AgileEncryptionHeader)getEncryptionInfo().getHeader();
+        int blockSize = header.getBlockSize();
+        int keySize = header.getKeySize()/8;
+        int hashSize = header.getHashAlgorithm().hashSize;
         
-        byte[] verifierSalt = new byte[blockSize]
-             , verifier = new byte[blockSize]
-             , keySalt = new byte[blockSize]
-             , keySpec = new byte[keySize]
-             , integritySalt = new byte[hashSize];
-        r.nextBytes(verifierSalt); // blocksize
-        r.nextBytes(verifier); // blocksize
-        r.nextBytes(keySalt); // blocksize
-        r.nextBytes(keySpec); // keysize
-        r.nextBytes(integritySalt); // hashsize
+        byte[] newVerifierSalt = IOUtils.safelyAllocate(blockSize, MAX_RECORD_LENGTH)
+             , newVerifier = IOUtils.safelyAllocate(blockSize, MAX_RECORD_LENGTH)
+             , newKeySalt = IOUtils.safelyAllocate(blockSize, MAX_RECORD_LENGTH)
+             , newKeySpec = IOUtils.safelyAllocate(keySize, MAX_RECORD_LENGTH)
+             , newIntegritySalt = IOUtils.safelyAllocate(hashSize, MAX_RECORD_LENGTH);
+        r.nextBytes(newVerifierSalt); // blocksize
+        r.nextBytes(newVerifier); // blocksize
+        r.nextBytes(newKeySalt); // blocksize
+        r.nextBytes(newKeySpec); // keysize
+        r.nextBytes(newIntegritySalt); // hashsize
         
-        confirmPassword(password, keySpec, keySalt, verifierSalt, verifier, integritySalt);
+        confirmPassword(password, newKeySpec, newKeySalt, newVerifierSalt, newVerifier, newIntegritySalt);
     }
 	
-	public void confirmPassword(String password, byte keySpec[], byte keySalt[], byte verifier[], byte verifierSalt[], byte integritySalt[]) {
-        AgileEncryptionVerifier ver = builder.getVerifier();
+	@Override
+    public void confirmPassword(String password, byte keySpec[], byte keySalt[], byte verifier[], byte verifierSalt[], byte integritySalt[]) {
+        AgileEncryptionVerifier ver = (AgileEncryptionVerifier)getEncryptionInfo().getVerifier();
+        AgileEncryptionHeader header = (AgileEncryptionHeader)getEncryptionInfo().getHeader();
+
         ver.setSalt(verifierSalt);
-        AgileEncryptionHeader header = builder.getHeader();
         header.setKeySalt(keySalt);
-        HashAlgorithm hashAlgo = ver.getHashAlgorithm();
 
         int blockSize = header.getBlockSize();
 	    
-        pwHash = hashPassword(password, hashAlgo, verifierSalt, ver.getSpinCount());
+        pwHash = hashPassword(password, ver.getHashAlgorithm(), verifierSalt, ver.getSpinCount());
         
         /**
          * encryptedVerifierHashInput: This attribute MUST be generated by using the following steps:
@@ -141,7 +135,7 @@ public class AgileEncryptor extends Encryptor {
          *    blockSize bytes.
          * 4. Use base64 to encode the result of step 3.
          */
-        byte encryptedVerifier[] = hashInput(builder, pwHash, kVerifierInputBlock, verifier, Cipher.ENCRYPT_MODE);
+        byte encryptedVerifier[] = hashInput(ver, pwHash, kVerifierInputBlock, verifier, Cipher.ENCRYPT_MODE);
         ver.setEncryptedVerifier(encryptedVerifier);
 	    
 
@@ -157,9 +151,9 @@ public class AgileEncryptor extends Encryptor {
          *    blockSize bytes, pad the hash value with 0x00 to an integral multiple of blockSize bytes.
          * 4. Use base64 to encode the result of step 3.
          */
-        MessageDigest hashMD = getMessageDigest(hashAlgo);
+        MessageDigest hashMD = getMessageDigest(ver.getHashAlgorithm());
         byte[] hashedVerifier = hashMD.digest(verifier);
-        byte encryptedVerifierHash[] = hashInput(builder, pwHash, kHashedVerifierBlock, hashedVerifier, Cipher.ENCRYPT_MODE);
+        byte encryptedVerifierHash[] = hashInput(ver, pwHash, kHashedVerifierBlock, hashedVerifier, Cipher.ENCRYPT_MODE);
         ver.setEncryptedVerifierHash(encryptedVerifierHash);
         
         /**
@@ -175,10 +169,10 @@ public class AgileEncryptor extends Encryptor {
          *    blockSize bytes.
          * 4. Use base64 to encode the result of step 3.
          */
-        byte encryptedKey[] = hashInput(builder, pwHash, kCryptoKeyBlock, keySpec, Cipher.ENCRYPT_MODE);
+        byte encryptedKey[] = hashInput(ver, pwHash, kCryptoKeyBlock, keySpec, Cipher.ENCRYPT_MODE);
         ver.setEncryptedKey(encryptedKey);
         
-        SecretKey secretKey = new SecretKeySpec(keySpec, ver.getCipherAlgorithm().jceId);
+        SecretKey secretKey = new SecretKeySpec(keySpec, header.getCipherAlgorithm().jceId);
         setSecretKey(secretKey);
         
         /*
@@ -205,24 +199,20 @@ public class AgileEncryptor extends Encryptor {
          *    0xa0, 0x67, 0x7f, 0x02, 0xb2, 0x2c, 0x84, and 0x33.
          * 7.  Assign the encryptedHmacValue attribute to the base64-encoded form of the result of step 6. 
          */
-        this.integritySalt = integritySalt;
+        this.integritySalt = integritySalt.clone();
 
         try {
-            byte vec[] = CryptoFunctions.generateIv(hashAlgo, header.getKeySalt(), kIntegrityKeyBlock, header.getBlockSize());
-            Cipher cipher = getCipher(secretKey, ver.getCipherAlgorithm(), ver.getChainingMode(), vec, Cipher.ENCRYPT_MODE);
-            byte filledSalt[] = getBlock0(integritySalt, getNextBlockSize(integritySalt.length, blockSize));
-            byte encryptedHmacKey[] = cipher.doFinal(filledSalt);
+            byte vec[] = CryptoFunctions.generateIv(header.getHashAlgorithm(), header.getKeySalt(), kIntegrityKeyBlock, header.getBlockSize());
+            Cipher cipher = getCipher(secretKey, header.getCipherAlgorithm(), header.getChainingMode(), vec, Cipher.ENCRYPT_MODE);
+            byte hmacKey[] = getBlock0(this.integritySalt, getNextBlockSize(this.integritySalt.length, blockSize));
+            byte encryptedHmacKey[] = cipher.doFinal(hmacKey);
             header.setEncryptedHmacKey(encryptedHmacKey);
 
-            this.integrityMD = CryptoFunctions.getMac(hashAlgo);
-            this.integrityMD.init(new SecretKeySpec(integritySalt, hashAlgo.jceHmacId));
-
-        
             cipher = Cipher.getInstance("RSA");
             for (AgileCertificateEntry ace : ver.getCertificates()) {
                 cipher.init(Cipher.ENCRYPT_MODE, ace.x509.getPublicKey());
                 ace.encryptedKey = cipher.doFinal(getSecretKey().getEncoded());
-                Mac x509Hmac = CryptoFunctions.getMac(hashAlgo);
+                Mac x509Hmac = CryptoFunctions.getMac(header.getHashAlgorithm());
                 x509Hmac.init(getSecretKey());
                 ace.certVerifier = x509Hmac.doFinal(ace.x509.getEncoded());
             }
@@ -231,180 +221,65 @@ public class AgileEncryptor extends Encryptor {
         }
 	}
 	
+    @Override
     public OutputStream getDataStream(DirectoryNode dir)
             throws IOException, GeneralSecurityException {
         // TODO: initialize headers
-        OutputStream countStream = new ChunkedCipherOutputStream(dir);
-    	return countStream;
+        return new AgileCipherOutputStream(dir);
     }
 
     /**
-     * 2.3.4.15 Data Encryption (Agile Encryption)
+     * Generate an HMAC, as specified in [RFC2104], of the encrypted form of the data (message), 
+     * which the DataIntegrity element will verify by using the Salt generated in step 2 as the key. 
+     * Note that the entire EncryptedPackage stream (1), including the StreamSize field, MUST be 
+     * used as the message.
      * 
-     * The EncryptedPackage stream (1) MUST be encrypted in 4096-byte segments to facilitate nearly
-     * random access while allowing CBC modes to be used in the encryption process.
-     * The initialization vector for the encryption process MUST be obtained by using the zero-based
-     * segment number as a blockKey and the binary form of the KeyData.saltValue as specified in
-     * section 2.3.4.12. The block number MUST be represented as a 32-bit unsigned integer.
-     * Data blocks MUST then be encrypted by using the initialization vector and the intermediate key
-     * obtained by decrypting the encryptedKeyValue from a KeyEncryptor contained within the
-     * KeyEncryptors sequence as specified in section 2.3.4.10. The final data block MUST be padded to
-     * the next integral multiple of the KeyData.blockSize value. Any padding bytes can be used. Note
-     * that the StreamSize field of the EncryptedPackage field specifies the number of bytes of
-     * unencrypted data as specified in section 2.3.4.4.
-     */
-    private class ChunkedCipherOutputStream extends FilterOutputStream implements POIFSWriterListener {
-        private long _pos = 0;
-        private final byte[] _chunk = new byte[4096];
-        private Cipher _cipher;
-        private final File fileOut;
-        protected final DirectoryNode dir;
+     * Encrypt the HMAC as in step 3 by using a blockKey byte array consisting of the following bytes:
+     * 0xa0, 0x67, 0x7f, 0x02, 0xb2, 0x2c, 0x84, and 0x33.
+     **/
+    protected void updateIntegrityHMAC(File tmpFile, int oleStreamSize) throws GeneralSecurityException, IOException {
+        // as the integrity hmac needs to contain the StreamSize,
+        // it's not possible to calculate it on-the-fly while buffering
+        // TODO: add stream size parameter to getDataStream()
+        AgileEncryptionHeader header = (AgileEncryptionHeader)getEncryptionInfo().getHeader();
+        int blockSize = header.getBlockSize();
+        HashAlgorithm hashAlgo = header.getHashAlgorithm();
+        Mac integrityMD = CryptoFunctions.getMac(hashAlgo);
+        byte hmacKey[] = getBlock0(this.integritySalt, getNextBlockSize(this.integritySalt.length, blockSize));
+        integrityMD.init(new SecretKeySpec(hmacKey, hashAlgo.jceHmacId));
 
-        public ChunkedCipherOutputStream(DirectoryNode dir) throws IOException {
-            super(null);
-            fileOut = TempFile.createTempFile("encrypted_package", "crypt");
-            this.out = new FileOutputStream(fileOut);
-            this.dir = dir;
-            EncryptionHeader header = builder.getHeader();
-            _cipher = getCipher(getSecretKey(), header.getCipherAlgorithm(), header.getChainingMode(), null, Cipher.ENCRYPT_MODE);
-        }
-
-        public void write(int b) throws IOException {
-            write(new byte[]{(byte)b});
-        }
-
-        public void write(byte[] b) throws IOException {
-            write(b, 0, b.length);
-        }
-
-        public void write(byte[] b, int off, int len)
-        throws IOException {
-            if (len == 0) return;
-            
-            if (len < 0 || b.length < off+len) {
-                throw new IOException("not enough bytes in your input buffer");
-            }
-            
-            while (len > 0) {
-                int posInChunk = (int)(_pos & 0xfff);
-                int nextLen = Math.min(4096-posInChunk, len);
-                System.arraycopy(b, off, _chunk, posInChunk, nextLen);
-                _pos += nextLen;
-                off += nextLen;
-                len -= nextLen;
-                if ((_pos & 0xfff) == 0) {
-                    writeChunk();
-                }
-            }
-        }
-
-        private void writeChunk() throws IOException {
-            EncryptionHeader header = builder.getHeader();
-            int blockSize = header.getBlockSize();
-
-            int posInChunk = (int)(_pos & 0xfff);
-            // normally posInChunk is 0, i.e. on the next chunk (-> index-1)
-            // but if called on close(), posInChunk is somewhere within the chunk data
-            int index = (int)(_pos >> 12);
-            if (posInChunk==0) {
-                index--;
-                posInChunk = 4096;
-            } else {
-                // pad the last chunk
-                _cipher = getCipher(getSecretKey(), header.getCipherAlgorithm(), header.getChainingMode(), null, Cipher.ENCRYPT_MODE, "PKCS5Padding");
-            }
-
-            byte[] blockKey = new byte[4];
-            LittleEndian.putInt(blockKey, 0, index);
-            byte[] iv = generateIv(header.getHashAlgorithmEx(), header.getKeySalt(), blockKey, blockSize);
-            try {
-                AlgorithmParameterSpec aps;
-                if (header.getCipherAlgorithm() == CipherAlgorithm.rc2) {
-                    aps = new RC2ParameterSpec(getSecretKey().getEncoded().length*8, iv);
-                } else {
-                    aps = new IvParameterSpec(iv);
-                }
-                
-                _cipher.init(Cipher.ENCRYPT_MODE, getSecretKey(), aps);
-                int ciLen = _cipher.doFinal(_chunk, 0, posInChunk, _chunk);
-                out.write(_chunk, 0, ciLen);
-            } catch (GeneralSecurityException e) {
-                throw (IOException)new IOException().initCause(e);
+        byte buf[] = new byte[1024];
+        LittleEndian.putLong(buf, 0, oleStreamSize);
+        integrityMD.update(buf, 0, LittleEndianConsts.LONG_SIZE);
+        
+        InputStream fis = new FileInputStream(tmpFile);
+        try {
+            int readBytes;
+            while ((readBytes = fis.read(buf)) != -1) {
+                integrityMD.update(buf, 0, readBytes);
             }
+        } finally {
+        	fis.close();
         }
         
-        public void close() throws IOException {
-            writeChunk();
-            super.close();
-            writeToPOIFS();
-        }
-
-        void writeToPOIFS() throws IOException {
-            DataSpaceMapUtils.addDefaultDataSpace(dir);
-            
-            /**
-             * Generate an HMAC, as specified in [RFC2104], of the encrypted form of the data (message), 
-             * which the DataIntegrity element will verify by using the Salt generated in step 2 as the key. 
-             * Note that the entire EncryptedPackage stream (1), including the StreamSize field, MUST be 
-             * used as the message.
-             * 
-             * Encrypt the HMAC as in step 3 by using a blockKey byte array consisting of the following bytes:
-             * 0xa0, 0x67, 0x7f, 0x02, 0xb2, 0x2c, 0x84, and 0x33.
-             **/
-            byte buf[] = new byte[4096];
-            LittleEndian.putLong(buf, 0, _pos);
-            integrityMD.update(buf, 0, LittleEndianConsts.LONG_SIZE);
-            
-            InputStream fis = new FileInputStream(fileOut);
-            for (int readBytes; (readBytes = fis.read(buf)) != -1; integrityMD.update(buf, 0, readBytes));
-            fis.close();
-            
-            AgileEncryptionHeader header = builder.getHeader(); 
-            int blockSize = header.getBlockSize();
-            
-            byte hmacValue[] = integrityMD.doFinal();
-            byte iv[] = CryptoFunctions.generateIv(header.getHashAlgorithmEx(), header.getKeySalt(), kIntegrityValueBlock, header.getBlockSize());
-            Cipher cipher = CryptoFunctions.getCipher(getSecretKey(), header.getCipherAlgorithm(), header.getChainingMode(), iv, Cipher.ENCRYPT_MODE);
-            try {
-                byte hmacValueFilled[] = getBlock0(hmacValue, getNextBlockSize(hmacValue.length, blockSize));
-                byte encryptedHmacValue[] = cipher.doFinal(hmacValueFilled);
-                header.setEncryptedHmacValue(encryptedHmacValue);
-            } catch (GeneralSecurityException e) {
-                throw new EncryptedDocumentException(e);
-            }
-
-            createEncryptionInfoEntry(dir);
-            
-            int oleStreamSize = (int)(fileOut.length()+LittleEndianConsts.LONG_SIZE);
-            dir.createDocument("EncryptedPackage", oleStreamSize, this);
-            // TODO: any properties???
-        }
-    
-        public void processPOIFSWriterEvent(POIFSWriterEvent event) {
-            try {
-                LittleEndianOutputStream leos = new LittleEndianOutputStream(event.getStream());
-
-                // StreamSize (8 bytes): An unsigned integer that specifies the number of bytes used by data 
-                // encrypted within the EncryptedData field, not including the size of the StreamSize field. 
-                // Note that the actual size of the \EncryptedPackage stream (1) can be larger than this 
-                // value, depending on the block size of the chosen encryption algorithm
-                leos.writeLong(_pos);
-
-                FileInputStream fis = new FileInputStream(fileOut);
-                IOUtils.copy(fis, leos);
-                fis.close();
-                fileOut.delete();
-
-                leos.close();
-            } catch (IOException e) {
-                throw new EncryptedDocumentException(e);
-            }
-        }
+        byte hmacValue[] = integrityMD.doFinal();
+        byte hmacValueFilled[] = getBlock0(hmacValue, getNextBlockSize(hmacValue.length, blockSize));
+        
+        byte iv[] = CryptoFunctions.generateIv(header.getHashAlgorithm(), header.getKeySalt(), kIntegrityValueBlock, blockSize);
+        Cipher cipher = CryptoFunctions.getCipher(getSecretKey(), header.getCipherAlgorithm(), header.getChainingMode(), iv, Cipher.ENCRYPT_MODE);
+        byte encryptedHmacValue[] = cipher.doFinal(hmacValueFilled);
+        
+        header.setEncryptedHmacValue(encryptedHmacValue);
     }
-
-    protected void createEncryptionInfoEntry(DirectoryNode dir) throws IOException {
-        AgileEncryptionVerifier ver = builder.getVerifier();
-        AgileEncryptionHeader header = builder.getHeader();
+    
+    private final CTKeyEncryptor.Uri.Enum passwordUri = 
+        CTKeyEncryptor.Uri.HTTP_SCHEMAS_MICROSOFT_COM_OFFICE_2006_KEY_ENCRYPTOR_PASSWORD;
+    private final CTKeyEncryptor.Uri.Enum certificateUri = 
+        CTKeyEncryptor.Uri.HTTP_SCHEMAS_MICROSOFT_COM_OFFICE_2006_KEY_ENCRYPTOR_CERTIFICATE;
+    
+    protected EncryptionDocument createEncryptionDocument() {
+        AgileEncryptionVerifier ver = (AgileEncryptionVerifier)getEncryptionInfo().getVerifier();
+        AgileEncryptionHeader header = (AgileEncryptionHeader)getEncryptionInfo().getHeader(); 
         
         EncryptionDocument ed = EncryptionDocument.Factory.newInstance();
         CTEncryption edRoot = ed.addNewEncryption();
@@ -412,24 +287,27 @@ public class AgileEncryptor extends Encryptor {
         CTKeyData keyData = edRoot.addNewKeyData();
         CTKeyEncryptors keyEncList = edRoot.addNewKeyEncryptors();
         CTKeyEncryptor keyEnc = keyEncList.addNewKeyEncryptor();
-        keyEnc.setUri(CTKeyEncryptor.Uri.HTTP_SCHEMAS_MICROSOFT_COM_OFFICE_2006_KEY_ENCRYPTOR_PASSWORD);
+        keyEnc.setUri(passwordUri);
         CTPasswordKeyEncryptor keyPass = keyEnc.addNewEncryptedPasswordKey();
 
         keyPass.setSpinCount(ver.getSpinCount());
         
         keyData.setSaltSize(header.getBlockSize());
-        keyPass.setSaltSize(header.getBlockSize());
+        keyPass.setSaltSize(ver.getBlockSize());
         
         keyData.setBlockSize(header.getBlockSize());
-        keyPass.setBlockSize(header.getBlockSize());
+        keyPass.setBlockSize(ver.getBlockSize());
 
         keyData.setKeyBits(header.getKeySize());
-        keyPass.setKeyBits(header.getKeySize());
+        keyPass.setKeyBits(ver.getKeySize());
 
-        HashAlgorithm hashAlgo = header.getHashAlgorithmEx();
-        keyData.setHashSize(hashAlgo.hashSize);
-        keyPass.setHashSize(hashAlgo.hashSize);
+        keyData.setHashSize(header.getHashAlgorithm().hashSize);
+        keyPass.setHashSize(ver.getHashAlgorithm().hashSize);
 
+        // header and verifier have to have the same cipher algorithm
+        if (!header.getCipherAlgorithm().xmlId.equals(ver.getCipherAlgorithm().xmlId)) {
+            throw new EncryptedDocumentException("Cipher algorithm of header and verifier have to match");
+        }
         STCipherAlgorithm.Enum xmlCipherAlgo = STCipherAlgorithm.Enum.forString(header.getCipherAlgorithm().xmlId);
         if (xmlCipherAlgo == null) {
             throw new EncryptedDocumentException("CipherAlgorithm "+header.getCipherAlgorithm()+" not supported.");
@@ -450,12 +328,8 @@ public class AgileEncryptor extends Encryptor {
             throw new EncryptedDocumentException("ChainingMode "+header.getChainingMode()+" not supported.");
         }
         
-        STHashAlgorithm.Enum xmlHashAlgo = STHashAlgorithm.Enum.forString(hashAlgo.ecmaString);
-        if (xmlHashAlgo == null) {
-            throw new EncryptedDocumentException("HashAlgorithm "+hashAlgo+" not supported.");
-        }
-        keyData.setHashAlgorithm(xmlHashAlgo);
-        keyPass.setHashAlgorithm(xmlHashAlgo);
+        keyData.setHashAlgorithm(mapHashAlgorithm(header.getHashAlgorithm()));
+        keyPass.setHashAlgorithm(mapHashAlgorithm(ver.getHashAlgorithm()));
 
         keyData.setSaltValue(header.getKeySalt());
         keyPass.setSaltValue(ver.getSalt());
@@ -469,7 +343,7 @@ public class AgileEncryptor extends Encryptor {
         
         for (AgileCertificateEntry ace : ver.getCertificates()) {
             keyEnc = keyEncList.addNewKeyEncryptor();
-            keyEnc.setUri(CTKeyEncryptor.Uri.HTTP_SCHEMAS_MICROSOFT_COM_OFFICE_2006_KEY_ENCRYPTOR_CERTIFICATE);
+            keyEnc.setUri(certificateUri);
             CTCertificateKeyEncryptor certData = keyEnc.addNewEncryptedCertificateKey();
             try {
                 certData.setX509Certificate(ace.x509.getEncoded());
@@ -479,43 +353,112 @@ public class AgileEncryptor extends Encryptor {
             certData.setEncryptedKeyValue(ace.encryptedKey);
             certData.setCertVerifier(ace.certVerifier);
         }
+        
+        return ed;
+    }
 
+    private static STHashAlgorithm.Enum mapHashAlgorithm(HashAlgorithm hashAlgo) {
+        STHashAlgorithm.Enum xmlHashAlgo = STHashAlgorithm.Enum.forString(hashAlgo.ecmaString);
+        if (xmlHashAlgo == null) {
+            throw new EncryptedDocumentException("HashAlgorithm "+hashAlgo+" not supported.");
+        }
+        return xmlHashAlgo;
+    }
+    
+    protected void marshallEncryptionDocument(EncryptionDocument ed, LittleEndianByteArrayOutputStream os) {
         XmlOptions xo = new XmlOptions();
         xo.setCharacterEncoding("UTF-8");
-        Map<String,String> nsMap = new HashMap<String,String>();
-        nsMap.put("http://schemas.microsoft.com/office/2006/keyEncryptor/password","p");
-        nsMap.put("http://schemas.microsoft.com/office/2006/keyEncryptor/certificate", "c");
-        nsMap.put("http://schemas.microsoft.com/office/2006/encryption","");
+        Map<String,String> nsMap = new HashMap<>();
+        nsMap.put(passwordUri.toString(),"p");
+        nsMap.put(certificateUri.toString(), "c");
+        xo.setUseDefaultNamespace();
         xo.setSaveSuggestedPrefixes(nsMap);
         xo.setSaveNamespacesFirst();
         xo.setSaveAggressiveNamespaces();
-        // setting standalone doesn't work with xmlbeans-2.3
+
+        // setting standalone doesn't work with xmlbeans-2.3 & 2.6
+        // ed.documentProperties().setStandalone(true);
         xo.setSaveNoXmlDecl();
-        
         ByteArrayOutputStream bos = new ByteArrayOutputStream();
-        bos.write("<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>\r\n".getBytes("UTF-8"));
-        ed.save(bos, xo);
+        try {
+            bos.write("<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>\r\n".getBytes("UTF-8"));
+            ed.save(bos, xo);
+            bos.writeTo(os);
+        } catch (IOException e) {
+            throw new EncryptedDocumentException("error marshalling encryption info document", e);
+        }
+    }
 
-        final byte buf[] = new byte[5000];        
-        LittleEndianByteArrayOutputStream leos = new LittleEndianByteArrayOutputStream(buf, 0);
-        EncryptionInfo info = builder.getInfo();
+    protected void createEncryptionInfoEntry(DirectoryNode dir, File tmpFile)
+    throws IOException, GeneralSecurityException {
+        DataSpaceMapUtils.addDefaultDataSpace(dir);
 
-        // EncryptionVersionInfo (4 bytes): A Version structure (section 2.1.4), where 
-        // Version.vMajor MUST be 0x0004 and Version.vMinor MUST be 0x0004
-        leos.writeShort(info.getVersionMajor());
-        leos.writeShort(info.getVersionMinor());
-        // Reserved (4 bytes): A value that MUST be 0x00000040
-        leos.writeInt(0x40);
-        leos.write(bos.toByteArray());
-        
-        dir.createDocument("EncryptionInfo", leos.getWriteIndex(), new POIFSWriterListener() {
-            public void processPOIFSWriterEvent(POIFSWriterEvent event) {
-                try {
-                    event.getStream().write(buf, 0, event.getLimit());
-                } catch (IOException e) {
-                    throw new EncryptedDocumentException(e);
-                }
+        final EncryptionInfo info = getEncryptionInfo();
+
+        EncryptionRecord er = new EncryptionRecord(){
+            @Override
+            public void write(LittleEndianByteArrayOutputStream bos) {
+                // EncryptionVersionInfo (4 bytes): A Version structure (section 2.1.4), where 
+                // Version.vMajor MUST be 0x0004 and Version.vMinor MUST be 0x0004
+                bos.writeShort(info.getVersionMajor());
+                bos.writeShort(info.getVersionMinor());
+                // Reserved (4 bytes): A value that MUST be 0x00000040
+                bos.writeInt(info.getEncryptionFlags());
+
+                EncryptionDocument ed = createEncryptionDocument();
+                marshallEncryptionDocument(ed, bos);
             }
-        });
+        };
+        
+        createEncryptionEntry(dir, "EncryptionInfo", er);
+    }
+    
+    
+    /**
+     * 2.3.4.15 Data Encryption (Agile Encryption)
+     * 
+     * The EncryptedPackage stream (1) MUST be encrypted in 4096-byte segments to facilitate nearly
+     * random access while allowing CBC modes to be used in the encryption process.
+     * The initialization vector for the encryption process MUST be obtained by using the zero-based
+     * segment number as a blockKey and the binary form of the KeyData.saltValue as specified in
+     * section 2.3.4.12. The block number MUST be represented as a 32-bit unsigned integer.
+     * Data blocks MUST then be encrypted by using the initialization vector and the intermediate key
+     * obtained by decrypting the encryptedKeyValue from a KeyEncryptor contained within the
+     * KeyEncryptors sequence as specified in section 2.3.4.10. The final data block MUST be padded to
+     * the next integral multiple of the KeyData.blockSize value. Any padding bytes can be used. Note
+     * that the StreamSize field of the EncryptedPackage field specifies the number of bytes of
+     * unencrypted data as specified in section 2.3.4.4.
+     */
+    private class AgileCipherOutputStream extends ChunkedCipherOutputStream {
+        public AgileCipherOutputStream(DirectoryNode dir) throws IOException, GeneralSecurityException {
+            super(dir, 4096);
+        }
+        
+        @Override
+        protected Cipher initCipherForBlock(Cipher existing, int block, boolean lastChunk)
+        throws GeneralSecurityException {
+            return AgileDecryptor.initCipherForBlock(existing, block, lastChunk, getEncryptionInfo(), getSecretKey(), Cipher.ENCRYPT_MODE);
+        }
+
+        @Override
+        protected void calculateChecksum(File fileOut, int oleStreamSize)
+        throws GeneralSecurityException, IOException {
+            // integrityHMAC needs to be updated before the encryption document is created
+            updateIntegrityHMAC(fileOut, oleStreamSize); 
+        }
+        
+        @Override
+        protected void createEncryptionInfoEntry(DirectoryNode dir, File tmpFile)
+        throws IOException, GeneralSecurityException {
+            AgileEncryptor.this.createEncryptionInfoEntry(dir, tmpFile);
+        }
+    }
+
+    @Override
+    public AgileEncryptor clone() throws CloneNotSupportedException {
+        AgileEncryptor other = (AgileEncryptor)super.clone();
+        other.integritySalt = (integritySalt == null) ? null : integritySalt.clone();
+        other.pwHash = (pwHash == null) ? null : pwHash.clone();
+        return other;
     }
 }
