@@ -16,14 +16,8 @@
 ==================================================================== */
 package org.apache.poi.xwpf.model;
 
-import java.io.IOException;
-import java.io.OutputStream;
-import java.util.HashMap;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Map;
-
-import org.apache.poi.POIXMLDocumentPart;
+import org.apache.poi.ooxml.POIXMLDocumentPart;
+import org.apache.poi.ooxml.POIXMLDocumentPart.RelationPart;
 import org.apache.poi.xwpf.usermodel.XWPFDocument;
 import org.apache.poi.xwpf.usermodel.XWPFFactory;
 import org.apache.poi.xwpf.usermodel.XWPFFooter;
@@ -31,8 +25,8 @@ import org.apache.poi.xwpf.usermodel.XWPFHeader;
 import org.apache.poi.xwpf.usermodel.XWPFHeaderFooter;
 import org.apache.poi.xwpf.usermodel.XWPFParagraph;
 import org.apache.poi.xwpf.usermodel.XWPFRelation;
-import org.apache.xmlbeans.XmlException;
-import org.apache.xmlbeans.XmlOptions;
+import org.apache.xmlbeans.impl.values.XmlValueOutOfRangeException;
+import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTBody;
 import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTHdrFtr;
 import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTHdrFtrRef;
 import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTP;
@@ -46,25 +40,25 @@ import org.openxmlformats.schemas.wordprocessingml.x2006.main.HdrDocument;
 import org.openxmlformats.schemas.wordprocessingml.x2006.main.STHdrFtr;
 import org.openxmlformats.schemas.wordprocessingml.x2006.main.STHdrFtr.Enum;
 
-import schemasMicrosoftComOfficeOffice.CTLock;
-import schemasMicrosoftComOfficeOffice.STConnectType;
-import schemasMicrosoftComVml.CTFormulas;
-import schemasMicrosoftComVml.CTGroup;
-import schemasMicrosoftComVml.CTH;
-import schemasMicrosoftComVml.CTHandles;
-import schemasMicrosoftComVml.CTPath;
-import schemasMicrosoftComVml.CTShape;
-import schemasMicrosoftComVml.CTShapetype;
-import schemasMicrosoftComVml.CTTextPath;
-import schemasMicrosoftComVml.STExt;
-import schemasMicrosoftComVml.STTrueFalse;
+import com.microsoft.schemas.office.office.CTLock;
+import com.microsoft.schemas.office.office.STConnectType;
+import com.microsoft.schemas.vml.CTFormulas;
+import com.microsoft.schemas.vml.CTGroup;
+import com.microsoft.schemas.vml.CTH;
+import com.microsoft.schemas.vml.CTHandles;
+import com.microsoft.schemas.vml.CTPath;
+import com.microsoft.schemas.vml.CTShape;
+import com.microsoft.schemas.vml.CTShapetype;
+import com.microsoft.schemas.vml.CTTextPath;
+import com.microsoft.schemas.vml.STExt;
+import com.microsoft.schemas.vml.STTrueFalse;
 
 /**
  * A .docx file can have no headers/footers, the same header/footer
- *  on each page, odd/even page footers, and optionally also 
- *  a different header/footer on the first page.
+ * on each page, odd/even page footers, and optionally also
+ * a different header/footer on the first page.
  * This class handles sorting out what there is, and giving you
- *  the right headers and footers for the document.
+ * the right headers and footers for the document.
  */
 public class XWPFHeaderFooterPolicy {
     public static final Enum DEFAULT = STHdrFtr.DEFAULT;
@@ -84,25 +78,31 @@ public class XWPFHeaderFooterPolicy {
 
     /**
      * Figures out the policy for the given document,
-     *  and creates any header and footer objects
-     *  as required.
+     * and creates any header and footer objects
+     * as required.
      */
-    public XWPFHeaderFooterPolicy(XWPFDocument doc) throws IOException, XmlException {
-        this(doc, doc.getDocument().getBody().getSectPr());
+    public XWPFHeaderFooterPolicy(XWPFDocument doc) {
+        this(doc, null);
     }
 
     /**
      * Figures out the policy for the given document,
-     *  and creates any header and footer objects
-     *  as required.
+     * and creates any header and footer objects
+     * as required.
      */
-    public XWPFHeaderFooterPolicy(XWPFDocument doc, CTSectPr sectPr) throws IOException, XmlException {
+    public XWPFHeaderFooterPolicy(XWPFDocument doc, CTSectPr sectPr) {
         // Grab what headers and footers have been defined
         // For now, we don't care about different ranges, as it
         //  doesn't seem that .docx properly supports that
         //  feature of the file format yet
+        if (sectPr == null) {
+            CTBody ctBody = doc.getDocument().getBody();
+            sectPr = ctBody.isSetSectPr()
+                    ? ctBody.getSectPr()
+                    : ctBody.addNewSectPr();
+        }
         this.doc = doc;
-        for(int i=0; i<sectPr.sizeOfHeaderReferenceArray(); i++) {
+        for (int i = 0; i < sectPr.sizeOfHeaderReferenceArray(); i++) {
             // Get the header
             CTHdrFtrRef ref = sectPr.getHeaderReferenceArray(i);
             POIXMLDocumentPart relatedPart = doc.getRelationById(ref.getId());
@@ -110,29 +110,39 @@ public class XWPFHeaderFooterPolicy {
             if (relatedPart != null && relatedPart instanceof XWPFHeader) {
                 hdr = (XWPFHeader) relatedPart;
             }
-            // Assign it
-            Enum type = ref.getType();
+            // Assign it; treat invalid options as "default" POI-60293
+            Enum type;
+            try {
+                type = ref.getType();
+            } catch (XmlValueOutOfRangeException e) {
+                type = STHdrFtr.DEFAULT;
+            }
+
             assignHeader(hdr, type);
         }
-        for(int i=0; i<sectPr.sizeOfFooterReferenceArray(); i++) {
+        for (int i = 0; i < sectPr.sizeOfFooterReferenceArray(); i++) {
             // Get the footer
             CTHdrFtrRef ref = sectPr.getFooterReferenceArray(i);
             POIXMLDocumentPart relatedPart = doc.getRelationById(ref.getId());
             XWPFFooter ftr = null;
-            if (relatedPart != null && relatedPart instanceof XWPFFooter)
-            {
+            if (relatedPart != null && relatedPart instanceof XWPFFooter) {
                 ftr = (XWPFFooter) relatedPart;
             }
-            // Assign it
-            Enum type = ref.getType();
+            // Assign it; treat invalid options as "default" POI-60293
+            Enum type;
+            try {
+                type = ref.getType();
+            } catch (XmlValueOutOfRangeException e) {
+                type = STHdrFtr.DEFAULT;
+            }
             assignFooter(ftr, type);
         }
     }
 
     private void assignFooter(XWPFFooter ftr, Enum type) {
-        if(type == STHdrFtr.FIRST) {
+        if (type == STHdrFtr.FIRST) {
             firstPageFooter = ftr;
-        } else if(type == STHdrFtr.EVEN) {
+        } else if (type == STHdrFtr.EVEN) {
             evenPageFooter = ftr;
         } else {
             defaultFooter = ftr;
@@ -140,140 +150,144 @@ public class XWPFHeaderFooterPolicy {
     }
 
     private void assignHeader(XWPFHeader hdr, Enum type) {
-        if(type == STHdrFtr.FIRST) {
+        if (type == STHdrFtr.FIRST) {
             firstPageHeader = hdr;
-        } else if(type == STHdrFtr.EVEN) {
+        } else if (type == STHdrFtr.EVEN) {
             evenPageHeader = hdr;
         } else {
             defaultHeader = hdr;
         }
     }
 
-    public XWPFHeader createHeader(Enum type) throws IOException {
+    /**
+     * Creates an empty header of the specified type, containing a single
+     * empty paragraph, to which you can then set text, add more paragraphs etc.
+     */
+    public XWPFHeader createHeader(Enum type) {
         return createHeader(type, null);
     }
 
-    public XWPFHeader createHeader(Enum type, XWPFParagraph[] pars) throws IOException {
-        XWPFRelation relation = XWPFRelation.HEADER;
-        String pStyle = "Header";
-        int i = getRelationIndex(relation);
-        HdrDocument hdrDoc = HdrDocument.Factory.newInstance();
-        XWPFHeader wrapper = (XWPFHeader)doc.createRelationship(relation, XWPFFactory.getInstance(), i);
+    /**
+     * Creates a new header of the specified type, to which the
+     * supplied (and previously unattached!) paragraphs are
+     * added to.
+     */
+    public XWPFHeader createHeader(Enum type, XWPFParagraph[] pars) {
+        XWPFHeader header = getHeader(type);
 
-        CTHdrFtr hdr = buildHdr(type, pStyle, wrapper, pars);
-        wrapper.setHeaderFooter(hdr);
+        if (header == null) {
+            HdrDocument hdrDoc = HdrDocument.Factory.newInstance();
 
-        OutputStream outputStream = wrapper.getPackagePart().getOutputStream();
-        hdrDoc.setHdr(hdr);
+            XWPFRelation relation = XWPFRelation.HEADER;
+            int i = getRelationIndex(relation);
 
-        XmlOptions xmlOptions = commit(wrapper);
+            XWPFHeader wrapper = (XWPFHeader) doc.createRelationship(relation,
+                    XWPFFactory.getInstance(), i);
+            wrapper.setXWPFDocument(doc);
 
-        assignHeader(wrapper, type);
-        hdrDoc.save(outputStream, xmlOptions);
-        outputStream.close();
-        return wrapper;
+            CTHdrFtr hdr = buildHdr(type, wrapper, pars);
+            wrapper.setHeaderFooter(hdr);
+            hdrDoc.setHdr(hdr);
+            assignHeader(wrapper, type);
+            header = wrapper;
+        }
+
+        return header;
     }
 
-    public XWPFFooter createFooter(Enum type) throws IOException {
+    /**
+     * Creates an empty footer of the specified type, containing a single
+     * empty paragraph, to which you can then set text, add more paragraphs etc.
+     */
+    public XWPFFooter createFooter(Enum type) {
         return createFooter(type, null);
     }
 
-    public XWPFFooter createFooter(Enum type, XWPFParagraph[] pars) throws IOException {
-        XWPFRelation relation = XWPFRelation.FOOTER;
-        String pStyle = "Footer";
-        int i = getRelationIndex(relation);
-        FtrDocument ftrDoc = FtrDocument.Factory.newInstance();
-        XWPFFooter wrapper = (XWPFFooter)doc.createRelationship(relation, XWPFFactory.getInstance(), i);
+    /**
+     * Creates a new footer of the specified type, to which the
+     * supplied (and previously unattached!) paragraphs are
+     * added to.
+     */
+    public XWPFFooter createFooter(Enum type, XWPFParagraph[] pars) {
+        XWPFFooter footer = getFooter(type);
 
-        CTHdrFtr ftr = buildFtr(type, pStyle, wrapper, pars);
-        wrapper.setHeaderFooter(ftr);
+        if (footer == null) {
+            FtrDocument ftrDoc = FtrDocument.Factory.newInstance();
 
-        OutputStream outputStream = wrapper.getPackagePart().getOutputStream();
-        ftrDoc.setFtr(ftr);
+            XWPFRelation relation = XWPFRelation.FOOTER;
+            int i = getRelationIndex(relation);
 
-        XmlOptions xmlOptions = commit(wrapper);
+            XWPFFooter wrapper = (XWPFFooter) doc.createRelationship(relation,
+                    XWPFFactory.getInstance(), i);
+            wrapper.setXWPFDocument(doc);
 
-        assignFooter(wrapper, type);
-        ftrDoc.save(outputStream, xmlOptions);
-        outputStream.close();
-        return wrapper;
+            CTHdrFtr ftr = buildFtr(type, wrapper, pars);
+            wrapper.setHeaderFooter(ftr);
+            ftrDoc.setFtr(ftr);
+            assignFooter(wrapper, type);
+            footer = wrapper;
+        }
+
+        return footer;
     }
 
     private int getRelationIndex(XWPFRelation relation) {
-        List<POIXMLDocumentPart> relations = doc.getRelations();
         int i = 1;
-        for (Iterator<POIXMLDocumentPart> it = relations.iterator(); it.hasNext() ; ) {
-            POIXMLDocumentPart item = it.next();
-            if (item.getPackageRelationship().getRelationshipType().equals(relation.getRelation())) {
-                i++;	
+        for (RelationPart rp : doc.getRelationParts()) {
+            if (rp.getRelationship().getRelationshipType().equals(relation.getRelation())) {
+                i++;
             }
         }
         return i;
     }
 
-    private CTHdrFtr buildFtr(Enum type, String pStyle, XWPFHeaderFooter wrapper, XWPFParagraph[] pars) {
+    private CTHdrFtr buildFtr(Enum type, XWPFHeaderFooter wrapper, XWPFParagraph[] pars) {
         //CTHdrFtr ftr = buildHdrFtr(pStyle, pars);				// MB 24 May 2010
-        CTHdrFtr ftr = buildHdrFtr(pStyle, pars, wrapper);		// MB 24 May 2010
+        CTHdrFtr ftr = buildHdrFtr(pars, wrapper);        // MB 24 May 2010
         setFooterReference(type, wrapper);
         return ftr;
     }
 
-    private CTHdrFtr buildHdr(Enum type, String pStyle, XWPFHeaderFooter wrapper, XWPFParagraph[] pars) {
+    private CTHdrFtr buildHdr(Enum type, XWPFHeaderFooter wrapper, XWPFParagraph[] pars) {
         //CTHdrFtr hdr = buildHdrFtr(pStyle, pars);				// MB 24 May 2010
-        CTHdrFtr hdr = buildHdrFtr(pStyle, pars, wrapper);		// MB 24 May 2010
+        CTHdrFtr hdr = buildHdrFtr(pars, wrapper);        // MB 24 May 2010
         setHeaderReference(type, wrapper);
         return hdr;
     }
 
-    private CTHdrFtr buildHdrFtr(String pStyle, XWPFParagraph[] paragraphs) {
-        CTHdrFtr ftr = CTHdrFtr.Factory.newInstance();
-        if (paragraphs != null) {
-            for (int i = 0 ; i < paragraphs.length ; i++) {
-                CTP p = ftr.addNewP();
-                //ftr.setPArray(0, paragraphs[i].getCTP());		// MB 23 May 2010
-                ftr.setPArray(i, paragraphs[i].getCTP());   	// MB 23 May 2010
-            }
-        }
-        else {
-            CTP p = ftr.addNewP();
-            byte[] rsidr = doc.getDocument().getBody().getPArray(0).getRsidR();
-            byte[] rsidrdefault = doc.getDocument().getBody().getPArray(0).getRsidRDefault();
-            p.setRsidP(rsidr);
-            p.setRsidRDefault(rsidrdefault);
-            CTPPr pPr = p.addNewPPr();
-            pPr.addNewPStyle().setVal(pStyle);
-        }
-        return ftr;
-    }
-
     /**
      * MB 24 May 2010. Created this overloaded buildHdrFtr() method because testing demonstrated
      * that the XWPFFooter or XWPFHeader object returned by calls to the createHeader(int, XWPFParagraph[])
      * and createFooter(int, XWPFParagraph[]) methods or the getXXXXXHeader/Footer methods where
      * headers or footers had been added to a document since it had been created/opened, returned
      * an object that contained no XWPFParagraph objects even if the header/footer itself did contain
-     * text. The reason was that this line of code; CTHdrFtr ftr = CTHdrFtr.Factory.newInstance(); 
+     * text. The reason was that this line of code; CTHdrFtr ftr = CTHdrFtr.Factory.newInstance();
      * created a brand new instance of the CTHDRFtr class which was then populated with data when
      * it should have recovered the CTHdrFtr object encapsulated within the XWPFHeaderFooter object
-     * that had previoulsy been instantiated in the createHeader(int, XWPFParagraph[]) or 
+     * that had previoulsy been instantiated in the createHeader(int, XWPFParagraph[]) or
      * createFooter(int, XWPFParagraph[]) methods.
      */
-    private CTHdrFtr buildHdrFtr(String pStyle, XWPFParagraph[] paragraphs, XWPFHeaderFooter wrapper) {
+    private CTHdrFtr buildHdrFtr(XWPFParagraph[] paragraphs, XWPFHeaderFooter wrapper) {
         CTHdrFtr ftr = wrapper._getHdrFtr();
         if (paragraphs != null) {
-            for (int i = 0 ; i < paragraphs.length ; i++) {
-                CTP p = ftr.addNewP();
+            for (int i = 0; i < paragraphs.length; i++) {
+                /*CTP p =*/ ftr.addNewP();
                 ftr.setPArray(i, paragraphs[i].getCTP());
             }
-        }
-        else {
-            CTP p = ftr.addNewP();
-            byte[] rsidr = doc.getDocument().getBody().getPArray(0).getRsidR();
-            byte[] rsidrdefault = doc.getDocument().getBody().getPArray(0).getRsidRDefault();
-            p.setRsidP(rsidr);
-            p.setRsidRDefault(rsidrdefault);
-            CTPPr pPr = p.addNewPPr();
-            pPr.addNewPStyle().setVal(pStyle);
+//        } else {
+//            CTP p = ftr.addNewP();
+//            CTBody body = doc.getDocument().getBody();
+//            if (body.sizeOfPArray() > 0) {
+//                CTP p0 = body.getPArray(0);
+//                if (p0.isSetRsidR()) {
+//                    byte[] rsidr = p0.getRsidR();
+//                    byte[] rsidrdefault = p0.getRsidRDefault();
+//                    p.setRsidP(rsidr);
+//                    p.setRsidRDefault(rsidrdefault);
+//                }
+//            }
+//            CTPPr pPr = p.addNewPPr();
+//            pPr.addNewPStyle().setVal(pStyle);
         }
         return ftr;
     }
@@ -282,108 +296,127 @@ public class XWPFHeaderFooterPolicy {
     private void setFooterReference(Enum type, XWPFHeaderFooter wrapper) {
         CTHdrFtrRef ref = doc.getDocument().getBody().getSectPr().addNewFooterReference();
         ref.setType(type);
-        ref.setId(wrapper.getPackageRelationship().getId());
+        ref.setId(doc.getRelationId(wrapper));
     }
 
 
     private void setHeaderReference(Enum type, XWPFHeaderFooter wrapper) {
         CTHdrFtrRef ref = doc.getDocument().getBody().getSectPr().addNewHeaderReference();
         ref.setType(type);
-        ref.setId(wrapper.getPackageRelationship().getId());
+        ref.setId(doc.getRelationId(wrapper));
     }
-
-
-    private XmlOptions commit(XWPFHeaderFooter wrapper) {
-        XmlOptions xmlOptions = new XmlOptions(wrapper.DEFAULT_XML_OPTIONS);
-        Map<String, String> map = new HashMap<String, String>();
-        map.put("http://schemas.openxmlformats.org/officeDocument/2006/math", "m");
-        map.put("urn:schemas-microsoft-com:office:office", "o");
-        map.put("http://schemas.openxmlformats.org/officeDocument/2006/relationships", "r");
-        map.put("urn:schemas-microsoft-com:vml", "v");
-        map.put("http://schemas.openxmlformats.org/markup-compatibility/2006", "ve");
-        map.put("http://schemas.openxmlformats.org/wordprocessingml/2006/main", "w");
-        map.put("urn:schemas-microsoft-com:office:word", "w10");
-        map.put("http://schemas.microsoft.com/office/word/2006/wordml", "wne");
-        map.put("http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing", "wp");
-        xmlOptions.setSaveSuggestedPrefixes(map);
-        return xmlOptions;
-    }
-
+    
     public XWPFHeader getFirstPageHeader() {
         return firstPageHeader;
     }
+
     public XWPFFooter getFirstPageFooter() {
         return firstPageFooter;
     }
+
     /**
      * Returns the odd page header. This is
-     *  also the same as the default one...
+     * also the same as the default one...
      */
     public XWPFHeader getOddPageHeader() {
         return defaultHeader;
     }
+
     /**
      * Returns the odd page footer. This is
-     *  also the same as the default one...
+     * also the same as the default one...
      */
     public XWPFFooter getOddPageFooter() {
         return defaultFooter;
     }
+
     public XWPFHeader getEvenPageHeader() {
         return evenPageHeader;
     }
+
     public XWPFFooter getEvenPageFooter() {
         return evenPageFooter;
     }
+
     public XWPFHeader getDefaultHeader() {
         return defaultHeader;
     }
+
     public XWPFFooter getDefaultFooter() {
         return defaultFooter;
     }
 
     /**
      * Get the header that applies to the given
-     *  (1 based) page.
+     * (1 based) page.
+     *
      * @param pageNumber The one based page number
      */
     public XWPFHeader getHeader(int pageNumber) {
-        if(pageNumber == 1 && firstPageHeader != null) {
+        if (pageNumber == 1 && firstPageHeader != null) {
             return firstPageHeader;
         }
-        if(pageNumber % 2 == 0 && evenPageHeader != null) {
+        if (pageNumber % 2 == 0 && evenPageHeader != null) {
             return evenPageHeader;
         }
         return defaultHeader;
     }
+    
+    /**
+     * Get this section header for the given type
+     *
+     * @param type of header to return
+     * @return {@link XWPFHeader} object
+     */
+    public XWPFHeader getHeader(Enum type) {
+        if (type == STHdrFtr.EVEN) {
+            return evenPageHeader;
+        } else if (type == STHdrFtr.FIRST) {
+            return firstPageHeader;
+        }
+        return defaultHeader;
+    }
+
     /**
      * Get the footer that applies to the given
-     *  (1 based) page.
+     * (1 based) page.
+     *
      * @param pageNumber The one based page number
      */
     public XWPFFooter getFooter(int pageNumber) {
-        if(pageNumber == 1 && firstPageFooter != null) {
+        if (pageNumber == 1 && firstPageFooter != null) {
             return firstPageFooter;
         }
-        if(pageNumber % 2 == 0 && evenPageFooter != null) {
+        if (pageNumber % 2 == 0 && evenPageFooter != null) {
             return evenPageFooter;
         }
         return defaultFooter;
     }
+    
+    /**
+     * Get this section footer for the given type
+     *
+     * @param type of footer to return
+     * @return {@link XWPFFooter} object
+     */
+    public XWPFFooter getFooter(Enum type) {
+        if (type == STHdrFtr.EVEN) {
+            return evenPageFooter;
+        } else if (type == STHdrFtr.FIRST) {
+            return firstPageFooter;
+        }
+        return defaultFooter;
+    }
+    
 
     public void createWatermark(String text) {
         XWPFParagraph[] pars = new XWPFParagraph[1];
-        try {
-            pars[0] = getWatermarkParagraph(text, 1);
-            createHeader(DEFAULT, pars);
-            pars[0] = getWatermarkParagraph(text, 2);
-            createHeader(FIRST, pars);
-            pars[0] = getWatermarkParagraph(text, 3);
-            createHeader(EVEN, pars);
-        } catch (IOException e) {
-            // TODO Auto-generated catch block
-            e.printStackTrace();
-        }
+        pars[0] = getWatermarkParagraph(text, 1);
+        createHeader(DEFAULT, pars);
+        pars[0] = getWatermarkParagraph(text, 2);
+        createHeader(FIRST, pars);
+        pars[0] = getWatermarkParagraph(text, 3);
+        createHeader(EVEN, pars);
     }
 
     /*
@@ -441,7 +474,7 @@ public class XWPFHeaderFooterPolicy {
         lock.setExt(STExt.EDIT);
         CTShape shape = group.addNewShape();
         shape.setId("PowerPlusWaterMarkObject" + idx);
-        shape.setSpid("_x0000_s102" + (4+idx));
+        shape.setSpid("_x0000_s102" + (4 + idx));
         shape.setType("#_x0000_t136");
         shape.setStyle("position:absolute;margin-left:0;margin-top:0;width:415pt;height:207.5pt;z-index:-251654144;mso-wrap-edited:f;mso-position-horizontal:center;mso-position-horizontal-relative:margin;mso-position-vertical:center;mso-position-vertical-relative:margin");
         shape.setWrapcoords("616 5068 390 16297 39 16921 -39 17155 7265 17545 7186 17467 -39 17467 18904 17467 10507 17467 8710 17545 18904 17077 18787 16843 18358 16297 18279 12554 19178 12476 20701 11774 20779 11228 21131 10059 21248 8811 21248 7563 20975 6316 20935 5380 19490 5146 14022 5068 2616 5068");
