@@ -26,9 +26,6 @@ import java.io.InputStream;
 import java.net.URI;
 import java.net.URISyntaxException;
 
-import junit.framework.AssertionFailedError;
-import junit.framework.TestCase;
-
 import org.apache.poi.POIDataSamples;
 import org.apache.poi.openxml4j.OpenXML4JTestDataSamples;
 import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
@@ -40,6 +37,11 @@ import org.apache.poi.openxml4j.opc.PackagingURIHelper;
 import org.apache.poi.openxml4j.opc.TargetMode;
 import org.apache.poi.util.IOUtils;
 import org.apache.poi.util.TempFile;
+import org.junit.Test;
+
+import junit.framework.AssertionFailedError;
+
+import static org.junit.Assert.*;
 
 /**
  * Test core properties Open Packaging Convention compliance.
@@ -73,47 +75,49 @@ import org.apache.poi.util.TempFile;
  * 
  * @author Julien Chable
  */
-public final class TestOPCComplianceCoreProperties extends TestCase {
+public final class TestOPCComplianceCoreProperties {
 
-	public void testCorePropertiesPart() {
-		OPCPackage pkg;
-		try {
-			InputStream is = OpenXML4JTestDataSamples.openComplianceSampleStream("OPCCompliance_CoreProperties_OnlyOneCorePropertiesPart.docx");
-			pkg = OPCPackage.open(is);
-		} catch (InvalidFormatException e) {
-			throw new RuntimeException(e);
-		} catch (IOException e) {
-			throw new RuntimeException(e);
-		}
-		pkg.revert();
-	}
+    @Test
+    public void testCorePropertiesPart() {
+        OPCPackage pkg;
+        try {
+            InputStream is = OpenXML4JTestDataSamples.openComplianceSampleStream("OPCCompliance_CoreProperties_OnlyOneCorePropertiesPart.docx");
+            pkg = OPCPackage.open(is);
+        } catch (InvalidFormatException | IOException e) {
+            throw new RuntimeException(e);
+        }
+        pkg.revert();
+    }
 
-	private static String extractInvalidFormatMessage(String sampleNameSuffix) {
-		InputStream is = OpenXML4JTestDataSamples.openComplianceSampleStream("OPCCompliance_CoreProperties_" + sampleNameSuffix);
-		OPCPackage pkg;
-		try {
-			pkg = OPCPackage.open(is);
-		} catch (InvalidFormatException e) {
-			// no longer required for successful test
-			return e.getMessage();
-		} catch (IOException e) {
-			throw new RuntimeException(e);
-		}
-		pkg.revert();
-		throw new AssertionFailedError("expected OPC compliance exception was not thrown");
-	}
-	
-	/**
-	 * Test M4.1 rule.
-	 */
-	public void testOnlyOneCorePropertiesPart() throws Exception {
-	   // We have relaxed this check, so we can read the file anyway
-	   try {
-	      extractInvalidFormatMessage("OnlyOneCorePropertiesPartFAIL.docx");
-	      fail("M4.1 should be being relaxed");
-	   } catch (AssertionFailedError e) {}
-	   
-	   // We will use the first core properties, and ignore the others
+    private static String extractInvalidFormatMessage(String sampleNameSuffix) {
+        InputStream is = OpenXML4JTestDataSamples.openComplianceSampleStream("OPCCompliance_CoreProperties_" + sampleNameSuffix);
+        OPCPackage pkg;
+        try {
+            pkg = OPCPackage.open(is);
+        } catch (InvalidFormatException e) {
+            // no longer required for successful test
+            return e.getMessage();
+        } catch (IOException e) {
+            throw new RuntimeException(e);
+        }
+        pkg.revert();
+        throw new AssertionFailedError("expected OPC compliance exception was not thrown");
+    }
+    
+    /**
+     * Test M4.1 rule.
+     */
+    @Test
+    public void testOnlyOneCorePropertiesPart() throws Exception {
+       // We have relaxed this check, so we can read the file anyway
+       try {
+          extractInvalidFormatMessage("OnlyOneCorePropertiesPartFAIL.docx");
+          fail("M4.1 should be being relaxed");
+       } catch (AssertionFailedError e) {
+           // expected here
+       }
+       
+       // We will use the first core properties, and ignore the others
       InputStream is = OpenXML4JTestDataSamples.openSampleStream("MultipleCoreProperties.docx");
       OPCPackage pkg = OPCPackage.open(is);
       
@@ -126,115 +130,114 @@ public final class TestOPCComplianceCoreProperties extends TestCase {
             "/docProps/core.xml",
             pkg.getPartsByRelationshipType(PackageRelationshipTypes.CORE_PROPERTIES).get(0).getPartName().toString()
       );
-	}
-	
-	private static URI createURI(String text) {
-		try {
-			return new URI(text);
-		} catch (URISyntaxException e) {
-			throw new RuntimeException(e);
-		}
-	}
+    }
+    
+    private static URI createURI(String text) {
+        try {
+            return new URI(text);
+        } catch (URISyntaxException e) {
+            throw new RuntimeException(e);
+        }
+    }
 
-	/**
-	 * Test M4.1 rule.
-	 */
-	public void testOnlyOneCorePropertiesPart_AddRelationship() {
-		InputStream is = OpenXML4JTestDataSamples.openComplianceSampleStream("OPCCompliance_CoreProperties_OnlyOneCorePropertiesPart.docx");
-		OPCPackage pkg;
-		try {
-			pkg = OPCPackage.open(is);
-		} catch (InvalidFormatException e) {
-			throw new RuntimeException(e);
-		} catch (IOException e) {
-			throw new RuntimeException(e);
-		}
-		URI partUri = createURI("/docProps/core2.xml");
-		try {
-			pkg.addRelationship(PackagingURIHelper.createPartName(partUri), TargetMode.INTERNAL,
-					PackageRelationshipTypes.CORE_PROPERTIES);
-			// no longer fail on compliance error
-			//fail("expected OPC compliance exception was not thrown");
-		} catch (InvalidFormatException e) {
-			throw new RuntimeException(e);
-		} catch (InvalidOperationException e) {
-			// expected during successful test
-			assertEquals("OPC Compliance error [M4.1]: can't add another core properties part ! Use the built-in package method instead.", e.getMessage());
-		}
-		pkg.revert();
-	}
+    /**
+     * Test M4.1 rule.
+     */
+    @Test
+    public void testOnlyOneCorePropertiesPart_AddRelationship() {
+        InputStream is = OpenXML4JTestDataSamples.openComplianceSampleStream("OPCCompliance_CoreProperties_OnlyOneCorePropertiesPart.docx");
+        OPCPackage pkg;
+        try {
+            pkg = OPCPackage.open(is);
+        } catch (InvalidFormatException | IOException e) {
+            throw new RuntimeException(e);
+        }
+        URI partUri = createURI("/docProps/core2.xml");
+        try {
+            pkg.addRelationship(PackagingURIHelper.createPartName(partUri), TargetMode.INTERNAL,
+                    PackageRelationshipTypes.CORE_PROPERTIES);
+            // no longer fail on compliance error
+            //fail("expected OPC compliance exception was not thrown");
+        } catch (InvalidFormatException e) {
+            throw new RuntimeException(e);
+        } catch (InvalidOperationException e) {
+            // expected during successful test
+            assertEquals("OPC Compliance error [M4.1]: can't add another core properties part ! Use the built-in package method instead.", e.getMessage());
+        }
+        pkg.revert();
+    }
 
-	/**
-	 * Test M4.1 rule.
-	 */
-	public void testOnlyOneCorePropertiesPart_AddPart() {
-		String sampleFileName = "OPCCompliance_CoreProperties_OnlyOneCorePropertiesPart.docx";
-		OPCPackage pkg = null;
-		try {
-			pkg = OPCPackage.open(POIDataSamples.getOpenXML4JInstance().getFile(sampleFileName).getPath());
-		} catch (Exception e) {
-			throw new RuntimeException(e);
-		}
-		
-		URI partUri = createURI("/docProps/core2.xml");
-		try {
-			pkg.createPart(PackagingURIHelper.createPartName(partUri),
-					ContentTypes.CORE_PROPERTIES_PART);
-			// no longer fail on compliance error
-			//fail("expected OPC compliance exception was not thrown");
-		} catch (InvalidFormatException e) {
-			throw new RuntimeException(e);
-		} catch (InvalidOperationException e) {
-			// expected during successful test
-			assertEquals("OPC Compliance error [M4.1]: you try to add more than one core properties relationship in the package !", e.getMessage());
-		}
-		pkg.revert();
-	}
+    /**
+     * Test M4.1 rule.
+     */
+    @Test
+    public void testOnlyOneCorePropertiesPart_AddPart() throws InvalidFormatException {
+        String sampleFileName = "OPCCompliance_CoreProperties_OnlyOneCorePropertiesPart.docx";
+        OPCPackage pkg = OPCPackage.open(POIDataSamples.getOpenXML4JInstance().getFile(sampleFileName).getPath());
 
-	/**
-	 * Test M4.2 rule.
-	 */
-	public void testDoNotUseCompatibilityMarkup() {
-		String msg = extractInvalidFormatMessage("DoNotUseCompatibilityMarkupFAIL.docx");
-		assertEquals("OPC Compliance error [M4.2]: A format consumer shall consider the use of the Markup Compatibility namespace to be an error.", msg);
-	}
+        URI partUri = createURI("/docProps/core2.xml");
+        try {
+            pkg.createPart(PackagingURIHelper.createPartName(partUri),
+                    ContentTypes.CORE_PROPERTIES_PART);
+            // no longer fail on compliance error
+            //fail("expected OPC compliance exception was not thrown");
+        } catch (InvalidOperationException e) {
+            // expected during successful test
+            assertEquals("OPC Compliance error [M4.1]: you try to add more than one core properties relationship in the package !", e.getMessage());
+        }
+        pkg.revert();
+    }
 
-	/**
-	 * Test M4.3 rule.
-	 */
-	public void testDCTermsNamespaceLimitedUse() {
-		String msg = extractInvalidFormatMessage("DCTermsNamespaceLimitedUseFAIL.docx");
-		assertEquals("OPC Compliance error [M4.3]: Producers shall not create a document element that contains refinements to the Dublin Core elements, except for the two specified in the schema: <dcterms:created> and <dcterms:modified> Consumers shall consider a document element that violates this constraint to be an error.", msg);
-	}
+    /**
+     * Test M4.2 rule.
+     */
+    @Test
+    public void testDoNotUseCompatibilityMarkup() {
+        String msg = extractInvalidFormatMessage("DoNotUseCompatibilityMarkupFAIL.docx");
+        assertEquals("OPC Compliance error [M4.2]: A format consumer shall consider the use of the Markup Compatibility namespace to be an error.", msg);
+    }
 
-	/**
-	 * Test M4.4 rule.
-	 */
-	public void testUnauthorizedXMLLangAttribute() {
-		String msg = extractInvalidFormatMessage("UnauthorizedXMLLangAttributeFAIL.docx");
-		assertEquals("OPC Compliance error [M4.4]: Producers shall not create a document element that contains the xml:lang attribute. Consumers shall consider a document element that violates this constraint to be an error.", msg);
-	}
+    /**
+     * Test M4.3 rule.
+     */
+    @Test
+    public void testDCTermsNamespaceLimitedUse() {
+        String msg = extractInvalidFormatMessage("DCTermsNamespaceLimitedUseFAIL.docx");
+        assertEquals("OPC Compliance error [M4.3]: Producers shall not create a document element that contains refinements to the Dublin Core elements, except for the two specified in the schema: <dcterms:created> and <dcterms:modified> Consumers shall consider a document element that violates this constraint to be an error.", msg);
+    }
 
-	/**
-	 * Test M4.5 rule.
-	 */
-	public void testLimitedXSITypeAttribute_NotPresent() {
-		String msg = extractInvalidFormatMessage("LimitedXSITypeAttribute_NotPresentFAIL.docx");
-		assertEquals("The element 'created' must have the 'xsi:type' attribute present !", msg);
-	}
+    /**
+     * Test M4.4 rule.
+     */
+    @Test
+    public void testUnauthorizedXMLLangAttribute() {
+        String msg = extractInvalidFormatMessage("UnauthorizedXMLLangAttributeFAIL.docx");
+        assertEquals("OPC Compliance error [M4.4]: Producers shall not create a document element that contains the xml:lang attribute. Consumers shall consider a document element that violates this constraint to be an error.", msg);
+    }
 
-	/**
-	 * Test M4.5 rule.
-	 */
-	public void testLimitedXSITypeAttribute_PresentWithUnauthorizedValue() {
-		String msg = extractInvalidFormatMessage("LimitedXSITypeAttribute_PresentWithUnauthorizedValueFAIL.docx");
-		assertEquals("The element 'modified' must have the 'xsi:type' attribute with the value 'dcterms:W3CDTF' !", msg);
-	}
-	
+    /**
+     * Test M4.5 rule.
+     */
+    @Test
+    public void testLimitedXSITypeAttribute_NotPresent() {
+        String msg = extractInvalidFormatMessage("LimitedXSITypeAttribute_NotPresentFAIL.docx");
+        assertEquals("The element 'created' must have the 'xsi:type' attribute present !", msg);
+    }
+
+    /**
+     * Test M4.5 rule.
+     */
+    @Test
+    public void testLimitedXSITypeAttribute_PresentWithUnauthorizedValue() {
+        String msg = extractInvalidFormatMessage("LimitedXSITypeAttribute_PresentWithUnauthorizedValueFAIL.docx");
+        assertEquals("The element 'modified' must have the 'xsi:type' attribute with the value 'dcterms:W3CDTF', but had 'W3CDTF' !", msg);
+    }
+    
     /**
      * Document with no core properties - testing at the OPC level,
      *  saving into a new stream
      */
+    @Test
     public void testNoCoreProperties_saveNew() throws Exception {
         String sampleFileName = "OPCCompliance_NoCoreProperties.xlsx";
         OPCPackage pkg = OPCPackage.open(POIDataSamples.getOpenXML4JInstance().getFile(sampleFileName).getPath());
@@ -243,12 +246,13 @@ public final class TestOPCComplianceCoreProperties extends TestCase {
         assertEquals(0, pkg.getPartsByContentType(ContentTypes.CORE_PROPERTIES_PART).size());
         assertNotNull(pkg.getPackageProperties());
         assertNotNull(pkg.getPackageProperties().getLanguageProperty());
-        assertNull(pkg.getPackageProperties().getLanguageProperty().getValue());
+        assertFalse(pkg.getPackageProperties().getLanguageProperty().isPresent());
 
         // Save and re-load
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         pkg.save(baos);
         ByteArrayInputStream bais = new ByteArrayInputStream(baos.toByteArray());
+        pkg.revert();
 
         pkg = OPCPackage.open(bais);
 
@@ -256,8 +260,8 @@ public final class TestOPCComplianceCoreProperties extends TestCase {
         assertEquals(1, pkg.getPartsByContentType(ContentTypes.CORE_PROPERTIES_PART).size());
         assertNotNull(pkg.getPackageProperties());
         assertNotNull(pkg.getPackageProperties().getLanguageProperty());
-        assertNull(pkg.getPackageProperties().getLanguageProperty().getValue());
-        
+        assertFalse(pkg.getPackageProperties().getLanguageProperty().isPresent());
+        pkg.close();
         
         // Open a new copy of it
         pkg = OPCPackage.open(POIDataSamples.getOpenXML4JInstance().getFile(sampleFileName).getPath());
@@ -265,6 +269,8 @@ public final class TestOPCComplianceCoreProperties extends TestCase {
         // Save and re-load, without having touched the properties yet
         baos = new ByteArrayOutputStream();
         pkg.save(baos);
+        pkg.revert();
+
         bais = new ByteArrayInputStream(baos.toByteArray());
         pkg = OPCPackage.open(bais);
         
@@ -272,23 +278,26 @@ public final class TestOPCComplianceCoreProperties extends TestCase {
         assertEquals(1, pkg.getPartsByContentType(ContentTypes.CORE_PROPERTIES_PART).size());
         assertNotNull(pkg.getPackageProperties());
         assertNotNull(pkg.getPackageProperties().getLanguageProperty());
-        assertNull(pkg.getPackageProperties().getLanguageProperty().getValue());
+        assertFalse(pkg.getPackageProperties().getLanguageProperty().isPresent());
     }
 
     /**
      * Document with no core properties - testing at the OPC level,
      *  from a temp-file, saving in-place
      */
+    @Test
     public void testNoCoreProperties_saveInPlace() throws Exception {
         String sampleFileName = "OPCCompliance_NoCoreProperties.xlsx";
 
         // Copy this into a temp file, so we can play with it
         File tmp = TempFile.createTempFile("poi-test", ".opc");
         FileOutputStream out = new FileOutputStream(tmp);
+        InputStream in = POIDataSamples.getOpenXML4JInstance().openResourceAsStream(sampleFileName);
         IOUtils.copy(
-                POIDataSamples.getOpenXML4JInstance().openResourceAsStream(sampleFileName),
+                in,
                 out);
         out.close();
+        in.close();
 
         // Open it from that temp file
         OPCPackage pkg = OPCPackage.open(tmp);
@@ -297,12 +306,11 @@ public final class TestOPCComplianceCoreProperties extends TestCase {
         assertEquals(0, pkg.getPartsByContentType(ContentTypes.CORE_PROPERTIES_PART).size());
         assertNotNull(pkg.getPackageProperties());
         assertNotNull(pkg.getPackageProperties().getLanguageProperty());
-        assertNull(pkg.getPackageProperties().getLanguageProperty().getValue());
+        assertFalse(pkg.getPackageProperties().getLanguageProperty().isPresent());
 
         // Save and close
         pkg.close();
 
-
         // Re-open and check
         pkg = OPCPackage.open(tmp);
 
@@ -310,10 +318,10 @@ public final class TestOPCComplianceCoreProperties extends TestCase {
         assertEquals(1, pkg.getPartsByContentType(ContentTypes.CORE_PROPERTIES_PART).size());
         assertNotNull(pkg.getPackageProperties());
         assertNotNull(pkg.getPackageProperties().getLanguageProperty());
-        assertNull(pkg.getPackageProperties().getLanguageProperty().getValue());
+        assertFalse(pkg.getPackageProperties().getLanguageProperty().isPresent());
 
         // Finish and tidy
         pkg.revert();
-        tmp.delete();
+        assertTrue(tmp.delete());
     }
 }
