@@ -16,24 +16,23 @@
 ==================================================================== */
 package org.apache.poi.xslf.usermodel;
 
-import junit.framework.TestCase;
-import org.openxmlformats.schemas.drawingml.x2006.main.CTTableStyle;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
 
-/**
- * @author Yegor Kozlov
- */
-public class TestXSLFTableStyles extends TestCase {
+import java.io.IOException;
 
-    public void testRead(){
+import org.junit.Test;
+
+public class TestXSLFTableStyles {
+
+    @Test
+    public void testRead() throws IOException {
         XMLSlideShow  ppt = new XMLSlideShow();
         XSLFTableStyles tblStyles = ppt.getTableStyles();
         assertNotNull(tblStyles);
 
         assertEquals(0, tblStyles.getStyles().size());
-    }
-
-    public void testStyle(){
-        CTTableStyle obj = CTTableStyle.Factory.newInstance();
-        XSLFTableStyle style = new XSLFTableStyle(obj);
+        
+        ppt.close();
     }
 }
\ No newline at end of file
