@@ -17,9 +17,12 @@
 
 package org.apache.poi.xssf.model;
 
-import org.apache.poi.xssf.usermodel.*;
+import org.apache.poi.ss.usermodel.CellType;
 import org.apache.poi.xssf.XSSFTestDataSamples;
-import org.openxmlformats.schemas.spreadsheetml.x2006.main.*;
+import org.apache.poi.xssf.usermodel.XSSFCell;
+import org.apache.poi.xssf.usermodel.XSSFSheet;
+import org.apache.poi.xssf.usermodel.XSSFWorkbook;
+import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCalcCell;
 
 import junit.framework.TestCase;
 
@@ -39,7 +42,7 @@ public final class TestCalculationChain extends TestCase {
         XSSFSheet sheet = wb.getSheet("Test");
         XSSFCell cell = sheet.getRow(0).getCell(4);
 
-        assertEquals(XSSFCell.CELL_TYPE_FORMULA, cell.getCellType());
+        assertEquals(CellType.FORMULA, cell.getCellType());
         cell.setCellFormula(null);
 
         //the count of items is less by one
@@ -50,9 +53,9 @@ public final class TestCalculationChain extends TestCase {
         assertEquals(10, c.getI());
         assertEquals("C1", c.getR());
 
-        assertEquals(XSSFCell.CELL_TYPE_STRING, cell.getCellType());
+        assertEquals(CellType.STRING, cell.getCellType());
         cell.setCellValue("ABC");
-        assertEquals(XSSFCell.CELL_TYPE_STRING, cell.getCellType());
+        assertEquals(CellType.STRING, cell.getCellType());
     }
 
 
