@@ -19,17 +19,23 @@
 
 package org.apache.poi.xssf.streaming;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+
 import java.io.IOException;
 
 import javax.xml.namespace.QName;
 
 import org.apache.poi.ss.usermodel.BaseTestXCell;
 import org.apache.poi.ss.usermodel.Cell;
+import org.apache.poi.ss.usermodel.FormulaError;
 import org.apache.poi.ss.usermodel.Workbook;
 import org.apache.poi.xssf.SXSSFITestDataProvider;
 import org.apache.poi.xssf.usermodel.XSSFCell;
 import org.apache.poi.xssf.usermodel.XSSFWorkbook;
 import org.apache.xmlbeans.XmlCursor;
+import org.junit.AfterClass;
+import org.junit.Test;
 import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTRst;
 
 /**
@@ -42,56 +48,12 @@ public class TestSXSSFCell extends BaseTestXCell {
         super(SXSSFITestDataProvider.instance);
     }
 
-    @Override
-    public void tearDown(){
+    @AfterClass
+    public static void tearDownClass(){
         SXSSFITestDataProvider.instance.cleanup();
     }
 
-    /**
-     * this test involves evaluation of formulas which isn't supported for SXSSF
-     */
-    @Override
-    public void testConvertStringFormulaCell() {
-        try {
-            super.testConvertStringFormulaCell();
-            fail("expected exception");
-        } catch (IllegalArgumentException e){
-            assertEquals(
-                    "Unexpected type of cell: class org.apache.poi.xssf.streaming.SXSSFCell. " +
-                    "Only XSSFCells can be evaluated.", e.getMessage());
-        }
-    }
-
-    /**
-     * this test involves evaluation of formulas which isn't supported for SXSSF
-     */
-    @Override
-    public void testSetTypeStringOnFormulaCell() {
-        try {
-            super.testSetTypeStringOnFormulaCell();
-            fail("expected exception");
-        } catch (IllegalArgumentException e){
-            assertEquals(
-                    "Unexpected type of cell: class org.apache.poi.xssf.streaming.SXSSFCell. " +
-                    "Only XSSFCells can be evaluated.", e.getMessage());
-        }
-    }
-    
-    /**
-     * this test involves evaluation of formulas which isn't supported for SXSSF
-     */
-    @Override
-    public void testGetErrorCellValueFromFormulaCell() {
-        try {
-            super.testConvertStringFormulaCell();
-            fail("expected exception");
-        } catch (IllegalArgumentException e){
-            assertEquals(
-                    "Unexpected type of cell: class org.apache.poi.xssf.streaming.SXSSFCell. " +
-                    "Only XSSFCells can be evaluated.", e.getMessage());
-        }
-    }
-
+    @Test
     public void testPreserveSpaces() throws IOException {
         String[] samplesWithSpaces = {
                 " POI",
@@ -100,7 +62,7 @@ public class TestSXSSFCell extends BaseTestXCell {
                 "\nPOI",
                 "\n\nPOI \n",
         };
-        for(String str : samplesWithSpaces){
+        for (String str : samplesWithSpaces) {
             Workbook swb = _testDataProvider.createWorkbook();
             Cell sCell = swb.createSheet().createRow(0).createCell(0);
             sCell.setCellValue(str);
@@ -111,11 +73,26 @@ public class TestSXSSFCell extends BaseTestXCell {
             XSSFCell xCell = xwb.getSheetAt(0).getRow(0).getCell(0);
 
             CTRst is = xCell.getCTCell().getIs();
+            assertNotNull(is);
             XmlCursor c = is.newCursor();
             c.toNextToken();
             String t = c.getAttributeText(new QName("http://www.w3.org/XML/1998/namespace", "space"));
             c.dispose();
             assertEquals("expected xml:spaces=\"preserve\" \"" + str + "\"", "preserve", t);
+            xwb.close();
+            swb.close();
+        }
+    }
+
+    @Test
+    public void test62216() throws IOException {
+        try (SXSSFWorkbook wb = new SXSSFWorkbook()) {
+            Cell instance = wb.createSheet().createRow(0).createCell(0);
+            String formula = "2";
+            instance.setCellFormula(formula);
+            instance.setCellErrorValue(FormulaError.NAME.getCode());
+
+            assertEquals(formula, instance.getCellFormula());
         }
     }
 }
