@@ -24,7 +24,7 @@ import static org.junit.Assert.fail;
 
 import java.io.IOException;
 
-import org.apache.poi.ss.usermodel.BaseTestSheet;
+import org.apache.poi.ss.usermodel.BaseTestXSheet;
 import org.apache.poi.ss.usermodel.Sheet;
 import org.apache.poi.ss.usermodel.Workbook;
 import org.apache.poi.xssf.SXSSFITestDataProvider;
@@ -33,7 +33,7 @@ import org.junit.After;
 import org.junit.Test;
 
 
-public class TestSXSSFSheet extends BaseTestSheet {
+public final class TestSXSSFSheet extends BaseTestXSheet {
 
     public TestSXSSFSheet() {
         super(SXSSFITestDataProvider.instance);
@@ -44,6 +44,12 @@ public class TestSXSSFSheet extends BaseTestSheet {
     public void tearDown(){
         SXSSFITestDataProvider.instance.cleanup();
     }
+    
+    @Override
+    protected void trackColumnsForAutoSizingIfSXSSF(Sheet sheet) {
+        SXSSFSheet sxSheet = (SXSSFSheet) sheet;
+        sxSheet.trackAllColumnsForAutoSizing();
+    }
 
 
     /**
@@ -51,17 +57,17 @@ public class TestSXSSFSheet extends BaseTestSheet {
      */
     @Override
     @Test
-    public void cloneSheet() {
+    public void cloneSheet() throws IOException {
         thrown.expect(RuntimeException.class);
-        thrown.expectMessage("NotImplemented");
+        thrown.expectMessage("Not Implemented");
         super.cloneSheet();
     }
 
     @Override
     @Test
-    public void cloneSheetMultipleTimes() {
+    public void cloneSheetMultipleTimes() throws IOException {
         thrown.expect(RuntimeException.class);
-        thrown.expectMessage("NotImplemented");
+        thrown.expectMessage("Not Implemented");
         super.cloneSheetMultipleTimes();
     }
     
@@ -70,9 +76,9 @@ public class TestSXSSFSheet extends BaseTestSheet {
      */
     @Override
     @Test
-    public void shiftMerged(){
+    public void shiftMerged() throws IOException {
         thrown.expect(RuntimeException.class);
-        thrown.expectMessage("NotImplemented");
+        thrown.expectMessage("Not Implemented");
         super.shiftMerged();
     }
 
@@ -83,17 +89,18 @@ public class TestSXSSFSheet extends BaseTestSheet {
      */
     @Override
     @Test
-    public void bug35084(){
+    public void bug35084() throws IOException {
         thrown.expect(RuntimeException.class);
-        thrown.expectMessage("NotImplemented");
+        thrown.expectMessage("Not Implemented");
         super.bug35084();
     }
 
+    @Override
     @Test
     public void getCellComment() throws IOException {
-    	// TODO: reading cell comments via Sheet does not work currently as it tries 
-    	// to access the underlying sheet for this, but comments are stored as
-    	// properties on Cells...
+        // TODO: reading cell comments via Sheet does not work currently as it tries 
+        // to access the underlying sheet for this, but comments are stored as
+        // properties on Cells...
     }
     
     @Override
@@ -145,7 +152,24 @@ public class TestSXSSFSheet extends BaseTestSheet {
             sheet.createRow(2);
         } finally {
             wb.close();
+            template.close();
         }
+    }
 
+    @Test
+    public void changeRowNum() throws IOException {
+        SXSSFWorkbook wb = new SXSSFWorkbook(3);
+        SXSSFSheet sheet = wb.createSheet();
+        SXSSFRow row0 = sheet.createRow(0);
+        SXSSFRow row1 = sheet.createRow(1);
+        sheet.changeRowNum(row0, 2);
+        
+        assertEquals("Row 1 knows its row number", 1, row1.getRowNum());
+        assertEquals("Row 2 knows its row number", 2, row0.getRowNum());
+        assertEquals("Sheet knows Row 1's row number", 1, sheet.getRowNum(row1));
+        assertEquals("Sheet knows Row 2's row number", 2, sheet.getRowNum(row0));
+        assertEquals("Sheet row iteratation order should be ascending", row1, sheet.iterator().next());
+        
+        wb.close();
     }
 }
