@@ -17,11 +17,15 @@
 
 package org.apache.poi.xssf.usermodel;
 
-import junit.framework.TestCase;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+
+import java.io.IOException;
 
 import org.apache.poi.util.POILogFactory;
 import org.apache.poi.util.POILogger;
 import org.apache.poi.xssf.XSSFTestDataSamples;
+import org.junit.Test;
 import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCol;
 import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCols;
 
@@ -29,80 +33,86 @@ import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCols;
  * Test asserts the POI produces &lt;cols&gt; element that could be read and properly interpreted by the MS Excel.
  * For specification of the "cols" element see the chapter 3.3.1.16 of the "Office Open XML Part 4 - Markup Language Reference.pdf".
  * The specification can be downloaded at http://www.ecma-international.org/publications/files/ECMA-ST/Office%20Open%20XML%201st%20edition%20Part%204%20(PDF).zip.
- * 
+ *
  * <p><em>
  * The test saves xlsx file on a disk if the system property is set:
  * -Dpoi.test.xssf.output.dir=${workspace_loc}/poi/build/xssf-output
  * </em>
- * 
+ *
  */
-public class TestXSSFColGrouping extends TestCase {
-	
+public class TestXSSFColGrouping {
+
 	private static final POILogger logger = POILogFactory.getLogger(TestXSSFColGrouping.class);
 
-	
+
     /**
-     * Tests that POI doesn't produce "col" elements without "width" attribute. 
+     * Tests that POI doesn't produce "col" elements without "width" attribute.
      * POI-52186
      */
-    @SuppressWarnings("deprecation")
-    public void testNoColsWithoutWidthWhenGrouping() {
-		XSSFWorkbook wb = new XSSFWorkbook();
-		XSSFSheet sheet = wb.createSheet("test");
+	@Test
+    public void testNoColsWithoutWidthWhenGrouping() throws IOException {
+		XSSFWorkbook wb1 = new XSSFWorkbook();
+		XSSFSheet sheet = wb1.createSheet("test");
 
         sheet.setColumnWidth(4, 5000);
         sheet.setColumnWidth(5, 5000);
-       
+
         sheet.groupColumn((short) 4, (short) 7);
         sheet.groupColumn((short) 9, (short) 12);
-        
-        wb = XSSFTestDataSamples.writeOutAndReadBack(wb, "testNoColsWithoutWidthWhenGrouping");
-        sheet = wb.getSheet("test");
-        
+
+        XSSFWorkbook wb2 = XSSFTestDataSamples.writeOutAndReadBack(wb1, "testNoColsWithoutWidthWhenGrouping");
+        sheet = wb2.getSheet("test");
+
         CTCols cols = sheet.getCTWorksheet().getColsArray(0);
         logger.log(POILogger.DEBUG, "test52186/cols:" + cols);
         for (CTCol col : cols.getColArray()) {
-			assertTrue("Col width attribute is unset: " + col.toString(), col.isSetWidth());
+			assertTrue("Col width attribute is unset: " + col, col.isSetWidth());
 		}
+
+        wb2.close();
+        wb1.close();
     }
 
     /**
-     * Tests that POI doesn't produce "col" elements without "width" attribute. 
+     * Tests that POI doesn't produce "col" elements without "width" attribute.
      * POI-52186
      */
-    @SuppressWarnings("deprecation")
-    public void testNoColsWithoutWidthWhenGroupingAndCollapsing() {
-		XSSFWorkbook wb = new XSSFWorkbook();
-		XSSFSheet sheet = wb.createSheet("test");
+	@Test
+	public void testNoColsWithoutWidthWhenGroupingAndCollapsing() throws IOException {
+		XSSFWorkbook wb1 = new XSSFWorkbook();
+		XSSFSheet sheet = wb1.createSheet("test");
 
         sheet.setColumnWidth(4, 5000);
         sheet.setColumnWidth(5, 5000);
-       
+
         sheet.groupColumn((short) 4, (short) 5);
-        
+
         sheet.setColumnGroupCollapsed(4, true);
-        
+
         CTCols cols = sheet.getCTWorksheet().getColsArray(0);
         logger.log(POILogger.DEBUG, "test52186_2/cols:" + cols);
 
-        wb = XSSFTestDataSamples.writeOutAndReadBack(wb, "testNoColsWithoutWidthWhenGroupingAndCollapsing");
-        sheet = wb.getSheet("test");
-        
+        XSSFWorkbook wb2 = XSSFTestDataSamples.writeOutAndReadBack(wb1, "testNoColsWithoutWidthWhenGroupingAndCollapsing");
+        sheet = wb2.getSheet("test");
+
         for (int i = 4; i <= 5; i++) {
         	assertEquals("Unexpected width of column "+ i, 5000, sheet.getColumnWidth(i));
         }
         cols = sheet.getCTWorksheet().getColsArray(0);
         for (CTCol col : cols.getColArray()) {
-			assertTrue("Col width attribute is unset: " + col.toString(), col.isSetWidth());
+			assertTrue("Col width attribute is unset: " + col, col.isSetWidth());
 		}
+        wb2.close();
+        wb1.close();
     }
-    
+
     /**
      * Test the cols element is correct in case of NumericRanges.OVERLAPS_2_WRAPS
      */
-    public void testMergingOverlappingCols_OVERLAPS_2_WRAPS() {
-		XSSFWorkbook wb = new XSSFWorkbook();
-		XSSFSheet sheet = wb.createSheet("test");
+	@Test
+    public void testMergingOverlappingCols_OVERLAPS_2_WRAPS() throws IOException {
+		XSSFWorkbook wb1 = new XSSFWorkbook();
+		XSSFSheet sheet = wb1.createSheet("test");
 
         CTCols cols = sheet.getCTWorksheet().getColsArray(0);
         CTCol col = cols.addNewCol();
@@ -112,10 +122,10 @@ public class TestXSSFColGrouping extends TestCase {
         col.setCustomWidth(true);
 
         sheet.groupColumn((short) 2, (short) 3);
-        
+
         sheet.getCTWorksheet().getColsArray(0);
         logger.log(POILogger.DEBUG, "testMergingOverlappingCols_OVERLAPS_2_WRAPS/cols:" + cols);
-        
+
         assertEquals(0, cols.getColArray(0).getOutlineLevel());
         assertEquals(2, cols.getColArray(0).getMin()); // 1 based
         assertEquals(2, cols.getColArray(0).getMax()); // 1 based
@@ -123,30 +133,34 @@ public class TestXSSFColGrouping extends TestCase {
 
         assertEquals(1, cols.getColArray(1).getOutlineLevel());
         assertEquals(3, cols.getColArray(1).getMin()); // 1 based
-        assertEquals(4, cols.getColArray(1).getMax()); // 1 based        
+        assertEquals(4, cols.getColArray(1).getMax()); // 1 based
         assertEquals(true, cols.getColArray(1).getCustomWidth());
 
         assertEquals(0, cols.getColArray(2).getOutlineLevel());
         assertEquals(5, cols.getColArray(2).getMin()); // 1 based
         assertEquals(5, cols.getColArray(2).getMax()); // 1 based
         assertEquals(true, cols.getColArray(2).getCustomWidth());
-        
+
         assertEquals(3, cols.sizeOfColArray());
 
-        wb = XSSFTestDataSamples.writeOutAndReadBack(wb, "testMergingOverlappingCols_OVERLAPS_2_WRAPS");
-        sheet = wb.getSheet("test");
-        
+        XSSFWorkbook wb2 = XSSFTestDataSamples.writeOutAndReadBack(wb1, "testMergingOverlappingCols_OVERLAPS_2_WRAPS");
+        sheet = wb2.getSheet("test");
+
         for (int i = 1; i <= 4; i++) {
         	assertEquals("Unexpected width of column "+ i, 20 * 256, sheet.getColumnWidth(i));
         }
+
+        wb2.close();
+        wb1.close();
     }
 
     /**
      * Test the cols element is correct in case of NumericRanges.OVERLAPS_1_WRAPS
      */
-    public void testMergingOverlappingCols_OVERLAPS_1_WRAPS() {
-		XSSFWorkbook wb = new XSSFWorkbook();
-		XSSFSheet sheet = wb.createSheet("test");
+	@Test
+    public void testMergingOverlappingCols_OVERLAPS_1_WRAPS() throws IOException {
+		XSSFWorkbook wb1 = new XSSFWorkbook();
+		XSSFSheet sheet = wb1.createSheet("test");
 
         CTCols cols = sheet.getCTWorksheet().getColsArray(0);
         CTCol col = cols.addNewCol();
@@ -156,10 +170,10 @@ public class TestXSSFColGrouping extends TestCase {
         col.setCustomWidth(true);
 
         sheet.groupColumn((short) 1, (short) 5);
-        
+
         cols = sheet.getCTWorksheet().getColsArray(0);
         logger.log(POILogger.DEBUG, "testMergingOverlappingCols_OVERLAPS_1_WRAPS/cols:" + cols);
-        
+
         assertEquals(1, cols.getColArray(0).getOutlineLevel());
         assertEquals(2, cols.getColArray(0).getMin()); // 1 based
         assertEquals(2, cols.getColArray(0).getMax()); // 1 based
@@ -167,30 +181,34 @@ public class TestXSSFColGrouping extends TestCase {
 
         assertEquals(1, cols.getColArray(1).getOutlineLevel());
         assertEquals(3, cols.getColArray(1).getMin()); // 1 based
-        assertEquals(5, cols.getColArray(1).getMax()); // 1 based        
+        assertEquals(5, cols.getColArray(1).getMax()); // 1 based
         assertEquals(true, cols.getColArray(1).getCustomWidth());
 
         assertEquals(1, cols.getColArray(2).getOutlineLevel());
         assertEquals(6, cols.getColArray(2).getMin()); // 1 based
         assertEquals(6, cols.getColArray(2).getMax()); // 1 based
         assertEquals(false, cols.getColArray(2).getCustomWidth());
-        
+
         assertEquals(3, cols.sizeOfColArray());
-        
-        wb = XSSFTestDataSamples.writeOutAndReadBack(wb, "testMergingOverlappingCols_OVERLAPS_1_WRAPS");
-        sheet = wb.getSheet("test");
-        
+
+        XSSFWorkbook wb2 = XSSFTestDataSamples.writeOutAndReadBack(wb1, "testMergingOverlappingCols_OVERLAPS_1_WRAPS");
+        sheet = wb2.getSheet("test");
+
         for (int i = 2; i <= 4; i++) {
         	assertEquals("Unexpected width of column "+ i, 20 * 256, sheet.getColumnWidth(i));
         }
+
+        wb2.close();
+        wb1.close();
     }
 
     /**
      * Test the cols element is correct in case of NumericRanges.OVERLAPS_1_MINOR
      */
-    public void testMergingOverlappingCols_OVERLAPS_1_MINOR() {
-		XSSFWorkbook wb = new XSSFWorkbook();
-		XSSFSheet sheet = wb.createSheet("test");
+	@Test
+    public void testMergingOverlappingCols_OVERLAPS_1_MINOR() throws IOException {
+		XSSFWorkbook wb1 = new XSSFWorkbook();
+		XSSFSheet sheet = wb1.createSheet("test");
 
         CTCols cols = sheet.getCTWorksheet().getColsArray(0);
         CTCol col = cols.addNewCol();
@@ -200,7 +218,7 @@ public class TestXSSFColGrouping extends TestCase {
         col.setCustomWidth(true);
 
         sheet.groupColumn((short) 3, (short) 5);
-        
+
         cols = sheet.getCTWorksheet().getColsArray(0);
         logger.log(POILogger.DEBUG, "testMergingOverlappingCols_OVERLAPS_1_MINOR/cols:" + cols);
 
@@ -211,31 +229,35 @@ public class TestXSSFColGrouping extends TestCase {
 
         assertEquals(1, cols.getColArray(1).getOutlineLevel());
         assertEquals(4, cols.getColArray(1).getMin()); // 1 based
-        assertEquals(5, cols.getColArray(1).getMax()); // 1 based        
+        assertEquals(5, cols.getColArray(1).getMax()); // 1 based
         assertEquals(true, cols.getColArray(1).getCustomWidth());
 
         assertEquals(1, cols.getColArray(2).getOutlineLevel());
         assertEquals(6, cols.getColArray(2).getMin()); // 1 based
         assertEquals(6, cols.getColArray(2).getMax()); // 1 based
         assertEquals(false, cols.getColArray(2).getCustomWidth());
-        
+
         assertEquals(3, cols.sizeOfColArray());
-        
-        wb = XSSFTestDataSamples.writeOutAndReadBack(wb, "testMergingOverlappingCols_OVERLAPS_1_MINOR");
-        sheet = wb.getSheet("test");
-        
+
+        XSSFWorkbook wb2 = XSSFTestDataSamples.writeOutAndReadBack(wb1, "testMergingOverlappingCols_OVERLAPS_1_MINOR");
+        sheet = wb2.getSheet("test");
+
         for (int i = 2; i <= 4; i++) {
-        	assertEquals("Unexpected width of column "+ i, 20 * 256, sheet.getColumnWidth(i));
+        	assertEquals("Unexpected width of column "+ i, 20 * 256L, sheet.getColumnWidth(i));
         }
-    	assertEquals("Unexpected width of column "+ 5, sheet.getDefaultColumnWidth() * 256, sheet.getColumnWidth(5));
+    	assertEquals("Unexpected width of column "+ 5, sheet.getDefaultColumnWidth() * 256L, sheet.getColumnWidth(5));
+
+    	wb2.close();
+    	wb1.close();
     }
 
     /**
      * Test the cols element is correct in case of NumericRanges.OVERLAPS_2_MINOR
      */
-   public void testMergingOverlappingCols_OVERLAPS_2_MINOR() {
-		XSSFWorkbook wb = new XSSFWorkbook();
-		XSSFSheet sheet = wb.createSheet("test");
+	@Test
+    public void testMergingOverlappingCols_OVERLAPS_2_MINOR() throws IOException {
+		XSSFWorkbook wb1 = new XSSFWorkbook();
+		XSSFSheet sheet = wb1.createSheet("test");
 
         CTCols cols = sheet.getCTWorksheet().getColsArray(0);
         CTCol col = cols.addNewCol();
@@ -245,7 +267,7 @@ public class TestXSSFColGrouping extends TestCase {
         col.setCustomWidth(true);
 
         sheet.groupColumn((short) 1, (short) 3);
-        
+
         cols = sheet.getCTWorksheet().getColsArray(0);
         logger.log(POILogger.DEBUG, "testMergingOverlappingCols_OVERLAPS_2_MINOR/cols:" + cols);
 
@@ -256,23 +278,26 @@ public class TestXSSFColGrouping extends TestCase {
 
         assertEquals(1, cols.getColArray(1).getOutlineLevel());
         assertEquals(3, cols.getColArray(1).getMin()); // 1 based
-        assertEquals(4, cols.getColArray(1).getMax()); // 1 based        
+        assertEquals(4, cols.getColArray(1).getMax()); // 1 based
         assertEquals(true, cols.getColArray(1).getCustomWidth());
 
         assertEquals(0, cols.getColArray(2).getOutlineLevel());
         assertEquals(5, cols.getColArray(2).getMin()); // 1 based
         assertEquals(5, cols.getColArray(2).getMax()); // 1 based
         assertEquals(true, cols.getColArray(2).getCustomWidth());
-        
+
         assertEquals(3, cols.sizeOfColArray());
-        
-        wb = XSSFTestDataSamples.writeOutAndReadBack(wb, "testMergingOverlappingCols_OVERLAPS_2_MINOR");
-        sheet = wb.getSheet("test");
-        
+
+        XSSFWorkbook wb2 = XSSFTestDataSamples.writeOutAndReadBack(wb1, "testMergingOverlappingCols_OVERLAPS_2_MINOR");
+        sheet = wb2.getSheet("test");
+
         for (int i = 2; i <= 4; i++) {
-        	assertEquals("Unexpected width of column "+ i, 20 * 256, sheet.getColumnWidth(i));
+        	assertEquals("Unexpected width of column "+ i, 20 * 256L, sheet.getColumnWidth(i));
         }
-    	assertEquals("Unexpected width of column "+ 1, sheet.getDefaultColumnWidth() * 256, sheet.getColumnWidth(1));
+    	assertEquals("Unexpected width of column "+ 1, sheet.getDefaultColumnWidth() * 256L, sheet.getColumnWidth(1));
+
+    	wb2.close();
+    	wb1.close();
     }
 
 }
