@@ -17,6 +17,11 @@
 
 package org.apache.poi.xssf.usermodel;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertSame;
+import static org.junit.Assert.fail;
+
 import java.io.IOException;
 import java.util.HashMap;
 import java.util.Map;
@@ -25,6 +30,7 @@ import org.apache.poi.hssf.HSSFTestDataSamples;
 import org.apache.poi.ss.usermodel.BaseTestFormulaEvaluator;
 import org.apache.poi.ss.usermodel.Cell;
 import org.apache.poi.ss.usermodel.CellValue;
+import org.apache.poi.ss.usermodel.CreationHelper;
 import org.apache.poi.ss.usermodel.FormulaEvaluator;
 import org.apache.poi.ss.usermodel.Row;
 import org.apache.poi.ss.usermodel.Sheet;
@@ -32,6 +38,8 @@ import org.apache.poi.ss.usermodel.Workbook;
 import org.apache.poi.ss.util.CellReference;
 import org.apache.poi.xssf.XSSFITestDataProvider;
 import org.apache.poi.xssf.XSSFTestDataSamples;
+import org.junit.Ignore;
+import org.junit.Test;
 
 public final class TestXSSFFormulaEvaluation extends BaseTestFormulaEvaluator {
 
@@ -39,11 +47,13 @@ public final class TestXSSFFormulaEvaluation extends BaseTestFormulaEvaluator {
         super(XSSFITestDataProvider.instance);
     }
 
-    public void testSharedFormulas(){
+    @Test
+    public void testSharedFormulas() throws IOException {
         baseTestSharedFormulas("shared_formulas.xlsx");
     }
 
-    public void testSharedFormulas_evaluateInCell(){
+    @Test
+    public void testSharedFormulas_evaluateInCell() throws IOException {
         XSSFWorkbook wb = (XSSFWorkbook)_testDataProvider.openSampleWorkbook("49872.xlsx");
         FormulaEvaluator evaluator = wb.getCreationHelper().createFormulaEvaluator();
         XSSFSheet sheet = wb.getSheetAt(0);
@@ -58,24 +68,27 @@ public final class TestXSSFFormulaEvaluation extends BaseTestFormulaEvaluator {
 
         // get B3 and evaluate it in the cell
         XSSFCell b3 = sheet.getRow(2).getCell(1);
-        assertEquals(result, evaluator.evaluateInCell(b3).getNumericCellValue());
+        assertEquals(result, evaluator.evaluateInCell(b3).getNumericCellValue(), 0);
 
         //at this point the master formula is gone, but we are still able to evaluate dependent cells
         XSSFCell c3 = sheet.getRow(2).getCell(2);
-        assertEquals(result, evaluator.evaluateInCell(c3).getNumericCellValue());
+        assertEquals(result, evaluator.evaluateInCell(c3).getNumericCellValue(), 0);
 
         XSSFCell d3 = sheet.getRow(2).getCell(3);
-        assertEquals(result, evaluator.evaluateInCell(d3).getNumericCellValue());
+        assertEquals(result, evaluator.evaluateInCell(d3).getNumericCellValue(), 0);
+        
+        wb.close();
     }
 
     /**
      * Evaluation of cell references with column indexes greater than 255. See bugzilla 50096
      */
-    public void testEvaluateColumnGreaterThan255() {
+    @Test
+    public void testEvaluateColumnGreaterThan255() throws IOException {
         XSSFWorkbook wb = (XSSFWorkbook) _testDataProvider.openSampleWorkbook("50096.xlsx");
         XSSFFormulaEvaluator evaluator = wb.getCreationHelper().createFormulaEvaluator();
 
-        /**
+        /*
          *  The first row simply contains the numbers 1 - 300.
          *  The second row simply refers to the cell value above in the first row by a simple formula.
          */
@@ -94,8 +107,10 @@ public final class TestXSSFFormulaEvaluation extends BaseTestFormulaEvaluator {
             CellValue cv_noformula = evaluator.evaluate(cell_noformula);
             CellValue cv_formula = evaluator.evaluate(cell_formula);
             assertEquals("Wrong evaluation result in " + ref_formula.formatAsString(),
-                    cv_noformula.getNumberValue(), cv_formula.getNumberValue());
+                    cv_noformula.getNumberValue(), cv_formula.getNumberValue(), 0);
         }
+        
+        wb.close();
     }
     
     /**
@@ -103,6 +118,7 @@ public final class TestXSSFFormulaEvaluation extends BaseTestFormulaEvaluator {
      *  formulas that refer to cells and named ranges in multiple other
      *  workbooks, both HSSF and XSSF ones
      */
+    @Test
     public void testReferencesToOtherWorkbooks() throws Exception {
         XSSFWorkbook wb = (XSSFWorkbook) _testDataProvider.openSampleWorkbook("ref2-56737.xlsx");
         XSSFFormulaEvaluator evaluator = wb.getCreationHelper().createFormulaEvaluator();
@@ -119,7 +135,7 @@ public final class TestXSSFFormulaEvaluation extends BaseTestFormulaEvaluator {
         
         assertEquals("Hello!", cXSLX_cell.getStringCellValue());
         assertEquals("Test A1", cXSLX_sNR.getStringCellValue());
-        assertEquals(142.0, cXSLX_gNR.getNumericCellValue());
+        assertEquals(142.0, cXSLX_gNR.getNumericCellValue(), 0);
         
         // References to a .xls file
         Row rXSL = s.getRow(4);
@@ -132,7 +148,7 @@ public final class TestXSSFFormulaEvaluation extends BaseTestFormulaEvaluator {
         
         assertEquals("Hello!", cXSL_cell.getStringCellValue());
         assertEquals("Test A1", cXSL_sNR.getStringCellValue());
-        assertEquals(142.0, cXSL_gNR.getNumericCellValue());
+        assertEquals(142.0, cXSL_gNR.getNumericCellValue(), 0);
         
         // Try to evaluate without references, won't work
         // (At least, not unit we fix bug #56752 that is)
@@ -140,10 +156,12 @@ public final class TestXSSFFormulaEvaluation extends BaseTestFormulaEvaluator {
             evaluator.evaluate(cXSL_cell);
             fail("Without a fix for #56752, shouldn't be able to evaluate a " +
                  "reference to a non-provided linked workbook");
-        } catch(Exception e) {}
+        } catch(Exception e) {
+            // expected here
+        }
         
         // Setup the environment
-        Map<String,FormulaEvaluator> evaluators = new HashMap<String, FormulaEvaluator>();
+        Map<String,FormulaEvaluator> evaluators = new HashMap<>();
         evaluators.put("ref2-56737.xlsx", evaluator);
         evaluators.put("56737.xlsx", 
                 _testDataProvider.openSampleWorkbook("56737.xlsx").getCreationHelper().createFormulaEvaluator());
@@ -157,8 +175,19 @@ public final class TestXSSFFormulaEvaluation extends BaseTestFormulaEvaluator {
                 evaluator.evaluate(c);
             }
         }
+        // And evaluate the other way too
+        evaluator.evaluateAll();
         
-        // Evaluate and check results
+        // Static evaluator won't work, as no references passed in
+        try {
+            XSSFFormulaEvaluator.evaluateAllFormulaCells(wb);
+            fail("Static method lacks references, shouldn't work");
+        } catch(Exception e) {
+            // expected here
+        }
+        
+        
+        // Evaluate specific cells and check results
         assertEquals("\"Hello!\"",  evaluator.evaluate(cXSLX_cell).formatAsString());
         assertEquals("\"Test A1\"", evaluator.evaluate(cXSLX_sNR).formatAsString());
         assertEquals("142.0",   evaluator.evaluate(cXSLX_gNR).formatAsString());
@@ -182,32 +211,37 @@ public final class TestXSSFFormulaEvaluation extends BaseTestFormulaEvaluator {
         try {
             cXSLX_nw_cell.setCellFormula("[alt.xlsx]Sheet1!$A$1");
             fail("New workbook not linked, shouldn't be able to add");
-        } catch (Exception e) {}
+        } catch (Exception e) {
+            // expected here
+        }
         
         // Link and re-try
-        Workbook alt = new XSSFWorkbook();
-        alt.createSheet().createRow(0).createCell(0).setCellValue("In another workbook");
-        // TODO Implement the rest of this, see bug #57184
+        try (Workbook alt = new XSSFWorkbook()) {
+            alt.createSheet().createRow(0).createCell(0).setCellValue("In another workbook");
+            // TODO Implement the rest of this, see bug #57184
 /*
-        wb.linkExternalWorkbook("alt.xlsx", alt);
-                
-        cXSLX_nw_cell.setCellFormula("[alt.xlsx]Sheet1!$A$1");
-        // Check it - TODO Is this correct? Or should it become [3]Sheet1!$A$1 ?
-        assertEquals("[alt.xlsx]Sheet1!$A$1", cXSLX_nw_cell.getCellFormula());
-        
-        // Evaluate it, without a link to that workbook
-        try {
+            wb.linkExternalWorkbook("alt.xlsx", alt);
+
+            cXSLX_nw_cell.setCellFormula("[alt.xlsx]Sheet1!$A$1");
+            // Check it - TODO Is this correct? Or should it become [3]Sheet1!$A$1 ?
+            assertEquals("[alt.xlsx]Sheet1!$A$1", cXSLX_nw_cell.getCellFormula());
+
+            // Evaluate it, without a link to that workbook
+            try {
+                evaluator.evaluate(cXSLX_nw_cell);
+                fail("No cached value and no link to workbook, shouldn't evaluate");
+            } catch(Exception e) {}
+
+            // Add a link, check it does
+            evaluators.put("alt.xlsx", alt.getCreationHelper().createFormulaEvaluator());
+            evaluator.setupReferencedWorkbooks(evaluators);
+
             evaluator.evaluate(cXSLX_nw_cell);
-            fail("No cached value and no link to workbook, shouldn't evaluate");
-        } catch(Exception e) {}
-        
-        // Add a link, check it does
-        evaluators.put("alt.xlsx", alt.getCreationHelper().createFormulaEvaluator());
-        evaluator.setupReferencedWorkbooks(evaluators);
-        
-        evaluator.evaluate(cXSLX_nw_cell);
-        assertEquals("In another workbook", cXSLX_nw_cell.getStringCellValue());
+            assertEquals("In another workbook", cXSLX_nw_cell.getStringCellValue());
 */
+        }
+        
+        wb.close();
     }
     
     /**
@@ -217,8 +251,11 @@ public final class TestXSSFFormulaEvaluation extends BaseTestFormulaEvaluator {
      * TODO Add the support then add a unit test
      * See bug #56752
      */
-    public void TODOtestCachedReferencesToOtherWorkbooks() throws Exception {
+    @Test
+    @Ignore
+    public void testCachedReferencesToOtherWorkbooks() throws Exception {
         // TODO
+        fail("unit test not written yet");
     }
     
     /**
@@ -228,12 +265,12 @@ public final class TestXSSFFormulaEvaluation extends BaseTestFormulaEvaluator {
      * This test, based on common test files for HSSF and XSSF, checks
      *  that we can correctly evaluate these
      */
+    @Test
     public void testMultiSheetReferencesHSSFandXSSF() throws Exception {
-        Workbook[] wbs = new Workbook[] {
-                HSSFTestDataSamples.openSampleWorkbook("55906-MultiSheetRefs.xls"),
-                XSSFTestDataSamples.openSampleWorkbook("55906-MultiSheetRefs.xlsx")
-        };
-        for (Workbook wb : wbs) {
+        Workbook wb1 = HSSFTestDataSamples.openSampleWorkbook("55906-MultiSheetRefs.xls");
+        Workbook wb2 = XSSFTestDataSamples.openSampleWorkbook("55906-MultiSheetRefs.xlsx");
+
+        for (Workbook wb : new Workbook[] {wb1,wb2}) {
             FormulaEvaluator evaluator = wb.getCreationHelper().createFormulaEvaluator();
             Sheet s1 = wb.getSheetAt(0);
 
@@ -283,7 +320,11 @@ public final class TestXSSFFormulaEvaluation extends BaseTestFormulaEvaluator {
             assertEquals("COUNTA(Sheet1:Sheet3!E1)", countA_3F.getCellFormula());
             assertEquals("3.0", evaluator.evaluate(countA_3F).formatAsString());
         }
+        
+        wb2.close();
+        wb1.close();
     }
+    
     /**
      * A handful of functions (such as SUM, COUNTA, MIN) support
      *  multi-sheet areas (eg Sheet1:Sheet3!A1:B2 = Cell A1 to Cell B2,
@@ -291,12 +332,12 @@ public final class TestXSSFFormulaEvaluation extends BaseTestFormulaEvaluator {
      * This test, based on common test files for HSSF and XSSF, checks
      *  that we can correctly evaluate these
      */
-    public void testMultiSheetAreasHSSFandXSSF() throws Exception {
-        Workbook[] wbs = new Workbook[] {
-                HSSFTestDataSamples.openSampleWorkbook("55906-MultiSheetRefs.xls"),
-                XSSFTestDataSamples.openSampleWorkbook("55906-MultiSheetRefs.xlsx")
-        };
-        for (Workbook wb : wbs) {
+    @Test
+    public void testMultiSheetAreasHSSFandXSSF() throws IOException {
+        Workbook wb1 = HSSFTestDataSamples.openSampleWorkbook("55906-MultiSheetRefs.xls");
+        Workbook wb2 = XSSFTestDataSamples.openSampleWorkbook("55906-MultiSheetRefs.xlsx");
+
+        for (Workbook wb : new Workbook[]{wb1,wb2}) {
             FormulaEvaluator evaluator = wb.getCreationHelper().createFormulaEvaluator();
             Sheet s1 = wb.getSheetAt(0);
 
@@ -329,214 +370,124 @@ public final class TestXSSFFormulaEvaluation extends BaseTestFormulaEvaluator {
             assertEquals("COUNT(Sheet1:Sheet3!$A$1:$B$2)", countFA.getCellFormula());
             assertEquals("4.0", evaluator.evaluate(countFA).formatAsString());
         }
+        
+        wb2.close();
+        wb1.close();
+    }
+
+    // bug 57721
+    @Test
+    public void structuredReferences() throws IOException {
+        verifyAllFormulasInWorkbookCanBeEvaluated("evaluate_formula_with_structured_table_references.xlsx");
     }
     
-    public void testMultisheetFormulaEval() throws IOException {
-    	XSSFWorkbook wb = new XSSFWorkbook();
-    	try {
-    		XSSFSheet sheet1 = wb.createSheet("Sheet1");
-    		XSSFSheet sheet2 = wb.createSheet("Sheet2");
-    		XSSFSheet sheet3 = wb.createSheet("Sheet3");
-    		
-    		// sheet1 A1
-    		XSSFCell cell = sheet1.createRow(0).createCell(0);
-    		cell.setCellType(Cell.CELL_TYPE_NUMERIC);
-    		cell.setCellValue(1.0);
-    		
-    		// sheet2 A1
-    		cell = sheet2.createRow(0).createCell(0);
-    		cell.setCellType(Cell.CELL_TYPE_NUMERIC);
-    		cell.setCellValue(1.0);
-    		
-    		// sheet2 B1
-    		cell = sheet2.getRow(0).createCell(1);
-    		cell.setCellType(Cell.CELL_TYPE_NUMERIC);
-    		cell.setCellValue(1.0);
-    		
-    		// sheet3 A1
-    		cell = sheet3.createRow(0).createCell(0);
-    		cell.setCellType(Cell.CELL_TYPE_NUMERIC);
-    		cell.setCellValue(1.0);
-    		
-    		// sheet1 A2 formulae
-    		cell = sheet1.createRow(1).createCell(0);
-    		cell.setCellType(Cell.CELL_TYPE_FORMULA);
-    		cell.setCellFormula("SUM(Sheet1:Sheet3!A1)");
-    		
-    		// sheet1 A3 formulae
-    		cell = sheet1.createRow(2).createCell(0);
-    		cell.setCellType(Cell.CELL_TYPE_FORMULA);
-    		cell.setCellFormula("SUM(Sheet1:Sheet3!A1:B1)");
-    		
-    		wb.getCreationHelper().createFormulaEvaluator().evaluateAll();
-    		
-    		cell = sheet1.getRow(1).getCell(0);
-    		assertEquals(3.0, cell.getNumericCellValue());
-    		
-    		cell = sheet1.getRow(2).getCell(0);
-    		assertEquals(4.0, cell.getNumericCellValue());
-    	} finally {
-    	    wb.close();
-    	}
-	}
+    // bug 57840
+    @Ignore("Takes over a minute to evaluate all formulas in this large workbook. Run this test when profiling for formula evaluation speed.")
+    @Test
+    public void testLotsOfFormulasWithStructuredReferencesToCalculatedTableColumns() throws IOException {
+        verifyAllFormulasInWorkbookCanBeEvaluated("StructuredRefs-lots-with-lookups.xlsx");
+    }
 
-    public void testBug55843() throws IOException {
+    // FIXME: use junit4 parameterization
+    private static void verifyAllFormulasInWorkbookCanBeEvaluated(String sampleWorkbook) throws IOException {
+        XSSFWorkbook wb = XSSFTestDataSamples.openSampleWorkbook(sampleWorkbook);
+        XSSFFormulaEvaluator.evaluateAllFormulaCells(wb);
+        wb.close();
+    }
+
+    @Test
+    public void test59736() {
+        Workbook wb = XSSFTestDataSamples.openSampleWorkbook("59736.xlsx");
+        FormulaEvaluator evaluator = wb.getCreationHelper().createFormulaEvaluator();
+        Cell cell = wb.getSheetAt(0).getRow(0).getCell(0);
+        assertEquals(1, cell.getNumericCellValue(), 0.001);
+
+        cell = wb.getSheetAt(0).getRow(1).getCell(0);
+        CellValue value = evaluator.evaluate(cell);
+        assertEquals(1, value.getNumberValue(), 0.001);
+
+        cell = wb.getSheetAt(0).getRow(2).getCell(0);
+        value = evaluator.evaluate(cell);
+        assertEquals(1, value.getNumberValue(), 0.001);
+    }
+    
+    @Test
+    public void evaluateInCellReturnsSameDataType() throws IOException {
         XSSFWorkbook wb = new XSSFWorkbook();
-        try {
-            XSSFSheet sheet = wb.createSheet("test");
-            XSSFRow row = sheet.createRow(0);
-            XSSFRow row2 = sheet.createRow(1);
-            XSSFCell cellA2 = row2.createCell(0, Cell.CELL_TYPE_FORMULA);
-            XSSFCell cellB1 = row.createCell(1, Cell.CELL_TYPE_NUMERIC);
-            cellB1.setCellValue(10);
-            XSSFFormulaEvaluator formulaEvaluator = wb.getCreationHelper().createFormulaEvaluator();
-            cellA2.setCellFormula("IF(B1=0,\"\",((ROW()-ROW(A$1))*12))");
-            CellValue evaluate = formulaEvaluator.evaluate(cellA2);
-            System.out.println(evaluate);
-            assertEquals("12.0", evaluate.formatAsString());
+        wb.createSheet().createRow(0).createCell(0);
+        XSSFFormulaEvaluator evaluator = wb.getCreationHelper().createFormulaEvaluator();
+        XSSFCell cell = wb.getSheetAt(0).getRow(0).getCell(0);
+        XSSFCell same = evaluator.evaluateInCell(cell);
+        assertSame(cell, same);
+        wb.close();
+    }
+    
+    @Test
+    public void testBug61468() {
+        Workbook wb = XSSFTestDataSamples.openSampleWorkbook("simple-monthly-budget.xlsx");
+        FormulaEvaluator evaluator = wb.getCreationHelper().createFormulaEvaluator();
+        Cell cell = wb.getSheetAt(0).getRow(8).getCell(4);
+        assertEquals(3750, cell.getNumericCellValue(), 0.001);
 
-            cellA2.setCellFormula("IF(NOT(B1=0),((ROW()-ROW(A$1))*12),\"\")");
-            CellValue evaluateN = formulaEvaluator.evaluate(cellA2);
-            System.out.println(evaluateN);
-            
-            assertEquals(evaluate.toString(), evaluateN.toString());
-            assertEquals("12.0", evaluateN.formatAsString());
-        } finally {
-            wb.close();
+        CellValue value = evaluator.evaluate(cell);
+        assertEquals(3750, value.getNumberValue(), 0.001);
+    }
+    
+    @Test
+    @Ignore // this is from an open bug/discussion over handling localization for number formats
+    public void testBug61495() {
+        Workbook wb = XSSFTestDataSamples.openSampleWorkbook("61495-test.xlsm");
+        FormulaEvaluator evaluator = wb.getCreationHelper().createFormulaEvaluator();
+        Cell cell = wb.getSheetAt(0).getRow(0).getCell(1);
+//        assertEquals("D 67.10", cell.getStringCellValue());
+        
+        CellValue value = evaluator.evaluate(cell);
+        assertEquals("D 67.10", value.getStringValue());
+        
+        assertEquals("D 0,068", evaluator.evaluate(wb.getSheetAt(0).getRow(1).getCell(1)));
+    }
+
+    /**
+     * see bug 62275
+     * @throws IOException
+     */
+    @Test
+    public void testBug62275() throws IOException {
+        try (Workbook wb = new XSSFWorkbook()) {
+            Sheet sheet = wb.createSheet();
+            Row row = sheet.createRow(0);
+
+            Cell cell = row.createCell(0);
+            cell.setCellFormula("vlookup(A2,B1:B5,2,true)");
+
+            CreationHelper createHelper = wb.getCreationHelper();
+            FormulaEvaluator eval = createHelper.createFormulaEvaluator();
+            eval.evaluate(cell);
         }
     }
     
-    public void testBug55843a() throws IOException {
-        XSSFWorkbook wb = new XSSFWorkbook();
-        try {
-            XSSFSheet sheet = wb.createSheet("test");
-            XSSFRow row = sheet.createRow(0);
-            XSSFRow row2 = sheet.createRow(1);
-            XSSFCell cellA2 = row2.createCell(0, Cell.CELL_TYPE_FORMULA);
-            XSSFCell cellB1 = row.createCell(1, Cell.CELL_TYPE_NUMERIC);
-            cellB1.setCellValue(10);
-            XSSFFormulaEvaluator formulaEvaluator = wb.getCreationHelper().createFormulaEvaluator();
-            cellA2.setCellFormula("IF(B1=0,\"\",((ROW(A$1))))");
-            CellValue evaluate = formulaEvaluator.evaluate(cellA2);
-            System.out.println(evaluate);
-            assertEquals("1.0", evaluate.formatAsString());
+    /**
+     * see bug 62834, handle when a shared formula range doesn't contain only formula cells
+     * @throws IOException 
+     */
+    @Test
+    public void testBug62834() throws IOException {
+        try (Workbook wb = XSSFTestDataSamples.openSampleWorkbook("62834.xlsx")) {
+            FormulaEvaluator evaluator = wb.getCreationHelper().createFormulaEvaluator();
 
-            cellA2.setCellFormula("IF(NOT(B1=0),((ROW(A$1))),\"\")");
-            CellValue evaluateN = formulaEvaluator.evaluate(cellA2);
-            System.out.println(evaluateN);
+            Cell a2 = wb.getSheetAt(0).getRow(1).getCell(0);
+            Cell value = evaluator.evaluateInCell(a2);
+            assertEquals("wrong value A2", "a value", value.getStringCellValue());
             
-            assertEquals(evaluate.toString(), evaluateN.toString());
-            assertEquals("1.0", evaluateN.formatAsString());
-        } finally {
-            wb.close();
-        }
-    }    
-
-    public void testBug55843b() throws IOException {
-        XSSFWorkbook wb = new XSSFWorkbook();
-        try {
-            XSSFSheet sheet = wb.createSheet("test");
-            XSSFRow row = sheet.createRow(0);
-            XSSFRow row2 = sheet.createRow(1);
-            XSSFCell cellA2 = row2.createCell(0, Cell.CELL_TYPE_FORMULA);
-            XSSFCell cellB1 = row.createCell(1, Cell.CELL_TYPE_NUMERIC);
-            cellB1.setCellValue(10);
-            XSSFFormulaEvaluator formulaEvaluator = wb.getCreationHelper().createFormulaEvaluator();
-
-            cellA2.setCellFormula("IF(B1=0,\"\",((ROW())))");
-            CellValue evaluate = formulaEvaluator.evaluate(cellA2);
-            System.out.println(evaluate);
-            assertEquals("2.0", evaluate.formatAsString());
+//            evaluator.clearAllCachedResultValues();
             
-            cellA2.setCellFormula("IF(NOT(B1=0),((ROW())),\"\")");
-            CellValue evaluateN = formulaEvaluator.evaluate(cellA2);
-            System.out.println(evaluateN);
+            Cell a3 = wb.getSheetAt(0).getRow(2).getCell(0);
+            value = evaluator.evaluateInCell(a3);
+            assertEquals("wrong value A3", "a value", value.getStringCellValue());
             
-            assertEquals(evaluate.toString(), evaluateN.toString());
-            assertEquals("2.0", evaluateN.formatAsString());
-        } finally {
-            wb.close();
+            Cell a5 = wb.getSheetAt(0).getRow(4).getCell(0);
+            value = evaluator.evaluateInCell(a5);
+            assertEquals("wrong value A5", "another value", value.getStringCellValue());
         }
     }
-    
-    public void testBug55843c() throws IOException {
-        XSSFWorkbook wb = new XSSFWorkbook();
-        try {
-            XSSFSheet sheet = wb.createSheet("test");
-            XSSFRow row = sheet.createRow(0);
-            XSSFRow row2 = sheet.createRow(1);
-            XSSFCell cellA2 = row2.createCell(0, Cell.CELL_TYPE_FORMULA);
-            XSSFCell cellB1 = row.createCell(1, Cell.CELL_TYPE_NUMERIC);
-            cellB1.setCellValue(10);
-            XSSFFormulaEvaluator formulaEvaluator = wb.getCreationHelper().createFormulaEvaluator();
-            
-            cellA2.setCellFormula("IF(NOT(B1=0),((ROW())))");
-            CellValue evaluateN = formulaEvaluator.evaluate(cellA2);
-            System.out.println(evaluateN);
-            assertEquals("2.0", evaluateN.formatAsString());
-        } finally {
-            wb.close();
-        }
-    }
-    
-    public void testBug55843d() throws IOException {
-        XSSFWorkbook wb = new XSSFWorkbook();
-        try {
-            XSSFSheet sheet = wb.createSheet("test");
-            XSSFRow row = sheet.createRow(0);
-            XSSFRow row2 = sheet.createRow(1);
-            XSSFCell cellA2 = row2.createCell(0, Cell.CELL_TYPE_FORMULA);
-            XSSFCell cellB1 = row.createCell(1, Cell.CELL_TYPE_NUMERIC);
-            cellB1.setCellValue(10);
-            XSSFFormulaEvaluator formulaEvaluator = wb.getCreationHelper().createFormulaEvaluator();
-            
-            cellA2.setCellFormula("IF(NOT(B1=0),((ROW())),\"\")");
-            CellValue evaluateN = formulaEvaluator.evaluate(cellA2);
-            System.out.println(evaluateN);
-            assertEquals("2.0", evaluateN.formatAsString());
-        } finally {
-            wb.close();
-        }
-    }
-
-    public void testBug55843e() throws IOException {
-        XSSFWorkbook wb = new XSSFWorkbook();
-        try {
-            XSSFSheet sheet = wb.createSheet("test");
-            XSSFRow row = sheet.createRow(0);
-            XSSFRow row2 = sheet.createRow(1);
-            XSSFCell cellA2 = row2.createCell(0, Cell.CELL_TYPE_FORMULA);
-            XSSFCell cellB1 = row.createCell(1, Cell.CELL_TYPE_NUMERIC);
-            cellB1.setCellValue(10);
-            XSSFFormulaEvaluator formulaEvaluator = wb.getCreationHelper().createFormulaEvaluator();
-
-            cellA2.setCellFormula("IF(B1=0,\"\",((ROW())))");
-            CellValue evaluate = formulaEvaluator.evaluate(cellA2);
-            System.out.println(evaluate);
-            assertEquals("2.0", evaluate.formatAsString());
-        } finally {
-            wb.close();
-        }
-    }
-    
-
-    public void testBug55843f() throws IOException {
-        XSSFWorkbook wb = new XSSFWorkbook();
-        try {
-            XSSFSheet sheet = wb.createSheet("test");
-            XSSFRow row = sheet.createRow(0);
-            XSSFRow row2 = sheet.createRow(1);
-            XSSFCell cellA2 = row2.createCell(0, Cell.CELL_TYPE_FORMULA);
-            XSSFCell cellB1 = row.createCell(1, Cell.CELL_TYPE_NUMERIC);
-            cellB1.setCellValue(10);
-            XSSFFormulaEvaluator formulaEvaluator = wb.getCreationHelper().createFormulaEvaluator();
-
-            cellA2.setCellFormula("IF(B1=0,\"\",IF(B1=10,3,4))");
-            CellValue evaluate = formulaEvaluator.evaluate(cellA2);
-            System.out.println(evaluate);
-            assertEquals("3.0", evaluate.formatAsString());
-        } finally {
-            wb.close();
-        }
-    }    
 }
