@@ -19,6 +19,7 @@ package org.apache.poi.xwpf;
 
 import org.apache.poi.xwpf.extractor.TestXWPFWordExtractor;
 import org.apache.poi.xwpf.model.TestXWPFHeaderFooterPolicy;
+import org.apache.poi.xwpf.usermodel.TestXWPFChart;
 import org.apache.poi.xwpf.usermodel.TestXWPFDocument;
 import org.apache.poi.xwpf.usermodel.TestXWPFHeader;
 import org.apache.poi.xwpf.usermodel.TestXWPFHeadings;
@@ -36,21 +37,22 @@ import org.junit.runners.Suite;
  */
 @RunWith(Suite.class)
 @Suite.SuiteClasses({
-    TestXWPFBugs.class,
-    org.apache.poi.xwpf.usermodel.TestXWPFBugs.class,
-    TestXWPFDocument.class,
-    TestXWPFWordExtractor.class,
-    TestXWPFHeaderFooterPolicy.class,
-    TestXWPFHeader.class,
-    TestXWPFHeadings.class,
-    TestXWPFParagraph.class,
-    TestXWPFRun.class,
-    TestXWPFTable.class,
-    TestXWPFStyles.class,
-    TestXWPFPictureData.class,
-    TestXWPFNumbering.class,
-    TestAllExtendedProperties.class,
-    TestPackageCorePropertiesGetKeywords.class
+        TestXWPFBugs.class,
+        org.apache.poi.xwpf.usermodel.TestXWPFBugs.class,
+        TestXWPFChart.class,
+        TestXWPFDocument.class,
+        TestXWPFWordExtractor.class,
+        TestXWPFHeaderFooterPolicy.class,
+        TestXWPFHeader.class,
+        TestXWPFHeadings.class,
+        TestXWPFParagraph.class,
+        TestXWPFRun.class,
+        TestXWPFTable.class,
+        TestXWPFStyles.class,
+        TestXWPFPictureData.class,
+        TestXWPFNumbering.class,
+        TestAllExtendedProperties.class,
+        TestPackageCorePropertiesGetKeywords.class
 })
 public final class AllXWPFTests {
-}
\ No newline at end of file
+}
