@@ -21,40 +21,45 @@ import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
 
 import java.io.File;
+import java.io.IOException;
 import java.io.InputStream;
 
 import javax.crypto.Cipher;
 
+import org.apache.commons.compress.archivers.zip.ZipArchiveEntry;
+import org.apache.commons.compress.archivers.zip.ZipFile;
 import org.apache.poi.POIDataSamples;
 import org.apache.poi.openxml4j.opc.OPCPackage;
 import org.apache.poi.poifs.crypt.CipherAlgorithm;
 import org.apache.poi.poifs.crypt.Decryptor;
 import org.apache.poi.poifs.crypt.EncryptionInfo;
 import org.apache.poi.poifs.crypt.HashAlgorithm;
-import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
+import org.apache.poi.poifs.filesystem.POIFSFileSystem;
 import org.apache.poi.xwpf.extractor.XWPFWordExtractor;
 import org.apache.poi.xwpf.usermodel.XWPFDocument;
+import org.apache.xmlbeans.XmlException;
 import org.junit.Assume;
 import org.junit.Test;
+import org.openxmlformats.schemas.wordprocessingml.x2006.main.DocumentDocument;
 
 public class TestXWPFBugs {
     /**
      * A word document that's encrypted with non-standard
-     *  Encryption options, and no cspname section. See bug 53475
+     * Encryption options, and no cspname section. See bug 53475
      */
     @Test
     public void bug53475NoCSPName() throws Exception {
         File file = POIDataSamples.getDocumentInstance().getFile("bug53475-password-is-solrcell.docx");
-        NPOIFSFileSystem filesystem = new NPOIFSFileSystem(file, true);
+        POIFSFileSystem filesystem = new POIFSFileSystem(file, true);
 
         // Check the encryption details
         EncryptionInfo info = new EncryptionInfo(filesystem);
         assertEquals(128, info.getHeader().getKeySize());
         assertEquals(CipherAlgorithm.aes128, info.getHeader().getCipherAlgorithm());
-        assertEquals(HashAlgorithm.sha1, info.getHeader().getHashAlgorithmEx());
+        assertEquals(HashAlgorithm.sha1, info.getHeader().getHashAlgorithm());
 
         // Check it can be decoded
-        Decryptor d = Decryptor.getInstance(info);		
+        Decryptor d = Decryptor.getInstance(info);
         assertTrue("Unable to process: document is encrypted", d.verifyPassword("solrcell"));
 
         // Check we can read the word document in that
@@ -66,7 +71,7 @@ public class TestXWPFBugs {
         assertNotNull(text);
         assertEquals("This is password protected Word document.", text.trim());
         ex.close();
-        
+
         filesystem.close();
     }
 
@@ -80,17 +85,17 @@ public class TestXWPFBugs {
         Assume.assumeTrue("Please install JCE Unlimited Strength Jurisdiction Policy files for AES 256", maxKeyLen == 2147483647);
 
         File file = POIDataSamples.getDocumentInstance().getFile("bug53475-password-is-pass.docx");
-        NPOIFSFileSystem filesystem = new NPOIFSFileSystem(file, true);
+        POIFSFileSystem filesystem = new POIFSFileSystem(file, true);
 
         // Check the encryption details
         EncryptionInfo info = new EncryptionInfo(filesystem);
         assertEquals(16, info.getHeader().getBlockSize());
         assertEquals(256, info.getHeader().getKeySize());
         assertEquals(CipherAlgorithm.aes256, info.getHeader().getCipherAlgorithm());
-        assertEquals(HashAlgorithm.sha1, info.getHeader().getHashAlgorithmEx());
+        assertEquals(HashAlgorithm.sha1, info.getHeader().getHashAlgorithm());
 
         // Check it can be decoded
-        Decryptor d = Decryptor.getInstance(info);		
+        Decryptor d = Decryptor.getInstance(info);
         assertTrue("Unable to process: document is encrypted", d.verifyPassword("pass"));
 
         // Check we can read the word document in that
@@ -103,7 +108,20 @@ public class TestXWPFBugs {
         // I know ... a stupid typo, maybe next time ...
         assertEquals("The is a password protected document.", text.trim());
         ex.close();
-        
+
         filesystem.close();
     }
-}
+
+    
+    @Test
+    public void bug59058() throws IOException, XmlException {
+        String files[] = { "bug57031.docx", "bug59058.docx" };
+        for (String f : files) {
+            ZipFile zf = new ZipFile(POIDataSamples.getDocumentInstance().getFile(f));
+            ZipArchiveEntry entry = zf.getEntry("word/document.xml");
+            DocumentDocument document = DocumentDocument.Factory.parse(zf.getInputStream(entry));
+            assertNotNull(document);
+            zf.close();
+        }
+    }
+}
\ No newline at end of file
