@@ -18,13 +18,19 @@
 package org.apache.poi.xwpf.extractor;
 
 import java.io.IOException;
+import java.util.Locale;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
 import junit.framework.TestCase;
 
+import org.apache.poi.util.StringUtil;
 import org.apache.poi.xwpf.XWPFTestDataSamples;
 import org.apache.poi.xwpf.usermodel.XWPFDocument;
+import static org.apache.poi.POITestCase.assertContains;
+import static org.apache.poi.POITestCase.assertEndsWith;
+import static org.apache.poi.POITestCase.assertNotContained;
+import static org.apache.poi.POITestCase.assertStartsWith;
 
 /**
  * Tests for HXFWordExtractor
@@ -33,7 +39,8 @@ public class TestXWPFWordExtractor extends TestCase {
 
     /**
      * Get text out of the simple file
-     * @throws IOException 
+     *
+     * @throws IOException
      */
     public void testGetSimpleText() throws IOException {
         XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("sample.docx");
@@ -43,29 +50,24 @@ public class TestXWPFWordExtractor extends TestCase {
         assertTrue(text.length() > 0);
 
         // Check contents
-        assertTrue(text.startsWith(
+        assertStartsWith(text,
                 "Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Nunc at risus vel erat tempus posuere. Aenean non ante. Suspendisse vehicula dolor sit amet odio."
-        ));
-        assertTrue(text.endsWith(
+        );
+        assertEndsWith(text,
                 "Phasellus ultricies mi nec leo. Sed tempus. In sit amet lorem at velit faucibus vestibulum.\n"
-        ));
+        );
+
+        // Check number of paragraphs by counting number of newlines
+        int numberOfParagraphs = StringUtil.countMatches(text, '\n');
+        assertEquals(3, numberOfParagraphs);
 
-        // Check number of paragraphs
-        int ps = 0;
-        char[] t = text.toCharArray();
-        for (int i = 0; i < t.length; i++) {
-            if (t[i] == '\n') {
-                ps++;
-            }
-        }
-        assertEquals(3, ps);
-        
         extractor.close();
     }
 
     /**
      * Tests getting the text out of a complex file
-     * @throws IOException 
+     *
+     * @throws IOException
      */
     public void testGetComplexText() throws IOException {
         XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("IllustrativeCases.docx");
@@ -78,26 +80,20 @@ public class TestXWPFWordExtractor extends TestCase {
 //		System.err.println("'"+text.substring(text.length() - 40) + "'");
 
         // Check contents
-        assertTrue(text.startsWith(
+        assertStartsWith(text,
                 "  \n(V) ILLUSTRATIVE CASES\n\n"
-        ));
-        assertTrue(text.contains(
+        );
+        assertContains(text,
                 "As well as gaining " + euro + "90 from child benefit increases, he will also receive the early childhood supplement of " + euro + "250 per quarter for Vincent for the full four quarters of the year.\n\n\n\n"// \n\n\n"
-        ));
-        assertTrue(text.endsWith(
+        );
+        assertEndsWith(text,
                 "11.4%\t\t90\t\t\t\t\t250\t\t1,310\t\n\n \n\n\n"
-        ));
+        );
+
+        // Check number of paragraphs by counting number of newlines
+        int numberOfParagraphs = StringUtil.countMatches(text, '\n');
+        assertEquals(134, numberOfParagraphs);
 
-        // Check number of paragraphs
-        int ps = 0;
-        char[] t = text.toCharArray();
-        for (int i = 0; i < t.length; i++) {
-            if (t[i] == '\n') {
-                ps++;
-            }
-        }
-        assertEquals(134, ps);
-        
         extractor.close();
     }
 
@@ -108,23 +104,23 @@ public class TestXWPFWordExtractor extends TestCase {
         // Now check contents
         extractor.setFetchHyperlinks(false);
         assertEquals(
-				"This is a test document.\nThis bit is in bold and italic\n" +
-				"Back to normal\n" +
-				"This contains BOLD, ITALIC and BOTH, as well as RED and YELLOW text.\n" +
-				"We have a hyperlink here, and another.\n",
+                "This is a test document.\nThis bit is in bold and italic\n" +
+                        "Back to normal\n" +
+                        "This contains BOLD, ITALIC and BOTH, as well as RED and YELLOW text.\n" +
+                        "We have a hyperlink here, and another.\n",
                 extractor.getText()
         );
 
         // One hyperlink is a real one, one is just to the top of page
         extractor.setFetchHyperlinks(true);
         assertEquals(
-				"This is a test document.\nThis bit is in bold and italic\n" +
-				"Back to normal\n" +
-				"This contains BOLD, ITALIC and BOTH, as well as RED and YELLOW text.\n" +
-				"We have a hyperlink <http://poi.apache.org/> here, and another.\n",
+                "This is a test document.\nThis bit is in bold and italic\n" +
+                        "Back to normal\n" +
+                        "This contains BOLD, ITALIC and BOTH, as well as RED and YELLOW text.\n" +
+                        "We have a hyperlink <http://poi.apache.org/> here, and another.\n",
                 extractor.getText()
         );
-        
+
         extractor.close();
     }
 
@@ -173,7 +169,7 @@ public class TestXWPFWordExtractor extends TestCase {
                         "Footer Left\tFooter Middle\tFooter Right\n",
                 extractor.getText()
         );
-        
+
         extractor.close();
     }
 
@@ -181,9 +177,9 @@ public class TestXWPFWordExtractor extends TestCase {
         XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("footnotes.docx");
         XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
         String text = extractor.getText();
-        assertTrue(text.contains("snoska"));
-        assertTrue(text.contains("Eto ochen prostoy[footnoteRef:1] text so snoskoy"));
-        
+        assertContains(text,"snoska");
+        assertContains(text,"Eto ochen prostoy[footnoteRef:1] text so snoskoy");
+
         extractor.close();
     }
 
@@ -192,8 +188,8 @@ public class TestXWPFWordExtractor extends TestCase {
         XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("table_footnotes.docx");
         XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
 
-        assertTrue(extractor.getText().contains("snoska"));
-        
+        assertContains(extractor.getText(),"snoska");
+
         extractor.close();
     }
 
@@ -202,9 +198,9 @@ public class TestXWPFWordExtractor extends TestCase {
         XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
 
         String text = extractor.getText();
-        assertTrue("Unable to find expected word in text\n" + text, text.contains("testdoc"));
-        assertTrue("Unable to find expected word in text\n" + text, text.contains("test phrase"));
-        
+        assertContains(text,"testdoc");
+        assertContains(text,"test phrase");
+
         extractor.close();
     }
 
@@ -212,9 +208,9 @@ public class TestXWPFWordExtractor extends TestCase {
         XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("endnotes.docx");
         XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
         String text = extractor.getText();
-        assertTrue(text.contains("XXX"));
-        assertTrue(text.contains("tilaka [endnoteRef:2]or 'tika'"));
-        
+        assertContains(text,"XXX");
+        assertContains(text,"tilaka [endnoteRef:2]or 'tika'");
+
         extractor.close();
     }
 
@@ -222,9 +218,9 @@ public class TestXWPFWordExtractor extends TestCase {
         XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("delins.docx");
         XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
 
-        assertTrue(extractor.getText().contains("pendant worn"));
-        assertTrue(extractor.getText().contains("extremely well"));
-        
+        assertContains(extractor.getText(),"pendant worn");
+        assertContains(extractor.getText(),"extremely well");
+
         extractor.close();
     }
 
@@ -232,54 +228,57 @@ public class TestXWPFWordExtractor extends TestCase {
         XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("Headers.docx");
         XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
 
-        assertTrue(extractor.getText().contains("Section 1"));
-        assertTrue(extractor.getText().contains("Section 2"));
-        assertTrue(extractor.getText().contains("Section 3"));
-        
+        assertContains(extractor.getText(),"Section 1");
+        assertContains(extractor.getText(),"Section 2");
+        assertContains(extractor.getText(),"Section 3");
+
         extractor.close();
     }
 
     /**
      * Test that we can open and process .docm
-     *  (macro enabled) docx files (bug #45690)
-     * @throws IOException 
+     * (macro enabled) docx files (bug #45690)
+     *
+     * @throws IOException
      */
     public void testDOCMFiles() throws IOException {
         XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("45690.docm");
         XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
 
-        assertTrue(extractor.getText().contains("2004"));
-        assertTrue(extractor.getText().contains("2008"));
-        assertTrue(extractor.getText().contains("(120 "));
-        
+        assertContains(extractor.getText(),"2004");
+        assertContains(extractor.getText(),"2008");
+        assertContains(extractor.getText(),"(120 ");
+
         extractor.close();
     }
-    
+
     /**
      * Test that we handle things like tabs and
-     *  carriage returns properly in the text that
-     *  we're extracting (bug #49189)
-     * @throws IOException 
+     * carriage returns properly in the text that
+     * we're extracting (bug #49189)
+     *
+     * @throws IOException
      */
     public void testDocTabs() throws IOException {
-       XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("WithTabs.docx");
-       XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
- 
-       // Check bits
-       assertTrue(extractor.getText().contains("a"));
-       assertTrue(extractor.getText().contains("\t"));
-       assertTrue(extractor.getText().contains("b"));
-       
-       // Now check the first paragraph in total
-       assertTrue(extractor.getText().contains("a\tb\n"));
-       
-       extractor.close();
+        XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("WithTabs.docx");
+        XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
+
+        // Check bits
+        assertContains(extractor.getText(),"a");
+        assertContains(extractor.getText(),"\t");
+        assertContains(extractor.getText(),"b");
+
+        // Now check the first paragraph in total
+        assertContains(extractor.getText(),"a\tb\n");
+
+        extractor.close();
     }
-    
+
     /**
      * The output should not contain field codes, e.g. those specified in the
      * w:instrText tag (spec sec. 17.16.23)
-     * @throws IOException 
+     *
+     * @throws IOException
      */
     public void testNoFieldCodes() throws IOException {
         XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("FieldCodes.docx");
@@ -288,22 +287,23 @@ public class TestXWPFWordExtractor extends TestCase {
         assertTrue(text.length() > 0);
         assertFalse(text.contains("AUTHOR"));
         assertFalse(text.contains("CREATEDATE"));
-        
+
         extractor.close();
     }
-    
+
     /**
      * The output should contain the values of simple fields, those specified
      * with the fldSimple element (spec sec. 17.16.19)
-     * @throws IOException 
+     *
+     * @throws IOException
      */
     public void testFldSimpleContent() throws IOException {
         XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("FldSimple.docx");
         XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
         String text = extractor.getText();
         assertTrue(text.length() > 0);
-        assertTrue(text.contains("FldSimple.docx"));
-        
+        assertContains(text,"FldSimple.docx");
+
         extractor.close();
     }
 
@@ -316,12 +316,13 @@ public class TestXWPFWordExtractor extends TestCase {
         XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
         String text = extractor.getText();
         assertTrue(text.length() > 0);
-        
+
         extractor.close();
     }
-    
+
     /**
      * Test for basic extraction of SDT content
+     *
      * @throws IOException
      */
     public void testSimpleControlContent() throws IOException {
@@ -343,21 +344,21 @@ public class TestXWPFWordExtractor extends TestCase {
                 "endnote_sdt"
         };
         XWPFWordExtractor ex = new XWPFWordExtractor(doc);
-        String s = ex.getText().toLowerCase();
+        String s = ex.getText().toLowerCase(Locale.ROOT);
         int hits = 0;
-    
-        for (String targ : targs){
+
+        for (String targ : targs) {
             boolean hit = false;
-            if (s.indexOf(targ) > -1){
+            if (s.contains(targ)) {
                 hit = true;
                 hits++;
             }
-            assertEquals("controlled content loading-"+targ, true, hit);
+            assertEquals("controlled content loading-" + targ, true, hit);
         }
         assertEquals("controlled content loading hit count", targs.length, hits);
         ex.close();
-        
-        
+
+
         doc = XWPFTestDataSamples.openSampleDocument("Bug54771a.docx");
         targs = new String[]{
                 "bb",
@@ -365,49 +366,98 @@ public class TestXWPFWordExtractor extends TestCase {
                 "test user\n",
         };
         ex = new XWPFWordExtractor(doc);
-        s = ex.getText().toLowerCase();
-        
+        s = ex.getText().toLowerCase(Locale.ROOT);
+
         //At one point in development there were three copies of the text.
         //This ensures that there is only one copy.
-        for (String targ : targs){
+        for (String targ : targs) {
             Matcher m = Pattern.compile(targ).matcher(s);
             int hit = 0;
             while (m.find()) {
                 hit++;
             }
-            assertEquals("controlled content loading-"+targ, 1, hit);
+            assertEquals("controlled content loading-" + targ, 1, hit);
         }
         //"test\n" appears twice: once as the "title" and once in the text.
         //This also happens when you save this document as text from MSWord.
         Matcher m = Pattern.compile("test\n").matcher(s);
         int hit = 0;
-        while (m.find()){
+        while (m.find()) {
             hit++;
         }
         assertEquals("test<N>", 2, hit);
         ex.close();
     }
 
-    /** No Header or Footer in document */
+    /**
+     * No Header or Footer in document
+     */
     public void testBug55733() throws Exception {
         XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("55733.docx");
-    	XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
+        XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
 
         // Check it gives text without error
         extractor.getText();
         extractor.close();
     }
-    
-    public void testCheckboxes() throws IOException  {
+
+    public void testCheckboxes() throws IOException {
         XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("checkboxes.docx");
-        System.out.println(doc);
         XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
-        
+
         assertEquals("This is a small test for checkboxes \nunchecked: |_| \n" +
-                     "Or checked: |X|\n\n\n\n\n" +
-                     "Test a checkbox within a textbox: |_| -> |X|\n\n\n" +
-                     "In Table:\n|_|\t|X|\n\n\n" +
-                     "In Sequence:\n|X||_||X|\n", extractor.getText());
+                "Or checked: |X|\n\n\n\n\n" +
+                "Test a checkbox within a textbox: |_| -> |X|\n\n\n" +
+                "In Table:\n|_|\t|X|\n\n\n" +
+                "In Sequence:\n|X||_||X|\n", extractor.getText());
         extractor.close();
     }
+    
+    public void testMultipleBodyBug() throws IOException {
+        XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("MultipleBodyBug.docx");
+        XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
+        assertEquals("START BODY 1 The quick, brown fox jumps over a lazy dog. END BODY 1.\n"
+                        + "START BODY 2 The quick, brown fox jumps over a lazy dog. END BODY 2.\n"
+                        + "START BODY 3 The quick, brown fox jumps over a lazy dog. END BODY 3.\n",
+                extractor.getText());
+        extractor.close();
+    }
+
+    public void testPhonetic() throws IOException {
+        XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("61470.docx");
+        XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
+        //expect: baseText (phoneticText)
+        assertEquals("\u6771\u4EAC (\u3068\u3046\u304D\u3087\u3046)", extractor.getText().trim());
+        extractor.close();
+        extractor = new XWPFWordExtractor(doc);
+        extractor.setConcatenatePhoneticRuns(false);
+        assertEquals("\u6771\u4EAC", extractor.getText().trim());
+    }
+
+    public void testCTPictureBase() throws IOException {
+        //This forces ctpicturebase to be included in the poi-ooxml-schemas jar
+        XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("61991.docx");
+        XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
+        String txt = extractor.getText();
+        assertContains(txt, "Sequencing data");
+        extractor.close();
+    }
+
+    public void testGlossary() throws IOException {
+        XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("60316.dotx");
+        XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
+        String txt = extractor.getText();
+        assertContains(txt, "Getting the perfect");
+        //this content appears only in the glossary document
+        //once we add processing for this, we can change this to contains
+        assertNotContained(txt, "table rows");
+    }
+
+    public void testPartsInTemplate() throws IOException {
+        XWPFDocument doc = XWPFTestDataSamples.openSampleDocument("60316b.dotx");
+        XWPFWordExtractor extractor = new XWPFWordExtractor(doc);
+        String txt = extractor.getText();
+        assertContains(txt, "header 2");
+        assertContains(txt, "footer 1");
+    }
 }
