@@ -16,14 +16,19 @@
 ==================================================================== */
 package org.apache.poi.hwpf.converter;
 
-import java.io.File;
-import java.io.FileWriter;
-import java.util.List;
-import java.util.Stack;
+import static org.apache.poi.hwpf.converter.AbstractWordUtils.TWIPS_PER_INCH;
 
-import javax.xml.parsers.DocumentBuilderFactory;
+import java.io.File;
+import java.io.IOException;
+import java.util.Deque;
+import java.util.LinkedList;
+import java.util.List;
+
+import javax.xml.parsers.DocumentBuilder;
+import javax.xml.parsers.ParserConfigurationException;
 import javax.xml.transform.OutputKeys;
 import javax.xml.transform.Transformer;
+import javax.xml.transform.TransformerException;
 import javax.xml.transform.TransformerFactory;
 import javax.xml.transform.dom.DOMSource;
 import javax.xml.transform.stream.StreamResult;
@@ -45,20 +50,17 @@ import org.apache.poi.hwpf.usermodel.TableRow;
 import org.apache.poi.util.Beta;
 import org.apache.poi.util.POILogFactory;
 import org.apache.poi.util.POILogger;
+import org.apache.poi.util.XMLHelper;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Text;
 
-import static org.apache.poi.hwpf.converter.AbstractWordUtils.TWIPS_PER_INCH;
-
 /**
  * Converts Word files (95-2007) into HTML files.
  * <p>
  * This implementation doesn't create images or links to them. This can be
  * changed by overriding {@link #processImage(Element, boolean, Picture)}
  * method.
- * 
- * @author Sergey Vladimirov (vlsergey {at} gmail {dot} com)
  */
 @Beta
 public class WordToHtmlConverter extends AbstractWordConverter
@@ -79,9 +81,27 @@ public class WordToHtmlConverter extends AbstractWordConverter
         }
     }
 
-    private static final POILogger logger = POILogFactory
-            .getLogger( WordToHtmlConverter.class );
+    private static final POILogger logger = POILogFactory.getLogger( WordToHtmlConverter.class );
 
+    private final Deque<BlockProperies> blocksProperies = new LinkedList<>();
+
+    private final HtmlDocumentFacade htmlDocumentFacade;
+
+    private Element notes;
+
+    /**
+     * Creates new instance of {@link WordToHtmlConverter}. Can be used for
+     * output several {@link HWPFDocument}s into single HTML document.
+     * 
+     * @param document XML DOM Document used as HTML document
+     */
+    public WordToHtmlConverter( Document document ) {
+        this.htmlDocumentFacade = new HtmlDocumentFacade( document );
+    }
+
+    public WordToHtmlConverter( HtmlDocumentFacade htmlDocumentFacade ) {
+        this.htmlDocumentFacade = htmlDocumentFacade;
+    }
     
     private static String getSectionStyle( Section section )
     {
@@ -111,90 +131,58 @@ public class WordToHtmlConverter extends AbstractWordConverter
     }
 
     /**
-     * Java main() interface to interact with {@link WordToHtmlConverter}
+     * Java main() interface to interact with {@link WordToHtmlConverter}<p>
+     * 
+     * Usage: WordToHtmlConverter infile outfile<p>
      * 
-     * <p>
-     * Usage: WordToHtmlConverter infile outfile
-     * </p>
      * Where infile is an input .doc file ( Word 95-2007) which will be rendered
      * as HTML into outfile
      */
     public static void main( String[] args )
-    {
-        if ( args.length < 2 )
-        {
-            System.err
-                    .println( "Usage: WordToHtmlConverter <inputFile.doc> <saveTo.html>" );
+    throws IOException, ParserConfigurationException, TransformerException {
+        if ( args.length < 2 ) {
+            System.err.println( "Usage: WordToHtmlConverter <inputFile.doc> <saveTo.html>" );
             return;
         }
 
         System.out.println( "Converting " + args[0] );
         System.out.println( "Saving output to " + args[1] );
-        try
-        {
-            Document doc = WordToHtmlConverter.process( new File( args[0] ) );
 
-            FileWriter out = new FileWriter( args[1] );
-            DOMSource domSource = new DOMSource( doc );
-            StreamResult streamResult = new StreamResult( out );
+        Document doc = WordToHtmlConverter.process( new File( args[0] ) );
 
-            TransformerFactory tf = TransformerFactory.newInstance();
-            Transformer serializer = tf.newTransformer();
-            // TODO set encoding from a command argument
-            serializer.setOutputProperty( OutputKeys.ENCODING, "UTF-8" );
-            serializer.setOutputProperty( OutputKeys.INDENT, "yes" );
-            serializer.setOutputProperty( OutputKeys.METHOD, "html" );
-            serializer.transform( domSource, streamResult );
-            out.close();
+        DOMSource domSource = new DOMSource( doc );
+        StreamResult streamResult = new StreamResult( new File(args[1]) );
+
+        TransformerFactory tf = TransformerFactory.newInstance();
+        Transformer serializer = tf.newTransformer();
+        // TODO set encoding from a command argument
+        serializer.setOutputProperty( OutputKeys.ENCODING, "UTF-8" );
+        serializer.setOutputProperty( OutputKeys.INDENT, "yes" );
+        serializer.setOutputProperty( OutputKeys.METHOD, "html" );
+        serializer.transform( domSource, streamResult );
+    }
+
+    static Document process( File docFile ) throws IOException, ParserConfigurationException
+    {
+        final DocumentBuilder docBuild = XMLHelper.getDocumentBuilderFactory().newDocumentBuilder();
+        try (final HWPFDocumentCore wordDocument = AbstractWordUtils.loadDoc( docFile )) {
+            WordToHtmlConverter wordToHtmlConverter = new WordToHtmlConverter(docBuild.newDocument());
+            wordToHtmlConverter.processDocument(wordDocument);
+            return wordToHtmlConverter.getDocument();
         }
-        catch ( Exception e )
-        {
-            e.printStackTrace();
-        }
-    }
-
-    static Document process( File docFile ) throws Exception
-    {
-        final HWPFDocumentCore wordDocument = WordToHtmlUtils.loadDoc( docFile );
-        WordToHtmlConverter wordToHtmlConverter = new WordToHtmlConverter(
-                DocumentBuilderFactory.newInstance().newDocumentBuilder()
-                        .newDocument() );
-        wordToHtmlConverter.processDocument( wordDocument );
-        return wordToHtmlConverter.getDocument();
-    }
-
-    private final Stack<BlockProperies> blocksProperies = new Stack<BlockProperies>();
-
-    private final HtmlDocumentFacade htmlDocumentFacade;
-
-    private Element notes = null;
-
-    /**
-     * Creates new instance of {@link WordToHtmlConverter}. Can be used for
-     * output several {@link HWPFDocument}s into single HTML document.
-     * 
-     * @param document
-     *            XML DOM Document used as HTML document
-     */
-    public WordToHtmlConverter( Document document )
-    {
-        this.htmlDocumentFacade = new HtmlDocumentFacade( document );
-    }
-
-    public WordToHtmlConverter( HtmlDocumentFacade htmlDocumentFacade )
-    {
-        this.htmlDocumentFacade = htmlDocumentFacade;
     }
 
     @Override
     protected void afterProcess()
     {
-        if ( notes != null )
+        if ( notes != null ) {
             htmlDocumentFacade.getBody().appendChild( notes );
+        }
 
         htmlDocumentFacade.updateStylesheet();
     }
 
+    @Override
     public Document getDocument()
     {
         return htmlDocumentFacade.getDocument();
@@ -204,22 +192,22 @@ public class WordToHtmlConverter extends AbstractWordConverter
     protected void outputCharacters( Element pElement,
             CharacterRun characterRun, String text )
     {
-        Element span = htmlDocumentFacade.document.createElement( "span" );
+        Element span = htmlDocumentFacade.getDocument().createElement( "span" );
         pElement.appendChild( span );
 
         StringBuilder style = new StringBuilder();
         BlockProperies blockProperies = this.blocksProperies.peek();
         Triplet triplet = getCharacterRunTriplet( characterRun );
 
-        if ( WordToHtmlUtils.isNotEmpty( triplet.fontName )
-                && !WordToHtmlUtils.equals( triplet.fontName,
+        if ( AbstractWordUtils.isNotEmpty( triplet.fontName )
+                && !AbstractWordUtils.equals( triplet.fontName,
                         blockProperies.pFontName ) )
         {
-            style.append( "font-family:" + triplet.fontName + ";" );
+            style.append("font-family:").append(triplet.fontName).append(";");
         }
         if ( characterRun.getFontSize() / 2 != blockProperies.pFontSize )
         {
-            style.append( "font-size:" + characterRun.getFontSize() / 2 + "pt;" );
+            style.append("font-size:").append(characterRun.getFontSize() / 2).append("pt;");
         }
         if ( triplet.bold )
         {
@@ -231,8 +219,9 @@ public class WordToHtmlConverter extends AbstractWordConverter
         }
 
         WordToHtmlUtils.addCharactersProperties( characterRun, style );
-        if ( style.length() != 0 )
+        if ( style.length() != 0 ) {
             htmlDocumentFacade.addStyleClass( span, "s", style.toString() );
+        }
 
         Text textNode = htmlDocumentFacade.createText( text );
         span.appendChild( textNode );
@@ -252,26 +241,31 @@ public class WordToHtmlConverter extends AbstractWordConverter
             parent = bookmarkElement;
         }
 
-        if ( range != null )
+        if ( range != null ) {
             processCharacters( wordDocument, currentTableLevel, range, parent );
+        }
     }
 
     @Override
     protected void processDocumentInformation(
             SummaryInformation summaryInformation )
     {
-        if ( WordToHtmlUtils.isNotEmpty( summaryInformation.getTitle() ) )
+        if ( AbstractWordUtils.isNotEmpty( summaryInformation.getTitle() ) ) {
             htmlDocumentFacade.setTitle( summaryInformation.getTitle() );
+        }
 
-        if ( WordToHtmlUtils.isNotEmpty( summaryInformation.getAuthor() ) )
+        if ( AbstractWordUtils.isNotEmpty( summaryInformation.getAuthor() ) ) {
             htmlDocumentFacade.addAuthor( summaryInformation.getAuthor() );
+        }
 
-        if ( WordToHtmlUtils.isNotEmpty( summaryInformation.getKeywords() ) )
+        if ( AbstractWordUtils.isNotEmpty( summaryInformation.getKeywords() ) ) {
             htmlDocumentFacade.addKeywords( summaryInformation.getKeywords() );
+        }
 
-        if ( WordToHtmlUtils.isNotEmpty( summaryInformation.getComments() ) )
+        if ( AbstractWordUtils.isNotEmpty( summaryInformation.getComments() ) ) {
             htmlDocumentFacade
                     .addDescription( summaryInformation.getComments() );
+        }
     }
 
     @Override
@@ -327,19 +321,19 @@ public class WordToHtmlConverter extends AbstractWordConverter
         Element basicLink = htmlDocumentFacade.createHyperlink( hyperlink );
         currentBlock.appendChild( basicLink );
 
-        if ( textRange != null )
+        if ( textRange != null ) {
             processCharacters( wordDocument, currentTableLevel, textRange,
                     basicLink );
+        }
     }
 
+    @Override
     protected void processImage( Element currentBlock, boolean inlined,
             Picture picture, String imageSourcePath )
     {
         final int aspectRatioX = picture.getHorizontalScalingFactor();
         final int aspectRatioY = picture.getVerticalScalingFactor();
 
-        StringBuilder style = new StringBuilder();
-
         final float imageWidth;
         final float imageHeight;
 
@@ -350,11 +344,11 @@ public class WordToHtmlConverter extends AbstractWordConverter
 
         if ( aspectRatioX > 0 )
         {
-            imageWidth = picture.getDxaGoal() * aspectRatioX / 1000
+            imageWidth = picture.getDxaGoal() * aspectRatioX / 1000.f
                     / TWIPS_PER_INCH;
-            cropRight = picture.getDxaCropRight() * aspectRatioX / 1000
+            cropRight = picture.getDxaCropRight() * aspectRatioX / 1000.f
                     / TWIPS_PER_INCH;
-            cropLeft = picture.getDxaCropLeft() * aspectRatioX / 1000
+            cropLeft = picture.getDxaCropLeft() * aspectRatioX / 1000.f
                     / TWIPS_PER_INCH;
         }
         else
@@ -366,11 +360,11 @@ public class WordToHtmlConverter extends AbstractWordConverter
 
         if ( aspectRatioY > 0 )
         {
-            imageHeight = picture.getDyaGoal() * aspectRatioY / 1000
+            imageHeight = picture.getDyaGoal() * aspectRatioY / 1000.f
                     / TWIPS_PER_INCH;
-            cropTop = picture.getDyaCropTop() * aspectRatioY / 1000
+            cropTop = picture.getDyaCropTop() * aspectRatioY / 1000.f
                     / TWIPS_PER_INCH;
-            cropBottom = picture.getDyaCropBottom() * aspectRatioY / 1000
+            cropBottom = picture.getDyaCropBottom() * aspectRatioY / 1000.f
                     / TWIPS_PER_INCH;
         }
         else
@@ -381,7 +375,7 @@ public class WordToHtmlConverter extends AbstractWordConverter
         }
 
         Element root;
-        if ( cropTop != 0 || cropRight != 0 || cropBottom != 0 || cropLeft != 0 )
+        if ( Math.abs(cropTop)+Math.abs(cropRight)+Math.abs(cropBottom)+Math.abs(cropLeft) > 0 )
         {
             float visibleWidth = Math
                     .max( 0, imageWidth - cropLeft - cropRight );
@@ -407,7 +401,6 @@ public class WordToHtmlConverter extends AbstractWordConverter
                             + imageHeight + "in;" );
             inner.appendChild( image );
 
-            style.append( "overflow:hidden;" );
         }
         else
         {
@@ -424,7 +417,7 @@ public class WordToHtmlConverter extends AbstractWordConverter
             boolean inlined, Picture picture )
     {
         // no default implementation -- skip
-        currentBlock.appendChild( htmlDocumentFacade.document
+        currentBlock.appendChild( htmlDocumentFacade.getDocument()
                 .createComment( "Image link to '"
                         + picture.suggestFullFileName() + "' can be here" ) );
     }
@@ -491,6 +484,7 @@ public class WordToHtmlConverter extends AbstractWordConverter
         flow.appendChild( htmlDocumentFacade.createLineBreak() );
     }
 
+    @Override
     protected void processPageref( HWPFDocumentCore hwpfDocument,
             Element currentBlock, Range textRange, int currentTableLevel,
             String pageref )
@@ -498,11 +492,13 @@ public class WordToHtmlConverter extends AbstractWordConverter
         Element basicLink = htmlDocumentFacade.createHyperlink( "#" + pageref );
         currentBlock.appendChild( basicLink );
 
-        if ( textRange != null )
+        if ( textRange != null ) {
             processCharacters( hwpfDocument, currentTableLevel, textRange,
                     basicLink );
+        }
     }
 
+    @Override
     protected void processParagraph( HWPFDocumentCore hwpfDocument,
             Element parentElement, int currentTableLevel, Paragraph paragraph,
             String bulletText )
@@ -535,13 +531,13 @@ public class WordToHtmlConverter extends AbstractWordConverter
             else
             {
                 pFontSize = -1;
-                pFontName = WordToHtmlUtils.EMPTY;
+                pFontName = AbstractWordUtils.EMPTY;
             }
             blocksProperies.push( new BlockProperies( pFontName, pFontSize ) );
         }
         try
         {
-            if ( WordToHtmlUtils.isNotEmpty( bulletText ) )
+            if ( AbstractWordUtils.isNotEmpty( bulletText ) )
             {
                 if ( bulletText.endsWith( "\t" ) )
                 {
@@ -550,9 +546,9 @@ public class WordToHtmlConverter extends AbstractWordConverter
                      * least simplest case shall be handled
                      */
                     final float defaultTab = TWIPS_PER_INCH / 2;
+                    // char have some space
                     float firstLinePosition = paragraph.getIndentFromLeft()
-                            + paragraph.getFirstLineIndent() + 20; // char have
-                                                                   // some space
+                            + paragraph.getFirstLineIndent() + 20f;
 
                     float nextStop = (float) ( Math.ceil( firstLinePosition
                             / defaultTab ) * defaultTab );
@@ -590,19 +586,20 @@ public class WordToHtmlConverter extends AbstractWordConverter
             blocksProperies.pop();
         }
 
-        if ( style.length() > 0 )
+        if ( style.length() > 0 ) {
             htmlDocumentFacade.addStyleClass( pElement, "p", style.toString() );
+        }
 
         WordToHtmlUtils.compactSpans( pElement );
-        return;
     }
 
+    @Override
     protected void processSection( HWPFDocumentCore wordDocument,
             Section section, int sectionCounter )
     {
         Element div = htmlDocumentFacade.createBlock();
         htmlDocumentFacade.addStyleClass( div, "d", getSectionStyle( section ) );
-        htmlDocumentFacade.body.appendChild( div );
+        htmlDocumentFacade.getBody().appendChild( div );
 
         processParagraphes( wordDocument, div, section, Integer.MIN_VALUE );
     }
@@ -611,20 +608,21 @@ public class WordToHtmlConverter extends AbstractWordConverter
     protected void processSingleSection( HWPFDocumentCore wordDocument,
             Section section )
     {
-        htmlDocumentFacade.addStyleClass( htmlDocumentFacade.body, "b",
+        htmlDocumentFacade.addStyleClass( htmlDocumentFacade.getBody(), "b",
                 getSectionStyle( section ) );
 
-        processParagraphes( wordDocument, htmlDocumentFacade.body, section,
+        processParagraphes( wordDocument, htmlDocumentFacade.getBody(), section,
                 Integer.MIN_VALUE );
     }
 
+    @Override
     protected void processTable( HWPFDocumentCore hwpfDocument, Element flow,
             Table table )
     {
         Element tableHeader = htmlDocumentFacade.createTableHeader();
         Element tableBody = htmlDocumentFacade.createTableBody();
 
-        final int[] tableCellEdges = WordToHtmlUtils
+        final int[] tableCellEdges = AbstractWordUtils
                 .buildTableCellEdgesArray( table );
         final int tableRows = table.numRows();
 
@@ -676,18 +674,21 @@ public class WordToHtmlConverter extends AbstractWordConverter
                         currentEdgeIndex, tableCell );
                 currentEdgeIndex += colSpan;
 
-                if ( colSpan == 0 )
+                if ( colSpan == 0 ) {
                     continue;
+                }
 
-                if ( colSpan != 1 )
+                if ( colSpan != 1 ) {
                     tableCellElement.setAttribute( "colspan",
                             String.valueOf( colSpan ) );
+                }
 
                 final int rowSpan = getNumberRowsSpanned( table,
                         tableCellEdges, r, c, tableCell );
-                if ( rowSpan > 1 )
+                if ( rowSpan > 1 ) {
                     tableCellElement.setAttribute( "rowspan",
                             String.valueOf( rowSpan ) );
+                }
 
                 processParagraphes( hwpfDocument, tableCellElement, tableCell,
                         table.getTableLevel() );
@@ -697,17 +698,19 @@ public class WordToHtmlConverter extends AbstractWordConverter
                     tableCellElement.appendChild( htmlDocumentFacade
                             .createParagraph() );
                 }
-                if ( tableCellStyle.length() > 0 )
+                if ( tableCellStyle.length() > 0 ) {
                     htmlDocumentFacade.addStyleClass( tableCellElement,
                             tableCellElement.getTagName(),
                             tableCellStyle.toString() );
+                }
 
                 tableRowElement.appendChild( tableCellElement );
             }
 
-            if ( tableRowStyle.length() > 0 )
+            if ( tableRowStyle.length() > 0 ) {
                 tableRowElement.setAttribute( "class", htmlDocumentFacade
                         .getOrCreateCssClass( "r", tableRowStyle.toString() ) );
+            }
 
             if ( tableRow.isTableHeader() )
             {
