@@ -18,62 +18,82 @@
 package org.apache.poi.hslf.model;
 
 import static org.junit.Assert.assertArrayEquals;
+import static org.junit.Assert.assertEquals;
 
 import java.awt.geom.Rectangle2D;
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.File;
+import java.io.IOException;
 import java.io.InputStream;
-
-import junit.framework.TestCase;
+import java.util.List;
 
 import org.apache.poi.POIDataSamples;
-import org.apache.poi.hslf.HSLFSlideShow;
-import org.apache.poi.hslf.usermodel.ObjectData;
-import org.apache.poi.hslf.usermodel.PictureData;
-import org.apache.poi.hslf.usermodel.SlideShow;
+import org.apache.poi.hslf.usermodel.HSLFObjectData;
+import org.apache.poi.hslf.usermodel.HSLFPictureData;
+import org.apache.poi.hslf.usermodel.HSLFShape;
+import org.apache.poi.hslf.usermodel.HSLFSlide;
+import org.apache.poi.hslf.usermodel.HSLFSlideShow;
+import org.apache.poi.hslf.usermodel.HSLFSlideShowImpl;
+import org.apache.poi.hslf.usermodel.HSLFObjectShape;
 import org.apache.poi.hssf.usermodel.HSSFSheet;
 import org.apache.poi.hssf.usermodel.HSSFWorkbook;
 import org.apache.poi.hwpf.HWPFDocument;
 import org.apache.poi.poifs.filesystem.POIFSFileSystem;
+import org.apache.poi.sl.usermodel.PictureData.PictureType;
 import org.apache.poi.util.IOUtils;
+import org.junit.Test;
 
-public final class TestOleEmbedding extends TestCase {
+public final class TestOleEmbedding {
     private static POIDataSamples _slTests = POIDataSamples.getSlideShowInstance();
     /**
      * Tests support for OLE objects.
      *
      * @throws Exception if an error occurs.
      */
-    public void testOleEmbedding2003() throws Exception {
-        HSLFSlideShow slideShow = new HSLFSlideShow(_slTests.openResourceAsStream("ole2-embedding-2003.ppt"));
+    @Test
+    public void testOleEmbedding2003() throws IOException {
+        HSLFSlideShowImpl slideShow = new HSLFSlideShowImpl(_slTests.openResourceAsStream("ole2-embedding-2003.ppt"));
         // Placeholder EMFs for clients that don't support the OLE components.
-        PictureData[] pictures = slideShow.getPictures();
-        assertEquals("Should be two pictures", 2, pictures.length);
-        //assertDigestEquals("Wrong data for picture 1", "8d1fbadf4814f321bb1ccdd056e3c788", pictures[0].getData());
-        //assertDigestEquals("Wrong data for picture 2", "987a698e83559cf3d38a0deeba1cc63b", pictures[1].getData());
+        List<HSLFPictureData> pictures = slideShow.getPictureData();
+        assertEquals("Should be two pictures", 2, pictures.size());
+        
+        long checkSums[] = { 0xD37A4204l, 0x26A62F68l, 0x82853169l, 0xE0E45D2Bl };
+        int checkId = 0;
+        
+        // check for checksum to be uptodate
+        for (HSLFPictureData pd : pictures) {
+            long checkEMF = IOUtils.calculateChecksum(pd.getData());
+            assertEquals(checkSums[checkId++], checkEMF);
+        }
 
         // Actual embedded objects.
-        ObjectData[] objects = slideShow.getEmbeddedObjects();
+        HSLFObjectData[] objects = slideShow.getEmbeddedObjects();
         assertEquals("Should be two objects", 2, objects.length);
-        //assertDigestEquals("Wrong data for objecs 1", "0d1fcc61a83de5c4894dc0c88e9a019d", objects[0].getData());
-        //assertDigestEquals("Wrong data for object 2", "b323604b2003a7299c77c2693b641495", objects[1].getData());
+        for (HSLFObjectData od : objects) {
+            long checkEMF = IOUtils.calculateChecksum(od.getInputStream());
+            assertEquals(checkSums[checkId++], checkEMF);
+        }
+        
+        slideShow.close();
     }
+    
+    
 
-    public void testOLEShape() throws Exception {
-        SlideShow ppt = new SlideShow(_slTests.openResourceAsStream("ole2-embedding-2003.ppt"));
+    @Test
+    public void testOLEShape() throws IOException {
+        HSLFSlideShow ppt = new HSLFSlideShow(_slTests.openResourceAsStream("ole2-embedding-2003.ppt"));
 
-        Slide slide = ppt.getSlides()[0];
-        Shape[] sh = slide.getShapes();
+        HSLFSlide slide = ppt.getSlides().get(0);
         int cnt = 0;
-        for (int i = 0; i < sh.length; i++) {
-            if(sh[i] instanceof OLEShape){
+        for (HSLFShape sh : slide.getShapes()) {
+            if(sh instanceof HSLFObjectShape){
                 cnt++;
-                OLEShape ole = (OLEShape)sh[i];
-                ObjectData data = ole.getObjectData();
+                HSLFObjectShape ole = (HSLFObjectShape)sh;
+                HSLFObjectData data = ole.getObjectData();
                 if("Worksheet".equals(ole.getInstanceName())){
                     //Voila! we created a workbook from the embedded OLE data
-                    HSSFWorkbook wb = new HSSFWorkbook(data.getData());
+                    HSSFWorkbook wb = new HSSFWorkbook(data.getInputStream());
                     HSSFSheet sheet = wb.getSheetAt(0);
                     //verify we can access the xls data
                     assertEquals(1, sheet.getRow(0).getCell(0).getNumericCellValue(), 0);
@@ -81,24 +101,27 @@ public final class TestOleEmbedding extends TestCase {
                     assertEquals(2, sheet.getRow(2).getCell(0).getNumericCellValue(), 0);
                     assertEquals(3, sheet.getRow(3).getCell(0).getNumericCellValue(), 0);
                     assertEquals(8, sheet.getRow(5).getCell(0).getNumericCellValue(), 0);
+                    wb.close();
                 } else if ("Document".equals(ole.getInstanceName())){
                     //creating a HWPF document
-                    HWPFDocument doc = new HWPFDocument(data.getData());
+                    HWPFDocument doc = new HWPFDocument(data.getInputStream());
                     String txt = doc.getRange().getParagraph(0).text();
                     assertEquals("OLE embedding is thoroughly unremarkable.\r", txt);
+                    doc.close();
                 }
             }
 
         }
         assertEquals("Expected 2 OLE shapes", 2, cnt);
+        ppt.close();
     }
     
-    public void testEmbedding() throws Exception {
-    	HSLFSlideShow _hslfSlideShow = HSLFSlideShow.create();
-    	SlideShow ppt = new SlideShow(_hslfSlideShow);
+    @Test
+    public void testEmbedding() throws IOException {
+    	HSLFSlideShow ppt = new HSLFSlideShow();
     	
     	File pict = POIDataSamples.getSlideShowInstance().getFile("clock.jpg");
-    	int pictId = ppt.addPicture(pict, Picture.JPEG);
+    	HSLFPictureData pictData = ppt.addPicture(pict, PictureType.JPEG);
     	
     	InputStream is = POIDataSamples.getSpreadSheetInstance().openResourceAsStream("Employee.xls");
     	POIFSFileSystem poiData1 = new POIFSFileSystem(is);
@@ -106,15 +129,15 @@ public final class TestOleEmbedding extends TestCase {
     	
     	int oleObjectId1 = ppt.addEmbed(poiData1);
     	
-    	Slide slide1 = ppt.createSlide();
-    	OLEShape oleShape1 = new OLEShape(pictId);
+    	HSLFSlide slide1 = ppt.createSlide();
+    	HSLFObjectShape oleShape1 = new HSLFObjectShape(pictData);
     	oleShape1.setObjectID(oleObjectId1);
     	slide1.addShape(oleShape1);
     	oleShape1.setAnchor(new Rectangle2D.Double(100,100,100,100));
     	
     	// add second slide with different order in object creation
-    	Slide slide2 = ppt.createSlide();
-    	OLEShape oleShape2 = new OLEShape(pictId);
+    	HSLFSlide slide2 = ppt.createSlide();
+    	HSLFObjectShape oleShape2 = new HSLFObjectShape(pictData);
 
         is = POIDataSamples.getSpreadSheetInstance().openResourceAsStream("SimpleWithImages.xls");
         POIFSFileSystem poiData2 = new POIFSFileSystem(is);
@@ -129,9 +152,9 @@ public final class TestOleEmbedding extends TestCase {
     	ByteArrayOutputStream bos = new ByteArrayOutputStream();
     	ppt.write(bos);
     	
-    	ppt = new SlideShow(new ByteArrayInputStream(bos.toByteArray()));
-    	OLEShape comp = (OLEShape)ppt.getSlides()[0].getShapes()[0];
-    	byte compData[] = IOUtils.toByteArray(comp.getObjectData().getData());
+    	ppt = new HSLFSlideShow(new ByteArrayInputStream(bos.toByteArray()));
+    	HSLFObjectShape comp = (HSLFObjectShape)ppt.getSlides().get(0).getShapes().get(0);
+    	byte compData[] = IOUtils.toByteArray(comp.getObjectData().getInputStream());
     	
     	bos.reset();
     	poiData1.writeFilesystem(bos);
@@ -139,5 +162,10 @@ public final class TestOleEmbedding extends TestCase {
     	
     	assertArrayEquals(expData, compData);
     	
+    	poiData1.close();
+    	poiData2.close();
+    	ppt.close();
     }
+
+    
 }
