@@ -30,7 +30,7 @@ import junit.framework.TestCase;
  */
 public final class TestExOleObjAtom extends TestCase {
 	// From a real file (embedded SWF control)
-	private byte[] data = {
+	private final byte[] data = {
 			0x01, 0x00, (byte)0xC3, 0x0F, 0x18, 0x00, 0x00, 0x00,
 			0x01, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
 			0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, (byte)0x96, 0x13, 0x00  };
