@@ -31,7 +31,7 @@ import junit.framework.TestCase;
  */
 public final class TestHeadersFootersContainer extends TestCase {
 	// SlideHeadersFootersContainer
-	private byte[] slideData = new byte[] {
+	private final byte[] slideData = new byte[] {
             0x3F, 0x00, (byte)0xD9, 0x0F, 0x2E, 0x00, 0x00, 0x00,
             0x00, 0x00, (byte)0xDA, 0x0F, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x23, 0x00,
             0x20, 0x00, (byte)0xBA, 0x0F, 0x1A, 0x00, 0x00, 0x00,
@@ -41,7 +41,7 @@ public final class TestHeadersFootersContainer extends TestCase {
     };
 
     // NotesHeadersFootersContainer
-    private byte[] notesData = new byte[] {
+    private final byte[] notesData = new byte[] {
             0x4F, 0x00, (byte)0xD9, 0x0F, 0x48, 0x00, 0x00, 0x00,
             0x00, 0x00, (byte)0xDA, 0x0F, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3D, 0x00,
             0x10, 0x00, (byte)0xBA, 0x0F, 0x16, 0x00, 0x00, 0x00,
