@@ -18,50 +18,49 @@
 package org.apache.poi.hslf.record;
 
 import static org.junit.Assert.assertArrayEquals;
-import junit.framework.AssertionFailedError;
-import junit.framework.TestCase;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+
+import java.io.IOException;
 
 import org.apache.poi.POIDataSamples;
-import org.apache.poi.hslf.usermodel.SlideShow;
+import org.apache.poi.hslf.usermodel.HSLFSlideShow;
+import org.junit.Test;
 
 /**
  * Tests Sound-related records: SoundCollection(2020), Sound(2022) and
  * SoundData(2023)).
- *
- * @author Yegor Kozlov
  */
-public final class TestSound extends TestCase {
-	public void testRealFile() throws Exception {
+public final class TestSound {
+    @Test
+	public void testRealFile() throws IOException {
         POIDataSamples slTests = POIDataSamples.getSlideShowInstance();
 
-		SlideShow ppt = new SlideShow(slTests.openResourceAsStream("sound.ppt"));
+		HSLFSlideShow ppt = new HSLFSlideShow(slTests.openResourceAsStream("sound.ppt"));
 
 		// Get the document
 		Document doc = ppt.getDocumentRecord();
 		SoundCollection soundCollection = null;
 		Record[] doc_ch = doc.getChildRecords();
-		for (int i = 0; i < doc_ch.length; i++) {
-			if (doc_ch[i] instanceof SoundCollection) {
-				soundCollection = (SoundCollection) doc_ch[i];
+		for (Record rec : doc_ch) {
+			if (rec instanceof SoundCollection) {
+				soundCollection = (SoundCollection) rec;
 				break;
 			}
 		}
-		if (soundCollection == null) {
-			throw new AssertionFailedError("soundCollection must not be null");
-		}
+		assertNotNull(soundCollection);
 
 		Sound sound = null;
 		Record[] sound_ch = soundCollection.getChildRecords();
 		int k = 0;
-		for (int i = 0; i < sound_ch.length; i++) {
-			if (sound_ch[i] instanceof Sound) {
-				sound = (Sound) sound_ch[i];
+		for (Record rec : sound_ch) {
+			if (rec instanceof Sound) {
+				sound = (Sound) rec;
 				k++;
 			}
 		}
-		if (sound == null) {
-			throw new AssertionFailedError("sound must not be null");
-		}
+		
+		assertNotNull(sound);
 		assertEquals(1, k);
 
 		assertEquals("ringin.wav", sound.getSoundName());
@@ -70,5 +69,7 @@ public final class TestSound extends TestCase {
 
 		byte[] ref_data = slTests.readFile("ringin.wav");
 		assertArrayEquals(ref_data, sound.getSoundData());
-	}
+
+		ppt.close();
+    }
 }
