@@ -17,19 +17,24 @@
 
 package org.apache.poi.hsmf;
 
+import static org.apache.poi.POITestCase.assertContains;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+
 import java.io.ByteArrayOutputStream;
-import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.PrintStream;
 import java.text.SimpleDateFormat;
 import java.util.Calendar;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Locale;
 import java.util.Map;
 import java.util.TimeZone;
 
 import org.apache.poi.POIDataSamples;
-import org.apache.poi.POITestCase;
 import org.apache.poi.hsmf.datatypes.ChunkBasedPropertyValue;
 import org.apache.poi.hsmf.datatypes.Chunks;
 import org.apache.poi.hsmf.datatypes.MAPIProperty;
@@ -39,41 +44,58 @@ import org.apache.poi.hsmf.datatypes.PropertyValue.TimePropertyValue;
 import org.apache.poi.hsmf.dev.HSMFDump;
 import org.apache.poi.hsmf.extractor.OutlookTextExtactor;
 import org.apache.poi.poifs.filesystem.POIFSFileSystem;
+import org.apache.poi.util.LocaleUtil;
+import org.junit.AfterClass;
+import org.junit.BeforeClass;
+import org.junit.Test;
 
 /**
  * Tests that we can read fixed sized properties, as well as variable
  *  ones, for example Submission Dates
  */
-public final class TestFixedSizedProperties extends POITestCase {
-   protected static final String messageSucceeds = "53784_succeeds.msg";
-   protected static final String messageFails = "53784_fails.msg";
-   private MAPIMessage mapiMessageSucceeds;
-   private MAPIMessage mapiMessageFails;
-   private POIFSFileSystem fsMessageSucceeds;
-   private POIFSFileSystem fsMessageFails;
-   private SimpleDateFormat messageDateFormat;
+public final class TestFixedSizedProperties {
+   private static final String messageSucceeds = "53784_succeeds.msg";
+   private static final String messageFails = "53784_fails.msg";
+   private static MAPIMessage mapiMessageSucceeds;
+   private static MAPIMessage mapiMessageFails;
+   private static POIFSFileSystem fsMessageSucceeds;
+   private static POIFSFileSystem fsMessageFails;
+   private static SimpleDateFormat messageDateFormat;
+   private static TimeZone userTimeZone;
 
    /**
     * Initialize this test, load up the messages.
     */
-   public TestFixedSizedProperties() throws Exception {
+   @BeforeClass
+   public static void initMapi()  throws Exception {
        POIDataSamples samples = POIDataSamples.getHSMFInstance();
-      this.mapiMessageSucceeds = new MAPIMessage(
-                samples.openResourceAsStream(messageSucceeds));
-      this.mapiMessageFails = new MAPIMessage(
-                samples.openResourceAsStream(messageFails));		
-      this.fsMessageSucceeds = new POIFSFileSystem(new FileInputStream(samples.getFile(messageSucceeds)));
-      this.fsMessageFails = new POIFSFileSystem(new FileInputStream(samples.getFile(messageFails)));
+       fsMessageSucceeds = new POIFSFileSystem(samples.getFile(messageSucceeds));
+       fsMessageFails = new POIFSFileSystem(samples.getFile(messageFails));
+
+       mapiMessageSucceeds = new MAPIMessage(fsMessageSucceeds);
+       mapiMessageFails = new MAPIMessage(fsMessageFails);        
       
-      messageDateFormat = new SimpleDateFormat("E, d MMM yyyy HH:mm:ss");
-      messageDateFormat.setTimeZone(TimeZone.getTimeZone("GMT"));
+       messageDateFormat = new SimpleDateFormat("E, d MMM yyyy HH:mm:ss", Locale.ROOT);
+       messageDateFormat.setTimeZone(LocaleUtil.TIMEZONE_UTC);       
+
+       userTimeZone = LocaleUtil.getUserTimeZone();
+       LocaleUtil.setUserTimeZone(LocaleUtil.TIMEZONE_UTC);
+   }
+   
+   
+   @AfterClass
+   public static void closeFS() throws Exception {
+       LocaleUtil.setUserTimeZone(userTimeZone);
+       fsMessageSucceeds.close();
+       fsMessageFails.close();
    }
    
    /**
     * Check we can find a sensible number of properties on a few
     * of our test files
     */
-   public void testPropertiesFound() throws Exception {
+   @Test
+   public void testPropertiesFound() {
        Map<MAPIProperty,List<PropertyValue>> props;
        
        props = mapiMessageSucceeds.getMainChunks().getProperties();
@@ -86,13 +108,14 @@ public final class TestFixedSizedProperties extends POITestCase {
    /**
     * Check we find properties of a variety of different types
     */
-   public void testPropertyValueTypes() throws Exception {
+   @Test
+   public void testPropertyValueTypes() {
        Chunks mainChunks = mapiMessageSucceeds.getMainChunks();
        
        // Ask to have the values looked up
        Map<MAPIProperty,List<PropertyValue>> props = mainChunks.getProperties();
-       HashSet<Class<? extends PropertyValue>> seenTypes = 
-               new HashSet<Class<? extends PropertyValue>>();
+       HashSet<Class<? extends PropertyValue>> seenTypes =
+               new HashSet<>();
        for (List<PropertyValue> pvs : props.values()) {
            for (PropertyValue pv : pvs) {
                seenTypes.add(pv.getClass());
@@ -116,30 +139,36 @@ public final class TestFixedSizedProperties extends POITestCase {
 
    /**
     * Test to see if we can read the Date Chunk with OutlookTextExtractor.
-    * TODO Work out why the Fri 22nd vs Monday 25th problem is occurring and fix
     */
-   public void DISABLEDtestReadMessageDateSucceedsWithOutlookTextExtractor() {
+   @Test
+   // @Ignore("TODO Work out why the Fri 22nd vs Monday 25th problem is occurring and fix")
+   public void testReadMessageDateSucceedsWithOutlookTextExtractor() throws Exception {
       OutlookTextExtactor ext = new OutlookTextExtactor(mapiMessageSucceeds);
+      ext.setFilesystem(null); // Don't close re-used test resources here
+      
       String text = ext.getText();
-
-      assertContains(text, "Date: Fri, 22 Jun 2012 21:32:54\n");
+      assertContains(text, "Date: Fri, 22 Jun 2012 18:32:54 +0000\n");
+      ext.close();
    }
 
    /**
     * Test to see if we can read the Date Chunk with OutlookTextExtractor.
-    * TODO Work out why the Thu 21st vs Monday 25th problem is occurring and fix
     */
-   public void DISABLEDtestReadMessageDateFailsWithOutlookTextExtractor() {
+   @Test
+   // @Ignore("TODO Work out why the Thu 21st vs Monday 25th problem is occurring and fix")
+   public void testReadMessageDateFailsWithOutlookTextExtractor() throws Exception {
       OutlookTextExtactor ext = new OutlookTextExtactor(mapiMessageFails);
+      ext.setFilesystem(null); // Don't close re-used test resources here
+      
       String text = ext.getText();
-
-      assertContains(text, "Date: Thu, 21 Jun 2012 17:14:04\n");
+      assertContains(text, "Date: Thu, 21 Jun 2012 14:14:04 +0000\n");
+      ext.close();
    }
 
    /**
     * Test to see if we can read the Date Chunk with HSMFDump.
-    * @throws IOException 
     */
+   @Test
    public void testReadMessageDateSucceedsWithHSMFDump() throws IOException {
        PrintStream stream = new PrintStream(new ByteArrayOutputStream());
        HSMFDump dump = new HSMFDump(fsMessageSucceeds);
@@ -148,8 +177,8 @@ public final class TestFixedSizedProperties extends POITestCase {
 
    /**
     * Test to see if we can read the Date Chunk with HSMFDump.
-    * @throws Exception 
     */
+   @Test
    public void testReadMessageDateFailsWithHSMFDump() throws Exception {
        PrintStream stream = new PrintStream(new ByteArrayOutputStream());
        HSMFDump dump = new HSMFDump(fsMessageFails);
@@ -159,6 +188,7 @@ public final class TestFixedSizedProperties extends POITestCase {
    /**
     * Will be based on the ClientSubmit time
     */
+   @Test
    public void testClientSubmitTime() throws Exception {
        // Check via the message date
        Calendar clientSubmitTime = mapiMessageSucceeds.getMessageDate();
