@@ -50,7 +50,7 @@ public final class POIDataSamples {
     /** <code>true</code> if standard system propery is not set,
      * but the data is available on the test runtime classpath */
     private boolean _sampleDataIsAvaliableOnClassPath;
-    private String _moduleDir;
+    private final String _moduleDir;
 
     /**
      *
@@ -156,7 +156,7 @@ public final class POIDataSamples {
     /**
      *
      * @param sampleFileName    the name of the test file
-     * @return
+     * @return Verifies that the file with the given name exists in the test-data directory
      * @throws RuntimeException if the file was not found
      */
     public File getFile(String sampleFileName) {
@@ -197,12 +197,16 @@ public final class POIDataSamples {
                 return;
             }
 
-            throw new RuntimeException("Must set system property '" +
-                    TEST_PROPERTY + "' before running tests");
+            if(new File("test-data").exists()) {
+               dataDirName = "test-data";
+            } else {
+               throw new RuntimeException("Must set system property '" +
+                       TEST_PROPERTY + "' before running tests");
+            }
         }
         File dataDir = new File(dataDirName, _moduleDir);
         if (!dataDir.exists()) {
-            throw new RuntimeException("Data dir '" + _moduleDir + " does not exist");
+            throw new RuntimeException("Data dir '" + dataDir + "' does not exist");
         }
         // convert to canonical file, to make any subsequent error messages
         // clearer.
@@ -232,26 +236,26 @@ public final class POIDataSamples {
         }
 
         @Override
-		public int read() throws IOException {
+        public int read() throws IOException {
             return _is.read();
         }
         @Override
-		public int read(byte[] b, int off, int len) throws IOException {
+        public int read(byte[] b, int off, int len) throws IOException {
             return _is.read(b, off, len);
         }
         @Override
-		public boolean markSupported() {
+        public boolean markSupported() {
             return false;
         }
         @Override
-		public void close() throws IOException {
+        public void close() throws IOException {
             _is.close();
         }
     }
 
     /**
      * @param  fileName the file to open
-     * @return byte array of sample file content from file found in standard hssf test data dir
+     * @return byte array of sample file content from file found in standard test-data directory
      */
     public byte[] readFile(String fileName) {
         ByteArrayOutputStream bos = new ByteArrayOutputStream();
