@@ -18,13 +18,18 @@
 package org.apache.poi.ddf;
 
 import static org.junit.Assert.assertArrayEquals;
-import junit.framework.TestCase;
+import static org.junit.Assert.assertEquals;
 
+import java.io.IOException;
+
+import org.apache.poi.poifs.storage.RawDataUtil;
 import org.apache.poi.util.HexDump;
 import org.apache.poi.util.HexRead;
+import org.junit.Test;
 
-public final class TestEscherOptRecord extends TestCase {
+public final class TestEscherOptRecord {
 
+    @Test
     public void testFillFields() {
         checkFillFieldsSimple();
         checkFillFieldsComplex();
@@ -74,6 +79,7 @@ public final class TestEscherOptRecord extends TestCase {
         assertEquals( prop3, r.getEscherProperty( 2 ) );
     }
 
+    @Test
     public void testSerialize() {
         checkSerializeSimple();
         checkSerializeComplex();
@@ -130,6 +136,7 @@ public final class TestEscherOptRecord extends TestCase {
         assertEquals( 26, bytesWritten );
     }
 
+    @Test
     public void testToString() {
         String nl = System.getProperty("line.separator");
         EscherOptRecord r = new EscherOptRecord();
@@ -138,21 +145,25 @@ public final class TestEscherOptRecord extends TestCase {
         r.setRecordId(EscherOptRecord.RECORD_ID);
         EscherProperty prop1 = new EscherBoolProperty((short)1, 1);
         r.addEscherProperty(prop1);
-        String expected = "org.apache.poi.ddf.EscherOptRecord:" + nl +
-                "  isContainer: false" + nl +
-                "  version: 0x0003" + nl +
-                "  instance: 0x0001" + nl +
-                "  recordId: 0x" + HexDump.toHex(EscherOptRecord.RECORD_ID) + nl +
-                "  numchildren: 0" + nl +
-                "  properties:" + nl +
-                "    propNum: 1, RAW: 0x0001, propName: unknown, complex: false, blipId: false, value: 1 (0x00000001)" + nl;
+        String expected =
+            "org.apache.poi.ddf.EscherOptRecord (Opt):" + nl +
+            "  RecordId: 0xF00B" + nl +
+            "  Version: 0x0003" + nl +
+            "  Instance: 0x0001" + nl +
+            "  Options: 0x0013" + nl +
+            "  Record Size: 14" + nl +
+            "  isContainer: false" + nl +
+            "  numchildren: 0x00000000" + nl +
+            "  properties: 0x00000001" + nl +
+            "  unknown:   propNum: 1, RAW: 0x0001, propName: unknown, complex: false, blipId: false, value: 1 (0x00000001)";
         assertEquals( expected, r.toString());
     }
 
     /**
-     * Test serialisation of a particually complex example
+     * Test serialization of a particularly complex example
      * This test is currently broken!
      */
+    @Test
     public void testComplexSerialise() {
     	byte[] data = {
     		0x53, 0x01, 0x0B, 0xF0-256, 0x9C-256, 0x01, 0x00, 0x00,
@@ -233,15 +244,13 @@ public final class TestEscherOptRecord extends TestCase {
         assertEquals(data.length, filled);
         assertEquals(data.length, r.getRecordSize());
 
-        // Serialise it
+        // Serialize it
         byte[] dest = new byte[data.length];
         int written = r.serialize(0, dest);
 
         // Check it serialised it back to the same data
         assertEquals(data.length, written);
-        for(int i=0; i<data.length; i++) {
-        	assertEquals(data[i], dest[i]);
-        }
+        assertArrayEquals(data, dest);
     }
 
     /**
@@ -254,43 +263,20 @@ public final class TestEscherOptRecord extends TestCase {
      *
      * See Bug 41946 for details.
      */
-    public void test41946() {
-        String dataStr1 =
-                "03 08 0B F0 00 03 00 00 81 00 30 65 01 00 82 00 98 B2 00 00 83 00 30 65 01 " +
-                "00 84 00 98 B2 00 00 85 00 00 00 00 00 87 00 01 00 00 00 88 00 00 00 00 00 " +
-                "89 00 00 00 00 00 BF 00 00 00 0F 00 0C 01 F4 00 00 10 0D 01 00 00 00 20 0E " +
-                "01 00 00 00 20 80 01 00 00 00 00 81 01 04 00 00 08 82 01 00 00 01 00 83 01 " +
-                "00 00 00 08 84 01 00 00 01 00 85 01 00 00 00 20 86 41 00 00 00 00 87 C1 00 " +
-                "00 00 00 88 01 00 00 00 00 89 01 00 00 00 00 8A 01 00 00 00 00 8B 01 00 00 " +
-                "00 00 8C 01 00 00 00 00 8D 01 00 00 00 00 8E 01 00 00 00 00 8F 01 00 00 00 " +
-                "00 90 01 00 00 00 00 91 01 00 00 00 00 92 01 00 00 00 00 93 01 00 00 00 00 " +
-                "94 01 00 00 00 00 95 01 00 00 00 00 96 01 00 00 00 00 97 C1 00 00 00 00 98 " +
-                "01 00 00 00 00 99 01 00 00 00 00 9A 01 00 00 00 00 9B 01 00 00 00 00 9C 01 " +
-                "03 00 00 40 BF 01 0C 00 1E 00 C0 01 01 00 00 08 C1 01 00 00 01 00 C2 01 FF " +
-                "FF FF 00 C3 01 00 00 00 20 C4 01 00 00 00 00 C5 41 00 00 00 00 C6 C1 00 00 " +
-                "00 00 C7 01 00 00 00 00 C8 01 00 00 00 00 C9 01 00 00 00 00 CA 01 00 00 00 " +
-                "00 CB 01 35 25 00 00 CC 01 00 00 08 00 CD 01 00 00 00 00 CE 01 00 00 00 00 " +
-                "CF C1 00 00 00 00 D7 01 02 00 00 00 FF 01 06 00 0E 00 00 02 00 00 00 00 01 " +
-                "02 02 00 00 08 02 02 CB CB CB 00 03 02 00 00 00 20 04 02 00 00 01 00 05 02 " +
-                "38 63 00 00 06 02 38 63 00 00 07 02 00 00 00 00 08 02 00 00 00 00 09 02 00 " +
-                "00 01 00 0A 02 00 00 00 00 0B 02 00 00 00 00 0C 02 00 00 01 00 0D 02 00 00 " +
-                "00 00 0E 02 00 00 00 00 0F 02 00 01 00 00 10 02 00 00 00 00 11 02 00 00 00 " +
-                "00 3F 02 00 00 03 00 80 02 00 00 00 00 81 02 00 00 01 00 82 02 05 00 00 00 " +
-                "83 02 9C 31 00 00 84 02 00 00 00 00 85 02 F0 F9 06 00 86 02 00 00 00 00 87 " +
-                "02 F7 00 00 10 88 02 00 00 00 20 BF 02 01 00 0F 00 C0 02 00 00 00 00 C1 02 " +
-                "00 00 00 00 C2 02 64 00 00 00 C3 02 00 00 00 00 C4 02 00 00 00 00 C5 02 00 " +
-                "00 00 00 C6 02 00 00 00 00 C7 02 00 00 00 00 C8 02 00 00 00 00 C9 02 00 00 " +
-                "00 00 CA 02 30 75 00 00 CB 02 D0 12 13 00 CC 02 30 ED EC FF CD 02 40 54 89 " +
-                "00 CE 02 00 80 00 00 CF 02 00 80 FF FF D0 02 00 00 79 FF D1 02 32 00 00 00 " +
-                "D2 02 20 4E 00 00 D3 02 50 C3 00 00 D4 02 00 00 00 00 D5 02 10 27 00 00 D6 " +
-                "02 70 94 00 00 D7 02 B0 3C FF FF D8 02 00 00 00 00 D9 02 10 27 00 00 DA 02 " +
-                "70 94 00 00 FF 02 16 00 1F 00 04 03 01 00 00 00 41 03 A8 29 01 00 42 03 00 " +
-                "00 00 00 43 03 03 00 00 00 44 03 7C BE 01 00 45 03 00 00 00 00 7F 03 00 00 " +
-                "0F 00 84 03 7C BE 01 00 85 03 00 00 00 00 86 03 7C BE 01 00 87 03 00 00 00 " +
-                "00";
+    @Test
+    public void test41946() throws IOException {
+        String data64 =
+            "H4sIAAAAAAAAAB3SuW5TQRjF8TPfOOZCHMeARAluEKIzSEgUSCQsLaLgDYCehgIJCe8L+xIgQB6"+
+            "AEvEAOI6zOwlhX54BpBRIiGqY+Vvy7x6d+3k8nmufje/ISzVVrjrVNftWapCb5JbSqyMX7ZJ72I"+
+            "/vSRXcH6k0kW6Wi1hNquZyUlaP2amRmqxJbjHTnmbNQbLLfA9v4x28i/fwPj7Ah/gIH+MTnMGn+"+
+            "Ayfs/4s+QW+xFc45+KPnuq7gg5q3sUqG7DDBRdC0JB9LjK5xG6XWW2FZhXXcB1H7sRhaSMto02a"+
+            "LXzPp745iwaXV1FKUc7iJTMbjUbyqSnnLH37mJ28LOVxF5MZ7ubuHvI4FmgmyEWctPSQSuS9eDr"+
+            "qVSXXmK/bWMwNmzsmNelbtvMvrza5Y3/jAl320zcXn+88/QAX7Ep0SF7EJVzGFVzFNVy3yvV4Mr"+
+            "a9b782rPL7V9i0qUs9bZmq8WSiIWzHyRvhgx2P8x+tfEH6ZBeH0mdW+GKlI9JXuzYTz9DenArhO"+
+            "/0P+p/0wQ7okHI+Hfe0f33U6YxPM2d9upzzN985nae55dM/tknTommTO+T/V9IPpAgDAAA=";
 
         EscherOptRecord r = new EscherOptRecord();
-        byte[] data = HexRead.readFromString( dataStr1 );
+        byte[] data = RawDataUtil.decompress(data64);
         r.fillFields( data, 0, new DefaultEscherRecordFactory() );
         assertEquals( (short) 0xF00B, r.getRecordId() );
 
@@ -306,6 +292,7 @@ public final class TestEscherOptRecord extends TestCase {
      * Test that EscherOptRecord can properly read/write array properties
      * with empty complex part.
      */
+    @Test
     public void testEmptyArrayProperty() {
         EscherOptRecord r = new EscherOptRecord();
         EscherArrayProperty p = new EscherArrayProperty((short)(EscherProperties.FILL__SHADECOLORS + 0x8000), new byte[0] );
