@@ -17,12 +17,15 @@
 
 package org.apache.poi.hssf;
 
+import java.io.InputStream;
+
 import org.apache.poi.POIDataSamples;
 import org.apache.poi.hssf.usermodel.HSSFFormulaEvaluator;
 import org.apache.poi.hssf.usermodel.HSSFWorkbook;
 import org.apache.poi.ss.ITestDataProvider;
 import org.apache.poi.ss.SpreadsheetVersion;
 import org.apache.poi.ss.usermodel.FormulaEvaluator;
+import org.apache.poi.ss.usermodel.Sheet;
 import org.apache.poi.ss.usermodel.Workbook;
 
 /**
@@ -35,10 +38,16 @@ public final class HSSFITestDataProvider implements ITestDataProvider {
         // enforce singleton
     }
     
+    @Override
     public HSSFWorkbook openSampleWorkbook(String sampleFileName) {
         return HSSFTestDataSamples.openSampleWorkbook(sampleFileName);
     }
     
+    public InputStream openWorkbookStream(String sampleFileName) {
+        return HSSFTestDataSamples.openSampleFileStream(sampleFileName);
+    }
+    
+    @Override
     public HSSFWorkbook writeOutAndReadBack(Workbook original) {
         if(!(original instanceof HSSFWorkbook)) {
             throw new IllegalArgumentException("Expected an instance of HSSFWorkbook");
@@ -46,22 +55,37 @@ public final class HSSFITestDataProvider implements ITestDataProvider {
         return HSSFTestDataSamples.writeOutAndReadBack((HSSFWorkbook)original);
     }
     
+    @Override
     public HSSFWorkbook createWorkbook(){
         return new HSSFWorkbook();
     }
     
+    //************ SXSSF-specific methods ***************//
+    @Override
+    public HSSFWorkbook createWorkbook(int rowAccessWindowSize) {
+        return createWorkbook();
+    }
+    
+    @Override
+    public void trackAllColumnsForAutosizing(Sheet sheet) {}
+    //************ End SXSSF-specific methods ***************//
+    
+    @Override
     public FormulaEvaluator createFormulaEvaluator(Workbook wb) {
         return new HSSFFormulaEvaluator((HSSFWorkbook) wb);
     }
 
+    @Override
     public byte[] getTestDataFileContent(String fileName) {
         return POIDataSamples.getSpreadSheetInstance().readFile(fileName);
     }
     
+    @Override
     public SpreadsheetVersion getSpreadsheetVersion(){
         return SpreadsheetVersion.EXCEL97;
     }
     
+    @Override
     public String getStandardFileNameExtension() {
         return "xls";
     }
