@@ -17,14 +17,17 @@
 
 package org.apache.poi.hssf.model;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
 
-import junit.framework.AssertionFailedError;
-import junit.framework.TestCase;
-
 import org.apache.poi.ddf.EscherDggRecord;
 import org.apache.poi.hssf.HSSFTestDataSamples;
 import org.apache.poi.hssf.record.BOFRecord;
@@ -59,16 +62,18 @@ import org.apache.poi.hssf.usermodel.HSSFRow;
 import org.apache.poi.hssf.usermodel.HSSFSheet;
 import org.apache.poi.hssf.usermodel.HSSFWorkbook;
 import org.apache.poi.hssf.usermodel.RecordInspector.RecordCollector;
+import org.apache.poi.ss.SpreadsheetVersion;
 import org.apache.poi.ss.formula.FormulaShifter;
 import org.apache.poi.ss.util.CellRangeAddress;
 import org.apache.poi.util.HexRead;
+import org.junit.Test;
+
+import junit.framework.AssertionFailedError;
 
 /**
  * Unit test for the {@link InternalSheet} class.
- *
- * @author Glen Stampoultzis (glens at apache.org)
  */
-public final class TestSheet extends TestCase {
+public final class TestSheet {
 	private static InternalSheet createSheet(List<Record> inRecs) {
 		return InternalSheet.createSheet(new RecordStream(inRecs, 0));
 	}
@@ -79,9 +84,10 @@ public final class TestSheet extends TestCase {
 		return rc.getRecords();
 	}
 
+	@Test
 	public void testCreateSheet() {
 		// Check we're adding row and cell aggregates
-		List<Record> records = new ArrayList<Record>();
+		List<Record> records = new ArrayList<>();
 		records.add(BOFRecord.createSheetBOF());
 		records.add( new DimensionsRecord() );
 		records.add(createWindow2Record());
@@ -114,7 +120,8 @@ public final class TestSheet extends TestCase {
 		public MergedCellListener() {
 			_count = 0;
 		}
-		public void visitRecord(Record r) {
+		@Override
+        public void visitRecord(Record r) {
 			if (r instanceof MergeCellsRecord) {
 				_count++;
 			}
@@ -124,6 +131,7 @@ public final class TestSheet extends TestCase {
 		}
 	}
 
+    @Test
 	public void testAddMergedRegion() {
 		InternalSheet sheet = InternalSheet.createSheet();
 		int regionsToAdd = 4096;
@@ -164,6 +172,7 @@ public final class TestSheet extends TestCase {
 		}
 	}
 
+    @Test
 	public void testRemoveMergedRegion() {
 		InternalSheet sheet = InternalSheet.createSheet();
 		int regionsToAdd = 4096;
@@ -194,8 +203,9 @@ public final class TestSheet extends TestCase {
 	 * fills up the records.
 	 *
 	 */
+    @Test
 	public void testMovingMergedRegion() {
-		List<Record> records = new ArrayList<Record>();
+		List<Record> records = new ArrayList<>();
 
 		CellRangeAddress[] cras = {
 			new CellRangeAddress(0, 1, 0, 2),
@@ -218,10 +228,12 @@ public final class TestSheet extends TestCase {
 		assertEquals("Should be no more merged regions", 0, sheet.getNumMergedRegions());
 	}
 
+    @Test
 	public void testGetMergedRegionAt() {
 		//TODO
 	}
 
+    @Test
 	public void testGetNumMergedRegions() {
 		//TODO
 	}
@@ -230,8 +242,9 @@ public final class TestSheet extends TestCase {
 	 * Makes sure all rows registered for this sheet are aggregated, they were being skipped
 	 *
 	 */
+    @Test
 	public void testRowAggregation() {
-		List<Record> records = new ArrayList<Record>();
+		List<Record> records = new ArrayList<>();
 
 		records.add(InternalSheet.createBOF());
 		records.add(new DimensionsRecord());
@@ -253,6 +266,7 @@ public final class TestSheet extends TestCase {
 	 * Make sure page break functionality works (in memory)
 	 *
 	 */
+    @Test
 	public void testRowPageBreaks() {
 		short colFrom = 0;
 		short colTo = 255;
@@ -283,8 +297,7 @@ public final class TestSheet extends TestCase {
 		boolean is11 = false;
 
 		int[] rowBreaks = sheet.getRowBreaks();
-		for (int i = 0; i < rowBreaks.length; i++) {
-			int main = rowBreaks[i];
+		for (int main : rowBreaks) {
 			if (main != 0 && main != 10 && main != 11) fail("Invalid page break");
 			if (main == 0)	 is0 = true;
 			if (main == 10) is10= true;
@@ -309,6 +322,7 @@ public final class TestSheet extends TestCase {
 	 * Make sure column pag breaks works properly (in-memory)
 	 *
 	 */
+    @Test
 	public void testColPageBreaks() {
 		short rowFrom = 0;
 		short rowTo = (short)65535;
@@ -340,8 +354,7 @@ public final class TestSheet extends TestCase {
 		boolean is15 = false;
 
 		int[] colBreaks = sheet.getColumnBreaks();
-		for (int i = 0; i < colBreaks.length; i++) {
-			int main = colBreaks[i];
+		for (int main : colBreaks) {
 			if (main != 0 && main != 1 && main != 10 && main != 15) fail("Invalid page break");
 			if (main == 0)  is0 = true;
 			if (main == 1)  is1 = true;
@@ -370,6 +383,7 @@ public final class TestSheet extends TestCase {
 	 * test newly added method Sheet.getXFIndexForColAt(..)
 	 * works as designed.
 	 */
+    @Test
 	public void testXFIndexForColumn() {
 		final short TEST_IDX = 10;
 		final short DEFAULT_IDX = 0xF; // 15
@@ -442,7 +456,8 @@ public final class TestSheet extends TestCase {
 		public SizeCheckingRecordVisitor() {
 			_totalSize = 0;
 		}
-		public void visitRecord(Record r) {
+		@Override
+        public void visitRecord(Record r) {
 
 			int estimatedSize=r.getRecordSize();
 			byte[] buf = new byte[estimatedSize];
@@ -459,11 +474,12 @@ public final class TestSheet extends TestCase {
 	}
 	/**
 	 * Prior to bug 45066, POI would get the estimated sheet size wrong
-	 * when an <tt>UncalcedRecord</tt> was present.<p/>
+	 * when an <tt>UncalcedRecord</tt> was present.<p>
 	 */
+    @Test
 	public void testUncalcSize_bug45066() {
 
-		List<Record> records = new ArrayList<Record>();
+		List<Record> records = new ArrayList<>();
 		records.add(BOFRecord.createSheetBOF());
 		records.add(new UncalcedRecord());
 		records.add(new DimensionsRecord());
@@ -482,10 +498,11 @@ public final class TestSheet extends TestCase {
 	/**
 	 * Prior to bug 45145 <tt>RowRecordsAggregate</tt> and <tt>ValueRecordsAggregate</tt> could
 	 * sometimes occur in reverse order.  This test reproduces one of those situations and makes
-	 * sure that RRA comes before VRA.<br/>
+	 * sure that RRA comes before VRA.<br>
 	 *
 	 * The code here represents a normal POI use case where a spreadsheet is created from scratch.
 	 */
+    @Test
 	public void testRowValueAggregatesOrder_bug45145() {
 
 		InternalSheet sheet = InternalSheet.createSheet();
@@ -506,12 +523,12 @@ public final class TestSheet extends TestCase {
 			throw new AssertionFailedError("Identified  bug 45145");
 		}
 
-		if (false) {
-			// make sure that RRA and VRA are in the right place
-			// (Aug 2008) since the VRA is now part of the RRA, there is much less chance that
-			// they could get out of order. Still, one could write serialize the sheet here,
-			// and read back with EventRecordFactory to make sure...
-		}
+//		if (false) {
+//			// make sure that RRA and VRA are in the right place
+//			// (Aug 2008) since the VRA is now part of the RRA, there is much less chance that
+//			// they could get out of order. Still, one could write serialize the sheet here,
+//			// and read back with EventRecordFactory to make sure...
+//		}
 		assertEquals(242, dbCellRecordPos);
 	}
 
@@ -524,8 +541,7 @@ public final class TestSheet extends TestCase {
 		MyIndexRecordListener myIndexListener = new MyIndexRecordListener();
 		sheet.visitContainedRecords(myIndexListener, 0);
 		IndexRecord indexRecord = myIndexListener.getIndexRecord();
-		int dbCellRecordPos = indexRecord.getDbcellAt(0);
-		return dbCellRecordPos;
+        return indexRecord.getDbcellAt(0);
 	}
 
 	private static final class MyIndexRecordListener implements RecordVisitor {
@@ -537,7 +553,8 @@ public final class TestSheet extends TestCase {
 		public IndexRecord getIndexRecord() {
 			return _indexRecord;
 		}
-		public void visitRecord(Record r) {
+		@Override
+        public void visitRecord(Record r) {
 			if (r instanceof IndexRecord) {
 				if (_indexRecord != null) {
 					throw new RuntimeException("too many index records");
@@ -551,6 +568,7 @@ public final class TestSheet extends TestCase {
 	 * Checks for bug introduced around r682282-r683880 that caused a second GUTS records
 	 * which in turn got the dimensions record out of alignment
 	 */
+    @Test
 	public void testGutsRecord_bug45640() {
 
 		InternalSheet sheet = InternalSheet.createSheet();
@@ -571,21 +589,25 @@ public final class TestSheet extends TestCase {
 		assertEquals(1, count);
 	}
 
-	public void testMisplacedMergedCellsRecords_bug45699() {
+    @Test
+	public void testMisplacedMergedCellsRecords_bug45699() throws Exception {
 		HSSFWorkbook wb = HSSFTestDataSamples.openSampleWorkbook("ex45698-22488.xls");
 
 		HSSFSheet sheet = wb.getSheetAt(0);
 		HSSFRow row = sheet.getRow(3);
 		HSSFCell cell = row.getCell(4);
 		if (cell == null) {
-			throw new AssertionFailedError("Identified bug 45699");
+			fail("Identified bug 45699");
 		}
 		assertEquals("Informations", cell.getRichStringCellValue().getString());
+		
+		wb.close();
 	}
 	/**
 	 * In 3.1, setting margins between creating first row and first cell caused an exception.
 	 */
-	public void testSetMargins_bug45717() {
+    @Test
+	public void testSetMargins_bug45717() throws Exception {
 		HSSFWorkbook workbook = new HSSFWorkbook();
 		HSSFSheet sheet = workbook.createSheet("Vorschauliste");
 		HSSFRow row = sheet.createRow(0);
@@ -595,9 +617,11 @@ public final class TestSheet extends TestCase {
 			row.createCell(0);
 		} catch (IllegalStateException e) {
 			if (e.getMessage().equals("Cannot create value records before row records exist")) {
-				throw new AssertionFailedError("Identified bug 45717");
+				fail("Identified bug 45717");
 			}
 			throw e;
+		} finally {
+		    workbook.close();
 		}
 	}
 
@@ -605,6 +629,7 @@ public final class TestSheet extends TestCase {
 	 * Some apps seem to write files with missing DIMENSION records.
 	 * Excel(2007) tolerates this, so POI should too.
 	 */
+    @Test
 	public void testMissingDims() {
 
 		int rowIx = 5;
@@ -614,7 +639,7 @@ public final class TestSheet extends TestCase {
 		nr.setColumn((short) colIx);
 		nr.setValue(3.0);
 
-		List<Record> inRecs = new ArrayList<Record>();
+		List<Record> inRecs = new ArrayList<>();
 		inRecs.add(BOFRecord.createSheetBOF());
 		inRecs.add(new RowRecord(rowIx));
 		inRecs.add(nr);
@@ -648,6 +673,7 @@ public final class TestSheet extends TestCase {
 	 * aggregates. However, since this unnecessary creation helped expose bug 46547b,
 	 * and since there is a slight performance hit the fix was made to avoid it.
 	 */
+    @Test
 	public void testShiftFormulasAddCondFormat_bug46547() {
 		// Create a sheet with data validity (similar to bugzilla attachment id=23131).
 		InternalSheet sheet = InternalSheet.createSheet();
@@ -655,7 +681,7 @@ public final class TestSheet extends TestCase {
 		List<RecordBase> sheetRecs = sheet.getRecords();
 		assertEquals(23, sheetRecs.size());
 
-		FormulaShifter shifter = FormulaShifter.createForRowShift(0, "", 0, 0, 1);
+		FormulaShifter shifter = FormulaShifter.createForRowShift(0, "", 0, 0, 1, SpreadsheetVersion.EXCEL97);
 		sheet.updateFormulasAfterCellShift(shifter, 0);
 		if (sheetRecs.size() == 24 && sheetRecs.get(22) instanceof ConditionalFormattingTable) {
 			throw new AssertionFailedError("Identified bug 46547a");
@@ -666,6 +692,7 @@ public final class TestSheet extends TestCase {
 	 * Bug 46547 happened when attempting to add conditional formatting to a sheet
 	 * which already had data validity constraints.
 	 */
+    @Test
 	public void testAddCondFormatAfterDataValidation_bug46547() {
 		// Create a sheet with data validity (similar to bugzilla attachment id=23131).
 		InternalSheet sheet = InternalSheet.createSheet();
@@ -682,6 +709,7 @@ public final class TestSheet extends TestCase {
 		assertNotNull(cft);
 	}
 
+    @Test
 	public void testCloneMulBlank_bug46776() {
 		Record[]  recs = {
 				InternalSheet.createBOF(),
@@ -711,6 +739,7 @@ public final class TestSheet extends TestCase {
 		assertEquals(recs.length+2, clonedRecs.length); // +2 for INDEX and DBCELL
 	}
 
+    @Test
     public void testCreateAggregate() {
         String msoDrawingRecord1 =
                 "0F 00 02 F0 20 01 00 00 10 00 08 F0 08 00 00 00 \n" +
@@ -747,7 +776,7 @@ public final class TestSheet extends TestCase {
         r2.setStr(new HSSFRichTextString("Aggregated"));
         NoteRecord n2 = new NoteRecord();
 
-        List<Record> recordStream = new ArrayList<Record>();
+        List<Record> recordStream = new ArrayList<>();
         recordStream.add(InternalSheet.createBOF());
         recordStream.add( d1 );
         recordStream.add( r1 );
@@ -757,7 +786,7 @@ public final class TestSheet extends TestCase {
         confirmAggregatedRecords(recordStream);
 
 
-        recordStream = new ArrayList<Record>();
+        recordStream = new ArrayList<>();
         recordStream.add(InternalSheet.createBOF());
         recordStream.add( d1 );
         recordStream.add( r1 );
@@ -768,7 +797,7 @@ public final class TestSheet extends TestCase {
 
         confirmAggregatedRecords(recordStream);
 
-        recordStream = new ArrayList<Record>();
+        recordStream = new ArrayList<>();
         recordStream.add(InternalSheet.createBOF());
         recordStream.add( d1 );
         recordStream.add( r1 );
@@ -798,6 +827,7 @@ public final class TestSheet extends TestCase {
         assertEquals(EOFRecord.sid, ((Record)sheetRecords.get(3)).getSid());
     }
 
+    @Test
     public void testSheetDimensions() throws IOException{
         InternalSheet sheet = InternalSheet.createSheet();
         DimensionsRecord dimensions = (DimensionsRecord)sheet.findFirstRecordBySid(DimensionsRecord.sid);
