@@ -26,7 +26,7 @@ import junit.framework.TestCase;
  * @author Yegor Kozlov
  */
 public final class TestAutoFilterInfoRecord extends TestCase {
-    private byte[] data = new byte[] {
+    private final byte[] data = new byte[] {
         0x05, 0x00
     };
 
@@ -57,7 +57,7 @@ public final class TestAutoFilterInfoRecord extends TestCase {
         record.setNumEntries((short)3);
         byte[] src = record.serialize();
 
-        AutoFilterInfoRecord cloned = (AutoFilterInfoRecord)record.clone();
+        AutoFilterInfoRecord cloned = record.clone();
         assertEquals(3, record.getNumEntries());
         byte[] cln = cloned.serialize();
 
