@@ -33,7 +33,6 @@ public final class TestDrawingRecord extends TestCase {
      * Check that RecordFactoryInputStream properly handles continued DrawingRecords
      * See Bugzilla #47548
      */
-    @SuppressWarnings("deprecation")
     public void testReadContinued() throws IOException {
 
         //simulate a continues drawing record
@@ -56,7 +55,7 @@ public final class TestDrawingRecord extends TestCase {
         assertTrue(rec.get(0) instanceof DrawingRecord);
         assertTrue(rec.get(1) instanceof ContinueRecord);
 
-        assertArrayEquals(data1, ((DrawingRecord)rec.get(0)).getData());
+        assertArrayEquals(data1, ((DrawingRecord)rec.get(0)).getRecordData());
         assertArrayEquals(data2, ((ContinueRecord)rec.get(1)).getData());
 
     }
