@@ -28,7 +28,7 @@ import junit.framework.TestCase;
  * @author Yegor Kozlov
  */
 public final class TestFtCblsSubRecord extends TestCase {
-    private byte[] data = new byte[] {
+    private final byte[] data = new byte[] {
         0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x64, 0x00,
         0x01, 0x00, 0x0A, 0x00, 0x00, 0x00, 0x10, 0x00, 0x01, 0x00
     };
@@ -56,7 +56,7 @@ public final class TestFtCblsSubRecord extends TestCase {
         FtCblsSubRecord record = new FtCblsSubRecord();
         byte[] src = record.serialize();
 
-        FtCblsSubRecord cloned = (FtCblsSubRecord)record.clone();
+        FtCblsSubRecord cloned = record.clone();
         byte[] cln = cloned.serialize();
 
         assertEquals(record.getDataSize(), cloned.getDataSize());
