@@ -17,17 +17,15 @@
 
 package org.apache.poi.hssf.record.aggregates;
 
-import static org.junit.Assert.assertArrayEquals;
+import static org.junit.Assert.*;
 
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.List;
 import java.util.zip.CRC32;
 
-import junit.framework.AssertionFailedError;
-import junit.framework.TestCase;
-
 import org.apache.poi.hssf.HSSFTestDataSamples;
 import org.apache.poi.hssf.model.RecordStream;
 import org.apache.poi.hssf.model.RowBlocksReader;
@@ -39,35 +37,45 @@ import org.apache.poi.hssf.record.Record;
 import org.apache.poi.hssf.record.SharedFormulaRecord;
 import org.apache.poi.hssf.record.WindowTwoRecord;
 import org.apache.poi.hssf.record.aggregates.RecordAggregate.RecordVisitor;
-import org.apache.poi.hssf.usermodel.HSSFRow;
 import org.apache.poi.hssf.usermodel.HSSFSheet;
 import org.apache.poi.hssf.usermodel.HSSFWorkbook;
 import org.apache.poi.util.HexRead;
+import org.junit.Test;
+
+import junit.framework.AssertionFailedError;
 
 /**
  * Tests for {@link ValueRecordsAggregate}
  */
-public final class TestValueRecordsAggregate extends TestCase {
+public final class TestValueRecordsAggregate {
 	private static final String ABNORMAL_SHARED_FORMULA_FLAG_TEST_FILE = "AbnormalSharedFormulaFlag.xls";
 	private final ValueRecordsAggregate valueRecord = new ValueRecordsAggregate();
+	
+	private List<CellValueRecordInterface> getValueRecords() {
+	    List<CellValueRecordInterface> list = new ArrayList<>();
+	    for ( CellValueRecordInterface rec : valueRecord ) {
+	        list.add(rec);
+	    }
+	    return Collections.unmodifiableList(list);
+	}
 
 	/**
 	 * Make sure the shared formula DOESNT makes it to the FormulaRecordAggregate when being parsed
 	 * as part of the value records
 	 */
-    @SuppressWarnings("deprecation") // uses deprecated {@link ValueRecordsAggregate#getValueRecords()}
+    @Test
 	public void testSharedFormula() {
-		List<Record> records = new ArrayList<Record>();
+		List<Record> records = new ArrayList<>();
 		records.add(new FormulaRecord());
 		records.add(new SharedFormulaRecord());
 		records.add(new WindowTwoRecord());
 
 		constructValueRecord(records);
-		CellValueRecordInterface[] cvrs = valueRecord.getValueRecords();
+		List<CellValueRecordInterface> cvrs = getValueRecords();
 		//Ensure that the SharedFormulaRecord has been converted
-		assertEquals(1, cvrs.length);
+		assertEquals(1, cvrs.size());
 
-		CellValueRecordInterface record = cvrs[0];
+		CellValueRecordInterface record = cvrs.get(0);
 		assertNotNull( "Row contains a value", record );
 		assertTrue( "First record is a FormulaRecordsAggregate", ( record instanceof FormulaRecordAggregate ) );
 	}
@@ -83,7 +91,7 @@ public final class TestValueRecordsAggregate extends TestCase {
 	}
 
 	private static List<Record> testData() {
-		List<Record> records = new ArrayList<Record>();
+		List<Record> records = new ArrayList<>();
 		FormulaRecord formulaRecord = new FormulaRecord();
 		BlankRecord blankRecord = new BlankRecord();
 		formulaRecord.setRow(1);
@@ -96,30 +104,28 @@ public final class TestValueRecordsAggregate extends TestCase {
 		return records;
 	}
 
-    @SuppressWarnings("deprecation") // uses deprecated {@link ValueRecordsAggregate#getValueRecords()}
+    @Test
 	public void testInsertCell() {
-		CellValueRecordInterface[] cvrs = valueRecord.getValueRecords();
-		assertEquals(0, cvrs.length);
+		assertEquals(0, getValueRecords().size());
 
 		BlankRecord blankRecord = newBlankRecord();
 		valueRecord.insertCell( blankRecord );
-		cvrs = valueRecord.getValueRecords();
-		assertEquals(1, cvrs.length);
+		assertEquals(1, getValueRecords().size());
 	}
 
-    @SuppressWarnings("deprecation") // uses deprecated {@link ValueRecordsAggregate#getValueRecords()}
-	public void testRemoveCell() {
+    @Test
+    public void testRemoveCell() {
 		BlankRecord blankRecord1 = newBlankRecord();
 		valueRecord.insertCell( blankRecord1 );
 		BlankRecord blankRecord2 = newBlankRecord();
 		valueRecord.removeCell( blankRecord2 );
-		CellValueRecordInterface[] cvrs = valueRecord.getValueRecords();
-		assertEquals(0, cvrs.length);
+		assertEquals(0, getValueRecords().size());
 
 		// removing an already empty cell just falls through
 		valueRecord.removeCell( blankRecord2 );
 	}
 
+    @Test
 	public void testGetPhysicalNumberOfCells() {
 		assertEquals(0, valueRecord.getPhysicalNumberOfCells());
 		BlankRecord blankRecord1 = newBlankRecord();
@@ -129,6 +135,7 @@ public final class TestValueRecordsAggregate extends TestCase {
 		assertEquals(0, valueRecord.getPhysicalNumberOfCells());
 	}
 
+    @Test
 	public void testGetFirstCellNum() {
 		assertEquals( -1, valueRecord.getFirstCellNum() );
 		valueRecord.insertCell( newBlankRecord( 2, 2 ) );
@@ -141,6 +148,7 @@ public final class TestValueRecordsAggregate extends TestCase {
 		assertEquals( 2, valueRecord.getFirstCellNum() );
 	}
 
+    @Test
 	public void testGetLastCellNum() {
 		assertEquals( -1, valueRecord.getLastCellNum() );
 		valueRecord.insertCell( newBlankRecord( 2, 2 ) );
@@ -163,7 +171,8 @@ public final class TestValueRecordsAggregate extends TestCase {
 			_writeIndex = 0;
 
 		}
-		public void visitRecord(Record r) {
+		@Override
+        public void visitRecord(Record r) {
 			r.serialize(_writeIndex, _buf);
 			_writeIndex += r.getRecordSize();
 		}
@@ -172,6 +181,7 @@ public final class TestValueRecordsAggregate extends TestCase {
 		}
 	}
 
+    @Test
 	public void testSerialize() {
 		byte[] expectedArray = HexRead.readFromString(""
 				+ "06 00 16 00 " // Formula
@@ -204,17 +214,17 @@ public final class TestValueRecordsAggregate extends TestCase {
 	 * Sometimes the 'shared formula' flag (<tt>FormulaRecord.isSharedFormula()</tt>) is set when
 	 * there is no corresponding SharedFormulaRecord available. SharedFormulaRecord definitions do
 	 * not span multiple sheets.  They are are only defined within a sheet, and thus they do not
-	 * have a sheet index field (only row and column range fields).<br/>
+	 * have a sheet index field (only row and column range fields).<br>
 	 * So it is important that the code which locates the SharedFormulaRecord for each
 	 * FormulaRecord does not allow matches across sheets.</br>
 	 *
 	 * Prior to bugzilla 44449 (Feb 2008), POI <tt>ValueRecordsAggregate.construct(int, List)</tt>
 	 * allowed <tt>SharedFormulaRecord</tt>s to be erroneously used across sheets.  That incorrect
-	 * behaviour is shown by this test.<p/>
+	 * behaviour is shown by this test.<p>
 	 *
 	 * <b>Notes on how to produce the test spreadsheet</b>:</p>
 	 * The setup for this test (AbnormalSharedFormulaFlag.xls) is rather fragile, insomuchas
-	 * re-saving the file (either with Excel or POI) clears the flag.<br/>
+	 * re-saving the file (either with Excel or POI) clears the flag.<br>
 	 * <ol>
 	 * <li>A new spreadsheet was created in Excel (File | New | Blank Workbook).</li>
 	 * <li>Sheet3 was deleted.</li>
@@ -224,13 +234,14 @@ public final class TestValueRecordsAggregate extends TestCase {
 	 * <li>The spreadsheet was saved as AbnormalSharedFormulaFlag.xls.</li>
 	 * </ol>
 	 * Prior to the row delete action the spreadsheet has two <tt>SharedFormulaRecord</tt>s. One
-	 * for each sheet. To expose the bug, the shared formulas have been made to overlap.<br/>
+	 * for each sheet. To expose the bug, the shared formulas have been made to overlap.<br>
 	 * The row delete action (as described here) seems to to delete the
-	 * <tt>SharedFormulaRecord</tt> from Sheet1 (but not clear the 'shared formula' flags.<br/>
+	 * <tt>SharedFormulaRecord</tt> from Sheet1 (but not clear the 'shared formula' flags.<br>
 	 * There are other variations on this theme to create the same effect.
 	 *
 	 */
-	public void testSpuriousSharedFormulaFlag() {
+    @Test
+	public void testSpuriousSharedFormulaFlag() throws Exception {
 
 		long actualCRC = getFileCRC(HSSFTestDataSamples.openSampleFileStream(ABNORMAL_SHARED_FORMULA_FLAG_TEST_FILE));
 		long expectedCRC = 2277445406L;
@@ -245,18 +256,15 @@ public final class TestValueRecordsAggregate extends TestCase {
 		String cellFormula;
 		cellFormula = getFormulaFromFirstCell(s, 0); // row "1"
 		// the problem is not observable in the first row of the shared formula
-		if(!cellFormula.equals("\"first formula\"")) {
-			throw new RuntimeException("Something else wrong with this test case");
-		}
+		assertEquals("Something else wrong with this test case", "\"first formula\"", cellFormula);
 
 		// but the problem is observable in rows 2,3,4
 		cellFormula = getFormulaFromFirstCell(s, 1); // row "2"
-		if(cellFormula.equals("\"second formula\"")) {
-			throw new AssertionFailedError("found bug 44449 (Wrong SharedFormulaRecord was used).");
-		}
-		if(!cellFormula.equals("\"first formula\"")) {
-			throw new RuntimeException("Something else wrong with this test case");
-		}
+		assertNotEquals("found bug 44449 (Wrong SharedFormulaRecord was used).", "\"second formula\"", cellFormula);
+
+		assertEquals("Something else wrong with this test case", "\"first formula\"", cellFormula);
+		
+		wb.close();
 	}
 	private static String getFormulaFromFirstCell(HSSFSheet s, int rowIx) {
 		return s.getRow(rowIx).getCell(0).getCellFormula();
@@ -302,6 +310,8 @@ public final class TestValueRecordsAggregate extends TestCase {
 
 		return crc.getValue();
 	}
+	
+    @Test
 	public void testRemoveNewRow_bug46312() {
 		// To make bug occur, rowIndex needs to be >= ValueRecordsAggregate.records.length
 		int rowIndex = 30;
@@ -316,26 +326,27 @@ public final class TestValueRecordsAggregate extends TestCase {
 			throw e;
 		}
 
-		if (false) { // same bug as demonstrated through usermodel API
-
-			HSSFWorkbook wb = new HSSFWorkbook();
-			HSSFSheet sheet = wb.createSheet();
-			HSSFRow row = sheet.createRow(rowIndex);
-			if (false) { // must not add any cells to the new row if we want to see the bug
-				row.createCell(0); // this causes ValueRecordsAggregate.records to auto-extend
-			}
-			try {
-				sheet.createRow(rowIndex);
-			} catch (IllegalArgumentException e) {
-				throw new AssertionFailedError("Identified bug 46312");
-			}
-		}
+//		if (false) { // same bug as demonstrated through usermodel API
+//
+//			HSSFWorkbook wb = new HSSFWorkbook();
+//			HSSFSheet sheet = wb.createSheet();
+//			HSSFRow row = sheet.createRow(rowIndex);
+//			if (false) { // must not add any cells to the new row if we want to see the bug
+//				row.createCell(0); // this causes ValueRecordsAggregate.records to auto-extend
+//			}
+//			try {
+//				sheet.createRow(rowIndex);
+//			} catch (IllegalArgumentException e) {
+//				throw new AssertionFailedError("Identified bug 46312");
+//			}
+//		}
 	}
 
 	/**
 	 * Tests various manipulations of blank cells, to make sure that {@link MulBlankRecord}s
 	 * are use appropriately
 	 */
+    @Test
 	public void testMultipleBlanks() {
 		BlankRecord brA2 = newBlankRecord(0, 1);
 		BlankRecord brB2 = newBlankRecord(1, 1);
@@ -386,7 +397,8 @@ public final class TestValueRecordsAggregate extends TestCase {
 		final BlankStats bs = new BlankStats();
 		RecordVisitor rv = new RecordVisitor() {
 
-			public void visitRecord(Record r) {
+			@Override
+            public void visitRecord(Record r) {
 				if (r instanceof MulBlankRecord) {
 					MulBlankRecord mbr = (MulBlankRecord) r;
 					bs.countMulBlankRecords++;
