@@ -23,20 +23,25 @@ import java.io.IOException;
 import java.util.Calendar;
 import java.util.Date;
 
-import junit.framework.TestCase;
-
 import org.apache.poi.hssf.HSSFTestDataSamples;
+import org.apache.poi.ss.usermodel.BorderStyle;
 import org.apache.poi.ss.usermodel.Cell;
 import org.apache.poi.ss.usermodel.CellStyle;
+import org.apache.poi.ss.usermodel.CellType;
+import org.apache.poi.ss.usermodel.FillPatternType;
+import org.apache.poi.ss.usermodel.Font;
+import org.apache.poi.ss.usermodel.HorizontalAlignment;
 import org.apache.poi.ss.usermodel.Row;
 import org.apache.poi.ss.usermodel.Sheet;
 import org.apache.poi.ss.usermodel.Workbook;
+import org.apache.poi.util.LocaleUtil;
 import org.apache.poi.util.TempFile;
+import org.junit.Test;
+
+import junit.framework.TestCase;
 
 /**
  * Class to test cell styling functionality
- *
- * @author Andrew C. Oliver
  */
 
 public final class TestCellStyle extends TestCase {
@@ -67,7 +72,7 @@ public final class TestCellStyle extends TestCase {
         HSSFCellStyle    cs   = wb.createCellStyle();
 
         fnt.setColor(HSSFFont.COLOR_RED);
-        fnt.setBoldweight(HSSFFont.BOLDWEIGHT_BOLD);
+        fnt.setBold(true);
         cs.setFont(fnt);
         for (int rownum = 0; rownum < 100; rownum++) {
             r = s.createRow(rownum);
@@ -114,8 +119,7 @@ public final class TestCellStyle extends TestCase {
         cell = row.createCell(2);
         cs.setDataFormat(HSSFDataFormat.getBuiltinFormat("m/d/yy"));
         cell.setCellStyle(cs);
-        Calendar cal = Calendar.getInstance();
-        cal.setTime(new Date());
+        Calendar cal = LocaleUtil.getLocaleCalendar();
         cell.setCellValue(cal);
 
         wb.write(out);
@@ -127,7 +131,7 @@ public final class TestCellStyle extends TestCase {
         assertEquals("FIRST ROW ", 0, s.getFirstRowNum());
     }
     
-    public void testHashEquals() {
+    public void testHashEquals() throws IOException {
         HSSFWorkbook     wb   = new HSSFWorkbook();
         HSSFSheet        s    = wb.createSheet();
         HSSFCellStyle    cs1  = wb.createCellStyle();
@@ -154,6 +158,8 @@ public final class TestCellStyle extends TestCase {
         int hash1 = cs1.hashCode();
         cs1.setDataFormat(HSSFDataFormat.getBuiltinFormat("m/dd/yy"));
         assertFalse(hash1 == cs1.hashCode());
+        
+        wb.close();
     }
 
     /**
@@ -178,16 +184,16 @@ public final class TestCellStyle extends TestCase {
         HSSFCellStyle    cs   = wb.createCellStyle();
         HSSFCellStyle    cs2  = wb.createCellStyle();
 
-        cs.setBorderBottom(HSSFCellStyle.BORDER_THIN);
-        cs.setBorderLeft(HSSFCellStyle.BORDER_THIN);
-        cs.setBorderRight(HSSFCellStyle.BORDER_THIN);
-        cs.setBorderTop(HSSFCellStyle.BORDER_THIN);
+        cs.setBorderBottom(BorderStyle.THIN);
+        cs.setBorderLeft(BorderStyle.THIN);
+        cs.setBorderRight(BorderStyle.THIN);
+        cs.setBorderTop(BorderStyle.THIN);
         cs.setFillForegroundColor(( short ) 0xA);
-        cs.setFillPattern(( short ) 1);
+        cs.setFillPattern(FillPatternType.DIAMONDS);
         fnt.setColor(( short ) 0xf);
         fnt.setItalic(true);
         cs2.setFillForegroundColor(( short ) 0x0);
-        cs2.setFillPattern(( short ) 1);
+        cs2.setFillPattern(FillPatternType.DIAMONDS);
         cs2.setFont(fnt);
         for (int rownum = 0; rownum < 100; rownum++) {
             r = s.createRow(rownum);
@@ -222,23 +228,23 @@ public final class TestCellStyle extends TestCase {
         assertEquals(5, wb.getNumberOfFonts());
         
         HSSFCellStyle orig = wb.createCellStyle();
-        orig.setAlignment(HSSFCellStyle.ALIGN_RIGHT);
+        orig.setAlignment(HorizontalAlignment.JUSTIFY);
         orig.setFont(fnt);
         orig.setDataFormat((short)18);
         
-        assertTrue(HSSFCellStyle.ALIGN_RIGHT == orig.getAlignment());
-        assertTrue(fnt == orig.getFont(wb));
-        assertTrue(18 == orig.getDataFormat());
+        assertEquals(HorizontalAlignment.JUSTIFY, orig.getAlignment());
+        assertEquals(fnt, orig.getFont(wb));
+        assertEquals(18, orig.getDataFormat());
         
         HSSFCellStyle clone = wb.createCellStyle();
-        assertFalse(HSSFCellStyle.ALIGN_RIGHT == clone.getAlignment());
+        assertFalse(HorizontalAlignment.RIGHT == clone.getAlignment());
         assertFalse(fnt == clone.getFont(wb));
         assertFalse(18 == clone.getDataFormat());
         
         clone.cloneStyleFrom(orig);
-        assertTrue(HSSFCellStyle.ALIGN_RIGHT == clone.getAlignment());
-        assertTrue(fnt == clone.getFont(wb));
-        assertTrue(18 == clone.getDataFormat());
+        assertEquals(HorizontalAlignment.JUSTIFY, clone.getAlignment());
+        assertEquals(fnt, clone.getFont(wb));
+        assertEquals(18, clone.getDataFormat());
         assertEquals(5, wb.getNumberOfFonts());
     }
     
@@ -258,13 +264,13 @@ public final class TestCellStyle extends TestCase {
         fmt.getFormat("MadeUpTwo");
         
         HSSFCellStyle orig = wbOrig.createCellStyle();
-        orig.setAlignment(HSSFCellStyle.ALIGN_RIGHT);
+        orig.setAlignment(HorizontalAlignment.RIGHT);
         orig.setFont(fnt);
         orig.setDataFormat(fmt.getFormat("Test##"));
         
-        assertTrue(HSSFCellStyle.ALIGN_RIGHT == orig.getAlignment());
-        assertTrue(fnt == orig.getFont(wbOrig));
-        assertTrue(fmt.getFormat("Test##") == orig.getDataFormat());
+        assertEquals(HorizontalAlignment.RIGHT, orig.getAlignment());
+        assertEquals(fnt, orig.getFont(wbOrig));
+        assertEquals(fmt.getFormat("Test##"), orig.getDataFormat());
         
         // Now a style on another workbook
         HSSFWorkbook wbClone = new HSSFWorkbook();
@@ -274,13 +280,13 @@ public final class TestCellStyle extends TestCase {
         HSSFCellStyle clone = wbClone.createCellStyle();
         assertEquals(4, wbClone.getNumberOfFonts());
         
-        assertFalse(HSSFCellStyle.ALIGN_RIGHT == clone.getAlignment());
+        assertFalse(HorizontalAlignment.RIGHT == clone.getAlignment());
         assertFalse("TestingFont" == clone.getFont(wbClone).getFontName());
         
         clone.cloneStyleFrom(orig);
-        assertTrue(HSSFCellStyle.ALIGN_RIGHT == clone.getAlignment());
-        assertTrue("TestingFont" == clone.getFont(wbClone).getFontName());
-        assertTrue(fmtClone.getFormat("Test##") == clone.getDataFormat());
+        assertEquals(HorizontalAlignment.RIGHT, clone.getAlignment());
+        assertEquals("TestingFont", clone.getFont(wbClone).getFontName());
+        assertEquals(fmtClone.getFormat("Test##"), clone.getDataFormat());
         assertFalse(fmtClone.getFormat("Test##") == fmt.getFormat("Test##"));
         assertEquals(5, wbClone.getNumberOfFonts());
     }
@@ -344,40 +350,40 @@ public final class TestCellStyle extends TestCase {
     	HSSFCellStyle cs;
 
     	cs = s.getRow(0).getCell(0).getCellStyle();
-    	assertEquals(CellStyle.BORDER_HAIR, cs.getBorderRight());
+    	assertEquals(BorderStyle.HAIR, cs.getBorderRight());
 
     	cs = s.getRow(1).getCell(1).getCellStyle();
-    	assertEquals(CellStyle.BORDER_DOTTED, cs.getBorderRight());
+    	assertEquals(BorderStyle.DOTTED, cs.getBorderRight());
 
     	cs = s.getRow(2).getCell(2).getCellStyle();
-    	assertEquals(CellStyle.BORDER_DASH_DOT_DOT, cs.getBorderRight());
+    	assertEquals(BorderStyle.DASH_DOT_DOT, cs.getBorderRight());
 
     	cs = s.getRow(3).getCell(3).getCellStyle();
-    	assertEquals(CellStyle.BORDER_DASHED, cs.getBorderRight());
+    	assertEquals(BorderStyle.DASHED, cs.getBorderRight());
 
     	cs = s.getRow(4).getCell(4).getCellStyle();
-    	assertEquals(CellStyle.BORDER_THIN, cs.getBorderRight());
+    	assertEquals(BorderStyle.THIN, cs.getBorderRight());
 
     	cs = s.getRow(5).getCell(5).getCellStyle();
-    	assertEquals(CellStyle.BORDER_MEDIUM_DASH_DOT_DOT, cs.getBorderRight());
+    	assertEquals(BorderStyle.MEDIUM_DASH_DOT_DOT, cs.getBorderRight());
 
     	cs = s.getRow(6).getCell(6).getCellStyle();
-    	assertEquals(CellStyle.BORDER_SLANTED_DASH_DOT, cs.getBorderRight());
+    	assertEquals(BorderStyle.SLANTED_DASH_DOT, cs.getBorderRight());
 
     	cs = s.getRow(7).getCell(7).getCellStyle();
-    	assertEquals(CellStyle.BORDER_MEDIUM_DASH_DOT, cs.getBorderRight());
+    	assertEquals(BorderStyle.MEDIUM_DASH_DOT, cs.getBorderRight());
 
     	cs = s.getRow(8).getCell(8).getCellStyle();
-    	assertEquals(CellStyle.BORDER_MEDIUM_DASHED, cs.getBorderRight());
+    	assertEquals(BorderStyle.MEDIUM_DASHED, cs.getBorderRight());
 
     	cs = s.getRow(9).getCell(9).getCellStyle();
-    	assertEquals(CellStyle.BORDER_MEDIUM, cs.getBorderRight());
+    	assertEquals(BorderStyle.MEDIUM, cs.getBorderRight());
 
     	cs = s.getRow(10).getCell(10).getCellStyle();
-    	assertEquals(CellStyle.BORDER_THICK, cs.getBorderRight());
+    	assertEquals(BorderStyle.THICK, cs.getBorderRight());
 
     	cs = s.getRow(11).getCell(11).getCellStyle();
-    	assertEquals(CellStyle.BORDER_DOUBLE, cs.getBorderRight());
+    	assertEquals(BorderStyle.DOUBLE, cs.getBorderRight());
     }
 
     public void testShrinkToFit() {
@@ -413,8 +419,8 @@ public final class TestCellStyle extends TestCase {
     
     
     private static class CellFormatBugExample extends Thread {
-        private String fileName;
-        private Throwable exception = null;
+        private final String fileName;
+        private Throwable exception;
 
         public CellFormatBugExample(String fileName) {
             this.fileName = fileName;
@@ -432,10 +438,10 @@ public final class TestCellStyle extends TestCase {
         
                             Cell cell = row.getCell(idxCell);
                             cell.getCellStyle().getDataFormatString();
-                            if (cell.getCellType() == HSSFCell.CELL_TYPE_NUMERIC) {
+                            if (cell.getCellType() == CellType.NUMERIC) {
                                 boolean isDate = HSSFDateUtil.isCellDateFormatted(cell);
                                 if (idxCell > 0 && isDate) {
-                                    fail("cell " + idxCell + " is not a date: " + idxCell.toString());
+                                    fail("cell " + idxCell + " is not a date: " + idxCell);
                                 }
                             }
                         }
@@ -449,8 +455,8 @@ public final class TestCellStyle extends TestCase {
         public Throwable getException() {
             return exception;
         }
-    };
-    
+    }
+
     public void test56563() throws Throwable {
         CellFormatBugExample threadA = new CellFormatBugExample("56563a.xls");
         threadA.start();
@@ -467,4 +473,79 @@ public final class TestCellStyle extends TestCase {
             throw threadB.getException();
         }
     }
+    
+    public void test56959() throws IOException {
+        Workbook wb = new HSSFWorkbook();
+        Sheet sheet = wb.createSheet("somesheet");
+        
+        Row row = sheet.createRow(0);
+        
+        // Create a new font and alter it.
+        Font font = wb.createFont();
+        font.setFontHeightInPoints((short)24);
+        font.setFontName("Courier New");
+        font.setItalic(true);
+        font.setStrikeout(true);
+        font.setColor(Font.COLOR_RED);
+        
+        CellStyle style = wb.createCellStyle();
+        style.setBorderBottom(BorderStyle.DOTTED);
+        style.setFont(font);
+        
+        Cell cell = row.createCell(0);
+        cell.setCellStyle(style);
+        cell.setCellValue("testtext");
+        
+        Cell newCell = row.createCell(1);
+        
+        newCell.setCellStyle(style);
+        newCell.setCellValue("2testtext2");
+
+        CellStyle newStyle = newCell.getCellStyle();
+        assertEquals(BorderStyle.DOTTED, newStyle.getBorderBottom());
+        assertEquals(Font.COLOR_RED, ((HSSFCellStyle)newStyle).getFont(wb).getColor());
+        
+//        OutputStream out = new FileOutputStream("/tmp/56959.xls");
+//        try {
+//            wb.write(out);
+//        } finally {
+//            out.close();
+//        }
+    }
+
+
+    @Test
+    public void test58043() throws IOException {
+        HSSFWorkbook     wb   = new HSSFWorkbook();
+        HSSFCellStyle    cellStyle   = wb.createCellStyle();
+
+        assertEquals(0, cellStyle.getRotation());
+
+        cellStyle.setRotation((short)89);
+        assertEquals(89, cellStyle.getRotation());
+        
+        cellStyle.setRotation((short)90);
+        assertEquals(90, cellStyle.getRotation());
+        
+        cellStyle.setRotation((short)-1);
+        assertEquals(-1, cellStyle.getRotation());
+        
+        cellStyle.setRotation((short)-89);
+        assertEquals(-89, cellStyle.getRotation());
+        
+        cellStyle.setRotation((short)-90);
+        assertEquals(-90, cellStyle.getRotation());
+        
+        cellStyle.setRotation((short)-89);
+        assertEquals(-89, cellStyle.getRotation());
+
+        // values above 90 are mapped to the correct values for compatibility between HSSF and XSSF
+        cellStyle.setRotation((short)179);
+        assertEquals(-89, cellStyle.getRotation());
+        
+        cellStyle.setRotation((short)180);
+        assertEquals(-90, cellStyle.getRotation());
+        
+        wb.close();
+    }
 }
