@@ -17,11 +17,15 @@
 
 package org.apache.poi.hssf.usermodel;
 
-import java.io.IOException;
-import java.util.Date;
-import java.util.GregorianCalendar;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.fail;
 
-import junit.framework.AssertionFailedError;
+import java.io.IOException;
+import java.util.Calendar;
+import java.util.Date;
 
 import org.apache.poi.hssf.HSSFITestDataProvider;
 import org.apache.poi.hssf.HSSFTestDataSamples;
@@ -32,18 +36,20 @@ import org.apache.poi.hssf.record.Record;
 import org.apache.poi.hssf.record.StringRecord;
 import org.apache.poi.ss.usermodel.BaseTestCell;
 import org.apache.poi.ss.usermodel.Cell;
+import org.apache.poi.ss.usermodel.CellType;
 import org.apache.poi.ss.usermodel.FormulaError;
 import org.apache.poi.ss.usermodel.RichTextString;
 import org.apache.poi.ss.usermodel.Row;
 import org.apache.poi.ss.usermodel.Sheet;
 import org.apache.poi.ss.usermodel.Workbook;
+import org.apache.poi.util.LocaleUtil;
+import org.junit.Test;
+
+import junit.framework.AssertionFailedError;
 
 /**
  * Tests various functionality having to do with {@link HSSFCell}.  For instance support for
  * particular datatypes, etc.
- * @author Andrew C. Oliver (andy at superlinksoftware dot com)
- * @author  Dan Sherman (dsherman at isisph.com)
- * @author Alex Jacoby (ajacoby at gmail.com)
  */
 public final class TestHSSFCell extends BaseTestCell {
 
@@ -56,25 +62,28 @@ public final class TestHSSFCell extends BaseTestCell {
 	 *  is working properly. Conversion of the date is also an issue,
 	 *  but there's a separate unit test for that.
 	 */
-	public void testDateWindowingRead() {
-		GregorianCalendar cal = new GregorianCalendar(2000,0,1); // Jan. 1, 2000
+	@Test
+	public void testDateWindowingRead() throws IOException {
+	    Calendar cal = LocaleUtil.getLocaleCalendar(2000, 0, 1, 0, 0, 0);// Jan. 1, 2000
 		Date date = cal.getTime();
 
 		// first check a file with 1900 Date Windowing
-		HSSFWorkbook workbook = HSSFTestDataSamples.openSampleWorkbook("1900DateWindowing.xls");
-		HSSFSheet sheet = workbook.getSheetAt(0);
+		HSSFWorkbook wb = HSSFTestDataSamples.openSampleWorkbook("1900DateWindowing.xls");
+		HSSFSheet sheet = wb.getSheetAt(0);
 
 		assertEquals("Date from file using 1900 Date Windowing",
 				date.getTime(),
 				sheet.getRow(0).getCell(0).getDateCellValue().getTime());
+		wb.close();
 
 		// now check a file with 1904 Date Windowing
-		workbook = HSSFTestDataSamples.openSampleWorkbook("1904DateWindowing.xls");
-		sheet	= workbook.getSheetAt(0);
+		wb = HSSFTestDataSamples.openSampleWorkbook("1904DateWindowing.xls");
+		sheet	= wb.getSheetAt(0);
 
 		assertEquals("Date from file using 1904 Date Windowing",
 				date.getTime(),
 				sheet.getRow(0).getCell(0).getDateCellValue().getTime());
+		wb.close();
 	}
 
 
@@ -85,28 +94,32 @@ public final class TestHSSFCell extends BaseTestCell {
 	 * previous test ({@link #testDateWindowingRead}) fails, the
 	 * results of this test are meaningless.
 	 */
-	public void testDateWindowingWrite() {
-		GregorianCalendar cal = new GregorianCalendar(2000,0,1); // Jan. 1, 2000
+	@Test
+	public void testDateWindowingWrite() throws IOException {
+	    Calendar cal = LocaleUtil.getLocaleCalendar(2000,0,1,0,0,0); // Jan. 1, 2000
 		Date date = cal.getTime();
 
 		// first check a file with 1900 Date Windowing
-		HSSFWorkbook wb;
-		wb = HSSFTestDataSamples.openSampleWorkbook("1900DateWindowing.xls");
+		HSSFWorkbook wb1 = HSSFTestDataSamples.openSampleWorkbook("1900DateWindowing.xls");
 
-		setCell(wb, 0, 1, date);
-		wb = HSSFTestDataSamples.writeOutAndReadBack(wb);
+		setCell(wb1, 0, 1, date);
+		HSSFWorkbook wb2 = HSSFTestDataSamples.writeOutAndReadBack(wb1);
 
 		assertEquals("Date from file using 1900 Date Windowing",
 				date.getTime(),
-				readCell(wb, 0, 1).getTime());
+				readCell(wb2, 0, 1).getTime());
+        wb1.close();
+		wb2.close();
 
 		// now check a file with 1904 Date Windowing
-		wb = HSSFTestDataSamples.openSampleWorkbook("1904DateWindowing.xls");
-		setCell(wb, 0, 1, date);
-		wb = HSSFTestDataSamples.writeOutAndReadBack(wb);
+		wb1 = HSSFTestDataSamples.openSampleWorkbook("1904DateWindowing.xls");
+		setCell(wb1, 0, 1, date);
+		wb2 = HSSFTestDataSamples.writeOutAndReadBack(wb1);
 		assertEquals("Date from file using 1900 Date Windowing",
 				date.getTime(),
-				readCell(wb, 0, 1).getTime());
+				readCell(wb2, 0, 1).getTime());
+        wb1.close();
+        wb2.close();
 	}
 
 	private static void setCell(HSSFWorkbook workbook, int rowIdx, int colIdx, Date date) {
@@ -130,12 +143,13 @@ public final class TestHSSFCell extends BaseTestCell {
 	/**
 	 * Tests that the active cell can be correctly read and set
 	 */
-	public void testActiveCell() {
+	@Test
+	public void testActiveCell() throws IOException {
 		//read in sample
-		HSSFWorkbook book = HSSFTestDataSamples.openSampleWorkbook("Simple.xls");
+		HSSFWorkbook wb1 = HSSFTestDataSamples.openSampleWorkbook("Simple.xls");
 
 		//check initial position
-		HSSFSheet umSheet = book.getSheetAt(0);
+		HSSFSheet umSheet = wb1.getSheetAt(0);
 		InternalSheet s = umSheet.getSheet();
 		assertEquals("Initial active cell should be in col 0",
 			(short) 0, s.getActiveCellCol());
@@ -151,18 +165,22 @@ public final class TestHSSFCell extends BaseTestCell {
 			3, s.getActiveCellRow());
 
 		//write book to temp file; read and verify that position is serialized
-		book = HSSFTestDataSamples.writeOutAndReadBack(book);
+		HSSFWorkbook wb2 = HSSFTestDataSamples.writeOutAndReadBack(wb1);
+		wb1.close();
 
-		umSheet = book.getSheetAt(0);
+		umSheet = wb2.getSheetAt(0);
 		s = umSheet.getSheet();
 
 		assertEquals("After serialize, active cell should be in col 2",
 			(short) 2, s.getActiveCellCol());
 		assertEquals("After serialize, active cell should be on row 3",
 			3, s.getActiveCellRow());
+		
+		wb2.close();
 	}
 
-	
+
+	@Test
 	public void testActiveCellBug56114() throws IOException {
 	    Workbook wb = new HSSFWorkbook();
 	    Sheet sh = wb.createSheet();
@@ -179,15 +197,17 @@ public final class TestHSSFCell extends BaseTestCell {
         assertEquals(0, ((HSSFSheet)wb.getSheetAt(0)).getSheet().getActiveCellCol());
 
 	    cell.setAsActiveCell();
+	    cell.setCellValue("this should be active");
         
         assertEquals(1, ((HSSFSheet)wb.getSheetAt(0)).getSheet().getActiveCellRow());
         assertEquals(3, ((HSSFSheet)wb.getSheetAt(0)).getSheet().getActiveCellCol());
 
-//	    FileOutputStream fos = new FileOutputStream("/tmp/56114.xls");
-//
-//	    wb.write(fos);
-//
-//	    fos.close();
+	    /*OutputStream fos = new FileOutputStream("c:/temp/56114.xls");
+		try {
+			wb.write(fos);
+		} finally {
+			fos.close();
+		}*/
 	            
 	    Workbook wbBack = _testDataProvider.writeOutAndReadBack(wb);
 	    wb.close();
@@ -199,12 +219,13 @@ public final class TestHSSFCell extends BaseTestCell {
         
         assertEquals(3, ((HSSFSheet)wbBack.getSheetAt(0)).getSheet().getActiveCellRow());
         assertEquals(3, ((HSSFSheet)wbBack.getSheetAt(0)).getSheet().getActiveCellCol());
-	    
-//	    fos = new FileOutputStream("/tmp/56114a.xls");
-//
-//	    wbBack.write(fos);
-//
-//	    fos.close();
+
+		/*fos = new FileOutputStream("c:/temp/56114a.xls");
+		try {
+			wb.write(fos);
+		} finally {
+			fos.close();
+		}*/
 	            
         Workbook wbBack2 = _testDataProvider.writeOutAndReadBack(wbBack);
         wbBack.close();
@@ -217,7 +238,8 @@ public final class TestHSSFCell extends BaseTestCell {
 	/**
 	 * Test reading hyperlinks
 	 */
-	public void testWithHyperlink() {
+	@Test
+	public void testWithHyperlink() throws IOException {
 
 		HSSFWorkbook wb = HSSFTestDataSamples.openSampleWorkbook("WithHyperlink.xls");
 
@@ -230,12 +252,15 @@ public final class TestHSSFCell extends BaseTestCell {
 		assertEquals("http://poi.apache.org/", link.getAddress());
 		assertEquals(4, link.getFirstRow());
 		assertEquals(0, link.getFirstColumn());
+		
+		wb.close();
 	}
 
 	/**
 	 * Test reading hyperlinks
 	 */
-	public void testWithTwoHyperlinks() {
+	@Test
+	public void testWithTwoHyperlinks() throws IOException {
 
 		HSSFWorkbook wb = HSSFTestDataSamples.openSampleWorkbook("WithTwoHyperLinks.xls");
 
@@ -256,13 +281,16 @@ public final class TestHSSFCell extends BaseTestCell {
 		assertEquals("http://poi.apache.org/hssf/", link2.getAddress());
 		assertEquals(8, link2.getFirstRow());
 		assertEquals(1, link2.getFirstColumn());
+		
+		wb.close();
 	}
 
 	/**
 	 * Test to ensure we can only assign cell styles that belong
 	 *  to our workbook, and not those from other workbooks.
 	 */
-	public void testCellStyleWorkbookMatch() {
+	@Test
+	public void testCellStyleWorkbookMatch() throws IOException {
 		HSSFWorkbook wbA = new HSSFWorkbook();
 		HSSFWorkbook wbB = new HSSFWorkbook();
 
@@ -273,34 +301,37 @@ public final class TestHSSFCell extends BaseTestCell {
 		styB.verifyBelongsToWorkbook(wbB);
 		try {
 			styA.verifyBelongsToWorkbook(wbB);
-			fail();
+			fail("expected IllegalArgumentException");
 		} catch (IllegalArgumentException e) {
 			// expected during successful test
 		}
 		try {
 			styB.verifyBelongsToWorkbook(wbA);
-			fail();
+			fail("expected IllegalArgumentException");
 		} catch (IllegalArgumentException e) {
 			// expected during successful test
 		}
 
-		HSSFCell cellA = wbA.createSheet().createRow(0).createCell(0);
-		HSSFCell cellB = wbB.createSheet().createRow(0).createCell(0);
+		Cell cellA = wbA.createSheet().createRow(0).createCell(0);
+		Cell cellB = wbB.createSheet().createRow(0).createCell(0);
 
 		cellA.setCellStyle(styA);
 		cellB.setCellStyle(styB);
 		try {
 			cellA.setCellStyle(styB);
-			fail();
+			fail("expected IllegalArgumentException");
 		} catch (IllegalArgumentException e) {
 			// expected during successful test
 		}
 		try {
 			cellB.setCellStyle(styA);
-			fail();
+			fail("expected IllegalArgumentException");
 		} catch (IllegalArgumentException e) {
 			// expected during successful test
 		}
+		
+		wbB.close();
+		wbA.close();
 	}
 
 	/**
@@ -308,8 +339,8 @@ public final class TestHSSFCell extends BaseTestCell {
 	 * the {@link StringRecord} following the {@link FormulaRecord} after the result type had been
 	 * changed to number/boolean/error.  Excel silently ignores the extra record, but some POI
 	 * versions (prior to bug 46213 / r717883) crash instead.
-	 * @throws IOException 
 	 */
+	@Test
 	public void testCachedTypeChange() throws IOException {
 		HSSFWorkbook wb = new HSSFWorkbook();
         HSSFSheet sheet = wb.createSheet("Sheet1");
@@ -321,7 +352,7 @@ public final class TestHSSFCell extends BaseTestCell {
 		Record[] recs = RecordInspector.getRecords(sheet, 0);
 		if (recs.length == 28 && recs[23] instanceof StringRecord) {
 		    wb.close();
-			throw new AssertionFailedError("Identified bug - leftover StringRecord");
+			fail("Identified bug - leftover StringRecord");
 		}
 		confirmStringRecord(sheet, false);
 
@@ -350,29 +381,33 @@ public final class TestHSSFCell extends BaseTestCell {
 		} else {
 			assertFalse(StringRecord.class == recs[index].getClass());
 		}
-		Record dbcr = recs[index++];
+		Record dbcr = recs[index];
 		assertEquals(DBCellRecord.class, dbcr.getClass());
 	}
 
     /**
      * HSSF prior to version 3.7 had a bug: it could write a NaN but could not read such a file back.
      */
-    public void testReadNaN() {
+	@Test
+	public void testReadNaN() throws IOException {
         HSSFWorkbook wb = HSSFTestDataSamples.openSampleWorkbook("49761.xls");
         assertNotNull(wb);
+        wb.close();
     }
 
-    public void testHSSFCell() {
+	@Test
+	public void testHSSFCell() throws IOException {
         HSSFWorkbook wb = new HSSFWorkbook();
         HSSFSheet sheet = wb.createSheet();
         HSSFRow row = sheet.createRow(0);
         row.createCell(0);
         HSSFCell cell = new HSSFCell(wb, sheet, 0, (short)0);
-        assertNotNull(cell);  
+        assertNotNull(cell);
+        wb.close();
     }
 
-    @SuppressWarnings("deprecation")
-    public void testDeprecatedMethods() {
+    @Test
+    public void testDeprecatedMethods() throws IOException {
         HSSFWorkbook wb = new HSSFWorkbook();
         HSSFSheet sheet = wb.createSheet();
         HSSFRow row = sheet.createRow(0);
@@ -380,61 +415,57 @@ public final class TestHSSFCell extends BaseTestCell {
 
         // cover some deprecated methods and other smaller stuff...
         assertEquals(wb.getWorkbook(), cell.getBoundWorkbook());
-        cell.getCellNum();
-        cell.setCellNum((short)0);
 
         try {
             cell.getCachedFormulaResultType();
             fail("Should catch exception");
         } catch (IllegalStateException e) {
-        }
-        
-        try {
-            assertNotNull(new HSSFCell(wb, sheet, 0, (short)0, Cell.CELL_TYPE_ERROR+1 ));
-            fail("Should catch exception");
-        } catch (RuntimeException e) {
+            // expected here
         }
         
         cell.removeCellComment();
         cell.removeCellComment();
+        
+        wb.close();
     }
 
+    @Test
     public void testCellType() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
         Sheet sheet = wb.createSheet();
         Row row = sheet.createRow(0);
         Cell cell = row.createCell(0);
 
-        cell.setCellType(Cell.CELL_TYPE_BLANK);
+        cell.setCellType(CellType.BLANK);
         assertNull(null, cell.getDateCellValue());
         assertFalse(cell.getBooleanCellValue());
         assertEquals("", cell.toString());
         
-        cell.setCellType(Cell.CELL_TYPE_STRING);
+        cell.setCellType(CellType.STRING);
         assertEquals("", cell.toString());
-        cell.setCellType(Cell.CELL_TYPE_STRING);
+        cell.setCellType(CellType.STRING);
         cell.setCellValue(1.2);
-        cell.setCellType(Cell.CELL_TYPE_NUMERIC);
+        cell.setCellType(CellType.NUMERIC);
         assertEquals("1.2", cell.toString());
-        cell.setCellType(Cell.CELL_TYPE_BOOLEAN);
+        cell.setCellType(CellType.BOOLEAN);
         assertEquals("TRUE", cell.toString());
-        cell.setCellType(Cell.CELL_TYPE_BOOLEAN);
+        cell.setCellType(CellType.BOOLEAN);
         cell.setCellValue("" + FormulaError.VALUE.name());
-        cell.setCellType(Cell.CELL_TYPE_ERROR);
+        cell.setCellType(CellType.ERROR);
         assertEquals("#VALUE!", cell.toString());
-        cell.setCellType(Cell.CELL_TYPE_ERROR);
-        cell.setCellType(Cell.CELL_TYPE_BOOLEAN);
+        cell.setCellType(CellType.ERROR);
+        cell.setCellType(CellType.BOOLEAN);
         assertEquals("FALSE", cell.toString());
         cell.setCellValue(1.2);
-        cell.setCellType(Cell.CELL_TYPE_NUMERIC);
+        cell.setCellType(CellType.NUMERIC);
         assertEquals("1.2", cell.toString());
-        cell.setCellType(Cell.CELL_TYPE_BOOLEAN);
-        cell.setCellType(Cell.CELL_TYPE_STRING);
-        cell.setCellType(Cell.CELL_TYPE_ERROR);
-        cell.setCellType(Cell.CELL_TYPE_STRING);
+        cell.setCellType(CellType.BOOLEAN);
+        cell.setCellType(CellType.STRING);
+        cell.setCellType(CellType.ERROR);
+        cell.setCellType(CellType.STRING);
         cell.setCellValue(1.2);
-        cell.setCellType(Cell.CELL_TYPE_NUMERIC);
-        cell.setCellType(Cell.CELL_TYPE_STRING);
+        cell.setCellType(CellType.NUMERIC);
+        cell.setCellType(CellType.STRING);
         assertEquals("1.2", cell.toString());
         
         cell.setCellValue((String)null);
