@@ -17,42 +17,53 @@
 
 package org.apache.poi.hssf.usermodel;
 
+import static java.util.Calendar.AUGUST;
+import static java.util.Calendar.FEBRUARY;
+import static java.util.Calendar.JANUARY;
+import static java.util.Calendar.JULY;
+import static java.util.Calendar.MARCH;
+import static java.util.Calendar.MAY;
+import static java.util.Calendar.OCTOBER;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.io.IOException;
 import java.text.ParseException;
 import java.text.SimpleDateFormat;
 import java.util.Calendar;
 import java.util.Date;
-import java.util.GregorianCalendar;
+import java.util.Locale;
 import java.util.TimeZone;
 
 import org.apache.poi.hssf.HSSFTestDataSamples;
 import org.apache.poi.hssf.model.InternalWorkbook;
 import org.apache.poi.ss.usermodel.DateUtil;
+import org.apache.poi.util.LocaleUtil;
+import org.junit.AfterClass;
+import org.junit.BeforeClass;
 import org.junit.Test;
 
 /**
  * Class TestHSSFDateUtil
- *
- *
- * @author  Dan Sherman (dsherman at isisph.com)
- * @author  Hack Kampbjorn (hak at 2mba.dk)
- * @author  Pavel Krupets (pkrupets at palmtreebusiness dot com)
- * @author Alex Jacoby (ajacoby at gmail.com)
- * @version %I%, %G%
  */
-public final class TestHSSFDateUtil {
-
-    public static final int CALENDAR_JANUARY = 0;
-    public static final int CALENDAR_FEBRUARY = 1;
-    public static final int CALENDAR_MARCH = 2;
-    public static final int CALENDAR_APRIL = 3;
-    public static final int CALENDAR_JULY = 6;
-    public static final int CALENDAR_OCTOBER = 9;
+public class TestHSSFDateUtil {
 
+    static TimeZone userTimeZone;
+    
+    @BeforeClass
+    public static void setCEST() {
+        userTimeZone = LocaleUtil.getUserTimeZone();
+        LocaleUtil.setUserTimeZone(TimeZone.getTimeZone("CEST"));
+    }
+    
+    @AfterClass
+    public static void resetTimeZone() {
+        LocaleUtil.setUserTimeZone(userTimeZone);
+    }
+    
     /**
      * Checks the date conversion functions in the HSSFDateUtil class.
      */
@@ -60,25 +71,24 @@ public final class TestHSSFDateUtil {
     public void dateConversion() {
 
         // Iteratating over the hours exposes any rounding issues.
-        for (int hour = 0; hour < 23; hour++)
-        {
-            GregorianCalendar date      = new GregorianCalendar(2002, 0, 1,
-                    hour, 1, 1);
-            double            excelDate =
-                    HSSFDateUtil.getExcelDate(date.getTime(), false);
+        Calendar cal = LocaleUtil.getLocaleCalendar(2002,JANUARY,1,0,1,1);
+        for (int hour = 0; hour < 23; hour++) {
+            double excelDate = HSSFDateUtil.getExcelDate(cal.getTime(), false);
 
-            assertEquals("Checking hour = " + hour, date.getTime().getTime(),
+            assertEquals("Checking hour = " + hour, cal.getTime().getTime(),
                     HSSFDateUtil.getJavaDate(excelDate, false).getTime());
+
+            cal.add(Calendar.HOUR_OF_DAY, 1);
         }
 
         // check 1900 and 1904 date windowing conversions
         double excelDate = 36526.0;
         // with 1900 windowing, excelDate is Jan. 1, 2000
         // with 1904 windowing, excelDate is Jan. 2, 2004
-        GregorianCalendar cal = new GregorianCalendar(2000,0,1); // Jan. 1, 2000
+        cal.set(2000,JANUARY,1,0,0,0); // Jan. 1, 2000
         Date dateIf1900 = cal.getTime();
-        cal.add(GregorianCalendar.YEAR,4); // now Jan. 1, 2004
-        cal.add(GregorianCalendar.DATE,1); // now Jan. 2, 2004
+        cal.add(Calendar.YEAR,4); // now Jan. 1, 2004
+        cal.add(Calendar.DATE,1); // now Jan. 2, 2004
         Date dateIf1904 = cal.getTime();
         // 1900 windowing
         assertEquals("Checking 1900 Date Windowing",
@@ -96,11 +106,9 @@ public final class TestHSSFDateUtil {
      */
     @Test
     public void excelConversionOnDSTStart() {
-        TimeZone cet = TimeZone.getTimeZone("Europe/Copenhagen");
-        TimeZone.setDefault(cet);
-        Calendar cal = new GregorianCalendar(2004, CALENDAR_MARCH, 28);
+        Calendar cal = LocaleUtil.getLocaleCalendar(2004,MARCH,28,0,0,0);
         for (int hour = 0; hour < 24; hour++) {
-
+            
             // Skip 02:00 CET as that is the Daylight change time
             // and Java converts it automatically to 03:00 CEST
             if (hour == 2) {
@@ -109,6 +117,8 @@ public final class TestHSSFDateUtil {
 
             cal.set(Calendar.HOUR_OF_DAY, hour);
             Date javaDate = cal.getTime();
+
+            
             double excelDate = HSSFDateUtil.getExcelDate(javaDate, false);
             double difference = excelDate - Math.floor(excelDate);
             int differenceInHours = (int) (difference * 24 * 60 + 0.5) / 60;
@@ -127,9 +137,7 @@ public final class TestHSSFDateUtil {
      */
     @Test
     public void javaConversionOnDSTStart() {
-        TimeZone cet = TimeZone.getTimeZone("Europe/Copenhagen");
-        TimeZone.setDefault(cet);
-        Calendar cal = new GregorianCalendar(2004, CALENDAR_MARCH, 28);
+        Calendar cal = LocaleUtil.getLocaleCalendar(2004,MARCH,28,0,0,0);
         double excelDate = HSSFDateUtil.getExcelDate(cal.getTime(), false);
         double oneHour = 1.0 / 24;
         double oneMinute = oneHour / 60;
@@ -143,9 +151,9 @@ public final class TestHSSFDateUtil {
 
             cal.set(Calendar.HOUR_OF_DAY, hour);
             Date javaDate = HSSFDateUtil.getJavaDate(excelDate, false);
+            double actDate = HSSFDateUtil.getExcelDate(javaDate, false);
             assertEquals("Checking " + hour + " hours on Daylight Saving Time start date",
-                    excelDate,
-                    HSSFDateUtil.getExcelDate(javaDate, false), oneMinute);
+                    excelDate, actDate, oneMinute);
         }
     }
 
@@ -155,9 +163,7 @@ public final class TestHSSFDateUtil {
      */
     @Test
     public void excelConversionOnDSTEnd() {
-        TimeZone cet = TimeZone.getTimeZone("Europe/Copenhagen");
-        TimeZone.setDefault(cet);
-        Calendar cal = new GregorianCalendar(2004, CALENDAR_OCTOBER, 31);
+        Calendar cal = LocaleUtil.getLocaleCalendar(2004,OCTOBER,31,0,0,0);
         for (int hour = 0; hour < 24; hour++) {
             cal.set(Calendar.HOUR_OF_DAY, hour);
             Date javaDate = cal.getTime();
@@ -179,9 +185,7 @@ public final class TestHSSFDateUtil {
      */
     @Test
     public void javaConversionOnDSTEnd() {
-        TimeZone cet = TimeZone.getTimeZone("Europe/Copenhagen");
-        TimeZone.setDefault(cet);
-        Calendar cal = new GregorianCalendar(2004, CALENDAR_OCTOBER, 31);
+        Calendar cal = LocaleUtil.getLocaleCalendar(2004,OCTOBER,31,0,0,0);
         double excelDate = HSSFDateUtil.getExcelDate(cal.getTime(), false);
         double oneHour = 1.0 / 24;
         double oneMinute = oneHour / 60;
@@ -199,40 +203,45 @@ public final class TestHSSFDateUtil {
      */
     @Test
     public void calendarConversion() {
-        GregorianCalendar date = new GregorianCalendar(2002, 0, 1, 12, 1, 1);
-        Date expected = date.getTime();
-
-        // Iterating over the hours exposes any rounding issues.
-        for (int hour = -12; hour <= 12; hour++)
-        {
-            String id = "GMT" + (hour < 0 ? "" : "+") + hour + ":00";
-            date.setTimeZone(TimeZone.getTimeZone(id));
-            date.set(Calendar.HOUR_OF_DAY, 12);
-            double excelDate = HSSFDateUtil.getExcelDate(date, false);
-            Date javaDate = HSSFDateUtil.getJavaDate(excelDate);
-
-            // Should match despite time-zone
-            assertEquals("Checking timezone " + id, expected.getTime(), javaDate.getTime());
+        TimeZone userTZ = LocaleUtil.getUserTimeZone();
+        LocaleUtil.setUserTimeZone(TimeZone.getTimeZone("CET"));
+        try {
+            Calendar cal = LocaleUtil.getLocaleCalendar(2002,JANUARY,1,12,1,1);
+            Date expected = cal.getTime();
+    
+            // Iterating over the hours exposes any rounding issues.
+            for (int hour = -12; hour <= 12; hour++)
+            {
+                String id = "GMT" + (hour < 0 ? "" : "+") + hour + ":00";
+                cal.setTimeZone(TimeZone.getTimeZone(id));
+                cal.set(Calendar.HOUR_OF_DAY, 12);
+                double excelDate = HSSFDateUtil.getExcelDate(cal, false);
+                Date javaDate = HSSFDateUtil.getJavaDate(excelDate);
+    
+                // Should match despite time-zone
+                assertEquals("Checking timezone " + id, expected.getTime(), javaDate.getTime());
+            }
+            
+            // Check that the timezone aware getter works correctly 
+            TimeZone cet = TimeZone.getTimeZone("Europe/Copenhagen");
+            TimeZone ldn = TimeZone.getTimeZone("Europe/London");
+            
+            // 12:45 on 27th April 2012
+            double excelDate = 41026.53125;
+            
+            // Same, no change
+            assertEquals(
+                  HSSFDateUtil.getJavaDate(excelDate, false).getTime(),
+                  HSSFDateUtil.getJavaDate(excelDate, false, cet).getTime()
+            );
+            
+            // London vs Copenhagen, should differ by an hour
+            Date cetDate = HSSFDateUtil.getJavaDate(excelDate, false);
+            Date ldnDate = HSSFDateUtil.getJavaDate(excelDate, false, ldn);
+            assertEquals(ldnDate.getTime() - cetDate.getTime(), 60*60*1000);
+        } finally {
+            LocaleUtil.setUserTimeZone(userTZ);
         }
-        
-        // Check that the timezone aware getter works correctly 
-        TimeZone cet = TimeZone.getTimeZone("Europe/Copenhagen");
-        TimeZone ldn = TimeZone.getTimeZone("Europe/London");
-        TimeZone.setDefault(cet);
-        
-        // 12:45 on 27th April 2012
-        double excelDate = 41026.53125;
-        
-        // Same, no change
-        assertEquals(
-              HSSFDateUtil.getJavaDate(excelDate, false).getTime(),
-              HSSFDateUtil.getJavaDate(excelDate, false, cet).getTime()
-        );
-        
-        // London vs Copenhagen, should differ by an hour
-        Date cetDate = HSSFDateUtil.getJavaDate(excelDate, false);
-        Date ldnDate = HSSFDateUtil.getJavaDate(excelDate, false, ldn);
-        assertEquals(ldnDate.getTime() - cetDate.getTime(), 60*60*1000);
     }
 
     /**
@@ -242,18 +251,18 @@ public final class TestHSSFDateUtil {
     public void identifyDateFormats() {
         // First up, try with a few built in date formats
         short[] builtins = new short[] { 0x0e, 0x0f, 0x10, 0x16, 0x2d, 0x2e };
-        for(int i=0; i<builtins.length; i++) {
-            String formatStr = HSSFDataFormat.getBuiltinFormat(builtins[i]);
-            assertTrue( HSSFDateUtil.isInternalDateFormat(builtins[i]) );
-            assertTrue( HSSFDateUtil.isADateFormat(builtins[i],formatStr) );
+        for (short builtin : builtins) {
+            String formatStr = HSSFDataFormat.getBuiltinFormat(builtin);
+            assertTrue( HSSFDateUtil.isInternalDateFormat(builtin) );
+            assertTrue( HSSFDateUtil.isADateFormat(builtin,formatStr) );
         }
 
         // Now try a few built-in non date formats
         builtins = new short[] { 0x01, 0x02, 0x17, 0x1f, 0x30 };
-        for(int i=0; i<builtins.length; i++) {
-            String formatStr = HSSFDataFormat.getBuiltinFormat(builtins[i]);
-            assertFalse( HSSFDateUtil.isInternalDateFormat(builtins[i]) );
-            assertFalse( HSSFDateUtil.isADateFormat(builtins[i],formatStr) );
+        for (short builtin : builtins) {
+            String formatStr = HSSFDataFormat.getBuiltinFormat(builtin);
+            assertFalse( HSSFDateUtil.isInternalDateFormat(builtin) );
+            assertFalse( HSSFDateUtil.isADateFormat(builtin,formatStr) );
         }
 
         // Now for some non-internal ones
@@ -287,10 +296,10 @@ public final class TestHSSFDateUtil {
                 "[BLACK]dddd/mm/yy",
                 "[yeLLow]yyyy-mm-dd"
         };
-        for(int i=0; i<formats.length; i++) {
+        for (String format : formats) {
             assertTrue(
-                    formats[i] + " is a date format",
-                    HSSFDateUtil.isADateFormat(formatId, formats[i])
+                    format + " is a date format",
+                    HSSFDateUtil.isADateFormat(formatId, format)
             );
         }
 
@@ -305,10 +314,10 @@ public final class TestHSSFDateUtil {
                 //support elapsed time [h],[m],[s]
                 "[hh]", "[mm]", "[ss]", "[SS]", "[red][hh]"
         };
-        for(int i=0; i<formats.length; i++) {
+        for (String format : formats) {
             assertTrue(
-                    formats[i] + " is a datetime format",
-                    HSSFDateUtil.isADateFormat(formatId, formats[i])
+                    format + " is a datetime format",
+                    HSSFDateUtil.isADateFormat(formatId, format)
             );
         }
 
@@ -321,10 +330,10 @@ public final class TestHSSFDateUtil {
                 "[ms]", "[Mh]",
                 "", null
         };
-        for(int i=0; i<formats.length; i++) {
+        for (String format : formats) {
             assertFalse(
-                    formats[i] + " is not a date or datetime format",
-                    HSSFDateUtil.isADateFormat(formatId, formats[i])
+                    format + " is not a date or datetime format",
+                    HSSFDateUtil.isADateFormat(formatId, format)
             );
         }
 
@@ -333,7 +342,7 @@ public final class TestHSSFDateUtil {
         formats = new String[] {
                 "yyyy:mm:dd",
         };
-        for(int i=0; i<formats.length; i++) {
+        for (String format : formats) {
         //    assertFalse( HSSFDateUtil.isADateFormat(formatId, formats[i]) );
         }
     }
@@ -349,6 +358,7 @@ public final class TestHSSFDateUtil {
         HSSFWorkbook workbook = HSSFTestDataSamples.openSampleWorkbook("DateFormats.xls");
         HSSFSheet sheet       = workbook.getSheetAt(0);
         InternalWorkbook wb           = workbook.getWorkbook();
+        assertNotNull(wb);
 
         HSSFRow  row;
         HSSFCell cell;
@@ -405,7 +415,8 @@ public final class TestHSSFDateUtil {
 
     @Test
     public void excelDateBorderCases() throws ParseException {
-        SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd");
+        SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd", Locale.ROOT);
+        df.setTimeZone(LocaleUtil.getUserTimeZone());
         
         assertEquals(1.0, DateUtil.getExcelDate(df.parse("1900-01-01")), 0.00001);
         assertEquals(31.0, DateUtil.getExcelDate(df.parse("1900-01-31")), 0.00001);
@@ -415,38 +426,38 @@ public final class TestHSSFDateUtil {
 
     @Test
     public void dateBug_2Excel() {
-        assertEquals(59.0, HSSFDateUtil.getExcelDate(createDate(1900, CALENDAR_FEBRUARY, 28), false), 0.00001);
-        assertEquals(61.0, HSSFDateUtil.getExcelDate(createDate(1900, CALENDAR_MARCH, 1), false), 0.00001);
+        assertEquals(59.0, HSSFDateUtil.getExcelDate(createDate(1900, FEBRUARY, 28), false), 0.00001);
+        assertEquals(61.0, HSSFDateUtil.getExcelDate(createDate(1900, MARCH, 1), false), 0.00001);
 
-        assertEquals(37315.00, HSSFDateUtil.getExcelDate(createDate(2002, CALENDAR_FEBRUARY, 28), false), 0.00001);
-        assertEquals(37316.00, HSSFDateUtil.getExcelDate(createDate(2002, CALENDAR_MARCH, 1), false), 0.00001);
-        assertEquals(37257.00, HSSFDateUtil.getExcelDate(createDate(2002, CALENDAR_JANUARY, 1), false), 0.00001);
-        assertEquals(38074.00, HSSFDateUtil.getExcelDate(createDate(2004, CALENDAR_MARCH, 28), false), 0.00001);
+        assertEquals(37315.00, HSSFDateUtil.getExcelDate(createDate(2002, FEBRUARY, 28), false), 0.00001);
+        assertEquals(37316.00, HSSFDateUtil.getExcelDate(createDate(2002, MARCH, 1), false), 0.00001);
+        assertEquals(37257.00, HSSFDateUtil.getExcelDate(createDate(2002, JANUARY, 1), false), 0.00001);
+        assertEquals(38074.00, HSSFDateUtil.getExcelDate(createDate(2004, MARCH, 28), false), 0.00001);
     }
 
     @Test
     public void dateBug_2Java() {
-        assertEquals(createDate(1900, CALENDAR_FEBRUARY, 28), HSSFDateUtil.getJavaDate(59.0, false));
-        assertEquals(createDate(1900, CALENDAR_MARCH, 1), HSSFDateUtil.getJavaDate(61.0, false));
+        assertEquals(createDate(1900, FEBRUARY, 28), HSSFDateUtil.getJavaDate(59.0, false));
+        assertEquals(createDate(1900, MARCH, 1), HSSFDateUtil.getJavaDate(61.0, false));
 
-        assertEquals(createDate(2002, CALENDAR_FEBRUARY, 28), HSSFDateUtil.getJavaDate(37315.00, false));
-        assertEquals(createDate(2002, CALENDAR_MARCH, 1), HSSFDateUtil.getJavaDate(37316.00, false));
-        assertEquals(createDate(2002, CALENDAR_JANUARY, 1), HSSFDateUtil.getJavaDate(37257.00, false));
-        assertEquals(createDate(2004, CALENDAR_MARCH, 28), HSSFDateUtil.getJavaDate(38074.00, false));
+        assertEquals(createDate(2002, FEBRUARY, 28), HSSFDateUtil.getJavaDate(37315.00, false));
+        assertEquals(createDate(2002, MARCH, 1), HSSFDateUtil.getJavaDate(37316.00, false));
+        assertEquals(createDate(2002, JANUARY, 1), HSSFDateUtil.getJavaDate(37257.00, false));
+        assertEquals(createDate(2004, MARCH, 28), HSSFDateUtil.getJavaDate(38074.00, false));
     }
 
     @Test
     public void date1904() {
-        assertEquals(createDate(1904, CALENDAR_JANUARY, 2), HSSFDateUtil.getJavaDate(1.0, true));
-        assertEquals(createDate(1904, CALENDAR_JANUARY, 1), HSSFDateUtil.getJavaDate(0.0, true));
-        assertEquals(0.0, HSSFDateUtil.getExcelDate(createDate(1904, CALENDAR_JANUARY, 1), true), 0.00001);
-        assertEquals(1.0, HSSFDateUtil.getExcelDate(createDate(1904, CALENDAR_JANUARY, 2), true), 0.00001);
+        assertEquals(createDate(1904, JANUARY, 2), HSSFDateUtil.getJavaDate(1.0, true));
+        assertEquals(createDate(1904, JANUARY, 1), HSSFDateUtil.getJavaDate(0.0, true));
+        assertEquals(0.0, HSSFDateUtil.getExcelDate(createDate(1904, JANUARY, 1), true), 0.00001);
+        assertEquals(1.0, HSSFDateUtil.getExcelDate(createDate(1904, JANUARY, 2), true), 0.00001);
 
-        assertEquals(createDate(1998, CALENDAR_JULY, 5), HSSFDateUtil.getJavaDate(35981, false));
-        assertEquals(createDate(1998, CALENDAR_JULY, 5), HSSFDateUtil.getJavaDate(34519, true));
+        assertEquals(createDate(1998, JULY, 5), HSSFDateUtil.getJavaDate(35981, false));
+        assertEquals(createDate(1998, JULY, 5), HSSFDateUtil.getJavaDate(34519, true));
 
-        assertEquals(35981.0, HSSFDateUtil.getExcelDate(createDate(1998, CALENDAR_JULY, 5), false), 0.00001);
-        assertEquals(34519.0, HSSFDateUtil.getExcelDate(createDate(1998, CALENDAR_JULY, 5), true), 0.00001);
+        assertEquals(35981.0, HSSFDateUtil.getExcelDate(createDate(1998, JULY, 5), false), 0.00001);
+        assertEquals(34519.0, HSSFDateUtil.getExcelDate(createDate(1998, JULY, 5), true), 0.00001);
     }
 
     /**
@@ -462,9 +473,7 @@ public final class TestHSSFDateUtil {
      * @param day one based
      */
     private static Date createDate(int year, int month, int day, int hour, int minute, int second) {
-        Calendar c = new GregorianCalendar();
-        c.set(year, month, day, hour, minute, second);
-        c.set(Calendar.MILLISECOND, 0);
+        Calendar c = LocaleUtil.getLocaleCalendar(year, month, day, hour, minute, second);
         return c.getTime();
     }
 
@@ -474,11 +483,30 @@ public final class TestHSSFDateUtil {
     @Test
     public void absoluteDay() {
         // 1 Jan 1900 is 1 day after 31 Dec 1899
-        GregorianCalendar calendar = new GregorianCalendar(1900, 0, 1);
-        assertEquals("Checking absolute day (1 Jan 1900)", 1, HSSFDateUtil.absoluteDay(calendar, false));
+        Calendar cal = LocaleUtil.getLocaleCalendar(1900,JANUARY,1,0,0,0);
+        assertEquals("Checking absolute day (1 Jan 1900)", 1, HSSFDateUtil.absoluteDay(cal, false));
         // 1 Jan 1901 is 366 days after 31 Dec 1899
-        calendar = new GregorianCalendar(1901, 0, 1);
-        assertEquals("Checking absolute day (1 Jan 1901)", 366, HSSFDateUtil.absoluteDay(calendar, false));
+        cal.set(1901,JANUARY,1,0,0,0);
+        assertEquals("Checking absolute day (1 Jan 1901)", 366, HSSFDateUtil.absoluteDay(cal, false));
+    }
+
+    @Test
+    public void absoluteDayYearTooLow() {
+        Calendar cal = LocaleUtil.getLocaleCalendar(1899,JANUARY,1,0,0,0);
+        try {
+        	HSSFDateUtil.absoluteDay(cal, false);
+        	fail("Should fail here");
+        } catch (IllegalArgumentException e) {
+        	// expected here
+        }
+
+        try {
+            cal.set(1903,JANUARY,1,0,0,0);
+            HSSFDateUtil.absoluteDay(cal, true);
+        	fail("Should fail here");
+        } catch (IllegalArgumentException e) {
+        	// expected here
+        }
     }
 
     @Test
@@ -493,8 +521,8 @@ public final class TestHSSFDateUtil {
 
     @Test
     public void parseDate() {
-        assertEquals(createDate(2008, Calendar.AUGUST, 3), HSSFDateUtil.parseYYYYMMDDDate("2008/08/03"));
-        assertEquals(createDate(1994, Calendar.MAY, 1), HSSFDateUtil.parseYYYYMMDDDate("1994/05/01"));
+        assertEquals(createDate(2008, AUGUST, 3), HSSFDateUtil.parseYYYYMMDDDate("2008/08/03"));
+        assertEquals(createDate(1994, MAY, 1), HSSFDateUtil.parseYYYYMMDDDate("1994/05/01"));
     }
 
     /**
@@ -521,10 +549,8 @@ public final class TestHSSFDateUtil {
         HSSFSheet sheet = workbook.createSheet();
         HSSFCell cell = sheet.createRow(0).createCell(0);
 
-        Calendar cal = Calendar.getInstance();
-
         // A pseudo special Excel dates
-        cal.set(1900, 0, 1);
+        Calendar cal = LocaleUtil.getLocaleCalendar(1900, JANUARY, 1);
 
         Date valueToTest = cal.getTime();
 
