@@ -17,7 +17,10 @@
 
 package org.apache.poi.hssf.usermodel;
 
-import junit.framework.AssertionFailedError;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.fail;
+
+import java.io.IOException;
 
 import org.apache.poi.hssf.HSSFITestDataProvider;
 import org.apache.poi.hssf.HSSFTestDataSamples;
@@ -30,12 +33,10 @@ import org.apache.poi.ss.formula.eval.NumberEval;
 import org.apache.poi.ss.formula.eval.ValueEval;
 import org.apache.poi.ss.usermodel.BaseTestFormulaEvaluator;
 import org.apache.poi.ss.usermodel.Cell;
+import org.apache.poi.ss.usermodel.CellType;
 import org.apache.poi.ss.usermodel.CellValue;
+import org.junit.Test;
 
-/**
- *
- * @author Josh Micich
- */
 public final class TestHSSFFormulaEvaluator extends BaseTestFormulaEvaluator {
 
     public TestHSSFFormulaEvaluator() {
@@ -46,53 +47,27 @@ public final class TestHSSFFormulaEvaluator extends BaseTestFormulaEvaluator {
 	 * Test that the HSSFFormulaEvaluator can evaluate simple named ranges
 	 *  (single cells and rectangular areas)
 	 */
-	public void testEvaluateSimple() {
+    @Test
+	public void testEvaluateSimple() throws IOException {
 		HSSFWorkbook wb = HSSFTestDataSamples.openSampleWorkbook("testNames.xls");
 		HSSFSheet sheet = wb.getSheetAt(0);
 		HSSFCell cell = sheet.getRow(8).getCell(0);
 		HSSFFormulaEvaluator fe = new HSSFFormulaEvaluator(wb);
 		CellValue cv = fe.evaluate(cell);
-		assertEquals(HSSFCell.CELL_TYPE_NUMERIC, cv.getCellType());
+		assertEquals(CellType.NUMERIC, cv.getCellType());
 		assertEquals(3.72, cv.getNumberValue(), 0.0);
-	}
-
-	/**
-	 * Test for bug due to attempt to convert a cached formula error result to a boolean
-	 */
-	@Override
-	public void testUpdateCachedFormulaResultFromErrorToNumber_bug46479() {
-
-		HSSFWorkbook wb = new HSSFWorkbook();
-		HSSFSheet sheet = wb.createSheet("Sheet1");
-		HSSFRow row = sheet.createRow(0);
-		HSSFCell cellA1 = row.createCell(0);
-		HSSFCell cellB1 = row.createCell(1);
-		cellB1.setCellFormula("A1+1");
-		HSSFFormulaEvaluator fe = new HSSFFormulaEvaluator(wb);
-
-		cellA1.setCellErrorValue((byte)HSSFErrorConstants.ERROR_NAME);
-		fe.evaluateFormulaCell(cellB1);
-
-		cellA1.setCellValue(2.5);
-		fe.notifyUpdateCell(cellA1);
-		try {
-			fe.evaluateInCell(cellB1);
-		} catch (IllegalStateException e) {
-			if (e.getMessage().equals("Cannot get a numeric value from a error formula cell")) {
-				throw new AssertionFailedError("Identified bug 46479a");
-			}
-		}
-		assertEquals(3.5, cellB1.getNumericCellValue(), 0.0);
+		wb.close();
 	}
 
 	/**
 	 * When evaluating defined names, POI has to decide whether it is capable.  Currently
-	 * (May2009) POI only supports simple cell and area refs.<br/>
+	 * (May2009) POI only supports simple cell and area refs.<br>
 	 * The sample spreadsheet (bugzilla attachment 23508) had a name flagged as 'complex'
 	 * which contained a simple area ref.  It is not clear what the 'complex' flag is used
 	 * for but POI should look elsewhere to decide whether it can evaluate the name.
 	 */
-	public void testDefinedNameWithComplexFlag_bug47048() {
+    @Test
+	public void testDefinedNameWithComplexFlag_bug47048() throws IOException {
 		// Mock up a spreadsheet to match the critical details of the sample
 		HSSFWorkbook wb = new HSSFWorkbook();
 		HSSFSheet sheet = wb.createSheet("Input");
@@ -118,16 +93,20 @@ public final class TestHSSFFormulaEvaluator extends BaseTestFormulaEvaluator {
 		CellValue value;
 		try {
 			value = hsf.evaluate(cellA1);
+
+	        assertEquals(CellType.NUMERIC, value.getCellType());
+	        assertEquals(5.33, value.getNumberValue(), 0.0);
+	        
 		} catch (RuntimeException e) {
 			if (e.getMessage().equals("Don't now how to evalate name 'Is_Multicar_Vehicle'")) {
-				throw new AssertionFailedError("Identified bug 47048a");
+				fail("Identified bug 47048a");
 			}
 			throw e;
+		} finally {
+	        wb.close();
 		}
-
-		assertEquals(Cell.CELL_TYPE_NUMERIC, value.getCellType());
-		assertEquals(5.33, value.getNumberValue(), 0.0);
 	}
+    
 	private static final class EvalCountListener extends EvaluationListener {
 		private int _evalCount;
 		public EvalCountListener() {
@@ -145,8 +124,8 @@ public final class TestHSSFFormulaEvaluator extends BaseTestFormulaEvaluator {
 	/**
 	 * The HSSFFormula evaluator performance benefits greatly from caching of intermediate cell values
 	 */
-	public void testShortCircuitIfEvaluation() {
-
+	@Test
+	public void testShortCircuitIfEvaluation() throws IOException {
 		// Set up a simple IF() formula that has measurable evaluation cost for its operands.
 		HSSFWorkbook wb = new HSSFWorkbook();
 		HSSFSheet sheet = wb.createSheet("Sheet1");
@@ -166,25 +145,28 @@ public final class TestHSSFFormulaEvaluator extends BaseTestFormulaEvaluator {
 		int evalCount = evalListener.getEvalCount();
 		if (evalCount == 6) {
 			// Without short-circuit-if evaluation, evaluating cell 'A1' takes 3 extra evaluations (for D1,E1,F1)
-			throw new AssertionFailedError("Identifed bug 48195 - Formula evaluator should short-circuit IF() calculations.");
+			fail("Identifed bug 48195 - Formula evaluator should short-circuit IF() calculations.");
 		}
 		assertEquals(3, evalCount);
 		assertEquals(2.0, ((NumberEval)ve).getNumberValue(), 0D);
+
+		wb.close();
 	}
-	
+
 	/**
 	 * Ensures that we can handle NameXPtgs in the formulas
 	 *  we parse.
 	 */
-	public void testXRefs() throws Exception {
-      HSSFWorkbook wb = HSSFTestDataSamples.openSampleWorkbook("XRefCalc.xls");
-      HSSFWorkbook wbData = HSSFTestDataSamples.openSampleWorkbook("XRefCalcData.xls");
+	@Test
+	public void testXRefs() throws IOException {
+      HSSFWorkbook wb1 = HSSFTestDataSamples.openSampleWorkbook("XRefCalc.xls");
+      HSSFWorkbook wb2 = HSSFTestDataSamples.openSampleWorkbook("XRefCalcData.xls");
       Cell cell;
       
       // VLookup on a name in another file
-      cell = wb.getSheetAt(0).getRow(1).getCell(2);
-      assertEquals(Cell.CELL_TYPE_FORMULA, cell.getCellType());
-      assertEquals(Cell.CELL_TYPE_NUMERIC, cell.getCachedFormulaResultType());
+      cell = wb1.getSheetAt(0).getRow(1).getCell(2);
+      assertEquals(CellType.FORMULA, cell.getCellType());
+      assertEquals(CellType.NUMERIC, cell.getCachedFormulaResultType());
       assertEquals(12.30, cell.getNumericCellValue(), 0.0001);
       // WARNING - this is wrong!
       // The file name should be showing, but bug #45970 is fixed
@@ -193,9 +175,9 @@ public final class TestHSSFFormulaEvaluator extends BaseTestFormulaEvaluator {
       
       
       // Simple reference to a name in another file
-      cell = wb.getSheetAt(0).getRow(1).getCell(4);
-      assertEquals(Cell.CELL_TYPE_FORMULA, cell.getCellType());
-      assertEquals(Cell.CELL_TYPE_NUMERIC, cell.getCachedFormulaResultType());
+      cell = wb1.getSheetAt(0).getRow(1).getCell(4);
+      assertEquals(CellType.FORMULA, cell.getCellType());
+      assertEquals(CellType.NUMERIC, cell.getCachedFormulaResultType());
       assertEquals(36.90, cell.getNumericCellValue(), 0.0001);
       // TODO Correct this!
       // The file name should be shown too, see bug #56742
@@ -203,37 +185,37 @@ public final class TestHSSFFormulaEvaluator extends BaseTestFormulaEvaluator {
       
       
       // Evaluate the cells
-      HSSFFormulaEvaluator eval = new HSSFFormulaEvaluator(wb);
+      HSSFFormulaEvaluator eval = new HSSFFormulaEvaluator(wb1);
       HSSFFormulaEvaluator.setupEnvironment(
             new String[] { "XRefCalc.xls", "XRefCalcData.xls" },
             new HSSFFormulaEvaluator[] {
                   eval,
-                  new HSSFFormulaEvaluator(wbData)
+                  new HSSFFormulaEvaluator(wb2)
             }
       );
       eval.evaluateFormulaCell(
-            wb.getSheetAt(0).getRow(1).getCell(2)
+            wb1.getSheetAt(0).getRow(1).getCell(2)
       );      
       eval.evaluateFormulaCell(
-            wb.getSheetAt(0).getRow(1).getCell(4)
+            wb1.getSheetAt(0).getRow(1).getCell(4)
       );      
       
 
       // Re-check VLOOKUP one
-      cell = wb.getSheetAt(0).getRow(1).getCell(2);
-      assertEquals(Cell.CELL_TYPE_FORMULA, cell.getCellType());
-      assertEquals(Cell.CELL_TYPE_NUMERIC, cell.getCachedFormulaResultType());
+      cell = wb1.getSheetAt(0).getRow(1).getCell(2);
+      assertEquals(CellType.FORMULA, cell.getCellType());
+      assertEquals(CellType.NUMERIC, cell.getCachedFormulaResultType());
       assertEquals(12.30, cell.getNumericCellValue(), 0.0001);
       
       // Re-check ref one
-      cell = wb.getSheetAt(0).getRow(1).getCell(4);
-      assertEquals(Cell.CELL_TYPE_FORMULA, cell.getCellType());
-      assertEquals(Cell.CELL_TYPE_NUMERIC, cell.getCachedFormulaResultType());
+      cell = wb1.getSheetAt(0).getRow(1).getCell(4);
+      assertEquals(CellType.FORMULA, cell.getCellType());
+      assertEquals(CellType.NUMERIC, cell.getCachedFormulaResultType());
       assertEquals(36.90, cell.getNumericCellValue(), 0.0001);
       
       
       // Add a formula that refers to one of the existing external workbooks
-      cell = wb.getSheetAt(0).getRow(1).createCell(40);
+      cell = wb1.getSheetAt(0).getRow(1).createCell(40);
       cell.setCellFormula("Cost*[XRefCalcData.xls]MarkupSheet!$B$1");
       
       // Check is was stored correctly
@@ -241,20 +223,21 @@ public final class TestHSSFFormulaEvaluator extends BaseTestFormulaEvaluator {
       
       // Check it evaluates correctly
       eval.evaluateFormulaCell(cell);
-      assertEquals(24.60*1.8, cell.getNumericCellValue());
-      
-      
+      assertEquals(24.60*1.8, cell.getNumericCellValue(), 0);
+
       // Try to add a formula for a new external workbook, won't be allowed to start
       try {
-          cell = wb.getSheetAt(0).getRow(1).createCell(42);
+          cell = wb1.getSheetAt(0).getRow(1).createCell(42);
           cell.setCellFormula("[alt.xls]Sheet0!$A$1");
           fail("New workbook not linked, shouldn't be able to add");
-      } catch(Exception e) {}
+      } catch(Exception e) {
+      	// expected here
+	  }
       
       // Link our new workbook
-      HSSFWorkbook alt = new HSSFWorkbook();
-      alt.createSheet().createRow(0).createCell(0).setCellValue("In another workbook");
-      wb.linkExternalWorkbook("alt.xls", alt);
+      HSSFWorkbook wb3 = new HSSFWorkbook();
+      wb3.createSheet().createRow(0).createCell(0).setCellValue("In another workbook");
+      assertEquals(2, wb1.linkExternalWorkbook("alt.xls", wb3));
       
       // Now add a formula that refers to our new workbook
       cell.setCellFormula("[alt.xls]Sheet0!$A$1");
@@ -264,15 +247,17 @@ public final class TestHSSFFormulaEvaluator extends BaseTestFormulaEvaluator {
       try {
           eval.evaluate(cell);
           fail("No cached value and no link to workbook, shouldn't evaluate");
-      } catch(Exception e) {}
+      } catch(Exception e) {
+		  // expected here
+	  }
       
       // Add a link, check it does
       HSSFFormulaEvaluator.setupEnvironment(
               new String[] { "XRefCalc.xls", "XRefCalcData.xls", "alt.xls" },
               new HSSFFormulaEvaluator[] {
                     eval,
-                    new HSSFFormulaEvaluator(wbData),
-                    new HSSFFormulaEvaluator(alt)
+                    new HSSFFormulaEvaluator(wb2),
+                    new HSSFFormulaEvaluator(wb3)
               }
       );
       eval.evaluateFormulaCell(cell);
@@ -280,32 +265,37 @@ public final class TestHSSFFormulaEvaluator extends BaseTestFormulaEvaluator {
       
       
       // Save and re-load
-      wb = HSSFTestDataSamples.writeOutAndReadBack(wb);
-      eval = new HSSFFormulaEvaluator(wb);
+      HSSFWorkbook wb4 = HSSFTestDataSamples.writeOutAndReadBack(wb1);
+      eval = new HSSFFormulaEvaluator(wb4);
       HSSFFormulaEvaluator.setupEnvironment(
               new String[] { "XRefCalc.xls", "XRefCalcData.xls", "alt.xls" },
               new HSSFFormulaEvaluator[] {
                     eval,
-                    new HSSFFormulaEvaluator(wbData),
-                    new HSSFFormulaEvaluator(alt)
+                    new HSSFFormulaEvaluator(wb2),
+                    new HSSFFormulaEvaluator(wb3)
               }
       );
       
       // Check the one referring to the previously existing workbook behaves
-      cell = wb.getSheetAt(0).getRow(1).getCell(40);
+      cell = wb4.getSheetAt(0).getRow(1).getCell(40);
       assertEquals("Cost*[XRefCalcData.xls]MarkupSheet!$B$1", cell.getCellFormula());
       eval.evaluateFormulaCell(cell);
-      assertEquals(24.60*1.8, cell.getNumericCellValue());
+      assertEquals(24.60*1.8, cell.getNumericCellValue(), 0);
       
       // Now check the newly added reference
-      cell = wb.getSheetAt(0).getRow(1).getCell(42);
+      cell = wb4.getSheetAt(0).getRow(1).getCell(42);
       assertEquals("[alt.xls]Sheet0!$A$1", cell.getCellFormula());
       eval.evaluateFormulaCell(cell);
       assertEquals("In another workbook", cell.getStringCellValue());
+      
+      wb4.close();
+      wb3.close();
+      wb2.close();
+      wb1.close();
    }
 
-    public void testSharedFormulas(){
+	@Test
+    public void testSharedFormulas() throws IOException {
         baseTestSharedFormulas("shared_formulas.xls");
     }
-
 }
