@@ -17,20 +17,20 @@
 
 package org.apache.poi.hssf.usermodel;
 
-import java.io.File;
-import java.io.FileOutputStream;
-import java.io.IOException;
-import java.lang.reflect.Field;
-
+import org.apache.poi.POITestCase;
 import org.apache.poi.hssf.HSSFITestDataProvider;
 import org.apache.poi.hssf.HSSFTestDataSamples;
 import org.apache.poi.hssf.model.HSSFFormulaParser;
 import org.apache.poi.hssf.record.NameRecord;
-import org.apache.poi.ss.formula.ptg.Ptg;
+import org.apache.poi.ss.SpreadsheetVersion;
 import org.apache.poi.ss.formula.FormulaType;
+import org.apache.poi.ss.formula.ptg.Ptg;
 import org.apache.poi.ss.usermodel.BaseTestNamedRange;
 import org.apache.poi.ss.util.AreaReference;
-import org.apache.poi.util.TempFile;
+import org.apache.poi.ss.util.CellRangeAddress;
+import org.junit.Test;
+
+import static org.junit.Assert.*;
 
 /**
  * Tests various functionality having to do with {@link org.apache.poi.ss.usermodel.Name}.
@@ -38,57 +38,44 @@ import org.apache.poi.util.TempFile;
 public final class TestHSSFName extends BaseTestNamedRange {
 
     /**
-     * For manipulating the internals of {@link HSSFName} during testing.<br/>
+     * For manipulating the internals of {@link HSSFName} during testing.<br>
      * Some tests need a {@link NameRecord} with unusual state, not normally producible by POI.
      * This method achieves the aims at low cost without augmenting the POI usermodel api.
      * @return a reference to the wrapped {@link NameRecord}
      */
     public static NameRecord getNameRecord(HSSFName definedName) {
-
-        Field f;
-        try {
-            f = HSSFName.class.getDeclaredField("_definedNameRec");
-        } catch (NoSuchFieldException e) {
-            throw new RuntimeException(e);
-        }
-        f.setAccessible(true);
-        try {
-            return (NameRecord) f.get(definedName);
-        } catch (IllegalArgumentException e) {
-            throw new RuntimeException(e);
-        } catch (IllegalAccessException e) {
-            throw new RuntimeException(e);
-        }
+        return POITestCase.getFieldValue(HSSFName.class, definedName, NameRecord.class, "_definedNameRec");
     }
 
     public TestHSSFName() {
         super(HSSFITestDataProvider.instance);
     }
 
-    public void testRepeatingRowsAndColumsNames() {
+    @Test
+    public void testRepeatingRowsAndColumsNames() throws Exception {
          // First test that setting RR&C for same sheet more than once only creates a
          // single  Print_Titles built-in record
          HSSFWorkbook wb = new HSSFWorkbook();
          HSSFSheet sheet = wb.createSheet("FirstSheet");
 
          // set repeating rows and columns twice for the first sheet
+         CellRangeAddress cra = CellRangeAddress.valueOf("A1:A3");
          for (int i = 0; i < 2; i++) {
-             wb.setRepeatingRowsAndColumns(0, 0, 0, 0, 3-1);
+             sheet.setRepeatingColumns(cra);
+             sheet.setRepeatingRows(cra);
              sheet.createFreezePane(0, 3);
          }
          assertEquals(1, wb.getNumberOfNames());
          HSSFName nr1 = wb.getNameAt(0);
 
          assertEquals("Print_Titles", nr1.getNameName());
-         if (false) {
-             //     TODO - full column references not rendering properly, absolute markers not present either
-             assertEquals("FirstSheet!$A:$A,FirstSheet!$1:$3", nr1.getRefersToFormula());
-         } else {
-             assertEquals("FirstSheet!A:A,FirstSheet!$A$1:$IV$3", nr1.getRefersToFormula());
-         }
+         // TODO - full column references not rendering properly, absolute markers not present either
+         // assertEquals("FirstSheet!$A:$A,FirstSheet!$1:$3", nr1.getRefersToFormula());
+         assertEquals("FirstSheet!A:A,FirstSheet!$A$1:$IV$3", nr1.getRefersToFormula());
 
          // Save and re-open
          HSSFWorkbook nwb = HSSFTestDataSamples.writeOutAndReadBack(wb);
+         wb.close();
 
          assertEquals(1, nwb.getNumberOfNames());
          nr1 = nwb.getNameAt(0);
@@ -99,7 +86,9 @@ public final class TestHSSFName extends BaseTestNamedRange {
          // check that setting RR&C on a second sheet causes a new Print_Titles built-in
          // name to be created
          sheet = nwb.createSheet("SecondSheet");
-         nwb.setRepeatingRowsAndColumns(1, 1, 2, 0, 0);
+         cra = CellRangeAddress.valueOf("B1:C1");
+         sheet.setRepeatingColumns(cra);
+         sheet.setRepeatingRows(cra);
 
          assertEquals(2, nwb.getNumberOfNames());
          HSSFName nr2 = nwb.getNameAt(1);
@@ -107,29 +96,18 @@ public final class TestHSSFName extends BaseTestNamedRange {
          assertEquals("Print_Titles", nr2.getNameName());
          assertEquals("SecondSheet!B:C,SecondSheet!$A$1:$IV$1", nr2.getRefersToFormula());
 
-         if (false) {
-             // In case you fancy checking in excel, to ensure it
-             //  won't complain about the file now
-             try {
-                 File tempFile = TempFile.createTempFile("POI-45126-", ".xls");
-                 FileOutputStream fout = new FileOutputStream(tempFile);
-                 nwb.write(fout);
-                 fout.close();
-                 System.out.println("check out " + tempFile.getAbsolutePath());
-             } catch (IOException e) {
-                 throw new RuntimeException(e);
-             }
-         }
+         nwb.close();
      }
 
-    public void testNamedRange() {
-        HSSFWorkbook wb = HSSFTestDataSamples.openSampleWorkbook("Simple.xls");
+    @Test
+    public void testNamedRange() throws Exception {
+        HSSFWorkbook wb1 = HSSFTestDataSamples.openSampleWorkbook("Simple.xls");
 
         //Creating new Named Range
-        HSSFName newNamedRange = wb.createName();
+        HSSFName newNamedRange = wb1.createName();
 
         //Getting Sheet Name for the reference
-        String sheetName = wb.getSheetName(0);
+        String sheetName = wb1.getSheetName(0);
 
         //Setting its name
         newNamedRange.setNameName("RangeTest");
@@ -137,18 +115,21 @@ public final class TestHSSFName extends BaseTestNamedRange {
         newNamedRange.setRefersToFormula(sheetName + "!$D$4:$E$8");
 
         //Getting NAmed Range
-        HSSFName namedRange1 = wb.getNameAt(0);
+        HSSFName namedRange1 = wb1.getNameAt(0);
         //Getting it sheet name
         sheetName = namedRange1.getSheetName();
+        assertNotNull(sheetName);
 
         // sanity check
         SanityChecker c = new SanityChecker();
-        c.checkHSSFWorkbook(wb);
+        c.checkHSSFWorkbook(wb1);
 
-        wb = HSSFTestDataSamples.writeOutAndReadBack(wb);
-        HSSFName nm =wb.getNameAt(wb.getNameIndex("RangeTest"));
+        HSSFWorkbook wb2 = HSSFTestDataSamples.writeOutAndReadBack(wb1);
+        HSSFName nm = wb2.getNameAt(wb2.getNameIndex("RangeTest"));
         assertTrue("Name is "+nm.getNameName(),"RangeTest".equals(nm.getNameName()));
-        assertEquals(wb.getSheetName(0)+"!$D$4:$E$8", nm.getRefersToFormula());
+        assertEquals(wb2.getSheetName(0)+"!$D$4:$E$8", nm.getRefersToFormula());
+        wb2.close();
+        wb1.close();
     }
 
     /**
@@ -156,7 +137,8 @@ public final class TestHSSFName extends BaseTestNamedRange {
      * <p>
      * Addresses Bug <a href="http://issues.apache.org/bugzilla/show_bug.cgi?id=9632" target="_bug">#9632</a>
      */
-    public void testNamedRead() {
+    @Test
+    public void testNamedRead() throws Exception {
         HSSFWorkbook wb = HSSFTestDataSamples.openSampleWorkbook("namedinput.xls");
 
         //Get index of the named range with the name = "NamedRangeName" , which was defined in input.xls as A1:D10
@@ -175,6 +157,8 @@ public final class TestHSSFName extends BaseTestNamedRange {
 
         assertEquals(sheetName+"!$D$17:$G$27", namedRange2.getRefersToFormula());
         assertEquals("SecondNamedRange", namedRange2.getNameName());
+        
+        wb.close();
     }
 
     /**
@@ -182,7 +166,8 @@ public final class TestHSSFName extends BaseTestNamedRange {
      * <p>
      * Addresses Bug <a href="http://issues.apache.org/bugzilla/show_bug.cgi?id=16411" target="_bug">#16411</a>
      */
-    public void testNamedReadModify() {
+    @Test
+    public void testNamedReadModify() throws Exception {
         HSSFWorkbook wb = HSSFTestDataSamples.openSampleWorkbook("namedinput.xls");
 
         HSSFName name = wb.getNameAt(0);
@@ -195,29 +180,33 @@ public final class TestHSSFName extends BaseTestNamedRange {
 
         name.setRefersToFormula(newReference);
         assertEquals(newReference, name.getRefersToFormula());
+        
+        wb.close();
     }
 
      /**
       * Test to see if the print area can be retrieved from an excel created file
       */
-     public void testPrintAreaFileRead() {
-         HSSFWorkbook workbook = HSSFTestDataSamples.openSampleWorkbook("SimpleWithPrintArea.xls");
+    @Test
+    public void testPrintAreaFileRead() throws Exception {
+        HSSFWorkbook workbook = HSSFTestDataSamples.openSampleWorkbook("SimpleWithPrintArea.xls");
 
         String sheetName = workbook.getSheetName(0);
         String reference = sheetName+"!$A$1:$C$5";
 
         assertEquals(reference, workbook.getPrintArea(0));
+        workbook.close();
     }
 
-
-    public void testDeletedReference() {
+    @Test
+    public void testDeletedReference() throws Exception {
         HSSFWorkbook wb = HSSFTestDataSamples.openSampleWorkbook("24207.xls");
         assertEquals(2, wb.getNumberOfNames());
 
         HSSFName name1 = wb.getNameAt(0);
         assertEquals("a", name1.getNameName());
         assertEquals("Sheet1!$A$1", name1.getRefersToFormula());
-        new AreaReference(name1.getRefersToFormula());
+        wb.getCreationHelper().createAreaReference(name1.getRefersToFormula());
         assertTrue("Successfully constructed first reference", true);
 
         HSSFName name2 = wb.getNameAt(1);
@@ -225,11 +214,12 @@ public final class TestHSSFName extends BaseTestNamedRange {
         assertEquals("Sheet1!#REF!", name2.getRefersToFormula());
         assertTrue(name2.isDeleted());
         try {
-            new AreaReference(name2.getRefersToFormula());
+            wb.getCreationHelper().createAreaReference(name2.getRefersToFormula());
             fail("attempt to supply an invalid reference to AreaReference constructor results in exception");
         } catch (IllegalArgumentException e) { // TODO - use a stronger typed exception for this condition
             // expected during successful test
         }
+        wb.close();
     }
 
     /**
@@ -237,14 +227,15 @@ public final class TestHSSFName extends BaseTestNamedRange {
      * must set the type of operands to Ptg.CLASS_REF,
      * otherwise created named don't appear in the drop-down to the left of formula bar in Excel
      */
-    public void testTypeOfRootPtg(){
+    @Test
+    public void testTypeOfRootPtg() throws Exception {
         HSSFWorkbook wb = new HSSFWorkbook();
         wb.createSheet("CSCO");
 
         Ptg[] ptgs = HSSFFormulaParser.parse("CSCO!$E$71", wb, FormulaType.NAMEDRANGE, 0);
-        for (int i = 0; i < ptgs.length; i++) {
-            assertEquals('R', ptgs[i].getRVAType());
+        for (Ptg ptg : ptgs) {
+            assertEquals('R', ptg.getRVAType());
         }
-
+        wb.close();
     }
 }
