@@ -18,27 +18,32 @@
 package org.apache.poi.hssf.usermodel;
 
 import static org.junit.Assert.assertArrayEquals;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.fail;
 
+import java.awt.Color;
+import java.io.IOException;
 import java.util.Iterator;
 import java.util.Map;
 
-import junit.framework.TestCase;
-
 import org.apache.poi.hssf.HSSFTestDataSamples;
 import org.apache.poi.hssf.record.PaletteRecord;
 import org.apache.poi.hssf.util.HSSFColor;
+import org.apache.poi.hssf.util.HSSFColor.HSSFColorPredefined;
+import org.apache.poi.ss.usermodel.FillPatternType;
+import org.apache.poi.ss.usermodel.Font;
+import org.junit.Before;
+import org.junit.Test;
 
-/**
- * @author Brian Sanders (bsanders at risklabs dot com)
- */
-public final class TestHSSFPalette extends TestCase {
+public final class TestHSSFPalette {
     private PaletteRecord _palette;
     private HSSFPalette _hssfPalette;
 
 
-    @Override
-    public void setUp()
-    {
+    @Before
+    public void setUp() {
         _palette = new PaletteRecord();
         _hssfPalette = new HSSFPalette(_palette);
     }
@@ -46,6 +51,7 @@ public final class TestHSSFPalette extends TestCase {
     /**
      * Verifies that a custom palette can be created, saved, and reloaded
      */
+    @Test
     public void testCustomPalette() {
         //reading sample xls
         HSSFWorkbook book = HSSFTestDataSamples.openSampleWorkbook("Simple.xls");
@@ -59,9 +65,9 @@ public final class TestHSSFPalette extends TestCase {
         book = HSSFTestDataSamples.writeOutAndReadBack(book);
 
         palette = book.getCustomPalette();
-        HSSFColor color = palette.getColor(HSSFColor.CORAL.index);  //unmodified
+        HSSFColor color = palette.getColor(HSSFColorPredefined.CORAL.getIndex());  //unmodified
         assertNotNull("Unexpected null in custom palette (unmodified index)", color);
-        short[] expectedRGB = HSSFColor.CORAL.triplet;
+        short[] expectedRGB = HSSFColorPredefined.CORAL.getTriplet();
         short[] actualRGB = color.getTriplet();
         String msg = "Expected palette position to remain unmodified";
         assertEquals(msg, expectedRGB[0], actualRGB[0]);
@@ -80,6 +86,8 @@ public final class TestHSSFPalette extends TestCase {
     /**
      * Uses the palette from cell stylings
      */
+    @SuppressWarnings("deprecation")
+    @Test
     public void testPaletteFromCellColours() {
         HSSFWorkbook book = HSSFTestDataSamples.openSampleWorkbook("SimpleWithColours.xls");
 
@@ -95,8 +103,9 @@ public final class TestHSSFPalette extends TestCase {
         assertEquals("I'm plain", cellA.getStringCellValue());
         assertEquals(64, cellA.getCellStyle().getFillForegroundColor());
         assertEquals(64, cellA.getCellStyle().getFillBackgroundColor());
-        assertEquals(HSSFFont.COLOR_NORMAL, cellA.getCellStyle().getFont(book).getColor());
-        assertEquals(0, cellA.getCellStyle().getFillPattern());
+        assertEquals(Font.COLOR_NORMAL, cellA.getCellStyle().getFont(book).getColor());
+        assertEquals(FillPatternType.NO_FILL, cellA.getCellStyle().getFillPattern());
+        assertEquals(FillPatternType.NO_FILL, cellA.getCellStyle().getFillPatternEnum());
         assertEquals("0:0:0", p.getColor((short)64).getHexString());
         assertEquals(null, p.getColor((short)32767));
 
@@ -105,7 +114,8 @@ public final class TestHSSFPalette extends TestCase {
         assertEquals(64, cellB.getCellStyle().getFillForegroundColor());
         assertEquals(64, cellB.getCellStyle().getFillBackgroundColor());
         assertEquals(10, cellB.getCellStyle().getFont(book).getColor());
-        assertEquals(0, cellB.getCellStyle().getFillPattern());
+        assertEquals(FillPatternType.NO_FILL, cellB.getCellStyle().getFillPattern());
+        assertEquals(FillPatternType.NO_FILL, cellB.getCellStyle().getFillPatternEnum());
         assertEquals("0:0:0", p.getColor((short)64).getHexString());
         assertEquals("FFFF:0:0", p.getColor((short)10).getHexString());
 
@@ -114,7 +124,8 @@ public final class TestHSSFPalette extends TestCase {
         assertEquals(11, cellC.getCellStyle().getFillForegroundColor());
         assertEquals(64, cellC.getCellStyle().getFillBackgroundColor());
         assertEquals(10, cellC.getCellStyle().getFont(book).getColor());
-        assertEquals(1, cellC.getCellStyle().getFillPattern());
+        assertEquals(FillPatternType.SOLID_FOREGROUND, cellC.getCellStyle().getFillPattern());
+        assertEquals(FillPatternType.SOLID_FOREGROUND, cellC.getCellStyle().getFillPatternEnum());
         assertEquals("0:FFFF:0", p.getColor((short)11).getHexString());
         assertEquals("FFFF:0:0", p.getColor((short)10).getHexString());
 
@@ -123,7 +134,8 @@ public final class TestHSSFPalette extends TestCase {
         assertEquals(13, cellD.getCellStyle().getFillForegroundColor());
         assertEquals(64, cellD.getCellStyle().getFillBackgroundColor());
         assertEquals(14, cellD.getCellStyle().getFont(book).getColor());
-        assertEquals(0, cellD.getCellStyle().getFillPattern());
+        assertEquals(FillPatternType.NO_FILL, cellD.getCellStyle().getFillPattern());
+        assertEquals(FillPatternType.NO_FILL, cellD.getCellStyle().getFillPatternEnum());
         assertEquals("FFFF:FFFF:0", p.getColor((short)13).getHexString());
         assertEquals("FFFF:0:FFFF", p.getColor((short)14).getHexString());
 
@@ -132,12 +144,14 @@ public final class TestHSSFPalette extends TestCase {
         assertEquals(13, cellE.getCellStyle().getFillForegroundColor());
         assertEquals(64, cellE.getCellStyle().getFillBackgroundColor());
         assertEquals(14, cellE.getCellStyle().getFont(book).getColor());
-        assertEquals(0, cellE.getCellStyle().getFillPattern());
+        assertEquals(FillPatternType.NO_FILL, cellE.getCellStyle().getFillPattern());
+        assertEquals(FillPatternType.NO_FILL, cellE.getCellStyle().getFillPatternEnum());
         assertEquals("FFFF:FFFF:0", p.getColor((short)13).getHexString());
         assertEquals("FFFF:0:FFFF", p.getColor((short)14).getHexString());
     }
 
-    public void testFindSimilar() {
+    @Test
+    public void testFindSimilar() throws IOException {
         HSSFWorkbook book = new HSSFWorkbook();
         HSSFPalette p = book.getCustomPalette();
         
@@ -219,12 +233,15 @@ public final class TestHSSFPalette extends TestCase {
                 p.getColor((short)12).getHexString(),
                 p.findSimilarColor(255, 2, 10).getHexString()
         );
+        
+        book.close();
     }
     
     /**
      * Verifies that the generated gnumeric-format string values match the
      * hardcoded values in the HSSFColor default color palette
      */
+    @Test
     public void testGnumericStrings() {
         compareToDefaults(new ColorComparator() {
             @Override
@@ -238,6 +255,7 @@ public final class TestHSSFPalette extends TestCase {
     /**
      * Verifies that the palette handles invalid palette indexes
      */
+    @Test
     public void testBadIndexes() {
         //too small
         _hssfPalette.setColorAtIndex((short) 2, (byte) 255, (byte) 255, (byte) 255);
@@ -270,6 +288,7 @@ public final class TestHSSFPalette extends TestCase {
         }
     }
 
+    @Test
     public void testAddColor() {
         try
         {
@@ -283,4 +302,27 @@ public final class TestHSSFPalette extends TestCase {
     private static interface ColorComparator {
         void compare(HSSFColor expected, HSSFColor palette);
     }
+
+    @Test
+    public void test48403() throws Exception {
+        HSSFWorkbook wb = new HSSFWorkbook();
+
+        Color color = Color.decode("#006B6B");
+        HSSFPalette palette = wb.getCustomPalette();
+        
+        HSSFColor hssfColor = palette.findColor((byte) color.getRed(),
+                (byte) color.getGreen(), (byte) color.getBlue());
+        assertNull(hssfColor);
+
+        palette.setColorAtIndex(
+                (short) (PaletteRecord.STANDARD_PALETTE_SIZE - 1),
+                (byte) color.getRed(), (byte) color.getGreen(),
+                (byte) color.getBlue());
+        hssfColor = palette.getColor((short) (PaletteRecord.STANDARD_PALETTE_SIZE - 1));
+        assertNotNull(hssfColor);
+        assertEquals(55, hssfColor.getIndex());
+        assertArrayEquals(new short[] {0, 107, 107}, hssfColor.getTriplet());
+        
+        wb.close();
+    }
 }
