@@ -21,7 +21,7 @@ import org.junit.runner.RunWith;
 import org.junit.runners.Suite;
 
 /**
- * Tests for org.apache.poi.poifs.filesystem<br/>
+ * Tests for org.apache.poi.poifs.filesystem
  */
 @RunWith(Suite.class)
 @Suite.SuiteClasses({
@@ -29,13 +29,12 @@ import org.junit.runners.Suite;
     , TestDocument.class
     , TestDocumentDescriptor.class
     , TestDocumentInputStream.class
-    , TestDocumentNode.class
     , TestDocumentOutputStream.class
     , TestEmptyDocument.class
-    , TestOffice2007XMLException.class
+    , TestNotOLE2Exception.class
+    , TestOfficeXMLException.class
     , TestPOIFSDocumentPath.class
     , TestPOIFSFileSystem.class
-    , TestNPOIFSFileSystem.class
     , TestPropertySorter.class
     , TestOle10Native.class
 })
