@@ -17,9 +17,11 @@
 
 package org.apache.poi.poifs.filesystem;
 
+import static org.apache.poi.POITestCase.assertContains;
 import static org.hamcrest.core.IsEqual.equalTo;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertThat;
+import static org.junit.Assert.fail;
 
 import java.io.ByteArrayOutputStream;
 import java.io.File;
@@ -59,9 +61,9 @@ public class TestOle10Native {
         };
         
         for (File f : files) {
-            NPOIFSFileSystem fs = new NPOIFSFileSystem(f, true);
-            List<Entry> entries = new ArrayList<Entry>();
-            findOle10(entries, fs.getRoot(), "/", "");
+            POIFSFileSystem fs = new POIFSFileSystem(f, true);
+            List<Entry> entries = new ArrayList<>();
+            findOle10(entries, fs.getRoot(), "/");
             
             for (Entry e : entries) {
                 ByteArrayOutputStream bosExp = new ByteArrayOutputStream();
@@ -81,21 +83,7 @@ public class TestOle10Native {
         }
     }
 
-    /*
-    void searchOle10Files() throws Exception {
-        File dir = new File("test-data/document");
-        for (File file : dir.listFiles(new FileFilter(){
-            public boolean accept(File pathname) {
-                return pathname.getName().endsWith("doc");
-            }
-        })) {
-            NPOIFSFileSystem fs = new NPOIFSFileSystem(file, true);
-            findOle10(null, fs.getRoot(), "/", file.getName());
-            fs.close();
-        }
-    }*/
-    
-    void findOle10(List<Entry> entries, DirectoryNode dn, String path, String filename) {
+    private void findOle10(List<Entry> entries, DirectoryNode dn, String path) {
         Iterator<Entry> iter = dn.getEntries();
         while (iter.hasNext()) {
             Entry e = iter.next();
@@ -103,8 +91,20 @@ public class TestOle10Native {
                 if (entries != null) entries.add(e);
                 // System.out.println(filename+" : "+path);
             } else if (e.isDirectoryEntry()) {
-                findOle10(entries, (DirectoryNode)e, path+e.getName()+"/", filename);
+                findOle10(entries, (DirectoryNode)e, path+e.getName()+"/");
             }
         }
     }
+
+    @Test
+    public void testOleNativeOOM() throws IOException {
+        POIFSFileSystem fs = new POIFSFileSystem(dataSamples.openResourceAsStream("60256.bin"));
+        try {
+            Ole10Native.createFromEmbeddedOleObject(fs);
+            fail("Should have thrown exception because OLENative lacks a length parameter");
+        } catch (Ole10NativeException e) {
+            assertContains(e.getMessage(), "declared data length");
+        }
+    }
+
 }
