@@ -18,6 +18,7 @@
 package org.apache.poi.ss;
 
 import org.apache.poi.ss.usermodel.FormulaEvaluator;
+import org.apache.poi.ss.usermodel.Sheet;
 import org.apache.poi.ss.usermodel.Workbook;
 
 /**
@@ -45,6 +46,22 @@ public interface ITestDataProvider {
      * @return an instance of Workbook
      */
     Workbook createWorkbook();
+    
+    
+    //************ SXSSF-specific methods ***************//
+    /**
+     * Provides way of creating a SXSSFWorkbook with a specific row access window size.
+     * Equivalent to createWorkbook on others.
+     * @return an instance of Workbook
+     */
+    Workbook createWorkbook(int rowAccessWindowSize);
+    
+    /**
+     * Only matters for SXSSF - enables tracking of the column
+     *  widths so that autosizing can work. No-op on others.
+     */
+    void trackAllColumnsForAutosizing(Sheet sheet);
+    //************ End SXSSF-specific methods ***************//
 
     /**
      * Creates the corresponding {@link FormulaEvaluator} for the
