@@ -17,30 +17,26 @@
 
 package org.apache.poi.ss.formula.eval;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.runner.RunWith;
+import org.junit.runners.Suite;
 
 /**
  * Collects all tests the package <tt>org.apache.poi.hssf.record.formula.eval</tt>.
- *
- * @author Josh Micich
  */
+@RunWith(Suite.class)
+@Suite.SuiteClasses({
+    TestAreaEval.class,
+    TestHSSFCircularReferences.class,
+    TestDivideEval.class,
+    TestEqualEval.class,
+    TestExternalFunction.class,
+    TestFormulaBugs.class,
+    TestFormulasFromSpreadsheet.class,
+    TestMinusZeroResult.class,
+    TestMissingArgEval.class,
+    TestPercentEval.class,
+    TestRangeEval.class,
+    TestUnaryPlusEval.class
+})
 public class AllFormulaEvalTests {
-
-	public static Test suite() {
-		TestSuite result = new TestSuite(AllFormulaEvalTests.class.getName());
-		result.addTestSuite(TestAreaEval.class);
-		result.addTestSuite(TestHSSFCircularReferences.class);
-		result.addTestSuite(TestDivideEval.class);
-		result.addTestSuite(TestEqualEval.class);
-		result.addTestSuite(TestExternalFunction.class);
-		result.addTestSuite(TestFormulaBugs.class);
-		result.addTestSuite(TestFormulasFromSpreadsheet.class);
-		result.addTestSuite(TestMinusZeroResult.class);
-		result.addTestSuite(TestMissingArgEval.class);
-		result.addTestSuite(TestPercentEval.class);
-		result.addTestSuite(TestRangeEval.class);
-		result.addTestSuite(TestUnaryPlusEval.class);
-		return result;
-	}
 }
