@@ -17,15 +17,16 @@
 
 package org.apache.poi.ss.formula.functions;
 
+import java.util.Collection;
+
+import org.junit.runners.Parameterized.Parameters;
+
 /**
- * Tests CODE() as loaded from a test data spreadsheet.<p/>
- *
- * @author cedric dot walter @ gmail dot com
+ * Tests CODE() as loaded from a test data spreadsheet.<p>
  */
 public class TestCodeFunctionsFromSpreadsheet extends BaseTestFunctionsFromSpreadsheet {
-
-    @Override
-    protected String getFilename() {
-        return "CodeFunctionTestCaseData.xls";
+    @Parameters(name="{0}")
+    public static Collection<Object[]> data() throws Exception {
+        return data(TestCodeFunctionsFromSpreadsheet.class, "CodeFunctionTestCaseData.xls");
     }
 }
\ No newline at end of file
