@@ -81,6 +81,28 @@ public final class TestDec2Hex extends TestCase {
 
 		confirmValue("Converts decimal -54 to hexadecimal, 2 is ignored","-54", "2",  "FFFFFFFFCA");
 		confirmValue("places is optionnal","-54", "FFFFFFFFCA");
+		
+		confirmValue("Converts normal decimal number to hexadecimal", "100", "64");
+        
+		String maxInt = Integer.toString(Integer.MAX_VALUE);
+        assertEquals("2147483647", maxInt);
+        confirmValue("Converts INT_MAX to hexadecimal", maxInt, "7FFFFFFF");
+
+        String minInt = Integer.toString(Integer.MIN_VALUE);
+        assertEquals("-2147483648", minInt);
+        confirmValue("Converts INT_MIN to hexadecimal", minInt, "FF80000000");
+
+        String maxIntPlusOne = Long.toString(((long)Integer.MAX_VALUE)+1);
+        assertEquals("2147483648", maxIntPlusOne);
+        confirmValue("Converts INT_MAX + 1 to hexadecimal", maxIntPlusOne, "80000000");
+        
+        String maxLong = Long.toString(549755813887l);
+        assertEquals("549755813887", maxLong);
+        confirmValue("Converts the max supported value to hexadecimal", maxLong, "7FFFFFFFFF");
+        
+        String minLong = Long.toString(-549755813888l);
+        assertEquals("-549755813888", minLong);
+        confirmValue("Converts the min supported value to hexadecimal", minLong, "FF80000000");
 	}
 
     public void testErrors() {
@@ -115,13 +137,13 @@ public final class TestDec2Hex extends TestCase {
         HSSFEvaluationWorkbook workbook = HSSFEvaluationWorkbook.create(wb);
         WorkbookEvaluator workbookEvaluator = new WorkbookEvaluator(workbook, new IStabilityClassifier() {
             
+            @Override
             public boolean isCellFinal(int sheetIndex, int rowIndex, int columnIndex) {
                 return true;
             }
         }, null);
-        OperationEvaluationContext ctx = new OperationEvaluationContext(workbookEvaluator, 
+        return new OperationEvaluationContext(workbookEvaluator,
                 workbook, 0, 0, 0, null);
-        return ctx;
     }
 
     public void testRefs() {
@@ -130,7 +152,7 @@ public final class TestDec2Hex extends TestCase {
         ValueEval[] args = new ValueEval[] { ctx.getRefEval(0, 0) };
         ValueEval result = new Dec2Hex().evaluate(args, -1, -1);
 
-        assertEquals("Had: " + result.toString(), StringEval.class, result.getClass());
+        assertEquals("Had: " + result, StringEval.class, result.getClass());
         assertEquals("7B", ((StringEval) result).getStringValue());
     }
 
@@ -140,7 +162,7 @@ public final class TestDec2Hex extends TestCase {
         ValueEval[] args = new ValueEval[] { ctx.getRefEval(0, 0), ctx.getRefEval(0, 1) };
         ValueEval result = new Dec2Hex().evaluate(args, -1, -1);
 
-        assertEquals("Had: " + result.toString(), StringEval.class, result.getClass());
+        assertEquals("Had: " + result, StringEval.class, result.getClass());
         assertEquals("0000007B", ((StringEval) result).getStringValue());
     }
 
@@ -150,7 +172,7 @@ public final class TestDec2Hex extends TestCase {
         ValueEval[] args = new ValueEval[] { ctx.getRefEval(0, 0), ctx.getRefEval(0, 1) };
         ValueEval result = new Dec2Hex().evaluate(args, ctx);
 
-        assertEquals("Had: " + result.toString(), StringEval.class, result.getClass());
+        assertEquals("Had: " + result, StringEval.class, result.getClass());
         assertEquals("0000007B", ((StringEval) result).getStringValue());
     }
 
@@ -207,11 +229,11 @@ public final class TestDec2Hex extends TestCase {
     public void testBackAndForth() {
         for (int i = -512; i < 512; i++) {
             ValueEval result = invokeValue(Integer.toString(i));
-            assertEquals("Had: " + result.toString(), StringEval.class,
+            assertEquals("Had: " + result, StringEval.class,
                     result.getClass());
 
             ValueEval back = invokeBack(((StringEval) result).getStringValue());
-            assertEquals("Had: " + back.toString(), NumberEval.class,
+            assertEquals("Had: " + back, NumberEval.class,
                     back.getClass());
 
             assertEquals(Integer.toString(i),
