@@ -17,14 +17,16 @@
 
 package org.apache.poi.ss.formula.functions;
 
+import java.util.Collection;
+
+import org.junit.runners.Parameterized.Parameters;
+
 /**
- * Tests Roman() as loaded from a test data spreadsheet.<p/>
- *
- * @author cedric dot walter @ gmail dot com
+ * Tests Roman() as loaded from a test data spreadsheet.<p>
  */
 public class TestRomanFunctionsFromSpreadsheet extends BaseTestFunctionsFromSpreadsheet {
-
-    protected String getFilename() {
-        return "RomanFunctionTestCaseData.xls";
+    @Parameters(name="{0}")
+    public static Collection<Object[]> data() throws Exception {
+        return data(TestRomanFunctionsFromSpreadsheet.class, "RomanFunctionTestCaseData.xls");
     }
 }
