@@ -17,14 +17,16 @@
 
 package org.apache.poi.ss.formula.functions;
 
+import java.util.Collection;
+
+import org.junit.runners.Parameterized.Parameters;
+
 /**
- * Tests WeekNum() as loaded from a test data spreadsheet.<p/>
- *
- * @author cedric dot walter @ gmail dot com
+ * Tests WeekNum() as loaded from a test data spreadsheet.<p>
  */
 public class TestWeekNumFunctionsFromSpreadsheet extends BaseTestFunctionsFromSpreadsheet {
-
-    protected String getFilename() {
-        return "WeekNumFunctionTestCaseData.xls";
+    @Parameters(name="{0}")
+    public static Collection<Object[]> data() throws Exception {
+        return data(TestWeekNumFunctionsFromSpreadsheet.class, "WeekNumFunctionTestCaseData.xls");
     }
 }
