@@ -22,6 +22,8 @@ import junit.framework.TestCase;
 
 import org.apache.poi.hssf.model.HSSFFormulaParser;
 import org.apache.poi.hssf.usermodel.HSSFWorkbook;
+import org.apache.poi.ss.SpreadsheetVersion;
+import org.apache.poi.ss.util.AreaReference;
 
 /**
  * Tests for {@link AreaPtg}.
@@ -33,6 +35,7 @@ public final class TestAreaPtg extends TestCase {
 	AreaPtg relative;
 	AreaPtg absolute;
 	
+	@Override
 	protected void setUp() {
 		short firstRow=5;
 		short lastRow=13;
@@ -41,6 +44,17 @@ public final class TestAreaPtg extends TestCase {
 		relative = new AreaPtg(firstRow,lastRow,firstCol,lastCol,true,true,true,true);
 		absolute = new AreaPtg(firstRow,lastRow,firstCol,lastCol,false,false,false,false);
 	}
+	
+	public static void testSortTopLeftToBottomRight() {
+	    AreaPtg ptg = new AreaPtg(new AreaReference("A$1:$B5", SpreadsheetVersion.EXCEL2007));
+	    assertEquals("A$1:$B5", ptg.toFormulaString());
+	    ptg.setFirstColumn(3);
+	    assertEquals("Area Ptg should not implicitly re-sort itself (except during construction)",
+	            "D$1:$B5", ptg.toFormulaString());
+	    ptg.sortTopLeftToBottomRight();
+	    assertEquals("Area Ptg should restore itself to top-left to lower-right order when explicitly asked",
+	            "$B$1:D5", ptg.toFormulaString());
+	}
 
 	public void testSetColumnsAbsolute()
 	{
@@ -117,9 +131,7 @@ public final class TestAreaPtg extends TestCase {
 		int letUsShiftColumn1By1Column=1;
 		HSSFWorkbook wb = null;
 		Ptg[] ptgs = HSSFFormulaParser.parse(formula, wb);
-		for(int i=0; i<ptgs.length; i++)
-		{
-			Ptg ptg = ptgs[i];
+		for (Ptg ptg : ptgs) {
 			if (ptg instanceof AreaPtg )
 			{
 				AreaPtg aptg = (AreaPtg)ptg;
@@ -127,7 +139,6 @@ public final class TestAreaPtg extends TestCase {
 				aptg.setLastColumn((short)(aptg.getLastColumn()+letUsShiftColumn1By1Column));
 			}
 		}
-		String newFormula = HSSFFormulaParser.toFormulaString(wb, ptgs);
-		return newFormula;
+        return HSSFFormulaParser.toFormulaString(wb, ptgs);
 	}
 }
