@@ -17,13 +17,7 @@
 
 package org.apache.poi.ss.formula.ptg;
 
-import org.apache.poi.util.TempFile;
-
-import java.io.File;
-import java.io.FileOutputStream;
-import java.io.IOException;
-
-import junit.framework.TestCase;
+import static org.junit.Assert.assertEquals;
 
 import org.apache.poi.hssf.HSSFTestDataSamples;
 import org.apache.poi.hssf.model.HSSFFormulaParser;
@@ -32,45 +26,53 @@ import org.apache.poi.hssf.usermodel.HSSFFormulaEvaluator;
 import org.apache.poi.hssf.usermodel.HSSFSheet;
 import org.apache.poi.hssf.usermodel.HSSFWorkbook;
 import org.apache.poi.ss.usermodel.CellValue;
+import org.junit.Test;
+
 /**
  * Tests for functions from external workbooks (e.g. YEARFRAC).
  */
-public final class TestExternalFunctionFormulas extends TestCase {
+public final class TestExternalFunctionFormulas {
 
 	/**
 	 * tests <tt>NameXPtg.toFormulaString(Workbook)</tt> and logic in Workbook below that   
 	 */
-	public void testReadFormulaContainingExternalFunction() {
+    @Test
+	public void testReadFormulaContainingExternalFunction() throws Exception {
 		HSSFWorkbook wb = HSSFTestDataSamples.openSampleWorkbook("externalFunctionExample.xls");
 		
 		String expectedFormula = "YEARFRAC(B1,C1)";
 		HSSFSheet sht = wb.getSheetAt(0);
 		String cellFormula = sht.getRow(0).getCell(0).getCellFormula();
 		assertEquals(expectedFormula, cellFormula);
+		
+		wb.close();
 	}
 	
-	public void testParse() {
+    @Test
+    public void testParse() throws Exception {
 		HSSFWorkbook wb = HSSFTestDataSamples.openSampleWorkbook("externalFunctionExample.xls");
 		Ptg[] ptgs = HSSFFormulaParser.parse("YEARFRAC(B1,C1)", wb);
 		assertEquals(4, ptgs.length);
 		assertEquals(NameXPtg.class, ptgs[0].getClass());
 		
 		wb.getSheetAt(0).getRow(0).createCell(6).setCellFormula("YEARFRAC(C1,B1)");
-		if (false) {
-			// In case you fancy checking in excel
-			try {
-				File tempFile = TempFile.createTempFile("testExtFunc", ".xls");
-				FileOutputStream fout = new FileOutputStream(tempFile);
-				wb.write(fout);
-				fout.close();
-				System.out.println("check out " + tempFile.getAbsolutePath());
-			} catch (IOException e) {
-				throw new RuntimeException(e);
-			}
-		}
+//		if (false) {
+//			// In case you fancy checking in excel
+//			try {
+//				File tempFile = TempFile.createTempFile("testExtFunc", ".xls");
+//				FileOutputStream fout = new FileOutputStream(tempFile);
+//				wb.write(fout);
+//				fout.close();
+//				System.out.println("check out " + tempFile.getAbsolutePath());
+//			} catch (IOException e) {
+//				throw new RuntimeException(e);
+//			}
+//		}
+		wb.close();
 	}
 	
-	public void testEvaluate() {
+    @Test
+	public void testEvaluate() throws Exception {
 		HSSFWorkbook wb = HSSFTestDataSamples.openSampleWorkbook("externalFunctionExample.xls");
 		HSSFSheet sheet = wb.getSheetAt(0);
 		HSSFFormulaEvaluator fe = new HSSFFormulaEvaluator(wb);
@@ -79,6 +81,7 @@ public final class TestExternalFunctionFormulas extends TestCase {
 		confirmCellEval(sheet, 2, 0, fe, "YEARFRAC(B3,C3,D3)", 0.0);
 		confirmCellEval(sheet, 3, 0, fe, "IF(ISEVEN(3),1.2,1.6)", 1.6);
 		confirmCellEval(sheet, 4, 0, fe, "IF(ISODD(3),1.2,1.6)", 1.2);
+		wb.close();
 	}
 
 	private static void confirmCellEval(HSSFSheet sheet, int rowIx, int colIx, 
