@@ -17,25 +17,34 @@
 
 package org.apache.poi.ss.usermodel;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
+import java.io.IOException;
 import java.util.Iterator;
 
-import junit.framework.TestCase;
-
 import org.apache.poi.ss.ITestDataProvider;
+import org.apache.poi.ss.usermodel.Row.MissingCellPolicy;
+import org.junit.Test;
 
 /**
  * A base class for testing implementations of
  * {@link org.apache.poi.ss.usermodel.Row}
  */
-public abstract class BaseTestRow extends TestCase {
+public abstract class BaseTestRow {
 
-    private final ITestDataProvider _testDataProvider;
+    protected final ITestDataProvider _testDataProvider;
 
     protected BaseTestRow(ITestDataProvider testDataProvider) {
         _testDataProvider = testDataProvider;
     }
 
-    public void testLastAndFirstColumns() {
+    @Test
+    public void testLastAndFirstColumns() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
         Row row = sheet.createRow(0);
@@ -57,13 +66,15 @@ public abstract class BaseTestRow extends TestCase {
         row.createCell(3);
         assertEquals(1, row.getFirstCellNum());
         assertEquals(4, row.getLastCellNum());
+        workbook.close();
     }
 
     /**
      * Make sure that there is no cross-talk between rows especially with getFirstCellNum and getLastCellNum
      * This test was added in response to bug report 44987.
      */
-    public void testBoundsInMultipleRows() {
+    @Test
+    public void testBoundsInMultipleRows() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
         Row rowA = sheet.createRow(0);
@@ -85,12 +96,14 @@ public abstract class BaseTestRow extends TestCase {
         assertEquals(51, rowA.getLastCellNum());
 
         assertEquals(31, rowB.getLastCellNum());
+        workbook.close();
     }
 
-    public void testRemoveCell() {
-        Workbook workbook = _testDataProvider.createWorkbook();
+    @Test
+    public void testRemoveCell() throws IOException {
+        Workbook wb1 = _testDataProvider.createWorkbook();
         {
-            Sheet sheet = workbook.createSheet();
+            Sheet sheet = wb1.createSheet();
             Row row = sheet.createRow(0);
 
             assertEquals(0, row.getPhysicalNumberOfCells());
@@ -115,18 +128,21 @@ public abstract class BaseTestRow extends TestCase {
             assertEquals(0, row.getPhysicalNumberOfCells());
         }
 
-        workbook = _testDataProvider.writeOutAndReadBack(workbook);
+        Workbook wb2 = _testDataProvider.writeOutAndReadBack(wb1);
+        wb1.close();
 
         {
-            Sheet sheet = workbook.getSheetAt(0);
+            Sheet sheet = wb2.getSheetAt(0);
             Row row = sheet.getRow(0);
             assertEquals(-1, row.getLastCellNum());
             assertEquals(-1, row.getFirstCellNum());
             assertEquals(0, row.getPhysicalNumberOfCells());
         }
+        
+        wb2.close();
     }
 
-    public void baseTestRowBounds(int maxRowNum) {
+    protected void baseTestRowBounds(int maxRowNum) throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
         //Test low row bound
@@ -137,7 +153,8 @@ public abstract class BaseTestRow extends TestCase {
             fail("expected exception");
         } catch (IllegalArgumentException e) {
             // expected during successful test
-            assertTrue(e.getMessage().startsWith("Invalid row number (-1)"));
+            assertTrue("Did not find expected error message, had: " + e, 
+                    e.getMessage().startsWith("Invalid row number (-1)"));
         }
 
         //Test high row bound
@@ -150,11 +167,13 @@ public abstract class BaseTestRow extends TestCase {
             // expected during successful test
             assertEquals("Invalid row number ("+(maxRowNum + 1)+") outside allowable range (0.."+maxRowNum+")", e.getMessage());
         }
+        
+        workbook.close();
     }
 
-    public void baseTestCellBounds(int maxCellNum) {
-        Workbook workbook = _testDataProvider.createWorkbook();
-        Sheet sheet = workbook.createSheet();
+    protected void baseTestCellBounds(int maxCellNum) throws IOException {
+        Workbook wb1 = _testDataProvider.createWorkbook();
+        Sheet sheet = wb1.createSheet();
 
         Row row = sheet.createRow(0);
         //Test low cell bound
@@ -178,22 +197,25 @@ public abstract class BaseTestRow extends TestCase {
             row.createCell(i);
         }
         assertEquals(maxCellNum, row.getPhysicalNumberOfCells());
-        workbook = _testDataProvider.writeOutAndReadBack(workbook);
-        sheet = workbook.getSheetAt(0);
+        Workbook wb2 = _testDataProvider.writeOutAndReadBack(wb1);
+        wb1.close();
+        
+        sheet = wb2.getSheetAt(0);
         row = sheet.getRow(0);
         assertEquals(maxCellNum, row.getPhysicalNumberOfCells());
         for(int i=0; i < maxCellNum; i++){
             Cell cell = row.getCell(i);
             assertEquals(i, cell.getColumnIndex());
         }
-
+        wb2.close();
     }
 
     /**
      * Prior to patch 43901, POI was producing files with the wrong last-column
      * number on the row
      */
-    public void testLastCellNumIsCorrectAfterAddCell_bug43901(){
+    @Test
+    public void testLastCellNumIsCorrectAfterAddCell_bug43901() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet("test");
         Row row = sheet.createRow(0);
@@ -210,12 +232,14 @@ public abstract class BaseTestRow extends TestCase {
         assertEquals(1, row.getLastCellNum());
         row.createCell(255);
         assertEquals(256, row.getLastCellNum());
+        workbook.close();
     }
 
     /**
      * Tests for the missing/blank cell policy stuff
      */
-    public void testGetCellPolicy() {
+    @Test
+    public void testGetCellPolicy() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet("test");
         Row row = sheet.createRow(0);
@@ -228,65 +252,68 @@ public abstract class BaseTestRow extends TestCase {
         // 5 -> num
         row.createCell(0).setCellValue("test");
         row.createCell(1).setCellValue(3.2);
-        row.createCell(4, Cell.CELL_TYPE_BLANK);
+        row.createCell(4, CellType.BLANK);
         row.createCell(5).setCellValue(4);
 
         // First up, no policy given, uses default
-        assertEquals(Cell.CELL_TYPE_STRING,  row.getCell(0).getCellType());
-        assertEquals(Cell.CELL_TYPE_NUMERIC, row.getCell(1).getCellType());
+        assertEquals(CellType.STRING,  row.getCell(0).getCellType());
+        assertEquals(CellType.NUMERIC, row.getCell(1).getCellType());
         assertEquals(null, row.getCell(2));
         assertEquals(null, row.getCell(3));
-        assertEquals(Cell.CELL_TYPE_BLANK,   row.getCell(4).getCellType());
-        assertEquals(Cell.CELL_TYPE_NUMERIC, row.getCell(5).getCellType());
+        assertEquals(CellType.BLANK,   row.getCell(4).getCellType());
+        assertEquals(CellType.NUMERIC, row.getCell(5).getCellType());
 
         // RETURN_NULL_AND_BLANK - same as default
-        assertEquals(Cell.CELL_TYPE_STRING,  row.getCell(0, Row.RETURN_NULL_AND_BLANK).getCellType());
-        assertEquals(Cell.CELL_TYPE_NUMERIC, row.getCell(1, Row.RETURN_NULL_AND_BLANK).getCellType());
-        assertEquals(null, row.getCell(2, Row.RETURN_NULL_AND_BLANK));
-        assertEquals(null, row.getCell(3, Row.RETURN_NULL_AND_BLANK));
-        assertEquals(Cell.CELL_TYPE_BLANK,   row.getCell(4, Row.RETURN_NULL_AND_BLANK).getCellType());
-        assertEquals(Cell.CELL_TYPE_NUMERIC, row.getCell(5, Row.RETURN_NULL_AND_BLANK).getCellType());
+        assertEquals(CellType.STRING,  row.getCell(0, MissingCellPolicy.RETURN_NULL_AND_BLANK).getCellType());
+        assertEquals(CellType.NUMERIC, row.getCell(1, MissingCellPolicy.RETURN_NULL_AND_BLANK).getCellType());
+        assertEquals(null, row.getCell(2, MissingCellPolicy.RETURN_NULL_AND_BLANK));
+        assertEquals(null, row.getCell(3, MissingCellPolicy.RETURN_NULL_AND_BLANK));
+        assertEquals(CellType.BLANK,   row.getCell(4, MissingCellPolicy.RETURN_NULL_AND_BLANK).getCellType());
+        assertEquals(CellType.NUMERIC, row.getCell(5, MissingCellPolicy.RETURN_NULL_AND_BLANK).getCellType());
 
         // RETURN_BLANK_AS_NULL - nearly the same
-        assertEquals(Cell.CELL_TYPE_STRING,  row.getCell(0, Row.RETURN_BLANK_AS_NULL).getCellType());
-        assertEquals(Cell.CELL_TYPE_NUMERIC, row.getCell(1, Row.RETURN_BLANK_AS_NULL).getCellType());
-        assertEquals(null, row.getCell(2, Row.RETURN_BLANK_AS_NULL));
-        assertEquals(null, row.getCell(3, Row.RETURN_BLANK_AS_NULL));
-        assertEquals(null, row.getCell(4, Row.RETURN_BLANK_AS_NULL));
-        assertEquals(Cell.CELL_TYPE_NUMERIC, row.getCell(5, Row.RETURN_BLANK_AS_NULL).getCellType());
+        assertEquals(CellType.STRING,  row.getCell(0, MissingCellPolicy.RETURN_BLANK_AS_NULL).getCellType());
+        assertEquals(CellType.NUMERIC, row.getCell(1, MissingCellPolicy.RETURN_BLANK_AS_NULL).getCellType());
+        assertEquals(null, row.getCell(2, MissingCellPolicy.RETURN_BLANK_AS_NULL));
+        assertEquals(null, row.getCell(3, MissingCellPolicy.RETURN_BLANK_AS_NULL));
+        assertEquals(null, row.getCell(4, MissingCellPolicy.RETURN_BLANK_AS_NULL));
+        assertEquals(CellType.NUMERIC, row.getCell(5, MissingCellPolicy.RETURN_BLANK_AS_NULL).getCellType());
 
         // CREATE_NULL_AS_BLANK - creates as needed
-        assertEquals(Cell.CELL_TYPE_STRING,  row.getCell(0, Row.CREATE_NULL_AS_BLANK).getCellType());
-        assertEquals(Cell.CELL_TYPE_NUMERIC, row.getCell(1, Row.CREATE_NULL_AS_BLANK).getCellType());
-        assertEquals(Cell.CELL_TYPE_BLANK,   row.getCell(2, Row.CREATE_NULL_AS_BLANK).getCellType());
-        assertEquals(Cell.CELL_TYPE_BLANK,   row.getCell(3, Row.CREATE_NULL_AS_BLANK).getCellType());
-        assertEquals(Cell.CELL_TYPE_BLANK,   row.getCell(4, Row.CREATE_NULL_AS_BLANK).getCellType());
-        assertEquals(Cell.CELL_TYPE_NUMERIC, row.getCell(5, Row.CREATE_NULL_AS_BLANK).getCellType());
+        assertEquals(CellType.STRING,  row.getCell(0, MissingCellPolicy.CREATE_NULL_AS_BLANK).getCellType());
+        assertEquals(CellType.NUMERIC, row.getCell(1, MissingCellPolicy.CREATE_NULL_AS_BLANK).getCellType());
+        assertEquals(CellType.BLANK,   row.getCell(2, MissingCellPolicy.CREATE_NULL_AS_BLANK).getCellType());
+        assertEquals(CellType.BLANK,   row.getCell(3, MissingCellPolicy.CREATE_NULL_AS_BLANK).getCellType());
+        assertEquals(CellType.BLANK,   row.getCell(4, MissingCellPolicy.CREATE_NULL_AS_BLANK).getCellType());
+        assertEquals(CellType.NUMERIC, row.getCell(5, MissingCellPolicy.CREATE_NULL_AS_BLANK).getCellType());
 
         // Check created ones get the right column
-        assertEquals(0, row.getCell(0, Row.CREATE_NULL_AS_BLANK).getColumnIndex());
-        assertEquals(1, row.getCell(1, Row.CREATE_NULL_AS_BLANK).getColumnIndex());
-        assertEquals(2, row.getCell(2, Row.CREATE_NULL_AS_BLANK).getColumnIndex());
-        assertEquals(3, row.getCell(3, Row.CREATE_NULL_AS_BLANK).getColumnIndex());
-        assertEquals(4, row.getCell(4, Row.CREATE_NULL_AS_BLANK).getColumnIndex());
-        assertEquals(5, row.getCell(5, Row.CREATE_NULL_AS_BLANK).getColumnIndex());
+        assertEquals(0, row.getCell(0, MissingCellPolicy.CREATE_NULL_AS_BLANK).getColumnIndex());
+        assertEquals(1, row.getCell(1, MissingCellPolicy.CREATE_NULL_AS_BLANK).getColumnIndex());
+        assertEquals(2, row.getCell(2, MissingCellPolicy.CREATE_NULL_AS_BLANK).getColumnIndex());
+        assertEquals(3, row.getCell(3, MissingCellPolicy.CREATE_NULL_AS_BLANK).getColumnIndex());
+        assertEquals(4, row.getCell(4, MissingCellPolicy.CREATE_NULL_AS_BLANK).getColumnIndex());
+        assertEquals(5, row.getCell(5, MissingCellPolicy.CREATE_NULL_AS_BLANK).getColumnIndex());
 
 
         // Now change the cell policy on the workbook, check
         //  that that is now used if no policy given
-        workbook.setMissingCellPolicy(Row.RETURN_BLANK_AS_NULL);
+        workbook.setMissingCellPolicy(MissingCellPolicy.RETURN_BLANK_AS_NULL);
 
-        assertEquals(Cell.CELL_TYPE_STRING,  row.getCell(0).getCellType());
-        assertEquals(Cell.CELL_TYPE_NUMERIC, row.getCell(1).getCellType());
+        assertEquals(CellType.STRING,  row.getCell(0).getCellType());
+        assertEquals(CellType.NUMERIC, row.getCell(1).getCellType());
         assertEquals(null, row.getCell(2));
         assertEquals(null, row.getCell(3));
         assertEquals(null, row.getCell(4));
-        assertEquals(Cell.CELL_TYPE_NUMERIC, row.getCell(5).getCellType());
+        assertEquals(CellType.NUMERIC, row.getCell(5).getCellType());
+        
+        workbook.close();
     }
 
-    public void testRowHeight() {
-        Workbook workbook = _testDataProvider.createWorkbook();
-        Sheet sheet = workbook.createSheet();
+    @Test
+    public void testRowHeight() throws IOException {
+        Workbook wb1 = _testDataProvider.createWorkbook();
+        Sheet sheet = wb1.createSheet();
         Row row1 = sheet.createRow(0);
 
         assertEquals(sheet.getDefaultRowHeight(), row1.getHeight());
@@ -312,8 +339,9 @@ public abstract class BaseTestRow extends TestCase {
         row4.setZeroHeight(true);
         assertTrue(row4.getZeroHeight());
 
-        workbook = _testDataProvider.writeOutAndReadBack(workbook);
-        sheet = workbook.getSheetAt(0);
+        Workbook wb2 = _testDataProvider.writeOutAndReadBack(wb1);
+        wb1.close();
+        sheet = wb2.getSheetAt(0);
 
         row1 = sheet.getRow(0);
         row2 = sheet.getRow(1);
@@ -332,12 +360,14 @@ public abstract class BaseTestRow extends TestCase {
         assertFalse(row2.getZeroHeight());
         assertFalse(row3.getZeroHeight());
         assertTrue(row4.getZeroHeight());
+        wb2.close();
     }
 
     /**
      * Test adding cells to a row in various places and see if we can find them again.
      */
-    public void testCellIterator() {
+    @Test
+    public void testCellIterator() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
         Sheet sheet = wb.createSheet();
         Row row = sheet.createRow(0);
@@ -379,7 +409,7 @@ public abstract class BaseTestRow extends TestCase {
         assertFalse(it.hasNext());
 
         // Add another cell, specifying the cellType
-        Cell cell5 = row.createCell(2, Cell.CELL_TYPE_STRING);
+        Cell cell5 = row.createCell(2, CellType.STRING);
         it = row.cellIterator();
         assertNotNull(cell5);
         assertTrue(it.hasNext());
@@ -390,12 +420,14 @@ public abstract class BaseTestRow extends TestCase {
         assertTrue(cell5 == it.next());
         assertTrue(it.hasNext());
         assertTrue(cell2 == it.next());
-        assertEquals(Cell.CELL_TYPE_STRING, cell5.getCellType());
+        assertEquals(CellType.STRING, cell5.getCellType());
+        wb.close();
     }
 
-    public void testRowStyle() {
-       Workbook workbook = _testDataProvider.createWorkbook();
-       Sheet sheet = workbook.createSheet("test");
+    @Test
+    public void testRowStyle() throws IOException {
+       Workbook wb1 = _testDataProvider.createWorkbook();
+       Sheet sheet = wb1.createSheet("test");
        Row row1 = sheet.createRow(0);
        Row row2 = sheet.createRow(1);
 
@@ -406,7 +438,7 @@ public abstract class BaseTestRow extends TestCase {
        assertEquals(null, row2.getRowStyle());
 
        // Style one
-       CellStyle style = workbook.createCellStyle();
+       CellStyle style = wb1.createCellStyle();
        style.setDataFormat((short)4);
        row2.setRowStyle(style);
 
@@ -417,17 +449,86 @@ public abstract class BaseTestRow extends TestCase {
        assertEquals(style, row2.getRowStyle());
 
        // Save, load and re-check
-       workbook = _testDataProvider.writeOutAndReadBack(workbook);
-       sheet = workbook.getSheetAt(0);
+       Workbook wb2 = _testDataProvider.writeOutAndReadBack(wb1);
+       wb1.close();
+       
+       sheet = wb2.getSheetAt(0);
 
        row1 = sheet.getRow(0);
        row2 = sheet.getRow(1);
-       style = workbook.getCellStyleAt(style.getIndex());
+       style = wb2.getCellStyleAt(style.getIndex());
 
        assertEquals(false, row1.isFormatted());
        assertEquals(true, row2.isFormatted());
        assertEquals(null, row1.getRowStyle());
        assertEquals(style, row2.getRowStyle());
        assertEquals(4, style.getDataFormat());
+       
+       wb2.close();
+    }
+    
+    @Test
+    public void testCellShiftingRight() {
+        Workbook wb = _testDataProvider.createWorkbook();
+        Sheet sheet = wb.createSheet("sheet1");
+        Row row = sheet.createRow(0);
+        row.createCell(0, CellType.NUMERIC).setCellValue(0);
+        row.createCell(1, CellType.NUMERIC).setCellValue(1);
+        row.createCell(2, CellType.NUMERIC).setCellValue(2);//C
+        row.createCell(3, CellType.NUMERIC).setCellValue(3);//D
+        row.createCell(4, CellType.NUMERIC).setCellValue(4);//E
+        row.createCell(5, CellType.NUMERIC).setCellValue(5);//F
+        row.createCell(6, CellType.NUMERIC).setCellValue(6);//G
+        try {
+            row.shiftCellsLeft(6, 4, 2); // range [6-4] is illegal
+            fail("expected shiftLeft to fail");
+        } catch (IllegalArgumentException e){
+            row.shiftCellsRight(2, 4, 1);
+            //should be [0.0, 1.0, null, 2.0, 3.0, 4.0, 6.0, null]
+            
+            Cell h1 = row.getCell(7);
+            assertNull(h1);
+            Cell g1 = row.getCell(6);
+            assertEquals(6, g1.getNumericCellValue(), 0.01);
+            Cell f1 = row.getCell(5);
+            assertEquals(4, f1.getNumericCellValue(), 0.01);
+            Cell e1 = row.getCell(4);
+            assertEquals(3, e1.getNumericCellValue(), 0.01);
+            Cell d1 = row.getCell(3);
+            assertEquals(2, d1.getNumericCellValue(), 0.01);
+            Cell c1 = row.getCell(2);
+            assertNull(c1);
+        }
+    }
+    @Test
+    public void testCellShiftingLeft() {
+        Workbook wb = _testDataProvider.createWorkbook();
+        Sheet sheet = wb.createSheet("sheet1");
+        Row row = sheet.createRow(0);
+        row.createCell(0, CellType.NUMERIC).setCellValue(0);
+        row.createCell(1, CellType.NUMERIC).setCellValue(1);
+        row.createCell(2, CellType.NUMERIC).setCellValue(2);//C
+        row.createCell(3, CellType.NUMERIC).setCellValue(3);//D
+        row.createCell(4, CellType.NUMERIC).setCellValue(4);//E
+        row.createCell(5, CellType.NUMERIC).setCellValue(5);//F
+        row.createCell(6, CellType.NUMERIC).setCellValue(6);//G
+        try {
+            row.shiftCellsLeft(4, 6, -2); // step = -1 is illegal
+            fail("expected shiftLeft to fail");
+        } catch (IllegalArgumentException e){
+            row.shiftCellsLeft(4, 6, 2);
+            //should be [0.0, 1.0, 4.0, 5.0, 6.0, null, null, null]
+            
+            Cell b1 = row.getCell(1);
+            assertEquals(1, b1.getNumericCellValue(), 0.01);
+            Cell c1 = row.getCell(2);
+            assertEquals(4, c1.getNumericCellValue(), 0.01);
+            Cell d1 = row.getCell(3);
+            assertEquals(5, d1.getNumericCellValue(), 0.01);
+            Cell e1 = row.getCell(4);
+            assertEquals(6, e1.getNumericCellValue(), 0.01);
+            Cell f1 = row.getCell(5);
+            assertNull(f1);
+        }
     }
 }
