@@ -17,24 +17,28 @@
 
 package org.apache.poi.ss.usermodel;
 
-import static junit.framework.TestCase.assertNotNull;
-import static junit.framework.TestCase.assertTrue;
-import static org.junit.Assert.*;
-
-import java.io.IOException;
-import java.util.Iterator;
-
-import org.apache.poi.hssf.util.PaneInformation;
+import org.apache.poi.common.usermodel.HyperlinkType;
 import org.apache.poi.ss.ITestDataProvider;
 import org.apache.poi.ss.SpreadsheetVersion;
+import org.apache.poi.ss.util.CellAddress;
 import org.apache.poi.ss.util.CellRangeAddress;
+import org.apache.poi.ss.util.PaneInformation;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.ExpectedException;
 
+import java.io.IOException;
+import java.util.*;
+import java.util.Map.Entry;
+
+import static org.apache.poi.POITestCase.assertBetween;
+import static org.junit.Assert.*;
+import static org.junit.Assume.assumeTrue;
+
 /**
- * Common superclass for testing {@link org.apache.poi.xssf.usermodel.XSSFCell}  and
- * {@link org.apache.poi.hssf.usermodel.HSSFCell}
+ * Common superclass for testing {@link org.apache.poi.hssf.usermodel.HSSFCell},
+ * {@link org.apache.poi.xssf.usermodel.XSSFCell} and
+ * {@link org.apache.poi.xssf.streaming.SXSSFCell}
  */
 public abstract class BaseTestSheet {
     private static final int ROW_COUNT = 40000;
@@ -42,14 +46,18 @@ public abstract class BaseTestSheet {
     @Rule
     public ExpectedException thrown = ExpectedException.none();
     
-    private final ITestDataProvider _testDataProvider;
+    protected final ITestDataProvider _testDataProvider;
 
     protected BaseTestSheet(ITestDataProvider testDataProvider) {
-    	_testDataProvider = testDataProvider;
+        _testDataProvider = testDataProvider;
+    }
+    
+    protected void trackColumnsForAutoSizingIfSXSSF(Sheet sheet) {
+        // do nothing for Sheet base class. This will be overridden for SXSSFSheets.
     }
 
     @Test
-    public void createRow() {
+    public void createRow() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
         assertEquals(0, sheet.getPhysicalNumberOfRows());
@@ -86,11 +94,39 @@ public abstract class BaseTestSheet {
         Row row2_ovrewritten_ref = it2.next();
         assertSame(row2_ovrewritten, row2_ovrewritten_ref);
         assertEquals(100.0, row2_ovrewritten_ref.getCell(0).getNumericCellValue(), 0.0);
+        
+        workbook.close();
+    }
+    
+    @Test(expected=IllegalArgumentException.class)
+    public void createRowBeforeFirstRow() throws IOException {
+        final Workbook workbook = _testDataProvider.createWorkbook();
+        final Sheet sh = workbook.createSheet();
+        sh.createRow(0);
+        try {
+            // Negative rows not allowed
+            sh.createRow(-1);
+        } finally {
+            workbook.close();
+        }
+    }
+    
+    @Test(expected=IllegalArgumentException.class)
+    public void createRowAfterLastRow() throws IOException {
+        final SpreadsheetVersion version = _testDataProvider.getSpreadsheetVersion();
+        final Workbook workbook = _testDataProvider.createWorkbook();
+        final Sheet sh = workbook.createSheet();
+        sh.createRow(version.getLastRowIndex());
+        try {
+            // Row number must be between 0 and last row
+            sh.createRow(version.getLastRowIndex() + 1);
+        } finally {
+            workbook.close();
+        }
     }
 
-
     @Test
-    public void removeRow() {
+    public void removeRow() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet1 = workbook.createSheet();
         assertEquals(0, sheet1.getPhysicalNumberOfRows());
@@ -127,10 +163,12 @@ public abstract class BaseTestSheet {
         thrown.expect(IllegalArgumentException.class);
         thrown.expectMessage("Specified row does not belong to this sheet");
         sheet2.removeRow(row3);
+
+        workbook.close();
     }
 
     @Test
-    public void cloneSheet() {
+    public void cloneSheet() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         CreationHelper factory = workbook.getCreationHelper();
         Sheet sheet = workbook.createSheet("Test Clone");
@@ -157,13 +195,15 @@ public abstract class BaseTestSheet {
         }
         assertEquals(clonedRow.getCell(0).getRichStringCellValue().getString(), "clone_test");
         assertEquals(clonedRow.getCell(1).getCellFormula(), "SIN(1)");
+        
+        workbook.close();
     }
 
     /** tests that the sheet name for multiple clones of the same sheet is unique
      * BUG 37416
      */
     @Test
-    public void cloneSheetMultipleTimes() {
+    public void cloneSheetMultipleTimes() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         CreationHelper factory = workbook.getCreationHelper();
         Sheet sheet = workbook.createSheet("Test Clone");
@@ -185,16 +225,18 @@ public abstract class BaseTestSheet {
         workbook.createSheet("abc ( 123)");
         workbook.cloneSheet(0);
         assertEquals("abc (124)", workbook.getSheetName(1));
+        
+        workbook.close();
     }
 
     /**
      * Setting landscape and portrait stuff on new sheets
      */
     @Test
-    public void printSetupLandscapeNew() {
-        Workbook workbook = _testDataProvider.createWorkbook();
-        Sheet sheetL = workbook.createSheet("LandscapeS");
-        Sheet sheetP = workbook.createSheet("LandscapeP");
+    public void printSetupLandscapeNew() throws IOException {
+        Workbook wb1 = _testDataProvider.createWorkbook();
+        Sheet sheetL = wb1.createSheet("LandscapeS");
+        Sheet sheetP = wb1.createSheet("LandscapeP");
 
         // Check two aspects of the print setup
         assertFalse(sheetL.getPrintSetup().getLandscape());
@@ -213,14 +255,88 @@ public abstract class BaseTestSheet {
         assertEquals(3, sheetP.getPrintSetup().getCopies());
 
         // Save and re-load, and check still there
-        workbook = _testDataProvider.writeOutAndReadBack(workbook);
-        sheetL = workbook.getSheet("LandscapeS");
-        sheetP = workbook.getSheet("LandscapeP");
+        Workbook wb2 = _testDataProvider.writeOutAndReadBack(wb1);
+        wb1.close();
+        sheetL = wb2.getSheet("LandscapeS");
+        sheetP = wb2.getSheet("LandscapeP");
 
         assertTrue(sheetL.getPrintSetup().getLandscape());
         assertFalse(sheetP.getPrintSetup().getLandscape());
         assertEquals(1, sheetL.getPrintSetup().getCopies());
         assertEquals(3, sheetP.getPrintSetup().getCopies());
+        wb2.close();
+    }
+    
+    /**
+     * Disallow creating wholly or partially overlapping merged regions
+     * as this results in a corrupted workbook
+     */
+    @Test
+    public void addOverlappingMergedRegions() throws IOException {
+        final Workbook wb = _testDataProvider.createWorkbook();
+        final Sheet sheet = wb.createSheet();
+        
+        final CellRangeAddress baseRegion = new CellRangeAddress(0, 1, 0, 1); //A1:B2
+        sheet.addMergedRegion(baseRegion);
+        
+        try {
+            final CellRangeAddress duplicateRegion = new CellRangeAddress(0, 1, 0, 1); //A1:B2
+            sheet.addMergedRegion(duplicateRegion);
+            fail("Should not be able to add a merged region (" + duplicateRegion.formatAsString() + ") " +
+                 "if sheet already contains the same merged region (" + baseRegion.formatAsString() + ")");
+        } catch (final IllegalStateException e) {
+            // expected here
+        }
+        
+        try {
+            final CellRangeAddress partiallyOverlappingRegion = new CellRangeAddress(1, 2, 1, 2); //B2:C3
+            sheet.addMergedRegion(partiallyOverlappingRegion);
+            fail("Should not be able to add a merged region (" + partiallyOverlappingRegion.formatAsString() + ") " +
+                 "if it partially overlaps with an existing merged region (" + baseRegion.formatAsString() + ")");
+        } catch (final IllegalStateException e) {
+            // expected here
+        }
+        
+        try {
+            final CellRangeAddress subsetRegion = new CellRangeAddress(0, 1, 0, 0); //A1:A2
+            sheet.addMergedRegion(subsetRegion);
+            fail("Should not be able to add a merged region (" + subsetRegion.formatAsString() + ") " +
+                 "if it is a formal subset of an existing merged region (" + baseRegion.formatAsString() + ")");
+        } catch (final IllegalStateException e) {
+            // expected here
+        }
+        
+        try {
+            final CellRangeAddress supersetRegion = new CellRangeAddress(0, 2, 0, 2); //A1:C3
+            sheet.addMergedRegion(supersetRegion);
+            fail("Should not be able to add a merged region (" + supersetRegion.formatAsString() + ") " +
+                 "if it is a formal superset of an existing merged region (" + baseRegion.formatAsString() + ")");
+        } catch (final IllegalStateException e) {
+            // expected here
+        }
+        
+        final CellRangeAddress disjointRegion = new CellRangeAddress(10, 11, 10, 11);
+        sheet.addMergedRegion(disjointRegion);
+        
+        wb.close();
+    }
+
+    /*
+     * Bug 56345: Reject single-cell merged regions
+     */
+    @Test
+    public void addMergedRegionWithSingleCellShouldFail() throws IOException {
+        final Workbook wb = _testDataProvider.createWorkbook();
+
+        final Sheet sheet = wb.createSheet();
+        final CellRangeAddress region = CellRangeAddress.valueOf("A1:A1");
+        try {
+            sheet.addMergedRegion(region);
+            fail("Should not be able to add a single-cell merged region (" + region.formatAsString() + ")");
+        } catch (final IllegalArgumentException e) {
+            // expected
+        }
+        wb.close();
     }
 
     /**
@@ -229,7 +345,7 @@ public abstract class BaseTestSheet {
      *
      */
     @Test
-    public void addMerged() {
+    public void addMerged() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
         Sheet sheet = wb.createSheet();
         assertEquals(0, sheet.getNumMergedRegions());
@@ -261,6 +377,8 @@ public abstract class BaseTestSheet {
             assertEquals("Maximum row number is " + ssVersion.getLastRowIndex(), e.getMessage());
         }
         assertEquals(1, sheet.getNumMergedRegions());
+        
+        wb.close();
     }
 
     /**
@@ -268,18 +386,18 @@ public abstract class BaseTestSheet {
      *
      */
     @Test
-    public void removeMerged() {
+    public void removeMerged() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
         Sheet sheet = wb.createSheet();
         CellRangeAddress region = new CellRangeAddress(0, 1, 0, 1);
         sheet.addMergedRegion(region);
-        region = new CellRangeAddress(1, 2, 0, 1);
+        region = new CellRangeAddress(2, 3, 0, 1);
         sheet.addMergedRegion(region);
 
         sheet.removeMergedRegion(0);
 
         region = sheet.getMergedRegion(0);
-        assertEquals("Left over region should be starting at row 1", 1, region.getFirstRow());
+        assertEquals("Left over region should be starting at row 2", 2, region.getFirstRow());
 
         sheet.removeMergedRegion(0);
 
@@ -299,11 +417,43 @@ public abstract class BaseTestSheet {
         //should exist now!
         assertTrue("there isn't more than one merged region in there", 1 <= sheet.getNumMergedRegions());
         region = sheet.getMergedRegion(0);
-        assertEquals("the merged row to doesnt match the one we put in ", 4, region.getLastRow());
+        assertEquals("the merged row to doesn't match the one we put in ", 4, region.getLastRow());
+        
+        wb.close();
+    }
+    
+    /**
+     * Remove multiple merged regions
+     */
+    @Test
+    public void removeMergedRegions() throws IOException {
+        Workbook wb = _testDataProvider.createWorkbook();
+        Sheet sheet = wb.createSheet();
+        
+        Map<Integer, CellRangeAddress> mergedRegions = new HashMap<>();
+        for (int r=0; r<10; r++) {
+            CellRangeAddress region = new CellRangeAddress(r, r, 0, 1);
+            mergedRegions.put(r, region);
+            sheet.addMergedRegion(region);
+        }
+        assertCollectionEquals(mergedRegions.values(), sheet.getMergedRegions());
+        
+        Collection<Integer> removed = Arrays.asList(0, 2, 3, 6, 8);
+        mergedRegions.keySet().removeAll(removed);
+        sheet.removeMergedRegions(removed);
+        assertCollectionEquals(mergedRegions.values(), sheet.getMergedRegions());
+        
+        wb.close();
+    }
+    
+    private static <T> void assertCollectionEquals(Collection<T> expected, Collection<T> actual) {
+        Set<T> e = new HashSet<>(expected);
+        Set<T> a = new HashSet<>(actual);
+        assertEquals(e, a);
     }
 
     @Test
-    public void shiftMerged() {
+    public void shiftMerged() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
         CreationHelper factory = wb.getCreationHelper();
         Sheet sheet = wb.createSheet();
@@ -315,23 +465,74 @@ public abstract class BaseTestSheet {
         cell = row.createCell(1);
         cell.setCellValue(factory.createRichTextString("second row, second cell"));
 
-        CellRangeAddress region = new CellRangeAddress(1, 1, 0, 1);
+        CellRangeAddress region = CellRangeAddress.valueOf("A2:B2");
         sheet.addMergedRegion(region);
 
         sheet.shiftRows(1, 1, 1);
 
         region = sheet.getMergedRegion(0);
-        assertEquals("Merged region not moved over to row 2", 2, region.getFirstRow());
+        
+        CellRangeAddress expectedRegion = CellRangeAddress.valueOf("A3:B3");
+        assertEquals("Merged region should shift down a row", expectedRegion, region);
+        
+        wb.close();
+    }
+
+    /**
+     * bug 58885: checking for overlapping merged regions when
+     * adding a merged region is safe, but runs in O(n).
+     * the check for merged regions when adding a merged region
+     * can be skipped (unsafe) and run in O(1).
+     */
+    @Test
+    public void addMergedRegionUnsafe() throws IOException {
+        Workbook wb = _testDataProvider.createWorkbook();
+        Sheet sh = wb.createSheet();
+        CellRangeAddress region1 = CellRangeAddress.valueOf("A1:B2");
+        CellRangeAddress region2 = CellRangeAddress.valueOf("B2:C3");
+        CellRangeAddress region3 = CellRangeAddress.valueOf("C3:D4");
+        CellRangeAddress region4 = CellRangeAddress.valueOf("J10:K11");
+        assumeTrue(region1.intersects(region2));
+        assumeTrue(region2.intersects(region3));
+
+        sh.addMergedRegionUnsafe(region1);
+        assertTrue(sh.getMergedRegions().contains(region1));
+
+        // adding a duplicate or overlapping merged region should not
+        // raise an exception with the unsafe version of addMergedRegion.
+
+        sh.addMergedRegionUnsafe(region2);
+
+        // the safe version of addMergedRegion should throw when trying to add a merged region that overlaps an existing region
+        assertTrue(sh.getMergedRegions().contains(region2));
+        try {
+            sh.addMergedRegion(region3);
+            fail("Expected IllegalStateException. region3 overlaps already added merged region2.");
+        } catch (final IllegalStateException e) {
+            // expected
+            assertFalse(sh.getMergedRegions().contains(region3));
+        }
+        // addMergedRegion should not re-validate previously-added merged regions
+        sh.addMergedRegion(region4);
+
+        // validation methods should detect a problem with previously added merged regions (runs in O(n^2) time)
+        try {
+            sh.validateMergedRegions();
+            fail("Expected validation to fail. Sheet contains merged regions A1:B2 and B2:C3, which overlap at B2.");
+        } catch (final IllegalStateException e) {
+            // expected
+        }
+
+        wb.close();
     }
 
     /**
      * Tests the display of gridlines, formulas, and rowcolheadings.
-     * @author Shawn Laubach (slaubach at apache dot org)
      */
     @Test
-    public void displayOptions() {
-        Workbook wb = _testDataProvider.createWorkbook();
-        Sheet sheet = wb.createSheet();
+    public void displayOptions() throws IOException {
+        Workbook wb1 = _testDataProvider.createWorkbook();
+        Sheet sheet = wb1.createSheet();
 
         assertEquals(sheet.isDisplayGridlines(), true);
         assertEquals(sheet.isDisplayRowColHeadings(), true);
@@ -343,19 +544,22 @@ public abstract class BaseTestSheet {
         sheet.setDisplayFormulas(true);
         sheet.setDisplayZeros(false);
 
-        wb = _testDataProvider.writeOutAndReadBack(wb);
-        sheet = wb.getSheetAt(0);
+        Workbook wb2 = _testDataProvider.writeOutAndReadBack(wb1);
+        wb1.close();
+        sheet = wb2.getSheetAt(0);
 
         assertEquals(sheet.isDisplayGridlines(), false);
         assertEquals(sheet.isDisplayRowColHeadings(), false);
         assertEquals(sheet.isDisplayFormulas(), true);
         assertEquals(sheet.isDisplayZeros(), false);
+        
+        wb2.close();
     }
 
     @Test
-    public void columnWidth() {
-        Workbook wb = _testDataProvider.createWorkbook();
-        Sheet sheet = wb.createSheet();
+    public void columnWidth() throws IOException {
+        Workbook wb1 = _testDataProvider.createWorkbook();
+        Sheet sheet = wb1.createSheet();
 
         //default column width measured in characters
         sheet.setDefaultColumnWidth(10);
@@ -396,9 +600,10 @@ public abstract class BaseTestSheet {
         }
 
         //serialize and read again
-        wb = _testDataProvider.writeOutAndReadBack(wb);
+        Workbook wb2 = _testDataProvider.writeOutAndReadBack(wb1);
+        wb1.close();
 
-        sheet = wb.getSheetAt(0);
+        sheet = wb2.getSheetAt(0);
         assertEquals(20, sheet.getDefaultColumnWidth());
         //columns A-C have default width
         assertEquals(256*20, sheet.getColumnWidth(0));
@@ -410,11 +615,13 @@ public abstract class BaseTestSheet {
             assertEquals(w, sheet.getColumnWidth(i));
         }
         assertEquals(40000, sheet.getColumnWidth(10));
+        
+        wb2.close();
     }
 
     
     @Test
-    public void defaultRowHeight() {
+    public void defaultRowHeight() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
         sheet.setDefaultRowHeightInPoints(15);
@@ -439,11 +646,13 @@ public abstract class BaseTestSheet {
         sheet.setDefaultRowHeightInPoints(17.5f);
         assertEquals(17.5f, sheet.getDefaultRowHeightInPoints(), 0F);
         assertEquals((short)(17.5f*20), sheet.getDefaultRowHeight());
+        
+        workbook.close();
     }
 
     /** cell with formula becomes null on cloning a sheet*/
     @Test
-    public void bug35084() {
+    public void bug35084() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
         Sheet s = wb.createSheet("Sheet1");
         Row r = s.createRow(0);
@@ -454,11 +663,12 @@ public abstract class BaseTestSheet {
         assertEquals("double", r.getCell(0).getNumericCellValue(), 1, 0); // sanity check
         assertNotNull(r.getCell(1));
         assertEquals("formula", r.getCell(1).getCellFormula(), "A1*2");
+        wb.close();
     }
 
     /** test that new default column styles get applied */
     @Test
-    public void defaultColumnStyle() {
+    public void defaultColumnStyle() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
         CellStyle style = wb.createCellStyle();
         Sheet sheet = wb.createSheet();
@@ -471,13 +681,14 @@ public abstract class BaseTestSheet {
         CellStyle style2 = cell.getCellStyle();
         assertNotNull(style2);
         assertEquals("style should match", style.getIndex(), style2.getIndex());
+        wb.close();
     }
 
     @Test
-    public void outlineProperties() {
-        Workbook wb = _testDataProvider.createWorkbook();
+    public void outlineProperties() throws IOException {
+        Workbook wb1 = _testDataProvider.createWorkbook();
 
-        Sheet sheet = wb.createSheet();
+        Sheet sheet = wb1.createSheet();
 
         //TODO defaults are different in HSSF and XSSF
         //assertTrue(sheet.getRowSumsBelow());
@@ -495,17 +706,19 @@ public abstract class BaseTestSheet {
         assertTrue(sheet.getRowSumsBelow());
         assertTrue(sheet.getRowSumsRight());
 
-        wb = _testDataProvider.writeOutAndReadBack(wb);
-        sheet = wb.getSheetAt(0);
+        Workbook wb2 = _testDataProvider.writeOutAndReadBack(wb1);
+        wb1.close();
+        sheet = wb2.getSheetAt(0);
         assertTrue(sheet.getRowSumsBelow());
         assertTrue(sheet.getRowSumsRight());
+        wb2.close();
     }
 
     /**
-     * Test basic display properties
+     * Test basic display and print properties
      */
     @Test
-    public void sheetProperties() {
+    public void sheetProperties() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
         Sheet sheet = wb.createSheet();
 
@@ -524,6 +737,10 @@ public abstract class BaseTestSheet {
         assertFalse(sheet.isPrintGridlines());
         sheet.setPrintGridlines(true);
         assertTrue(sheet.isPrintGridlines());
+        
+        assertFalse(sheet.isPrintRowAndColumnHeadings());
+        sheet.setPrintRowAndColumnHeadings(true);
+        assertTrue(sheet.isPrintRowAndColumnHeadings());
 
         assertFalse(sheet.isDisplayFormulas());
         sheet.setDisplayFormulas(true);
@@ -555,9 +772,11 @@ public abstract class BaseTestSheet {
         assertTrue(sheet.getFitToPage());
         sheet.setFitToPage(false);
         assertFalse(sheet.getFitToPage());
+        
+        wb.close();
     }
 
-    public void baseTestGetSetMargin(double[] defaultMargins) {
+    public void baseTestGetSetMargin(double[] defaultMargins) throws IOException {
         double marginLeft = defaultMargins[0];
         double marginRight = defaultMargins[1];
         double marginTop = defaultMargins[2];
@@ -590,10 +809,12 @@ public abstract class BaseTestSheet {
         thrown.expect(IllegalArgumentException.class);
         thrown.expectMessage("Unknown margin constant:  65");
         sheet.setMargin((short) 65, 15);
+        
+        workbook.close();
     }
 
     @Test
-    public void rowBreaks() {
+    public void rowBreaks() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
         //Sheet#getRowBreaks() returns an empty array if no row breaks are defined
@@ -619,10 +840,12 @@ public abstract class BaseTestSheet {
 
         assertFalse(sheet.isRowBroken(1));
         assertFalse(sheet.isRowBroken(15));
+        
+        workbook.close();
     }
 
     @Test
-    public void columnBreaks() {
+    public void columnBreaks() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
         assertNotNull(sheet.getColumnBreaks());
@@ -647,10 +870,11 @@ public abstract class BaseTestSheet {
 
         assertFalse(sheet.isColumnBroken(11));
         assertFalse(sheet.isColumnBroken(12));
+        workbook.close();
     }
 
     @Test
-    public void getFirstLastRowNum() {
+    public void getFirstLastRowNum() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet("Sheet 1");
         sheet.createRow(9);
@@ -658,27 +882,30 @@ public abstract class BaseTestSheet {
         sheet.createRow(1);
         assertEquals(0, sheet.getFirstRowNum());
         assertEquals(9, sheet.getLastRowNum());
+        workbook.close();
     }
 
     @Test
-    public void getFooter() {
+    public void getFooter() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet("Sheet 1");
         assertNotNull(sheet.getFooter());
         sheet.getFooter().setCenter("test center footer");
         assertEquals("test center footer", sheet.getFooter().getCenter());
+        workbook.close();
     }
 
     @Test
-    public void getSetColumnHidden() {
+    public void getSetColumnHidden() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet("Sheet 1");
         sheet.setColumnHidden(2, true);
         assertTrue(sheet.isColumnHidden(2));
+        workbook.close();
     }
 
     @Test
-    public void protectSheet() {
+    public void protectSheet() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
         Sheet sheet = wb.createSheet();
         assertFalse(sheet.getProtect());
@@ -686,11 +913,11 @@ public abstract class BaseTestSheet {
         assertTrue(sheet.getProtect());
         sheet.protectSheet(null);
         assertFalse(sheet.getProtect());
-
+        wb.close();
     }
 
     @Test
-    public void createFreezePane() {
+    public void createFreezePane() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
         // create a workbook
         Sheet sheet = wb.createSheet();
@@ -737,11 +964,13 @@ public abstract class BaseTestSheet {
         sheet.createFreezePane(0, 0);
         // If both colSplit and rowSplit are zero then the existing freeze pane is removed
         assertNull(sheet.getPaneInformation());
+        
+        wb.close();
     }
 
     
     @Test
-    public void getRepeatingRowsAndColumns() {
+    public void getRepeatingRowsAndColumns() throws IOException {
         Workbook wb = _testDataProvider.openSampleWorkbook(
             "RepeatingRowsCols." 
             + _testDataProvider.getStandardFileNameExtension());
@@ -750,11 +979,12 @@ public abstract class BaseTestSheet {
         checkRepeatingRowsAndColumns(wb.getSheetAt(1), "1:1", null);
         checkRepeatingRowsAndColumns(wb.getSheetAt(2), null, "A:A");
         checkRepeatingRowsAndColumns(wb.getSheetAt(3), "2:3", "A:B");
+        wb.close();
     }
 
 
     @Test
-    public void setRepeatingRowsAndColumnsBug47294(){
+    public void setRepeatingRowsAndColumnsBug47294() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
         Sheet sheet1 = wb.createSheet();
         sheet1.setRepeatingRows(CellRangeAddress.valueOf("1:4"));
@@ -764,14 +994,15 @@ public abstract class BaseTestSheet {
         Sheet sheet2 = wb.createSheet("My' Sheet");
         sheet2.setRepeatingRows(CellRangeAddress.valueOf("1:4"));
         assertEquals("1:4", sheet2.getRepeatingRows().formatAsString());
+        wb.close();
     }
 
     @Test
-    public void setRepeatingRowsAndColumns() {
-        Workbook wb = _testDataProvider.createWorkbook();
-        Sheet sheet1 = wb.createSheet("Sheet1");
-        Sheet sheet2 = wb.createSheet("Sheet2");
-        Sheet sheet3 = wb.createSheet("Sheet3");
+    public void setRepeatingRowsAndColumns() throws IOException {
+        Workbook wb1 = _testDataProvider.createWorkbook();
+        Sheet sheet1 = wb1.createSheet("Sheet1");
+        Sheet sheet2 = wb1.createSheet("Sheet2");
+        Sheet sheet3 = wb1.createSheet("Sheet3");
         
         checkRepeatingRowsAndColumns(sheet1, null, null);
         
@@ -785,10 +1016,11 @@ public abstract class BaseTestSheet {
         checkRepeatingRowsAndColumns(sheet3, "1:4", "A:A");
         
         // write out, read back, and test refrain...
-        wb = _testDataProvider.writeOutAndReadBack(wb);
-        sheet1 = wb.getSheetAt(0);
-        sheet2 = wb.getSheetAt(1);
-        sheet3 = wb.getSheetAt(2);
+        Workbook wb2 = _testDataProvider.writeOutAndReadBack(wb1);
+        wb1.close();
+        sheet1 = wb2.getSheetAt(0);
+        sheet2 = wb2.getSheetAt(1);
+        sheet3 = wb2.getSheetAt(2);
         
         checkRepeatingRowsAndColumns(sheet1, "4:5", null);
         checkRepeatingRowsAndColumns(sheet2, null, "A:C");
@@ -800,6 +1032,7 @@ public abstract class BaseTestSheet {
         
         sheet3.setRepeatingColumns(null);
         checkRepeatingRowsAndColumns(sheet3, null, null);
+        wb2.close();
     }
 
     private void checkRepeatingRowsAndColumns(
@@ -817,23 +1050,25 @@ public abstract class BaseTestSheet {
     }
 
     @Test
-    public void baseZoom() {
+    public void baseZoom() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
         Sheet sheet = wb.createSheet();
         
         // here we can only verify that setting some zoom values works, range-checking is different between the implementations
-        sheet.setZoom(3,4);
+        sheet.setZoom(75);
+        wb.close();
     }
     
     @Test
-    public void baseShowInPane() {
+    public void baseShowInPane() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
         Sheet sheet = wb.createSheet();
         sheet.showInPane(2, 3);
+        wb.close();
     }
 
     @Test
-    public void bug55723(){
+    public void bug55723() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
         Sheet sheet = wb.createSheet();
 
@@ -846,6 +1081,7 @@ public abstract class BaseTestSheet {
         filter = sheet.setAutoFilter(range);
         assertNotNull(filter);
         // there seems to be currently no generic way to check the setting...
+        wb.close();
     }
 
     @Test
@@ -874,12 +1110,12 @@ public abstract class BaseTestSheet {
 
     /**
      * XSSFSheet autoSizeColumn() on empty RichTextString fails
-     * @throws IOException 
      */
     @Test
     public void bug48325() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
         Sheet sheet = wb.createSheet("Test");
+        trackColumnsForAutoSizingIfSXSSF(sheet);
         CreationHelper factory = wb.getCreationHelper();
 
         Row row = sheet.createRow(0);
@@ -901,19 +1137,119 @@ public abstract class BaseTestSheet {
     public void getCellComment() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
-        Drawing dg = sheet.createDrawingPatriarch();
+        Drawing<?> dg = sheet.createDrawingPatriarch();
         Comment comment = dg.createCellComment(workbook.getCreationHelper().createClientAnchor());
         Cell cell = sheet.createRow(9).createCell(2);
         comment.setAuthor("test C10 author");
         cell.setCellComment(comment);
 
-        assertNotNull(sheet.getCellComment(9, 2));
-        assertEquals("test C10 author", sheet.getCellComment(9, 2).getAuthor());
+        CellAddress ref = new CellAddress(9, 2);
+        assertNotNull(sheet.getCellComment(ref));
+        assertEquals("test C10 author", sheet.getCellComment(ref).getAuthor());
         
         assertNotNull(_testDataProvider.writeOutAndReadBack(workbook));
         
         workbook.close();
     }
+    
+    
+    @Test
+    public void getCellComments() throws IOException {
+        Workbook workbook = _testDataProvider.createWorkbook();
+        Sheet sheet = workbook.createSheet("TEST");
+
+        // a sheet with no cell comments should return an empty map (not null or raise NPE).
+        assertEquals(Collections.emptyMap(), sheet.getCellComments());
+
+        Drawing<?> dg = sheet.createDrawingPatriarch();
+        ClientAnchor anchor = workbook.getCreationHelper().createClientAnchor();
+        
+        int nRows = 5;
+        int nCols = 6;
+        
+        for (int r=0; r<nRows; r++) {
+            sheet.createRow(r);
+            // Create columns in reverse order
+            for (int c=nCols-1; c>=0; c--) {
+                // When the comment box is visible, have it show in a 1x3 space
+                anchor.setCol1(c);
+                anchor.setCol2(c);
+                anchor.setRow1(r);
+                anchor.setRow2(r);
+                
+                // Create the comment and set the text-author
+                Comment comment = dg.createCellComment(anchor);
+                Cell cell = sheet.getRow(r).createCell(c);
+                comment.setAuthor("Author " + r);
+                RichTextString text = workbook.getCreationHelper().createRichTextString("Test comment at row=" + r + ", column=" + c);
+                comment.setString(text);
+                
+                // Assign the comment to the cell
+                cell.setCellComment(comment);
+            }
+        }
+        
+        Workbook wb = _testDataProvider.writeOutAndReadBack(workbook);
+        Sheet sh = wb.getSheet("TEST");
+        Map<CellAddress, ? extends Comment> cellComments = sh.getCellComments();
+        assertEquals(nRows*nCols, cellComments.size());
+        
+        for (Entry<CellAddress, ? extends Comment> e : cellComments.entrySet()) {
+            CellAddress ref = e.getKey();
+            Comment aComment = e.getValue();
+            assertEquals("Author " + ref.getRow(), aComment.getAuthor());
+            String text = "Test comment at row=" + ref.getRow() + ", column=" + ref.getColumn();
+            assertEquals(text, aComment.getString().getString());
+        }
+        
+        workbook.close();
+        wb.close();
+    }
+    
+    @Test
+    public void getHyperlink() throws IOException {
+        Workbook workbook = _testDataProvider.createWorkbook();
+        Hyperlink hyperlink = workbook.getCreationHelper().createHyperlink(HyperlinkType.URL);
+        hyperlink.setAddress("https://poi.apache.org/");
+        
+        Sheet sheet = workbook.createSheet();
+        Cell cell = sheet.createRow(5).createCell(1);
+        
+        assertEquals("list size before add", 0, sheet.getHyperlinkList().size());
+        cell.setHyperlink(hyperlink);
+        assertEquals("list size after add", 1, sheet.getHyperlinkList().size());
+        
+        assertEquals("list", hyperlink, sheet.getHyperlinkList().get(0));
+        CellAddress B6 = new CellAddress(5, 1);
+        assertEquals("row, col", hyperlink, sheet.getHyperlink(5, 1));
+        assertEquals("addr", hyperlink, sheet.getHyperlink(B6));
+        assertEquals("no hyperlink at A1", null, sheet.getHyperlink(CellAddress.A1));
+        
+        workbook.close();
+    }
+    
+    @Test
+    public void removeAllHyperlinks() throws IOException {
+        Workbook workbook = _testDataProvider.createWorkbook();
+        Hyperlink hyperlink = workbook.getCreationHelper().createHyperlink(HyperlinkType.URL);
+        hyperlink.setAddress("https://poi.apache.org/");
+        Sheet sheet = workbook.createSheet();
+        Cell cell = sheet.createRow(5).createCell(1);
+        cell.setHyperlink(hyperlink);
+        
+        assertEquals(1, workbook.getSheetAt(0).getHyperlinkList().size());
+        // Save a workbook with a hyperlink
+        Workbook workbook2 = _testDataProvider.writeOutAndReadBack(workbook);
+        assertEquals(1, workbook2.getSheetAt(0).getHyperlinkList().size());
+        
+        // Remove all hyperlinks from a saved workbook
+        workbook2.getSheetAt(0).getRow(5).getCell(1).removeHyperlink();
+        assertEquals(0, workbook2.getSheetAt(0).getHyperlinkList().size());
+        
+        // Verify that hyperlink was removed from workbook after writing out
+        Workbook workbook3 = _testDataProvider.writeOutAndReadBack(workbook2);
+        assertEquals(0, workbook3.getSheetAt(0).getHyperlinkList().size());
+    }
 
 
     @Test
@@ -931,9 +1267,9 @@ public abstract class BaseTestSheet {
     }
 
     @Test
-    public void showInPaneManyRowsBug55248() {
-        Workbook workbook = _testDataProvider.createWorkbook();
-        Sheet sheet = workbook.createSheet("Sheet 1");
+    public void showInPaneManyRowsBug55248() throws IOException {
+        Workbook wb1 = _testDataProvider.createWorkbook();
+        Sheet sheet = wb1.createSheet("Sheet 1");
 
         sheet.showInPane(0, 0);
 
@@ -946,8 +1282,11 @@ public abstract class BaseTestSheet {
         int i = 0;
         sheet.showInPane(i, i);
 
-        Workbook wb = _testDataProvider.writeOutAndReadBack(workbook);
-        checkRowCount(wb);
+        Workbook wb2 = _testDataProvider.writeOutAndReadBack(wb1);
+        checkRowCount(wb2);
+        
+        wb2.close();
+        wb1.close();
     }
 
     private void checkRowCount(Workbook wb) {
@@ -971,4 +1310,77 @@ public abstract class BaseTestSheet {
         
         wb.close();
     }
+    
+    @Test
+    public void testNoMergedRegionsIsEmptyList() throws IOException {
+        Workbook wb = _testDataProvider.createWorkbook();
+        Sheet sheet = wb.createSheet();
+        assertTrue(sheet.getMergedRegions().isEmpty());
+        wb.close();
+    }
+
+    /**
+     * Tests that the setAsActiveCell and getActiveCell function pairs work together
+     */
+    @Test
+    public void setActiveCell() throws IOException {
+        Workbook wb1 = _testDataProvider.createWorkbook();
+        Sheet sheet = wb1.createSheet();
+        CellAddress B42 = new CellAddress("B42");
+        
+        // active cell behavior is undefined if not set.
+        // HSSFSheet defaults to A1 active cell, while XSSFSheet defaults to null.
+        if (sheet.getActiveCell() != null && !sheet.getActiveCell().equals(CellAddress.A1)) {
+            fail("If not set, active cell should default to null or A1");
+        }
+
+        sheet.setActiveCell(B42);
+
+        Workbook wb2 = _testDataProvider.writeOutAndReadBack(wb1);
+
+        assertEquals(B42, sheet.getActiveCell());
+
+        wb1.close();
+        wb2.close();
+    }
+
+
+    @Test
+    public void autoSizeDate() throws IOException {
+        Workbook wb = _testDataProvider.createWorkbook();
+        Sheet s = wb.createSheet("Sheet1");
+        Row r = s.createRow(0);
+        r.createCell(0).setCellValue(1);
+        r.createCell(1).setCellValue(123456);
+
+        // for the streaming-variant we need to enable autosize-tracking to make it work
+        trackColumnsForAutoSizingIfSXSSF(s);
+
+        // Will be sized fairly small
+        s.autoSizeColumn((short)0);
+        s.autoSizeColumn((short)1);
+
+        // Size ranges due to different fonts on different machines
+        assertBetween("Single number column width", s.getColumnWidth(0), 350, 570);
+        assertBetween("6 digit number column width", s.getColumnWidth(1), 1500, 2100);
+
+        // Set a date format
+        CellStyle cs = wb.createCellStyle();
+        DataFormat f = wb.createDataFormat();
+        cs.setDataFormat(f.getFormat("yyyy-mm-dd MMMM hh:mm:ss"));
+        r.getCell(0).setCellStyle(cs);
+        r.getCell(1).setCellStyle(cs);
+
+        assertTrue(DateUtil.isCellDateFormatted(r.getCell(0)));
+        assertTrue(DateUtil.isCellDateFormatted(r.getCell(1)));
+
+        // Should get much bigger now
+        s.autoSizeColumn((short)0);
+        s.autoSizeColumn((short)1);
+
+        assertBetween("Date column width", s.getColumnWidth(0), 4750, 7300);
+        assertBetween("Date column width", s.getColumnWidth(1), 4750, 7300);
+
+        wb.close();
+    }
 }
