@@ -18,28 +18,41 @@
 package org.apache.poi.ss.usermodel;
 
 import static org.junit.Assert.assertArrayEquals;
-import junit.framework.TestCase;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertSame;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assume.assumeTrue;
+import static org.junit.Assert.fail;
+
+import java.io.IOException;
+import java.util.Arrays;
 
 import org.apache.poi.ss.ITestDataProvider;
 import org.apache.poi.ss.formula.FormulaParseException;
 import org.apache.poi.ss.util.CellRangeAddress;
 import org.apache.poi.ss.util.CellReference;
+import org.junit.Ignore;
+import org.junit.Test;
 
 /**
- * Common superclass for testing usermodel API for array formulas.<br/>
+ * Common superclass for testing usermodel API for array formulas.<br>
  * Formula evaluation is not tested here.
  *
  * @author Yegor Kozlov
  * @author Josh Micich
  */
-public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
+public abstract class BaseTestSheetUpdateArrayFormulas {
     protected final ITestDataProvider _testDataProvider;
 
     protected BaseTestSheetUpdateArrayFormulas(ITestDataProvider testDataProvider) {
         _testDataProvider = testDataProvider;
     }
 
-    public final void testAutoCreateOtherCells() {
+    @Test
+    public final void testAutoCreateOtherCells() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet("Sheet1");
 
@@ -55,11 +68,14 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
         assertNotNull(row2);
         assertEquals(formula, row2.getCell(0).getCellFormula());
         assertEquals(formula, row2.getCell(1).getCellFormula());
+        
+        workbook.close();
     }
     /**
      *  Set single-cell array formula
      */
-    public final void testSetArrayFormula_singleCell() {
+    @Test
+    public final void testSetArrayFormula_singleCell() throws IOException {
         Cell[] cells;
 
         Workbook workbook = _testDataProvider.createWorkbook();
@@ -88,12 +104,15 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
         assertEquals(range.formatAsString(), cell.getArrayFormulaRange().formatAsString());
         //check the formula
         assertEquals("SUM(C11:C12*D11:D12)", cell.getCellFormula());
+        
+        workbook.close();
     }
 
     /**
      * Set multi-cell array formula
      */
-    public final void testSetArrayFormula_multiCell() {
+    @Test
+    public final void testSetArrayFormula_multiCell() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
 
@@ -114,18 +133,21 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
 
         for(Cell acell : cells){
             assertTrue(acell.isPartOfArrayFormulaGroup());
-            assertEquals(Cell.CELL_TYPE_FORMULA, acell.getCellType());
+            assertEquals(CellType.FORMULA, acell.getCellType());
             assertEquals("SUM(A1:A3*B1:B3)", acell.getCellFormula());
             //retrieve the range and check it is the same
             assertEquals(range.formatAsString(), acell.getArrayFormulaRange().formatAsString());
         }
+        
+        workbook.close();
     }
 
     /**
      * Passing an incorrect formula to sheet.setArrayFormula
      *  should throw FormulaParseException
      */
-    public final void testSetArrayFormula_incorrectFormula() {
+    @Test
+    public final void testSetArrayFormula_incorrectFormula() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
 
@@ -136,13 +158,16 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
         } catch (FormulaParseException e){
             //expected exception
         }
+        
+        workbook.close();
     }
 
     /**
      * Calls of cell.getArrayFormulaRange and sheet.removeArrayFormula
      * on a not-array-formula cell throw IllegalStateException
      */
-    public final void testArrayFormulas_illegalCalls() {
+    @Test
+    public final void testArrayFormulas_illegalCalls() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
 
@@ -161,12 +186,15 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
         } catch (IllegalArgumentException e){
             assertEquals("Cell A1 is not part of an array formula.", e.getMessage());
         }
+        
+        workbook.close();
     }
 
     /**
      * create and remove array formulas
      */
-    public final void testRemoveArrayFormula() {
+    @Test
+    public final void testRemoveArrayFormula() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
 
@@ -182,7 +210,7 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
 
         for(Cell acell : cr){
             assertFalse(acell.isPartOfArrayFormulaGroup());
-            assertEquals(Cell.CELL_TYPE_BLANK, acell.getCellType());
+            assertEquals(CellType.BLANK, acell.getCellType());
         }
 
         // cells C4:C6 are not included in array formula,
@@ -196,28 +224,32 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
                 assertEquals("Cell "+ref+" is not part of an array formula.", e.getMessage());
             }
         }
+        
+        workbook.close();
     }
 
     /**
      * Test that when reading a workbook from input stream, array formulas are recognized
      */
-    public final void testReadArrayFormula() {
+    @Test
+    public final void testReadArrayFormula() throws IOException {
         Cell[] cells;
 
-        Workbook workbook = _testDataProvider.createWorkbook();
-        Sheet sheet1 = workbook.createSheet();
+        Workbook workbook1 = _testDataProvider.createWorkbook();
+        Sheet sheet1 = workbook1.createSheet();
         cells = sheet1.setArrayFormula("SUM(A1:A3*B1:B3)", CellRangeAddress.valueOf("C4:C6")).getFlattenedCells();
         assertEquals(3, cells.length);
 
         cells = sheet1.setArrayFormula("MAX(A1:A3*B1:B3)", CellRangeAddress.valueOf("A4:A6")).getFlattenedCells();
         assertEquals(3, cells.length);
 
-        Sheet sheet2 = workbook.createSheet();
+        Sheet sheet2 = workbook1.createSheet();
         cells = sheet2.setArrayFormula("MIN(A1:A3*B1:B3)", CellRangeAddress.valueOf("D2:D4")).getFlattenedCells();
         assertEquals(3, cells.length);
 
-        workbook = _testDataProvider.writeOutAndReadBack(workbook);
-        sheet1 = workbook.getSheetAt(0);
+        Workbook workbook2 = _testDataProvider.writeOutAndReadBack(workbook1);
+        workbook1.close();
+        sheet1 = workbook2.getSheetAt(0);
         for(int rownum=3; rownum <= 5; rownum++) {
             Cell cell1 = sheet1.getRow(rownum).getCell(2);
             assertTrue( cell1.isPartOfArrayFormulaGroup());
@@ -226,17 +258,20 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
             assertTrue( cell2.isPartOfArrayFormulaGroup());
         }
 
-        sheet2 = workbook.getSheetAt(1);
+        sheet2 = workbook2.getSheetAt(1);
         for(int rownum=1; rownum <= 3; rownum++) {
             Cell cell1 = sheet2.getRow(rownum).getCell(3);
             assertTrue( cell1.isPartOfArrayFormulaGroup());
         }
+        
+        workbook2.close();
     }
 
     /**
      * Test that we can set pre-calculated formula result for array formulas
      */
-    public void testModifyArrayCells_setFormulaResult(){
+    @Test
+    public void testModifyArrayCells_setFormulaResult() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
 
@@ -244,24 +279,26 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
         CellRange<? extends Cell> srange =
                 sheet.setArrayFormula("SUM(A4:A6,B4:B6)", CellRangeAddress.valueOf("B5"));
         Cell scell = srange.getTopLeftCell();
-        assertEquals(Cell.CELL_TYPE_FORMULA, scell.getCellType());
-        assertEquals(0.0, scell.getNumericCellValue());
+        assertEquals(CellType.FORMULA, scell.getCellType());
+        assertEquals(0.0, scell.getNumericCellValue(), 0);
         scell.setCellValue(1.1);
-        assertEquals(1.1, scell.getNumericCellValue());
+        assertEquals(1.1, scell.getNumericCellValue(), 0);
 
         //multi-cell array formula
         CellRange<? extends Cell> mrange =
                 sheet.setArrayFormula("A1:A3*B1:B3", CellRangeAddress.valueOf("C1:C3"));
         for(Cell mcell : mrange){
-            assertEquals(Cell.CELL_TYPE_FORMULA, mcell.getCellType());
-            assertEquals(0.0, mcell.getNumericCellValue());
+            assertEquals(CellType.FORMULA, mcell.getCellType());
+            assertEquals(0.0, mcell.getNumericCellValue(), 0);
             double fmlaResult = 1.2;
             mcell.setCellValue(fmlaResult);
-            assertEquals(fmlaResult, mcell.getNumericCellValue());
+            assertEquals(fmlaResult, mcell.getNumericCellValue(), 0);
         }
+        workbook.close();
     }
 
-    public void testModifyArrayCells_setCellType(){
+    @Test
+    public void testModifyArrayCells_setCellType() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
 
@@ -270,10 +307,10 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
         CellRange<? extends Cell> srange =
                 sheet.setArrayFormula("SUM(A4:A6,B4:B6)", CellRangeAddress.valueOf("B5"));
         Cell scell = srange.getTopLeftCell();
-        assertEquals(Cell.CELL_TYPE_FORMULA, scell.getCellType());
-        assertEquals(0.0, scell.getNumericCellValue());
-        scell.setCellType(Cell.CELL_TYPE_STRING);
-        assertEquals(Cell.CELL_TYPE_STRING, scell.getCellType());
+        assertEquals(CellType.FORMULA, scell.getCellType());
+        assertEquals(0.0, scell.getNumericCellValue(), 0);
+        scell.setCellType(CellType.STRING);
+        assertEquals(CellType.STRING, scell.getCellType());
         scell.setCellValue("string cell");
         assertEquals("string cell", scell.getStringCellValue());
 
@@ -282,8 +319,8 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
                 sheet.setArrayFormula("A1:A3*B1:B3", CellRangeAddress.valueOf("C1:C3"));
         for(Cell mcell : mrange){
             try {
-                assertEquals(Cell.CELL_TYPE_FORMULA, mcell.getCellType());
-                mcell.setCellType(Cell.CELL_TYPE_NUMERIC);
+                assertEquals(CellType.FORMULA, mcell.getCellType());
+                mcell.setCellType(CellType.NUMERIC);
                 fail("expected exception");
             } catch (IllegalStateException e){
                 CellReference ref = new CellReference(mcell);
@@ -292,12 +329,14 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
             }
             // a failed invocation of Cell.setCellType leaves the cell
             // in the state that it was in prior to the invocation
-            assertEquals(Cell.CELL_TYPE_FORMULA, mcell.getCellType());
+            assertEquals(CellType.FORMULA, mcell.getCellType());
             assertTrue(mcell.isPartOfArrayFormulaGroup());
         }
+        workbook.close();
     }
 
-    public void testModifyArrayCells_setCellFormula(){
+    @Test
+    public void testModifyArrayCells_setCellFormula() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
 
@@ -305,17 +344,17 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
                 sheet.setArrayFormula("SUM(A4:A6,B4:B6)", CellRangeAddress.valueOf("B5"));
         Cell scell = srange.getTopLeftCell();
         assertEquals("SUM(A4:A6,B4:B6)", scell.getCellFormula());
-        assertEquals(Cell.CELL_TYPE_FORMULA, scell.getCellType());
+        assertEquals(CellType.FORMULA, scell.getCellType());
         assertTrue(scell.isPartOfArrayFormulaGroup());
         scell.setCellFormula("SUM(A4,A6)");
         //we are now a normal formula cell
         assertEquals("SUM(A4,A6)", scell.getCellFormula());
         assertFalse(scell.isPartOfArrayFormulaGroup());
-        assertEquals(Cell.CELL_TYPE_FORMULA, scell.getCellType());
+        assertEquals(CellType.FORMULA, scell.getCellType());
         //check that setting formula result works
-        assertEquals(0.0, scell.getNumericCellValue());
+        assertEquals(0.0, scell.getNumericCellValue(), 0);
         scell.setCellValue(33.0);
-        assertEquals(33.0, scell.getNumericCellValue());
+        assertEquals(33.0, scell.getNumericCellValue(), 0);
 
         //multi-cell array formula
         CellRange<? extends Cell> mrange =
@@ -336,9 +375,11 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
             assertEquals("A1:A3*B1:B3", mcell.getCellFormula());
             assertTrue(mcell.isPartOfArrayFormulaGroup());
         }
+        workbook.close();
     }
 
-    public void testModifyArrayCells_removeCell(){
+    @Test
+    public void testModifyArrayCells_removeCell() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
 
@@ -355,7 +396,7 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
 
         //re-create the removed cell
         scell = srow.createCell(cra.getFirstColumn());
-        assertEquals(Cell.CELL_TYPE_BLANK, scell.getCellType());
+        assertEquals(CellType.BLANK, scell.getCellType());
         assertFalse(scell.isPartOfArrayFormulaGroup());
 
         //we cannot remove cells included in a multi-cell array formula
@@ -376,11 +417,14 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
             // in the state that it was in prior to the invocation
             assertSame(mcell, mrow.getCell(columnIndex));
             assertTrue(mcell.isPartOfArrayFormulaGroup());
-            assertEquals(Cell.CELL_TYPE_FORMULA, mcell.getCellType());
+            assertEquals(CellType.FORMULA, mcell.getCellType());
         }
+        
+        workbook.close();
     }
 
-    public void testModifyArrayCells_removeRow(){
+    @Test
+    public void testModifyArrayCells_removeRow() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
 
@@ -389,7 +433,7 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
         CellRange<? extends Cell> srange =
                 sheet.setArrayFormula("SUM(A4:A6,B4:B6)", cra);
         Cell scell = srange.getTopLeftCell();
-        assertEquals(Cell.CELL_TYPE_FORMULA, scell.getCellType());
+        assertEquals(CellType.FORMULA, scell.getCellType());
 
         Row srow = scell.getRow();
         assertSame(srow, sheet.getRow(cra.getFirstRow()));
@@ -398,7 +442,7 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
 
         //re-create the removed row and cell
         scell = sheet.createRow(cra.getFirstRow()).createCell(cra.getFirstColumn());
-        assertEquals(Cell.CELL_TYPE_BLANK, scell.getCellType());
+        assertEquals(CellType.BLANK, scell.getCellType());
         assertFalse(scell.isPartOfArrayFormulaGroup());
 
         //we cannot remove rows with cells included in a multi-cell array formula
@@ -411,19 +455,22 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
                 sheet.removeRow(mrow);
                 fail("expected exception");
             } catch (IllegalStateException e){
-                String msg = "Row[rownum="+mrow.getRowNum()+"] contains cell(s) included in a multi-cell array formula. You cannot change part of an array.";
-                //assertEquals(msg, e.getMessage());
+                // String msg = "Row[rownum="+mrow.getRowNum()+"] contains cell(s) included in a multi-cell array formula. You cannot change part of an array.";
+                // assertEquals(msg, e.getMessage());
             }
             // a failed invocation of Row.removeCell leaves the row
             // in the state that it was in prior to the invocation
             assertSame(mrow, sheet.getRow(mrow.getRowNum()));
             assertSame(mcell, mrow.getCell(columnIndex));
             assertTrue(mcell.isPartOfArrayFormulaGroup());
-            assertEquals(Cell.CELL_TYPE_FORMULA, mcell.getCellType());
+            assertEquals(CellType.FORMULA, mcell.getCellType());
         }
+        
+        workbook.close();
     }
 
-    public void testModifyArrayCells_mergeCells(){
+    @Test
+    public void testModifyArrayCells_mergeCellsSingle() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
         assertEquals(0, sheet.getNumMergedRegions());
@@ -434,26 +481,63 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
         Cell scell = srange.getTopLeftCell();
         sheet.addMergedRegion(CellRangeAddress.valueOf("B5:C6"));
         //we are still an array formula
-        assertEquals(Cell.CELL_TYPE_FORMULA, scell.getCellType());
+        assertEquals(CellType.FORMULA, scell.getCellType());
         assertTrue(scell.isPartOfArrayFormulaGroup());
         assertEquals(1, sheet.getNumMergedRegions());
+        
+        workbook.close();
+    }
+    
+    @Test
+    public void testModifyArrayCells_mergeCellsMulti() throws IOException {
+        Workbook workbook = _testDataProvider.createWorkbook();
+        Sheet sheet = workbook.createSheet();
+        int expectedNumMergedRegions = 0;
+        assertEquals(expectedNumMergedRegions, sheet.getNumMergedRegions());
 
-        //we cannot merge cells included in an array formula
-        CellRange<? extends Cell> mrange =
-                sheet.setArrayFormula("A1:A3*B1:B3", CellRangeAddress.valueOf("C1:C3"));
-        CellRangeAddress cra = CellRangeAddress.valueOf("C1:C3");
-        try {
-            sheet.addMergedRegion(cra);
-            fail("expected exception");
-        } catch (IllegalStateException e){
-            String msg = "The range "+cra.formatAsString()+" intersects with a multi-cell array formula. You cannot merge cells of an array.";
-            assertEquals(msg, e.getMessage());
+        // we cannot merge cells included in an array formula
+        sheet.setArrayFormula("A1:A4*B1:B4", CellRangeAddress.valueOf("C2:F5"));
+        for (String ref : Arrays.asList(
+                "C2:F5", // identity
+                "D3:E4", "B1:G6", // contains
+                "B1:C2", "F1:G2", "F5:G6", "B5:C6", // 1x1 corner intersection
+                "B1:C6", "B1:G2", "F1:G6", "B5:G6", // 1-row/1-column intersection
+                "B1:D3", "E1:G3", "E4:G6", "B4:D6", // 2x2 corner intersection
+                "B1:D6", "B1:G3", "E1:G6", "B4:G6"  // 2-row/2-column intersection
+        )) {
+            CellRangeAddress cra = CellRangeAddress.valueOf(ref);
+            try {
+                sheet.addMergedRegion(cra);
+                fail("expected exception with ref " + ref);
+            } catch (IllegalStateException e) {
+                String msg = "The range "+cra.formatAsString()+" intersects with a multi-cell array formula. You cannot merge cells of an array.";
+                assertEquals(msg, e.getMessage());
+            }
         }
         //the number of merged regions remains the same
-        assertEquals(1, sheet.getNumMergedRegions());
+        assertEquals(expectedNumMergedRegions, sheet.getNumMergedRegions());
+        
+        // we can merge non-intersecting cells
+        for (String ref : Arrays.asList(
+                "C1:F1", //above
+                "G2:G5", //right
+                "C6:F6",  //bottom
+                "B2:B5", "H7:J9")) {
+            CellRangeAddress cra = CellRangeAddress.valueOf(ref);
+            try {
+                sheet.addMergedRegion(cra);
+                expectedNumMergedRegions++;
+                assertEquals(expectedNumMergedRegions, sheet.getNumMergedRegions());
+            } catch (IllegalStateException e) {
+                fail("did not expect exception with ref: " + ref + "\n" + e.getMessage());
+            }
+        }
+        
+        workbook.close();
     }
 
-    public void testModifyArrayCells_shiftRows(){
+    @Test
+    public void testModifyArrayCells_shiftRows() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet = workbook.createSheet();
 
@@ -466,8 +550,7 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
         sheet.shiftRows(0, 1, 1);
 
         //we cannot set individual formulas for cells included in an array formula
-        CellRange<? extends Cell> mrange =
-                sheet.setArrayFormula("A1:A3*B1:B3", CellRangeAddress.valueOf("C1:C3"));
+        sheet.setArrayFormula("A1:A3*B1:B3", CellRangeAddress.valueOf("C1:C3"));
 
         try {
             sheet.shiftRows(0, 0, 1);
@@ -487,9 +570,41 @@ public abstract class BaseTestSheetUpdateArrayFormulas extends TestCase {
             assertEquals(cra.formatAsString(), mcell.getArrayFormulaRange().formatAsString());
             assertEquals("A2:A4*B2:B4", mcell.getCellFormula());
             assertTrue(mcell.isPartOfArrayFormulaGroup());
-            assertEquals(Cell.CELL_TYPE_FORMULA, mcell.getCellType());
+            assertEquals(CellType.FORMULA, mcell.getCellType());
         }
 
         */
+        workbook.close();
+    }
+
+    @Ignore("See bug 59728")
+    @Test
+    public void shouldNotBeAbleToCreateArrayFormulaOnPreexistingMergedRegion() throws IOException {
+        /*
+         *  m  = merged region
+         *  f  = array formula
+         *  fm = cell belongs to a merged region and an array formula (illegal, that's what this tests for)
+         *  
+         *   A  B  C
+         * 1    f  f
+         * 2    fm fm
+         * 3    f  f
+         */
+        Workbook workbook = _testDataProvider.createWorkbook();
+        Sheet sheet = workbook.createSheet();
+        
+        CellRangeAddress mergedRegion = CellRangeAddress.valueOf("B2:C2");
+        sheet.addMergedRegion(mergedRegion);
+        CellRangeAddress arrayFormula = CellRangeAddress.valueOf("C1:C3");
+        assumeTrue(mergedRegion.intersects(arrayFormula));
+        assumeTrue(arrayFormula.intersects(mergedRegion));
+        try {
+            sheet.setArrayFormula("SUM(A1:A3)",  arrayFormula);
+            fail("expected exception: should not be able to create an array formula that intersects with a merged region");
+        } catch (IllegalStateException e) {
+            // expected
+        }
+        
+        workbook.close();
     }
 }
