@@ -17,6 +17,7 @@
 
 package org.apache.poi.ss.usermodel;
 
+import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
@@ -25,27 +26,112 @@ import static org.junit.Assert.assertSame;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
+import java.io.File;
+import java.io.FileOutputStream;
 import java.io.IOException;
+import java.io.OutputStream;
+import java.util.ConcurrentModificationException;
+import java.util.Iterator;
 
-import junit.framework.AssertionFailedError;
-
+import org.apache.poi.hssf.HSSFTestDataSamples;
 import org.apache.poi.ss.ITestDataProvider;
+import org.apache.poi.ss.usermodel.ClientAnchor.AnchorType;
+import org.apache.poi.ss.util.CellAddress;
 import org.apache.poi.ss.util.CellRangeAddress;
+import org.apache.poi.util.NullOutputStream;
+import org.apache.poi.util.TempFile;
 import org.junit.Test;
 
-/**
- * @author Yegor Kozlov
- */
 public abstract class BaseTestWorkbook {
 
-    private final ITestDataProvider _testDataProvider;
+    protected final ITestDataProvider _testDataProvider;
 
     protected BaseTestWorkbook(ITestDataProvider testDataProvider) {
-    _testDataProvider = testDataProvider;
+        _testDataProvider = testDataProvider;
+    }
+    
+    @Test
+    public void sheetIterator_forEach() throws IOException {
+        final Workbook wb = _testDataProvider.createWorkbook();
+        wb.createSheet("Sheet0");
+        wb.createSheet("Sheet1");
+        wb.createSheet("Sheet2");
+        int i = 0;
+        for (Sheet sh : wb) {
+            assertEquals("Sheet"+i, sh.getSheetName());
+            i++;
+        }
+        wb.close();
+    }
+    
+    /**
+     * Expected ConcurrentModificationException:
+     * should not be able to advance an iterator when the
+     * underlying data has been reordered
+     */
+    @Test(expected=ConcurrentModificationException.class)
+    public void sheetIterator_sheetsReordered() throws IOException {
+        final Workbook wb = _testDataProvider.createWorkbook();
+        wb.createSheet("Sheet0");
+        wb.createSheet("Sheet1");
+        wb.createSheet("Sheet2");
+        
+        Iterator<Sheet> it = wb.sheetIterator();
+        it.next();
+        wb.setSheetOrder("Sheet2", 1);
+        
+        // Iterator order should be fixed when iterator is created
+        try {
+            assertEquals("Sheet1", it.next().getSheetName());
+        } finally {
+            wb.close();
+        }
+    }
+    
+    /**
+     * Expected ConcurrentModificationException:
+     * should not be able to advance an iterator when the
+     * underlying data has been reordered
+     */
+    @Test(expected=ConcurrentModificationException.class)
+    public void sheetIterator_sheetRemoved() throws IOException {
+        final Workbook wb = _testDataProvider.createWorkbook();
+        wb.createSheet("Sheet0");
+        wb.createSheet("Sheet1");
+        wb.createSheet("Sheet2");
+        
+        Iterator<Sheet> it = wb.sheetIterator();
+        wb.removeSheetAt(1);
+        
+        // Iterator order should be fixed when iterator is created
+        try {
+            it.next();
+        } finally {
+            wb.close();
+        }
+    }
+    
+    /**
+     * Expected UnsupportedOperationException:
+     * should not be able to remove sheets from the sheet iterator
+     */
+    @Test(expected=UnsupportedOperationException.class)
+    public void sheetIterator_remove() throws IOException {
+        final Workbook wb = _testDataProvider.createWorkbook();
+        wb.createSheet("Sheet0");
+        
+        Iterator<Sheet> it = wb.sheetIterator();
+        it.next(); //Sheet0
+        try {
+            it.remove();
+        } finally {
+            wb.close();
+        }
     }
 
+
     @Test
-    public void createSheet() {
+    public void createSheet() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
         assertEquals(0, wb.getNumberOfSheets());
 
@@ -70,7 +156,7 @@ public abstract class BaseTestWorkbook {
         Sheet originalSheet = wb.createSheet("Sheet3");
         Sheet fetchedSheet = wb.getSheet("sheet3");
         if (fetchedSheet == null) {
-            throw new AssertionFailedError("Identified bug 44892");
+            fail("Identified bug 44892");
         }
         assertEquals("Sheet3", fetchedSheet.getSheetName());
         assertEquals(3, wb.getNumberOfSheets());
@@ -80,7 +166,7 @@ public abstract class BaseTestWorkbook {
             fail("should have thrown exceptiuon due to duplicate sheet name");
         } catch (IllegalArgumentException e) {
             // expected during successful test
-            assertEquals("The workbook already contains a sheet of this name", e.getMessage());
+            assertEquals("The workbook already contains a sheet named 'sHeeT3'", e.getMessage());
         }
 
         //names cannot be blank or contain any of /\*?[]
@@ -136,11 +222,13 @@ public abstract class BaseTestWorkbook {
         assertNull(wb.getSheet("unknown"));
 
         //serialize and read again
-        wb = _testDataProvider.writeOutAndReadBack(wb);
-        assertEquals(3, wb.getNumberOfSheets());
-        assertEquals(0, wb.getSheetIndex("sheet0"));
-        assertEquals(1, wb.getSheetIndex("sheet1"));
-        assertEquals(2, wb.getSheetIndex("I changed!"));
+        Workbook wb2 = _testDataProvider.writeOutAndReadBack(wb);
+        wb.close();
+        assertEquals(3, wb2.getNumberOfSheets());
+        assertEquals(0, wb2.getSheetIndex("sheet0"));
+        assertEquals(1, wb2.getSheetIndex("sheet1"));
+        assertEquals(2, wb2.getSheetIndex("I changed!"));
+        wb2.close();
     }
 
     /**
@@ -152,105 +240,122 @@ public abstract class BaseTestWorkbook {
      * but for the purpose of uniqueness long sheet names are silently truncated to 31 chars.
      */
     @Test
-    public void createSheetWithLongNames() {
-        Workbook wb = _testDataProvider.createWorkbook();
+    public void createSheetWithLongNames() throws IOException {
+        Workbook wb1 = _testDataProvider.createWorkbook();
 
         String sheetName1 = "My very long sheet name which is longer than 31 chars";
         String truncatedSheetName1 = sheetName1.substring(0, 31);
-        Sheet sh1 = wb.createSheet(sheetName1);
+        Sheet sh1 = wb1.createSheet(sheetName1);
         assertEquals(truncatedSheetName1, sh1.getSheetName());
-        assertSame(sh1, wb.getSheet(truncatedSheetName1));
+        assertSame(sh1, wb1.getSheet(truncatedSheetName1));
         // now via wb.setSheetName
-        wb.setSheetName(0, sheetName1);
+        wb1.setSheetName(0, sheetName1);
         assertEquals(truncatedSheetName1, sh1.getSheetName());
-        assertSame(sh1, wb.getSheet(truncatedSheetName1));
+        assertSame(sh1, wb1.getSheet(truncatedSheetName1));
 
         String sheetName2 = "My very long sheet name which is longer than 31 chars " +
                 "and sheetName2.substring(0, 31) == sheetName1.substring(0, 31)";
         try {
-            /*Sheet sh2 =*/ wb.createSheet(sheetName2);
+            /*Sheet sh2 =*/ wb1.createSheet(sheetName2);
             fail("expected exception");
         } catch (IllegalArgumentException e) {
             // expected during successful test
-            assertEquals("The workbook already contains a sheet of this name", e.getMessage());
+            assertEquals("The workbook already contains a sheet named 'My very long sheet name which is longer than 31 chars and sheetName2.substring(0, 31) == sheetName1.substring(0, 31)'", e.getMessage());
         }
 
         String sheetName3 = "POI allows creating sheets with names longer than 31 characters";
         String truncatedSheetName3 = sheetName3.substring(0, 31);
-        Sheet sh3 = wb.createSheet(sheetName3);
+        Sheet sh3 = wb1.createSheet(sheetName3);
         assertEquals(truncatedSheetName3, sh3.getSheetName());
-        assertSame(sh3, wb.getSheet(truncatedSheetName3));
+        assertSame(sh3, wb1.getSheet(truncatedSheetName3));
 
         //serialize and read again
-        wb = _testDataProvider.writeOutAndReadBack(wb);
-        assertEquals(2, wb.getNumberOfSheets());
-        assertEquals(0, wb.getSheetIndex(truncatedSheetName1));
-        assertEquals(1, wb.getSheetIndex(truncatedSheetName3));
+        Workbook wb2 = _testDataProvider.writeOutAndReadBack(wb1);
+        wb1.close();
+        assertEquals(2, wb2.getNumberOfSheets());
+        assertEquals(0, wb2.getSheetIndex(truncatedSheetName1));
+        assertEquals(1, wb2.getSheetIndex(truncatedSheetName3));
+        wb2.close();
     }
 
     @Test
     public void removeSheetAt() throws IOException {
-        Workbook workbook = _testDataProvider.createWorkbook();
-        try {
+        try (Workbook workbook = _testDataProvider.createWorkbook()) {
             workbook.createSheet("sheet1");
             workbook.createSheet("sheet2");
             workbook.createSheet("sheet3");
             assertEquals(3, workbook.getNumberOfSheets());
-    
+
             assertEquals(0, workbook.getActiveSheetIndex());
-    
+
             workbook.removeSheetAt(1);
             assertEquals(2, workbook.getNumberOfSheets());
             assertEquals("sheet3", workbook.getSheetName(1));
             assertEquals(0, workbook.getActiveSheetIndex());
-    
+
             workbook.removeSheetAt(0);
             assertEquals(1, workbook.getNumberOfSheets());
             assertEquals("sheet3", workbook.getSheetName(0));
             assertEquals(0, workbook.getActiveSheetIndex());
-    
+
             workbook.removeSheetAt(0);
             assertEquals(0, workbook.getNumberOfSheets());
             assertEquals(0, workbook.getActiveSheetIndex());
-    
+
             //re-create the sheets
             workbook.createSheet("sheet1");
             workbook.createSheet("sheet2");
             workbook.createSheet("sheet3");
             workbook.createSheet("sheet4");
             assertEquals(4, workbook.getNumberOfSheets());
-    
+
             assertEquals(0, workbook.getActiveSheetIndex());
             workbook.setActiveSheet(2);
             assertEquals(2, workbook.getActiveSheetIndex());
-    
+
             workbook.removeSheetAt(2);
             assertEquals(2, workbook.getActiveSheetIndex());
-    
+
             workbook.removeSheetAt(1);
             assertEquals(1, workbook.getActiveSheetIndex());
-    
+
             workbook.removeSheetAt(0);
             assertEquals(0, workbook.getActiveSheetIndex());
-    
+
             workbook.removeSheetAt(0);
             assertEquals(0, workbook.getActiveSheetIndex());
-        } finally {
-            workbook.close();
         }
     }
 
     @Test
-    public void defaultValues() {
+    public void testSetActiveCell() throws IOException {
+        try (Workbook wb = _testDataProvider.createWorkbook()) {
+            Sheet sheet = wb.createSheet("new sheet");
+            final CellAddress initialActiveCell = sheet.getActiveCell();
+            assertTrue(initialActiveCell == null || new CellAddress("A1").equals(initialActiveCell));
+            sheet.setActiveCell(new CellAddress("E11"));
+            assertEquals(new CellAddress("E11"), sheet.getActiveCell());
+
+            Workbook wbr = _testDataProvider.writeOutAndReadBack(wb);
+            sheet = wbr.getSheet("new sheet");
+            assertEquals(new CellAddress("E11"), sheet.getActiveCell());
+
+            //wbr.write(new FileOutputStream("c:/temp/yyy." + _testDataProvider.getStandardFileNameExtension()));
+        }
+    }
+
+    @Test
+    public void defaultValues() throws IOException {
         Workbook b = _testDataProvider.createWorkbook();
         assertEquals(0, b.getActiveSheetIndex());
         assertEquals(0, b.getFirstVisibleTab());
         assertEquals(0, b.getNumberOfNames());
         assertEquals(0, b.getNumberOfSheets());
+        b.close();
     }
 
     @Test
-    public void sheetSelection() {
+    public void sheetSelection() throws IOException {
         Workbook b = _testDataProvider.createWorkbook();
         b.createSheet("Sheet One");
         b.createSheet("Sheet Two");
@@ -259,10 +364,11 @@ public abstract class BaseTestWorkbook {
         b.setFirstVisibleTab(1);
         assertEquals(1, b.getActiveSheetIndex());
         assertEquals(1, b.getFirstVisibleTab());
+        b.close();
     }
 
     @Test
-    public void printArea() {
+    public void printArea() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         Sheet sheet1 = workbook.createSheet("Test Print Area");
         String sheetName1 = sheet1.getSheetName();
@@ -279,10 +385,11 @@ public abstract class BaseTestWorkbook {
 
         workbook.removePrintArea(0);
         assertNull(workbook.getPrintArea(0));
+        workbook.close();
     }
 
     @Test
-    public void getSetActiveSheet(){
+    public void getSetActiveSheet() throws IOException {
         Workbook workbook = _testDataProvider.createWorkbook();
         assertEquals(0, workbook.getActiveSheetIndex());
 
@@ -297,10 +404,11 @@ public abstract class BaseTestWorkbook {
         workbook.setActiveSheet(0);
         // test if second sheet is set up
         assertEquals(0, workbook.getActiveSheetIndex());
+        workbook.close();
     }
 
     @Test
-    public void setSheetOrder() {
+    public void setSheetOrder() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
 
         for (int i=0; i < 10; i++) {
@@ -344,6 +452,7 @@ public abstract class BaseTestWorkbook {
         assertEquals(9, wb.getSheetIndex("Sheet 1"));
 
         Workbook wbr = _testDataProvider.writeOutAndReadBack(wb);
+        wb.close();
 
         assertEquals(0, wbr.getSheetIndex("Sheet 6"));
         assertEquals(1, wbr.getSheetIndex("Sheet 0"));
@@ -363,16 +472,18 @@ public abstract class BaseTestWorkbook {
         	Sheet s = wbr.getSheetAt(i);
         	assertEquals(i, wbr.getSheetIndex(s));
         }
+        
+        wbr.close();
     }
 
     @Test
-    public void cloneSheet() {
+    public void cloneSheet() throws IOException {
         Workbook book = _testDataProvider.createWorkbook();
         Sheet sheet = book.createSheet("TEST");
         sheet.createRow(0).createCell(0).setCellValue("Test");
         sheet.createRow(1).createCell(0).setCellValue(36.6);
         sheet.addMergedRegion(new CellRangeAddress(0, 1, 0, 2));
-        sheet.addMergedRegion(new CellRangeAddress(1, 2, 0, 2));
+        sheet.addMergedRegion(new CellRangeAddress(2, 3, 0, 2));
         assertTrue(sheet.isSelected());
 
         Sheet clonedSheet = book.cloneSheet(0);
@@ -381,24 +492,24 @@ public abstract class BaseTestWorkbook {
         assertEquals(2, clonedSheet.getNumMergedRegions());
         assertFalse(clonedSheet.isSelected());
 
-        //cloned sheet is a deep copy, adding rows in the original does not affect the clone
+        //cloned sheet is a deep copy, adding rows or merged regions in the original does not affect the clone
         sheet.createRow(2).createCell(0).setCellValue(1);
-        sheet.addMergedRegion(new CellRangeAddress(0, 2, 0, 2));
-        assertEquals(2, clonedSheet.getPhysicalNumberOfRows());
+        sheet.addMergedRegion(new CellRangeAddress(4, 5, 0, 2));
         assertEquals(2, clonedSheet.getPhysicalNumberOfRows());
+        assertEquals(2, clonedSheet.getNumMergedRegions());
 
         clonedSheet.createRow(2).createCell(0).setCellValue(1);
-        clonedSheet.addMergedRegion(new CellRangeAddress(0, 2, 0, 2));
+        clonedSheet.addMergedRegion(new CellRangeAddress(6, 7, 0, 2));
         assertEquals(3, clonedSheet.getPhysicalNumberOfRows());
-        assertEquals(3, clonedSheet.getPhysicalNumberOfRows());
-
+        assertEquals(3, clonedSheet.getNumMergedRegions());
+        book.close();
     }
 
     @Test
-    public void parentReferences(){
-        Workbook workbook = _testDataProvider.createWorkbook();
-        Sheet sheet = workbook.createSheet();
-        assertSame(workbook, sheet.getWorkbook());
+    public void parentReferences() throws IOException {
+        Workbook wb1 = _testDataProvider.createWorkbook();
+        Sheet sheet = wb1.createSheet();
+        assertSame(wb1, sheet.getWorkbook());
 
         Row row = sheet.createRow(0);
         assertSame(sheet, row.getSheet());
@@ -407,9 +518,10 @@ public abstract class BaseTestWorkbook {
         assertSame(sheet, cell.getSheet());
         assertSame(row, cell.getRow());
 
-        workbook = _testDataProvider.writeOutAndReadBack(workbook);
-        sheet = workbook.getSheetAt(0);
-        assertSame(workbook, sheet.getWorkbook());
+        Workbook wb2 = _testDataProvider.writeOutAndReadBack(wb1);
+        wb1.close();
+        sheet = wb2.getSheetAt(0);
+        assertSame(wb2, sheet.getWorkbook());
 
         row = sheet.getRow(0);
         assertSame(sheet, row.getSheet());
@@ -417,46 +529,51 @@ public abstract class BaseTestWorkbook {
         cell = row.getCell(1);
         assertSame(sheet, cell.getSheet());
         assertSame(row, cell.getRow());
+        wb2.close();
     }
 
 
     /**
-     * Test is kept to ensure stub for deprecated business method passes test.
-     * 
-     * @Deprecated remove this test when 
-     * {@link Workbook#setRepeatingRowsAndColumns(int, int, int, int, int)} 
-     * is removed 
+     * Test to validate that replacement for removed setRepeatingRowsAnsColumns() methods
+     * is still working correctly 
      */
-    @Deprecated
     @Test
-    public void setRepeatingRowsAnsColumns(){
+    public void setRepeatingRowsAnsColumns() throws IOException {
         Workbook wb = _testDataProvider.createWorkbook();
+
+        CellRangeAddress cra = new CellRangeAddress(0, 3, 0, 0);
+        String expRows = "1:4", expCols = "A:A";
+
+        
         Sheet sheet1 = wb.createSheet();
-        wb.setRepeatingRowsAndColumns(wb.getSheetIndex(sheet1), 0, 0, 0, 3);
-        assertEquals("1:4", sheet1.getRepeatingRows().formatAsString());
-        assertEquals("A:A", sheet1.getRepeatingColumns().formatAsString());
+        sheet1.setRepeatingRows(cra);
+        sheet1.setRepeatingColumns(cra);
+        assertEquals(expRows, sheet1.getRepeatingRows().formatAsString());
+        assertEquals(expCols, sheet1.getRepeatingColumns().formatAsString());
 
         //must handle sheets with quotas, see Bugzilla #47294
         Sheet sheet2 = wb.createSheet("My' Sheet");
-        wb.setRepeatingRowsAndColumns(wb.getSheetIndex(sheet2), 0, 0, 0, 3);
-        assertEquals("1:4", sheet2.getRepeatingRows().formatAsString());
-        assertEquals("A:A", sheet1.getRepeatingColumns().formatAsString());
+        sheet2.setRepeatingRows(cra);
+        sheet2.setRepeatingColumns(cra);
+        assertEquals(expRows, sheet2.getRepeatingRows().formatAsString());
+        assertEquals(expCols, sheet2.getRepeatingColumns().formatAsString());
+        wb.close();
     }
 
     /**
      * Tests that all of the unicode capable string fields can be set, written and then read back
      */
     @Test
-    public void unicodeInAll() {
-        Workbook wb = _testDataProvider.createWorkbook();
-        CreationHelper factory = wb.getCreationHelper();
+    public void unicodeInAll() throws IOException {
+        Workbook wb1 = _testDataProvider.createWorkbook();
+        CreationHelper factory = wb1.getCreationHelper();
         //Create a unicode dataformat (contains euro symbol)
-        DataFormat df = wb.createDataFormat();
+        DataFormat df = wb1.createDataFormat();
         final String formatStr = "_([$\u20ac-2]\\\\\\ * #,##0.00_);_([$\u20ac-2]\\\\\\ * \\\\\\(#,##0.00\\\\\\);_([$\u20ac-2]\\\\\\ *\\\"\\-\\\\\"??_);_(@_)";
         short fmt = df.getFormat(formatStr);
 
         //Create a unicode sheet name (euro symbol)
-        Sheet s = wb.createSheet("\u20ac");
+        Sheet s = wb1.createSheet("\u20ac");
 
         //Set a unicode header (you guessed it the euro symbol)
         Header h = s.getHeader();
@@ -482,10 +599,11 @@ public abstract class BaseTestWorkbook {
         String formulaString = "TEXT(12.34,\"\u20ac###,##\")";
         c3.setCellFormula(formulaString);
 
-        wb = _testDataProvider.writeOutAndReadBack(wb);
+        Workbook wb2 = _testDataProvider.writeOutAndReadBack(wb1);
+        wb1.close();
 
         //Test the sheetname
-        s = wb.getSheet("\u20ac");
+        s = wb2.getSheet("\u20ac");
         assertNotNull(s);
 
         //Test the header
@@ -503,7 +621,7 @@ public abstract class BaseTestWorkbook {
         //Test the dataformat
         r = s.getRow(0);
         c = r.getCell(1);
-        df = wb.createDataFormat();
+        df = wb2.createDataFormat();
         assertEquals(formatStr, df.getFormat(c.getCellStyle().getDataFormat()));
 
         //Test the cell string value
@@ -513,9 +631,10 @@ public abstract class BaseTestWorkbook {
         //Test the cell formula
         c3 = r.getCell(3);
         assertEquals(c3.getCellFormula(), formulaString);
+        wb2.close();
     }
 
-    private Workbook newSetSheetNameTestingWorkbook() throws Exception {
+    private Workbook newSetSheetNameTestingWorkbook() {
         Workbook wb = _testDataProvider.createWorkbook();
         Sheet sh1 = wb.createSheet("Worksheet");
         Sheet sh2 = wb.createSheet("Testing 47100");
@@ -562,15 +681,15 @@ public abstract class BaseTestWorkbook {
      * @see <a href="https://issues.apache.org/bugzilla/show_bug.cgi?id=47100">Bugzilla 47100</a>
      */
     @Test
-    public void setSheetName() throws Exception {
+    public void setSheetName() throws IOException {
 
-        Workbook wb = newSetSheetNameTestingWorkbook();
+        Workbook wb1 = newSetSheetNameTestingWorkbook();
 
-        Sheet sh1 = wb.getSheetAt(0);
+        Sheet sh1 = wb1.getSheetAt(0);
 
-        Name sale_2 = wb.getNameAt(1);
-        Name sale_3 = wb.getNameAt(2);
-        Name sale_4 = wb.getNameAt(3);
+        Name sale_2 = wb1.getNameAt(1);
+        Name sale_3 = wb1.getNameAt(2);
+        Name sale_4 = wb1.getNameAt(3);
 
         assertEquals("sale_2", sale_2.getNameName());
         assertEquals("'Testing 47100'!$A$1", sale_2.getRefersToFormula());
@@ -579,7 +698,7 @@ public abstract class BaseTestWorkbook {
         assertEquals("sale_4", sale_4.getNameName());
         assertEquals("'To be renamed'!$A$3", sale_4.getRefersToFormula());
 
-        FormulaEvaluator evaluator = wb.getCreationHelper().createFormulaEvaluator();
+        FormulaEvaluator evaluator = wb1.getCreationHelper().createFormulaEvaluator();
 
         Cell cell0 = sh1.getRow(0).getCell(0);
         Cell cell1 = sh1.getRow(1).getCell(0);
@@ -593,8 +712,8 @@ public abstract class BaseTestWorkbook {
         assertEquals(21.0, evaluator.evaluate(cell1).getNumberValue(), 0);
         assertEquals(6.0, evaluator.evaluate(cell2).getNumberValue(), 0);
 
-        wb.setSheetName(1, "47100 - First");
-        wb.setSheetName(2, "47100 - Second");
+        wb1.setSheetName(1, "47100 - First");
+        wb1.setSheetName(2, "47100 - Second");
 
         assertEquals("sale_2", sale_2.getNameName());
         assertEquals("'47100 - First'!$A$1", sale_2.getRefersToFormula());
@@ -612,13 +731,14 @@ public abstract class BaseTestWorkbook {
         assertEquals(21.0, evaluator.evaluate(cell1).getNumberValue(), 0);
         assertEquals(6.0, evaluator.evaluate(cell2).getNumberValue(), 0);
 
-        wb = _testDataProvider.writeOutAndReadBack(wb);
+        Workbook wb2 = _testDataProvider.writeOutAndReadBack(wb1);
+        wb1.close();
 
-        sh1 = wb.getSheetAt(0);
+        sh1 = wb2.getSheetAt(0);
 
-        sale_2 = wb.getNameAt(1);
-        sale_3 = wb.getNameAt(2);
-        sale_4 = wb.getNameAt(3);
+        sale_2 = wb2.getNameAt(1);
+        sale_3 = wb2.getNameAt(2);
+        sale_4 = wb2.getNameAt(3);
 
         cell0 = sh1.getRow(0).getCell(0);
         cell1 = sh1.getRow(1).getCell(0);
@@ -635,13 +755,14 @@ public abstract class BaseTestWorkbook {
         assertEquals("SUM('47100 - First'!A1:C1,'47100 - Second'!A1:A5)", cell1.getCellFormula());
         assertEquals("sale_2+sale_3+'47100 - First'!C1", cell2.getCellFormula());
 
-        evaluator = wb.getCreationHelper().createFormulaEvaluator();
+        evaluator = wb2.getCreationHelper().createFormulaEvaluator();
         assertEquals(6.0, evaluator.evaluate(cell0).getNumberValue(), 0);
         assertEquals(21.0, evaluator.evaluate(cell1).getNumberValue(), 0);
         assertEquals(6.0, evaluator.evaluate(cell2).getNumberValue(), 0);
+        wb2.close();
     }
 
-    public void changeSheetNameWithSharedFormulas(String sampleFile){
+    protected void changeSheetNameWithSharedFormulas(String sampleFile) throws IOException {
         Workbook wb = _testDataProvider.openSampleWorkbook(sampleFile);
 
         FormulaEvaluator evaluator = wb.getCreationHelper().createFormulaEvaluator();
@@ -664,6 +785,7 @@ public abstract class BaseTestWorkbook {
 
             assertEquals(cellB.getStringCellValue(), evaluator.evaluate(cellA).getStringValue());
         }
+        wb.close();
     }
 
 	protected void assertSheetOrder(Workbook wb, String... sheets) {
@@ -671,11 +793,177 @@ public abstract class BaseTestWorkbook {
 		for(int i = 0;i < wb.getNumberOfSheets();i++) {
 			sheetNames.append(wb.getSheetAt(i).getSheetName()).append(",");
 		}
-		assertEquals("Had: " + sheetNames.toString(), 
+		assertEquals("Had: " + sheetNames,
 				sheets.length, wb.getNumberOfSheets());
 		for(int i = 0;i < wb.getNumberOfSheets();i++) {
-			assertEquals("Had: " + sheetNames.toString(), 
+			assertEquals("Had: " + sheetNames,
 					sheets[i], wb.getSheetAt(i).getSheetName());
 		}
 	}
+
+    @Test
+    public void test58499() throws IOException {
+        Workbook workbook = _testDataProvider.createWorkbook();
+        Sheet sheet = workbook.createSheet();
+        for (int i = 0; i < 900; i++) {
+            Row r = sheet.createRow(i);
+            Cell c = r.createCell(0);
+            CellStyle cs = workbook.createCellStyle();
+            c.setCellStyle(cs);
+            c.setCellValue("AAA");                
+        }
+        try (OutputStream os = new NullOutputStream()) {
+            workbook.write(os);
+        }
+        //workbook.dispose();
+        workbook.close();
+    }
+
+
+    @Test
+    public void windowOneDefaults() throws IOException {
+        Workbook b = _testDataProvider.createWorkbook();
+        try {
+            assertEquals(b.getActiveSheetIndex(), 0);
+            assertEquals(b.getFirstVisibleTab(), 0);
+        } catch (NullPointerException npe) {
+            fail("WindowOneRecord in Workbook is probably not initialized");
+        }
+        
+        b.close();
+    }
+
+    @Test
+    public void getSpreadsheetVersion() throws IOException {
+        final Workbook wb = _testDataProvider.createWorkbook();
+        assertEquals(_testDataProvider.getSpreadsheetVersion(), wb.getSpreadsheetVersion());
+        wb.close();
+    }
+    
+    /* FIXME copied from {@link org.apache.poi.ss.TestWorkbookFactory} */
+    protected static void assertCloseDoesNotModifyFile(String filename, Workbook wb) throws IOException {
+        final byte[] before = HSSFTestDataSamples.getTestDataFileContent(filename);
+        wb.close();
+        final byte[] after = HSSFTestDataSamples.getTestDataFileContent(filename);
+        assertArrayEquals(filename + " sample file was modified as a result of closing the workbook",
+                before, after);
+    }
+
+    @Test
+    public void sheetClone() throws IOException {
+        // First up, try a simple file
+        final Workbook b = _testDataProvider.createWorkbook();
+        assertEquals(0, b.getNumberOfSheets());
+        b.createSheet("Sheet One");
+        b.createSheet("Sheet Two");
+
+        assertEquals(2, b.getNumberOfSheets());
+        b.cloneSheet(0);
+        assertEquals(3, b.getNumberOfSheets());
+
+        // Now try a problem one with drawing records in it
+        Workbook bBack = HSSFTestDataSamples.openSampleWorkbook("SheetWithDrawing.xls");
+        assertEquals(1, bBack.getNumberOfSheets());
+        bBack.cloneSheet(0);
+        assertEquals(2, bBack.getNumberOfSheets());
+
+        bBack.close();
+        b.close();
+    }
+
+    @Test
+    public void getSheetIndex() throws IOException {
+        final Workbook wb = _testDataProvider.createWorkbook();
+        Sheet sheet1 = wb.createSheet("Sheet1");
+        Sheet sheet2 = wb.createSheet("Sheet2");
+        Sheet sheet3 = wb.createSheet("Sheet3");
+        Sheet sheet4 = wb.createSheet("Sheet4");
+
+        assertEquals(0, wb.getSheetIndex(sheet1));
+        assertEquals(1, wb.getSheetIndex(sheet2));
+        assertEquals(2, wb.getSheetIndex(sheet3));
+        assertEquals(3, wb.getSheetIndex(sheet4));
+
+        // remove sheets
+        wb.removeSheetAt(0);
+        wb.removeSheetAt(2);
+
+        // ensure that sheets are moved up and removed sheets are not found any more
+        assertEquals(-1, wb.getSheetIndex(sheet1));
+        assertEquals(0, wb.getSheetIndex(sheet2));
+        assertEquals(1, wb.getSheetIndex(sheet3));
+        assertEquals(-1, wb.getSheetIndex(sheet4));
+
+        wb.close();
+    }
+
+    @Test
+    public void addSheetTwice() throws IOException {
+        final Workbook wb = _testDataProvider.createWorkbook();
+        Sheet sheet1 = wb.createSheet("Sheet1");
+        assertNotNull(sheet1);
+        try {
+            wb.createSheet("Sheet1");
+            fail("Should fail if we add the same sheet twice");
+        } catch (IllegalArgumentException e) {
+            assertTrue(e.getMessage(), e.getMessage().contains("already contains a sheet named 'Sheet1'"));
+        }
+
+        wb.close();
+    }
+    
+    // bug 51233 and 55075: correctly size image if added to a row with a custom height
+    @Test
+    public void createDrawing() throws Exception {
+        Workbook wb = _testDataProvider.createWorkbook();
+        Sheet sheet = wb.createSheet("Main Sheet");
+        Row row0 = sheet.createRow(0);
+        Row row1 = sheet.createRow(1);
+        row1.createCell(0);
+        row0.createCell(1);
+        row1.createCell(0);
+        row1.createCell(1);
+
+        byte[] pictureData = _testDataProvider.getTestDataFileContent("logoKarmokar4.png");
+
+        int handle = wb.addPicture(pictureData, Workbook.PICTURE_TYPE_PNG);
+        Drawing<?> drawing = sheet.createDrawingPatriarch();
+        CreationHelper helper = wb.getCreationHelper();
+        ClientAnchor anchor = helper.createClientAnchor();
+        anchor.setAnchorType(AnchorType.DONT_MOVE_AND_RESIZE);
+        anchor.setCol1(0);
+        anchor.setRow1(0);
+        Picture picture = drawing.createPicture(anchor, handle);
+
+        row0.setHeightInPoints(144);
+        // set a column width so that XSSF and SXSSF have the same width (default widths may be different otherwise)
+        sheet.setColumnWidth(0, 100*256);
+        picture.resize();
+        
+        // The actual dimensions don't matter as much as having XSSF and SXSSF produce the same size drawings
+        
+        // Check drawing height
+        assertEquals(0, anchor.getRow1());
+        assertEquals(0, anchor.getRow2());
+        assertEquals(0, anchor.getDy1());
+        assertEquals(1609725, anchor.getDy2()); //HSSF: 225
+        
+        // Check drawing width
+        assertEquals(0, anchor.getCol1());
+        assertEquals(0, anchor.getCol2());
+        assertEquals(0, anchor.getDx1());
+        assertEquals(1114425, anchor.getDx2()); //HSSF: 171
+        
+        final boolean writeOut = false;
+        if (writeOut) {
+            String ext = "." + _testDataProvider.getStandardFileNameExtension();
+            String prefix = wb.getClass().getName() + "-createDrawing";
+            File f = TempFile.createTempFile(prefix, ext);
+            FileOutputStream out = new FileOutputStream(f);
+            wb.write(out);
+            out.close();
+        }
+        wb.close();
+    }
+
 }
