@@ -27,8 +27,6 @@ import java.util.Arrays;
 import java.util.Date;
 import java.util.Locale;
 
-import junit.framework.TestCase;
-
 import org.apache.poi.hssf.usermodel.HSSFWorkbook;
 import org.apache.poi.ss.usermodel.Cell;
 import org.apache.poi.ss.usermodel.CellStyle;
@@ -37,85 +35,86 @@ import org.apache.poi.ss.usermodel.Row;
 import org.apache.poi.ss.usermodel.Sheet;
 import org.apache.poi.ss.usermodel.Workbook;
 import org.apache.poi.util.TempFile;
+import org.junit.Ignore;
+import org.junit.Test;
 
-public final class TestDateFormatConverter extends TestCase {
+public final class TestDateFormatConverter {
     private void outputLocaleDataFormats( Date date, boolean dates, boolean times, int style, String styleName ) throws Exception {
-
-        Workbook workbook = new HSSFWorkbook();
-        String sheetName;
-        if( dates ) {
-            if( times ) {
-                sheetName = "DateTimes";
-            } else {
-                sheetName = "Dates";
-            }
-        } else {
-            sheetName = "Times";
-        }
-        Sheet sheet = workbook.createSheet(sheetName);
-        Row header = sheet.createRow(0);
-        header.createCell(0).setCellValue("locale");
-        header.createCell(1).setCellValue("DisplayName");
-        header.createCell(2).setCellValue("Excel " + styleName);
-        header.createCell(3).setCellValue("java.text.DateFormat");
-        header.createCell(4).setCellValue("Equals");
-        header.createCell(5).setCellValue("Java pattern");
-        header.createCell(6).setCellValue("Excel pattern");
-
-        int rowNum = 1;
-        for( Locale locale : DateFormat.getAvailableLocales() ) {
-            try {
-                Row row = sheet.createRow(rowNum++);
-    
-                row.createCell(0).setCellValue(locale.toString());
-                row.createCell(1).setCellValue(locale.getDisplayName());
-    
-                DateFormat dateFormat;
-                if( dates ) {
-                    if( times ) {
-                        dateFormat = DateFormat.getDateTimeInstance(style, style, locale);
-                    } else {
-                        dateFormat = DateFormat.getDateInstance(style, locale);
-                    }
+        try (Workbook workbook = new HSSFWorkbook()) {
+            String sheetName;
+            if (dates) {
+                if (times) {
+                    sheetName = "DateTimes";
                 } else {
-                    dateFormat = DateFormat.getTimeInstance(style, locale);
+                    sheetName = "Dates";
                 }
-    
-                Cell cell = row.createCell(2);
-    
-                cell.setCellValue(date);
-                CellStyle cellStyle = row.getSheet().getWorkbook().createCellStyle();
-    
-                String javaDateFormatPattern = ((SimpleDateFormat)dateFormat).toPattern();
-                String excelFormatPattern = DateFormatConverter.convert(locale, javaDateFormatPattern);
-    
-                DataFormat poiFormat = row.getSheet().getWorkbook().createDataFormat();
-                cellStyle.setDataFormat(poiFormat.getFormat(excelFormatPattern));
-                row.createCell(3).setCellValue(dateFormat.format(date));
-    
-                cell.setCellStyle(cellStyle);
-    
-                // the formula returns TRUE is the formatted date in column C equals to the string in column D
-                row.createCell(4).setCellFormula("TEXT(C"+rowNum+",G"+rowNum+")=D" + rowNum);
-                row.createCell(5).setCellValue(javaDateFormatPattern);
-                row.createCell(6).setCellValue(excelFormatPattern);
-            } catch (Exception e) {
-                throw new RuntimeException("Failed for locale: " + locale + ", having locales: " + 
-                        Arrays.toString(DateFormat.getAvailableLocales()), e);
+            } else {
+                sheetName = "Times";
             }
-        }
+            Sheet sheet = workbook.createSheet(sheetName);
+            Row header = sheet.createRow(0);
+            header.createCell(0).setCellValue("locale");
+            header.createCell(1).setCellValue("DisplayName");
+            header.createCell(2).setCellValue("Excel " + styleName);
+            header.createCell(3).setCellValue("java.text.DateFormat");
+            header.createCell(4).setCellValue("Equals");
+            header.createCell(5).setCellValue("Java pattern");
+            header.createCell(6).setCellValue("Excel pattern");
 
-        File outputFile = TempFile.createTempFile("Locale" + sheetName + styleName, ".xlsx");
-        FileOutputStream outputStream = new FileOutputStream(outputFile);
-        try {
-            workbook.write(outputStream);
-        } finally {
-            outputStream.close();
-        }
+            int rowNum = 1;
+            for (Locale locale : DateFormat.getAvailableLocales()) {
+                try {
+                    Row row = sheet.createRow(rowNum++);
 
-        System.out.println("Open " + outputFile.getAbsolutePath()+" in Excel");
+                    row.createCell(0).setCellValue(locale.toString());
+                    row.createCell(1).setCellValue(locale.getDisplayName(Locale.ROOT));
+
+                    DateFormat dateFormat;
+                    if (dates) {
+                        if (times) {
+                            dateFormat = DateFormat.getDateTimeInstance(style, style, locale);
+                        } else {
+                            dateFormat = DateFormat.getDateInstance(style, locale);
+                        }
+                    } else {
+                        dateFormat = DateFormat.getTimeInstance(style, locale);
+                    }
+
+                    Cell cell = row.createCell(2);
+
+                    cell.setCellValue(date);
+                    CellStyle cellStyle = row.getSheet().getWorkbook().createCellStyle();
+
+                    String javaDateFormatPattern = ((SimpleDateFormat) dateFormat).toPattern();
+                    String excelFormatPattern = DateFormatConverter.convert(locale, javaDateFormatPattern);
+
+                    DataFormat poiFormat = row.getSheet().getWorkbook().createDataFormat();
+                    cellStyle.setDataFormat(poiFormat.getFormat(excelFormatPattern));
+                    row.createCell(3).setCellValue(dateFormat.format(date));
+
+                    cell.setCellStyle(cellStyle);
+
+                    // the formula returns TRUE is the formatted date in column C equals to the string in column D
+                    row.createCell(4).setCellFormula("TEXT(C" + rowNum + ",G" + rowNum + ")=D" + rowNum);
+                    row.createCell(5).setCellValue(javaDateFormatPattern);
+                    row.createCell(6).setCellValue(excelFormatPattern);
+                } catch (Exception e) {
+                    throw new RuntimeException(
+                            "Failed for locale: " + locale + " and style " + style + "\n" +
+                            "Having locales: " + Arrays.toString(DateFormat.getAvailableLocales()), e);
+                }
+            }
+
+            File outputFile = TempFile.createTempFile("Locale" + sheetName + styleName, ".xlsx");
+            try (FileOutputStream outputStream = new FileOutputStream(outputFile)) {
+                workbook.write(outputStream);
+            }
+
+            //System.out.println("Open " + outputFile.getAbsolutePath() + " in Excel");
+        }
     }
 
+    @Test
     public void testJavaDateFormatsInExcel() throws Exception {
         Date date = new Date();
 
@@ -137,11 +136,16 @@ public final class TestDateFormatConverter extends TestCase {
         outputLocaleDataFormats(date, false, true, DateFormat.LONG, "Long" );
         outputLocaleDataFormats(date, false, true, DateFormat.FULL, "Full" );
     }
-    
+
+    @Test
     public void testJDK8EmptyLocale() {
         // JDK 8 seems to add an empty locale-string to the list returned via DateFormat.getAvailableLocales()
         // therefore we now cater for this special locale as well
         DateFormatConverter.getPrefixForLocale(new Locale(""));
     }
 
+    @Test
+    public void testJDK11MyLocale() {
+        DateFormat.getDateTimeInstance(DateFormat.DEFAULT, DateFormat.DEFAULT, Locale.forLanguageTag("my"));
+    }
 }
